(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    519235,       9742]
NotebookOptionsPosition[    513318,       9645]
NotebookOutlinePosition[    513664,       9660]
CellTagsIndexPosition[    513621,       9657]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Lippmann-Schwinger equation for Spherical Well", "Title",
 CellChangeTimes->{{3.78454023748571*^9, 
  3.784540251717599*^9}},ExpressionUUID->"bebd264f-1102-45fa-9f6e-\
ad78d8abc5f8"],

Cell[CellGroupData[{

Cell["Integration around a singular function", "Section",
 CellChangeTimes->{{3.784506870316028*^9, 
  3.784506878386558*^9}},ExpressionUUID->"da47f219-0b48-4020-bd48-\
331af43a1f17"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<NumericalDifferentialEquationAnalysis`\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.782836281266528*^9, 3.782836324533296*^9}, {
   3.782836362675128*^9, 3.782836370205055*^9}, {3.78283640464651*^9, 
   3.782836408045047*^9}, {3.782836462622154*^9, 3.78283648409*^9}, {
   3.782836538341793*^9, 3.7828365396623697`*^9}, {3.7828365780153613`*^9, 
   3.7828366316268153`*^9}, 3.782836683947054*^9, {3.782837316546872*^9, 
   3.7828373169133873`*^9}, {3.782837379133924*^9, 3.7828373936845436`*^9}, {
   3.7828374263074236`*^9, 3.782837438526125*^9}, {3.7828376822010117`*^9, 
   3.7828376823530874`*^9}, {3.7828377254121785`*^9, 
   3.7828377745594697`*^9}, {3.7828380468582773`*^9, 3.782838051193392*^9}, {
   3.7828381286103745`*^9, 3.7828381462675247`*^9}, {3.7828390895931406`*^9, 
   3.782839090168454*^9}, 3.7828392096312084`*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"a5443482-a9b0-44cc-81f1-214ed93a58f0"],

Cell[TextData[{
 "The task consists in integrating a function from 0 to \[Infinity] with a \
first-order pole in between. We assume that the pole lies slightly above the \
real z-axis so that we have to pass below it, i.e., we can deform the contour \
in the lower z-plane. First, let us define a singular function that converges \
on the real axis, for example:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", 
     RowBox[{"(", "z", ")"}]}], "=", 
    FractionBox[
     SuperscriptBox["e", 
      RowBox[{"-", "z"}]], 
     RowBox[{"z", "-", 
      SubscriptBox["z", "0"], "-", "i\[Epsilon]"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e56d3b1a-4cf3-48ba-8a01-8ad46e974a4c"]
}], "Text",
 CellChangeTimes->{{3.784506887868702*^9, 3.784507028185163*^9}, {
   3.7845084920399227`*^9, 3.784508543270994*^9}, 
   3.784510658986813*^9},ExpressionUUID->"ac2d353a-dd0a-4f5b-a785-\
4a95e83dad82"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"z0", "=", "4."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "z_", "]"}], "=", 
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"z", "-", "z0", "-", 
       RowBox[{"0.001", "*", "I"}]}], ")"}]}], 
    RowBox[{"Exp", "[", 
     RowBox[{"-", "z"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Integration along straight line: \>\"", ",", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{
      RowBox[{"f", "[", "z", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "0", ",", "Infinity"}], "}"}]}], "]"}], "//", 
    "N"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Imaginary part explicitly (Sokhotski\[Dash]Plemelj theorem): \>\"", 
   ",", 
   RowBox[{"Pi", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"-", "z0"}], "]"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Integration along deformed contour: \>\"", ",", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"f", "[", "z", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0.", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Alpha]", " ", "I"}]}], ")"}], "z0"}], ",", 
       RowBox[{"2", "z0"}], ",", "Infinity"}], "}"}]}], "]"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.784484850129228*^9, 3.784485106011035*^9}, {
   3.784487893701557*^9, 3.784487895783948*^9}, {3.7844912916358356`*^9, 
   3.784491341364497*^9}, {3.7844915197886*^9, 3.784491526770159*^9}, {
   3.7845071417713614`*^9, 3.7845071661832037`*^9}, {3.784507498430488*^9, 
   3.7845075246641617`*^9}, {3.7845075599672203`*^9, 3.784507630196863*^9}, 
   3.784507695917008*^9, 3.784508565488796*^9, 3.784508607800576*^9, {
   3.7845087572065563`*^9, 3.784508758403699*^9}, {3.784508810657055*^9, 
   3.7845088107730227`*^9}, {3.784508925181259*^9, 3.78450894544363*^9}, {
   3.784509000571142*^9, 3.7845090130214787`*^9}, 3.78450911050642*^9, {
   3.784509195979947*^9, 3.7845091969177313`*^9}, {3.784509236040353*^9, 
   3.784509365887561*^9}, {3.784509399297146*^9, 3.7845094323534813`*^9}, {
   3.7845095745823603`*^9, 3.784509585466385*^9}, {3.7845096233759623`*^9, 
   3.78450964040296*^9}, {3.784509702959785*^9, 3.7845097314145412`*^9}, {
   3.784510723508519*^9, 3.7845107262840548`*^9}, {3.784555644027787*^9, 
   3.7845556485746193`*^9}, {3.784555739552578*^9, 3.78455577011285*^9}, {
   3.784555877916382*^9, 3.784555881154217*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"40f3b6eb-ad38-4fca-85a7-a5bf081f58ba"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Integration along straight line: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "0.35949444407062786`"}], "+", 
    RowBox[{"0.05764979981374489`", " ", "\[ImaginaryI]"}]}]}],
  SequenceForm["Integration along straight line: ", 
   Complex[-0.35949444407062786`, 0.05764979981374489]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7845075811701612`*^9, 3.784507618358625*^9, {3.784507692719838*^9, 
   3.7845076968629208`*^9}, 3.784508566332384*^9, 3.784508612397565*^9, 
   3.784508759534193*^9, 3.7845088113699102`*^9, {3.784508936579739*^9, 
   3.7845090138531847`*^9}, 3.7845091143473186`*^9, 3.7845091977259073`*^9, {
   3.784509250717512*^9, 3.784509367246993*^9}, {3.784509403426011*^9, 
   3.7845094337073402`*^9}, {3.784509579226959*^9, 3.784509586432152*^9}, {
   3.784509632634294*^9, 3.784509641355113*^9}, {3.7845097055716743`*^9, 
   3.784509746125945*^9}, 3.7845107274156313`*^9, 3.784546181538775*^9, 
   3.7845556556583443`*^9, {3.784555742494382*^9, 3.784555772874434*^9}, 
   3.7845558838391457`*^9, 3.784557692746018*^9, 3.7845580697526007`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"edb82510-4b83-4a6a-8868-f723df5af45a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Imaginary part explicitly (Sokhotski\[Dash]Plemelj theorem): \
\"\>", "\[InvisibleSpace]", "0.057540276578650816`"}],
  SequenceForm[
  "Imaginary part explicitly (Sokhotski\[Dash]Plemelj theorem): ", 
   0.057540276578650816`],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7845075811701612`*^9, 3.784507618358625*^9, {3.784507692719838*^9, 
   3.7845076968629208`*^9}, 3.784508566332384*^9, 3.784508612397565*^9, 
   3.784508759534193*^9, 3.7845088113699102`*^9, {3.784508936579739*^9, 
   3.7845090138531847`*^9}, 3.7845091143473186`*^9, 3.7845091977259073`*^9, {
   3.784509250717512*^9, 3.784509367246993*^9}, {3.784509403426011*^9, 
   3.7845094337073402`*^9}, {3.784509579226959*^9, 3.784509586432152*^9}, {
   3.784509632634294*^9, 3.784509641355113*^9}, {3.7845097055716743`*^9, 
   3.784509746125945*^9}, 3.7845107274156313`*^9, 3.784546181538775*^9, 
   3.7845556556583443`*^9, {3.784555742494382*^9, 3.784555772874434*^9}, 
   3.7845558838391457`*^9, 3.784557692746018*^9, 3.784558069755033*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"bfe26d6c-bc18-4865-b9e0-015516e5ac5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Integration along deformed contour: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "0.3594944427930616`"}], "+", 
    RowBox[{"0.057649799814248406`", " ", "\[ImaginaryI]"}]}]}],
  SequenceForm["Integration along deformed contour: ", 
   Complex[-0.3594944427930616, 0.057649799814248406`]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7845075811701612`*^9, 3.784507618358625*^9, {3.784507692719838*^9, 
   3.7845076968629208`*^9}, 3.784508566332384*^9, 3.784508612397565*^9, 
   3.784508759534193*^9, 3.7845088113699102`*^9, {3.784508936579739*^9, 
   3.7845090138531847`*^9}, 3.7845091143473186`*^9, 3.7845091977259073`*^9, {
   3.784509250717512*^9, 3.784509367246993*^9}, {3.784509403426011*^9, 
   3.7845094337073402`*^9}, {3.784509579226959*^9, 3.784509586432152*^9}, {
   3.784509632634294*^9, 3.784509641355113*^9}, {3.7845097055716743`*^9, 
   3.784509746125945*^9}, 3.7845107274156313`*^9, 3.784546181538775*^9, 
   3.7845556556583443`*^9, {3.784555742494382*^9, 3.784555772874434*^9}, 
   3.7845558838391457`*^9, 3.784557692746018*^9, 3.7845580698029823`*^9},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"8de0e11f-5023-4d14-8e0c-fbd4d0650969"]
}, Open  ]]
}, Open  ]],

Cell["\<\
The first result is the integration along the real axis, the second result  \
provides the imaginary part calculated by hand. The third result comes from \
an explicit contour deformation (see picture below).  For that, note how easy \
it is to define an integration along a polyline in Mathematica. Just specify \
the boundaries. Next, we perform this integration explicitly along the same \
polyline, but by explicitly calling Gauss points and defining the path by \
hand:\
\>", "Text",
 CellChangeTimes->{{3.7845070383924437`*^9, 3.7845071014741373`*^9}, {
  3.784507171556075*^9, 3.784507191140993*^9}, {3.78450725858237*^9, 
  3.7845073305359497`*^9}, {3.784507370857489*^9, 3.784507423762088*^9}, {
  3.7845075285262423`*^9, 3.784507549694282*^9}, {3.784507650441594*^9, 
  3.784507688194408*^9}, {3.784507721963202*^9, 3.7845077264070473`*^9}, {
  3.784509564931041*^9, 3.7845095685940247`*^9}, {3.7845096075627117`*^9, 
  3.784509614435219*^9}},ExpressionUUID->"30bd0776-58cb-4761-9df2-\
b959ccf28349"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ng", "=", "10"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Number", " ", "of", " ", "Gauss", " ", "points", " ", "in", " ", "each", 
    " ", "path", " ", "segment"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gwp", "=", 
    RowBox[{"GaussianQuadratureWeights", "[", 
     RowBox[{"ng", ",", "0", ",", "1"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Initially", ",", " ", 
    RowBox[{
    "generate", " ", "Gaus", " ", "points", " ", "between", " ", "0", " ", 
     "and", " ", "1", " ", "and", " ", "subsequently", " ", "make", " ", 
     "three", " ", "suitable", " ", "substitutions", " ", "to", " ", "define",
      " ", "the", " ", "three", " ", "straight", " ", "paths"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.784486781309712*^9, 3.7844868482895927`*^9}, {
  3.7844870782855377`*^9, 3.784487082674206*^9}, {3.784487885428629*^9, 
  3.7844878855808153`*^9}, {3.7845083817031307`*^9, 3.7845084296704407`*^9}, {
  3.784508740003367*^9, 3.784508740209524*^9}, {3.784508832975635*^9, 
  3.784508833357476*^9}, {3.784509760042468*^9, 3.784509760773602*^9}, {
  3.784509912235898*^9, 3.7845099230814943`*^9}, {3.7845107688240356`*^9, 
  3.784510789313154*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"ab2df81e-2f5c-4338-ae51-1cf800c708a4"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"c", "=", "1.6"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Tune", " ", "the", " ", "distribution", " ", "of", " ", "Gauss", " ", 
     "points", " ", 
     SubscriptBox["\[CapitalGamma]", "3"]}], ";", " ", 
    RowBox[{
    "choose", " ", "such", " ", "that", " ", "number", " ", "of", " ", 
     "Gauss", " ", "points", " ", "is", " ", "as", " ", "low", " ", "as", " ",
      "possible"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gw1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"gwp", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "1"}], "]"}], "]"}], "z0", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"gwp", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "z0", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "ng"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalGamma]", "1"], " ", "starting", " ", "at", " ", 
     "0"}], ",", " ", 
    RowBox[{"ending", " ", "below", " ", "singularity"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gw2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"gwp", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}], "-", "1"}], ")"}], "z0", 
          "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}], "+", 
         RowBox[{"2", "z0"}]}], ",", 
        RowBox[{
         RowBox[{"gwp", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "z0", "*", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "ng"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", "2"], " ", "back", " ", "to", " ", "real",
     " ", "axis"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gw3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"c", "*", 
          RowBox[{"Tan", "[", 
           RowBox[{
            RowBox[{"Pi", "/", "2"}], 
            RowBox[{"gwp", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}]}], "+", 
         RowBox[{"2", "z0"}]}], ",", 
        RowBox[{
         RowBox[{"Pi", "/", "2"}], 
         RowBox[{"gwp", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "*", 
         RowBox[{"c", "/", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"Pi", "/", "2"}], 
             RowBox[{"gwp", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], "^", 
           "2"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "ng"}], "}"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    SubscriptBox["\[CapitalGamma]", "3"], " ", "to", " ", "\[Infinity]", " ", 
    "along", " ", "real", " ", "axis"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pj", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"gw1", ",", "gw2", ",", "gw3"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Join", " ", "all", " ", "Gauss", " ", "points"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gaupoplot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{"pj", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}], ",", 
         RowBox[{"Im", "[", 
          RowBox[{"pj", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"3", "ng"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"4", "z0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "z0"}], " ", "\[Alpha]"}], ",", 
          RowBox[{"z0", "/", "10"}]}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fuplot", "=", 
   RowBox[{"ContourPlot", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"f", "[", 
       RowBox[{"rez", "+", 
        RowBox[{"I", " ", "imz"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"rez", ",", "0", ",", 
       RowBox[{"4", "z0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"imz", ",", 
       RowBox[{
        RowBox[{"-", "z0"}], " ", "\[Alpha]"}], ",", 
       RowBox[{"z0", "/", "10"}]}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"ColorData", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<Reverse\>\""}], "}"}], 
       "]"}]}], ",", 
     RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "0.4"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Re z\>\"", ",", "\"\<Im z\>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"fuplot", ",", "gaupoplot"}], "]"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQBGIQLWGTOcNA/43jnjUq80D0nBKJxSCa6ebXlSC6YQbT
MxCtoVb5EkTn2c7hDjN64/j39CYhEF20o1QZRPf5HlQB0V9CrbRAdJi6hzGI
nrP0gjmIPsH7CExnZSW7guhbU1Z5gOgIm40+ILr5VXcqiO4qY8oC0Xx+iXkg
2mfO4iIQHfKMtwxEl4hPXRsOpJlzL4DpX4YrpCNA9n1NkQfR2+MP6oFopbk5
tiC6bJv373iQOUu2/QHR16SvqCUA6V7T3xYgeuECLTsQrTTjmw+InsyzMAhE
b65KTgDRLYtSM0C0JP+VQhB94PSFFhDNeO5bK4ieNZltNoiuqJu7GERX/dy5
DUSbRSbsAtGpklO+guiDjSvB9IOb7DsSgXT1Aq2dIPrnhuxp5UB6htipGSAa
AP4guTU=
  "],
 CellLabel->"In[10]:=",ExpressionUUID->"6ec8be34-6aff-4e26-b8af-de1ea2b9d0d9"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxk3QeUFEXXh3FY4gIbCGIWE5gAsxi/HhERA6JiwgBGzDm85pwRAyqiooIo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     "], {{
       {RGBColor[1., 1., 1.], EdgeForm[None], 
        GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnXecldXR+O/dvQtoAiwsC+guCAL2NKPGioiC0tRoEgu9KdLEnmJURERB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           "]], 
          PolygonBox[CompressedData["
1:eJwllX1o13UQx2/Lvm5z++l+T/bb9/uLclPIJoQYzJERuWWZi20iUU5dT1hh
ToMRmjNFt8pqoS60TcXUkmLOtsXcb0oGiS6fwgwqK3qEov6YRtATVK+398fB
3efuc3efu3vf58aHWxpX5ptZBzQOuiUyaxhvdntgtiphtiNu9gaK4xPMdmbM
fs6a/TbR7P48s0Z0hUnXFZWaZa836wvNzpeYHbjGbCP6Qew/xH5xodl9abMB
5LUFfvYefB90FL4OfTX6m4hfQ/yZxF9K/JeQjyBvRT6FnMP+DPbLsW/GvrXM
7Bf0Q+jH0I+hz5tktoH464n/AWdbAvfRga8mqAP+Cc660Q2Q70XyHcX+S+x/
534x99t483bkV9C/hf4g1CkeOgE/RtE+ifub9fani8y+nWw2gv7rEq+ZaldJ
vPnEqyLecuIN439Tgb9hBP57aBL2I5w9ljJ7gft7dR96EX5z0nuhmqv27ya9
Fnqj3rofn+0x/GLfg30vdK7Ee3AIvhz6DN856FH830nNfqV3rchz4aughfR9
NfJs+GJ8xolVg88ycp+VcttF1LsfXQU0a6LHVOyzyMfQHcSmEdvT6ifyAeR6
5AgftdimuRNDl0GeFvhZFr6Qsxi625DjyFOgSvR1yNPgy9G/PN5jToX/CMrh
fw/+F+B/WcJnRTWejv3jCa+1ZngG8mzoJO89TD2q4U9x/wj3d3B/HvdXcXY6
33u6Gv7ulOsuQPmh56zcF5BPuXqJvhvdRWgc+pPoh/DXhVyLbn7aZ0Mzfm/a
Z0izdJb7vdxvg9rJbw/yRvgNkfN3EKMy65gStpo4m4luLe9ZGvMZ1CxqpjXb
vZx1ol+EvC7PbW6NHEPCkmqq2n7O/f6Yz3g/9+/C5ink6eiz6NvQNys39NvQ
PyC85/lZFbbPJDwXzaRmU5gWtuWzS71N+2xMxV8Z/nqEV3T1yHOQt3H/kcAx
txBdT8Kxp54uiRzDwnId9tXYvyO8cv994u0l3ihnw4Ve83s0X8z/scAxKqxa
0mv7FfbD2M/F55LA3zgPfif0duA57YK/kPDaCSPCygre82a+x3wS/XeTHcvC
ZAX6B9O+G4TZxfA/cDZQ4DP4I/xP+OsLfAety3jOyv24MKx+QV0ljrFBYl1O
+K66gv3z2G8JHevq4dVeIm9FnoH9QNxrotoMkd/rkddUtV1TbLaS3Xcz8hzk
3ejXR74DtAty0C743aHzeqPeui/03DTzLciJyLF3AzmVwreUue+jnD1LfmXY
f8p7h6CHqH8G+WP4QagZ+UzWsf8NOZyHP5d1/hJnrSnviXqjnZiDr4gcS8K4
sJ4MHWt9UBP214WOLdV4GXIY+S7SztDueC10LGuHjZL/q6HvZs2sZlcYEpb2
cWdz5DOuWW9FbkAuiry26skE+GshWnG15gH8v6HvYmH6P/g/Q3+7dtpf8H+H
vku18/6BT6onMd+Z2p2qoWqpsxT85dBrpZ1zBb498tz0J20S9iOvtWZIs9Qd
ea81s5rd5yLvrXaGdkdp1nej/sg1Sf9T9bdqBjQL20PHsnbeCerRmfFZE2b+
wP8XoddamLqkfZDy3aWeGnJDyne3/owC5ENZ/xv0Rx+GryWHFTHHmLDWGHlt
hfF6+LqU72bNTBD6TtBu0J0a9P8DmBgwzQ==
           "]]}]}, 
       {RGBColor[1., 0.882715711776236, 0.49316702911923105`], EdgeForm[None],
         GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgmYVNWVxx8IdDfdXVVUdRd01XvNCLgbt+BGYiTigmgiNmgAMTF8iAaN
4LgroEY0cTJxwQFkXxpFtF0RF4xrQMVoZpKZKMTEaOLAiESNSxQUmP+v/6e/
fF+979536y7nnnuW/zn37TlhSttF3ZMkeXqPJNEvGZ9PkhkNSTK4R5KMqEuS
J/S+Z02SfKRnTa8kGaP2Lfr/MbVfWJsky7MkeVj1dpX3Zm5fpXJHIUm26zlW
zydq+1TPum5JsncuSfbSk9PYv5STpE5zHlZKkor6XaNnidrXNCbJo3raRdgz
Wneu+lwr4g7Lu/1atR+g9if1foVoXl/rsUtVXqz2p9WeV59TRf8v8+67UDR1
qL5A5Z8bXD9H/W/XuFl6Dkxc3qFnQI1L3pu09tvq/5D6T4C23knycc8k+bue
59T2TN5rwoMH69znS41bq/crNecirXe/6oszt79RMN3QtTZo219tq/V0qH5P
o/kFr57RWt20fqLnNxr/J7X/WuWHmfnyUFOS9FPZQ88u0TOrmiQj1Xe6+DlN
PP5c/cd295xLNd/6bj6PGXq+UP8NKl/W0z1o36pyjeh/K++1PlefX4qGnSq/
0tNH6zTo+VD1x/X/6jrLwDuZx76t8ou8153R3SXv54um50TDdtX/pvYVNa5/
oHpf1cs1nn9KjfcOna+LrqF6Jmn+/Ztd7qtym/Y1SM/7mu+pWo+Hvr4NPjPO
i//Y41aVC8STKWprF0+OUVtLwTzdonJzvK/TPLs1x6d6WmrMU95zMfe2nqZ3
R9DPvPCnQfM097IMIT+/66u9il//rfIktZ3I3NKXYzTPXur3fGK5p/1lvdc1
eA14+n09I9R2jfae6+PxU3qbJ/Bjazef6cSCeUt5btRPFl82iZ6XkTXRNrnG
cjAxSs4evWEMugMvh4YMnKSxGzX2JY1doLb+oukQjTtST3+NXSiaH9LYSzVm
dC/PTdlJU6PlCTnZEecFb+Hzt/Rc3tNtx8Za8PqYaD9Xe5mqucao/3310u2C
bc4MtY1X22DRuZ/aHtRzo9pWqTxetF1W44dx6PjzBY/FNi3VnDu1lyNkK+bl
bWd6qP2GzOXBkoGsNXgv3fkUndRcr6h+UpokF6j/MJWvauwrel7Tfys19+Sc
6ZlY5/9o311wn21aa4rGPI+9qlr+kIc28W2T5t+sPn9Q+VXBtqKgeR7W+7Oq
Dxbvv6panhPRNa1iO/uc6Hmrr8+/tdXjno2x0PuC1pjWw3RsUPv7omGI5pqB
fdLcE0TnS3m/N0iWetR6z49nbn8sM/1vFjx+WWb7tjSzLsKrL3VGo+ps47Bv
92XW+Q6VOzXuBdVLWndd3vXF6jO2zu/U6bNJz/PxTlncw3p9TMjJHzXXFrW/
qfJI8XCVeHib+PGq/n+tYL39et51bD++qNpof8RTaew0jZ0l7SK5089gQ9Cb
9/ADDbZp2DdKbDf+okH9P1N9mHh/nJ5FGjtdNCxU/VqVD6j/o+r3UU+fYa7B
74Oq1uF3dD6LRdeignV7Wc7yd6T2uFjvL6ls1/PNiuX2GJUdkvMbG+xDG/tY
zznji/RfATshPvytZFleJhrmaO7Zeip6v7NkOzpO7a1V0z9AZXc9n2nO4c22
I5822D4/o/43q/9P1P9PqrerPlv11er/Ov61ap7C6xWSq1k1rsPzX+VMK3qJ
XfmH5tzU07zhTDn3R4oao3mmaZ7Vqs/G5qq+Q32/bLDPqq26fnqzdWtjwTKM
f94YeoUN3hH9WefzBvvWHlXXR2jszviP9suabXdfE6/+mPdY7PYDRduV/ZqN
F+A9mAFdQA/WaX83pD6nG1PrKjq7QuVBouHCRvNokcqFeq6WfTs+7PGZ3azT
2Hr0+hTNMULPC6rfJt5OUPtpmnO5+izTc4DexxZtf2+tGptUAp+0Vmxj+1fs
97FXnBP7APuwF84WGaX/h7Ev9ne09vxj/TdBc/4oZ7nCViLXyHlR660r2gfc
oT4r1WeD6meJDy8Xbcdnq32ensdUn6/yKtmaimjoo7l/pz7r1X632u/V82vV
71P5ptr/R/VHqj6vLYHTXtL7NrW/XPX+toQ/XVC037s+8742R39s+D0F04yc
fhayiq5hB9Av9sI+0NOne9sPg22wAa+GHaAfWATdfFB7XK/6Is35apTo3oVF
y/Qi0fZijXUSmWAf19X6vVes846eLeAqzb058/rIHPK2u5fXQf776Iy/ofVK
qbEP/cEgN2mNxZr3pyrnqpyj55ButqUfNxjbjJecHKq59tHYedrHkJx96+iS
5WVPtZ9Ssi3pp/rRuZATvR+uerXBduDgnLEOfua21Pt9o2TcUmgwdpnTL0ne
Fe/qtZdbCsbrYI1ukrladK1i/lHHZjTHvtjffzbb/h9U8llydujm7nrjYHiG
T+mnZ6nO+HP1W63/bmkxjuBcwUuJePGJ6ic2mwefBB/eyPsd/8I5Ylehhfla
wh7eoLELxMOZKvcp2U73r3oPWwIzNUZ/aMGvQzO076g3vufcrtOYOzXP9VXH
FOAlcNDmkE/ktLHVPMqpnNJk3DOwYozGGvjNy/Rs6G47+ZTGr0XmVb8uM86Y
mdmX4lPBA/gF5uF8wQi7w892qLyvYHtxfdFy+YBoa+9njHhJk/ncKzA99oR2
cGNBYwbVGGdy/r3yjlOQHWzOZrWficyo/dBunouxe2svDZn9W5PO90q1D1P7
fmpvL3gN5shltmep+txVcB/mxM4xPzQ0gmV6Gx+2qb0VDNzNvrcSfnlG4D2w
4YDw012x1YCoQzuxJe/IdW+971/jeGSPvGPC+/uZBuidUXS8Q9wDX+APOos8
Em/xPk/0fFNj74InmX3Ud8u2G2AI/NrP4bXo+veq/TbnxBm1g/vytpPYs20R
XzxRNdZKmiwLDSEPPQJXIf/o66LgTyeOiDkrmX3dCWXb6UF541b43R7nij1Y
oXq9eDi/YL4Szy6VDGypMSaAH8Rn6MBpOffnXODZf/U237ATnA3j6zLHnUPK
xtgD8sbZxDjMgz1FBpFFMO0lOb9TRy6pEzPeH31oG5yab/APTMKa+EHi1ycj
hn22ydgVDIv/xGfiO/HzX4XfH5JZP84p2/5hB9nviIhViFOOSl3Hf85L3Z9x
17SYL1MqxkZgpA+k94enjp3OUP+fVe2zr1D7GL0v0XxHpPYRw/P2E29lxoV/
zuz/iUuJ6Yh9OAPs7bJ650GIR+ZFO3TC5wXRB9vTGPYK/LszsC44Bd+Bv1jT
ZJ80STQvbzQ/2OO7WvsD9f1f9tXLcTD2BfzHmS9Ivca8kKVfVM2jq0uOBeBn
F4YCV4Gj5raYFuKGkRGnEaMRQ30eMfjoonHN11PneMB5YLy5BZ8r/oWznB3x
C++zY+/Tc44/x3V325zosyxsCPJPnEBMtjXkeUHIdK1s60zV61T2bHVs26vV
dpocDLaa+eaGbI3TOmNqLEPnEvOL/r+IN78XD9fkzCOwLHjtrZIxxcrAFeRa
wBPMuzLwBjSBp9ABcMjUWu8T+h/pbf8ODunExTnHU4elpqGtaBs1N/gD/t0Z
GBhZQ/Y4V9YB36Djc1PP81fRdmDmmOC61LLGOXPel+ase4d3t8+CB8gN+OvK
WstFW7NzMa9qjjtr3MZ4cDe+AJ8wpej/lldtM3oUzB94RT3fwz5vUsH5NNp6
RjvxylTVx+1hew2unt/TmJF27OHAWAczuLZgrAzf+f/iGHuV9jZTbU+VnLPa
HvEdcR8xH/vFJ9BOroByR/QZGnX+75bZ3u1ObVvIl2FfsO3YddZYkHN8z7zX
R7xG3EZejf7YPjD1rsDVHTGOMa80mmb2x//0g/6Rajs97DDYjXf82niVZxds
R9Df8VFHn9AFci8DUscDgyJ+pT/5tnuiP/o+BptasO4xD+/IzLDw39jzovZ+
st6ny2aM1v9n8HRzPEJ9YcQlY2Ie7DFzMt/J4Uugnz6MR3fmqz5K9XmNftoK
xgZzog5GBa+yd9r+L7PMz2xy/9FBA31HRX/iJGQAjI0/Ghl8Ix+D3qNr4KMV
YdOWVo2f7pVsnNBs/PdirIP+QCf5G+wQNr0ldUxeTe1/8EPkhMjtgXvADKdq
njc1z4bMeJAcZFcejRL8OSpnvkDbXZlzLORassw6d2JqvSCegNYlgQf2itik
IebBpqwM/0isQGxAXEC8tb3e73c0OUd1suz85Vrn4LztJDjq7sBSlLxzTvhg
cDpxzYpoRwYe72eap2m+4bJhJ9U5v4l9Xxl2bGWTZXqM1vqiwXgILASmJt4A
V4OpawNXsyf2Bh6d1GQcAabu0+B4gbiBHDAldNG2q970gZvgDznDzhxrjTH8
bU0+k2EVnwN0QMNHkSPGluKjNoafQl/2C1xBPo86/giegS/GhsxgoziLyfi1
gjE2OkqcjP6SI6eOXtP3vLBp+BhsM34KO429xo8w5+SY57mobwgMz1j+r5cf
uhl9b3XuCR2+PXID0MA44lriW3wHJXERMflemXk0UOXIZucjXsnsR5oLtsHk
IIkRiDewd4zFmNaAm3K2r0tjXuYkj4J/IteAHCAP2AbsPW3gZ/bWFLkIYlz0
C76B3fAp8JN4AxrwZb20n+3iyXcil7I78AnnRjty+Ei98Ru5qZmpfRa+66YW
t4Pv0FPyre/V2C6D4eA5e2AvnX4idb1n6ruefXIR69U7d0neklhtr2ifiO9Q
fXnJbXtHO1gVuUQmiTmIgSsRs0+IPB54EKwGTsM+tYWtY3/nRO4Ovh2SC362
uP8WrbVn1Xz/brNxNHE1PK1P3b936hi6Mw7v5VwdeI+4kNgU24ptBJvsHfdZ
u6ve766qfSy+Fp9MPI9dOVXrno7N1LMlMR/5H/orqWM0YrViaj8Glgcr5WJd
YtiZ4Xewwfhj8OXosL3gPWKNVYGFOJ9vRG6T2GRY5KzYP3xYnNrGzwu8zh0J
cdKgzDIFrkBf1maOY5/IjEeHxJz3V51r66j+cw3+74qFOteq8Tmxxx+I1zVa
q1/V5zU/8iQT1Z5XfWDE63OjvS38Ej4LvHpfzPNs5DY7mpz/IK+DP2qpRJ6k
4vsH8szcdYAdVgQWebjq3M/Gkv3qojhH6qPDz74V+dKjyAmVvPZlFfvehYHj
sdv4P/wLfrg9coYTy8ZWtwqXDSs7h36cyvdb7C+2tthnUEcXuVehD9iZOK2t
zrlrcnercs5hHlv2feAEzXmBZHJtvfUIHV0aeGhWi9t3lYy1wdbgym+XPefQ
svX3vZA38BtjwXgd4WPxcfz/47o4t5zzpfSpa3EfbD9+mrPAVpzX27ajq/5o
0Ma49hh7ftlznlc21uB84dtNqfs8V3JefHXMM73iOf9R8jod0f7TFtc/UvtU
PWM19pDUOGt53HF+P3Rsv9TnMib+K1Uib6byPM5efQ4kFxd59blNpm1kyBx5
c2SsU9YiriS+BJ+Sp8A+zUgdB5BvOCvvPcK/jtS27o6i7QJ2Dft/kNq/p/qU
0j9zK9gB9IB2ZB5dHJOzPp6eGquAWdgr7egCOZ6xUcfeXxpxGTlE8OQZ5BpV
P0vtl5esh6yFXh4UNgN9IV8yrs76cUfq9jWhU8TK6BV6A35Hd+DL6FiXHOpr
MQ8ySn59xh4ety7GEnOTf6dtWmrcAn45W/VrNc+Ckvc0LvYLTr8r9BQ/T39k
GxvzYsyJjE6OuIlYa1LO2JOYaXHQOio1DptVMm8uD/6A2YljwTPExz/M2XbO
iHb6dPXDh2LzNsR9H/cuyAnywj3qtJiHO2HuhuHTkNRzHp1ad8lZwZtbUtfJ
Yx2fOhdCfoi8Qdf9GHu6IPYFT+aF3eukN9Yix0G8+W+Sw2+n3vvQ1Gd7SsgS
eIu5wIrg0Bmxr7lF563WVr23S6K9d6tzjp9Kt0qZcfOkku0i8oNtHJmaj20q
J6fGHOTXz5HdrlW/lqrz2mDbszX27aJt4C+KztnTH3wCHoGfvw98BE4Cn+AP
yScSc/UI3EQMe3jQyZn/CH3EJpaso6dFf3Id6yOv8kPRU0cusup7XPh5Quq7
VfD/vk0Rs8TYVRGnYVuRa+Sbdu5DTg9+8jAGfcVujQqbD4aEHvDnk5EnJF9I
3pC1uO8md0CcQ1z1tdT52fNF/0VFY9KL1PYHjflKYzZVnU89I2gjj8pczEPb
6Gh/lzw4uYWqcxedY9Vn/9Q8/IHm/4/U+kKOmbw0ORN4ij3CLnHvjR+BZnKY
5DxZi9j/pLBlw+N7E/ICxOzgD2wZdoxvQvrlHB/d2WK5Qr5eiNwoc0LvmWEr
tovWAfCk6jsd6txz8S0NeyF2YP2tQcPfq57/I+4P9QxUfUfVuQXq0PNJi+OU
j1UOTG3jyGEfUXZu+fCysQZrEK99HOt1xSnwDr6Rnya3Aa7u0eh24hew/+TA
/8jLaSEPyyKeJa4lhkAO2iNmWRv5nZ3x3Qz8eYn8lMb+PDWWZf/s/fbIS85K
jX3YG4ScGzgPjIcs0x98Tt6JXAf5D2KfRyPG7owj6x0HoousS4wGdsZPkUsn
70HOA/v8YObcyv0qpzX6exX8NfmryyJ/d1jZseehKndlvnfpXjGGJjZpixwL
+GBc2P5r4777lshVkrNsiXsicuXvFi0Xc0JOLoh1uTdbFNjp2cjZkrv9TZeO
FG1HsCdgK/L09wSumNM1p2Sgf+QVyS/y/8roAy7D/y8J/4JvwadwdpPizMgJ
gYe6eETJfrj/fCXa+KYAW4GtoT/t7J18z/jI+dyZWtfmp77v4M64Kc50YpzZ
X+ObN759I0YhV4k8fq/se2q+4+B7OPokmXNlyAYyP79kez5e81/dz3HLVSpz
Fcfz+YpjI751QN7Ji3BPiTzuG99QHdjsHA4+Ddv7dNnfTQxW+a3UdwbHpt7X
quBbR+D832r92hbfPR+X2u+hH/jchfGd1YK4Wzku8MZP4o6Mu7JfFW1rzy46
7iL+Oq3Zuka8zXmTpyDuIua6uZ9jv5+pvFjr3ao5p6r8bdE5+39VOb7ZettU
dVwMT+A5OQHGEjPOjftQ7kWJaZiHXGoWuSZyTntHHo983tt9fc/Dt0Lc2+Bn
0Q3yFuQs8J/cYXA38WRmn/Zm+C1ijtcj7rg0vkckNkPm0N3OXHCtvyXiDIhF
eAdHzY88HT63E+M3Wke4wwHDEx+AO8ljk8f5l/gOpDV0bmncuRDzkQ8lhvxO
2RjvVJWFFtNPvgrMNDVo45uCC8MX0zYl2k8p+5ueEWXzGp6fXLaMs9/Ou5my
13kgcx6FOznwRCcerLXukLPDJmNruS8fHnktbAnfaJKLHxxyeHzRtuyLyEtM
L3qOM/X/0WX3P0rll5njm20txhHwHhtxTWBBZPKssvk8rux8BTwhduUO5en4
rglsCkaFXrAYdpZzejTw2SOZ98zerygan8JP8B7rwB/wG99TrAlfwJ3IiMAM
hcjZoM7kJtFJ9JGc34rIBy6u2o8siW9F1sc9xdCQJfJG2OnzwmZC38KQJb47
IYd2e8k26e6wydzRwFfyM1enzqFfk9q2rYy4kv0yFzaR+xrum9A7+IQMwasD
mo1B9i1Z7taH7G3saxu+qa/lGPlBhr9W9X3wgVXbnqdiv9x3DY934jz2QkzH
HS0x1GrkJzX9L5Y8H3JJHD464mRksitfiX1cGPYWu4s84bPIgZ4ddoa4eUnc
++Bz/x8GLC/0
           "]], PolygonBox[CompressedData["
1:eJwtmHuYl2Max59qmkPT/KbmnZlmfu/7TnSwCElS7ToslY4ulSKaQtumtEx2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           "]]}]}, 
       {RGBColor[1., 0.7505586863956032, 0.25266494040791465`], EdgeForm[
        None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgm0VNWVhi+gxas3Fu9W1avpPiYVZ0UMiAFxSgS1RW2NQ8cBUJxacCAq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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHeU1NUVxx/Kzs46zA4wM7uz85vfwgoBpEWQUBSlWAAxtKAiCSJIs4EC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           "]]}]}, 
       {RGBColor[
        0.9933216686522682, 0.6078118688573969, 0.10430568029112781`], 
        EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXm0VNWVxq8Mb6iq90qrXlXduvWuQLQREzRAWsAQDIOISS8Zw+RTo3ki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           "]], PolygonBox[CompressedData["
1:eJwtmHeYVtURxi+wLOzuty7s/er9vgssgg0LYGRRRGkKmkea0kuABUUFkygd
EgsqqCCigkaUkqjwWII+RGMEQVFKgogF7NGAJSBgLLAkKpLfy7t/nOfO3Jkz
M2fOOVNO1Zhf97+ufhAE19QLgiK+8wtB8OQJ4Ikg2BEGwcJ0ENxdEgQJ/sXg
3yeN/wS9JB8E3aIg6FwWBO0R0hX4UDYITgO/sDwIhlcGwTHmNIF/CuMGZE0C
bwq9QWkQdMgEwX3wP4Te3eD3A/fJBcGj6JoKTz/g0cwZz9w+FUFwfhwEvdDR
E9og9PUEHpDC3sZBsAieCuw5hPzNzN/EeJS1bElZ/1TGZGTdg87O6KpoEAQ7
se9y+GvBe8HfHP6RyJyG/MHQRwDfgk27oGeLWTPzW8KfgXct/4ZCW4P8+sie
1CgIrkTeYmSsgX49/tkNb0tk7C/1GquAs4z3wPuCZ4AnwFOCvqPIOA3bDrCG
Sub/DZ7ByB/EGMb6mvJvP7QWoeE74Z+HPTMYs4ArGcXszef47Fvk1WLvZ8At
+JeFdjqjHrx5ZJSyN/vx55iU/4mWYTSH9zzGKcDl2l/sa4iM8eirRmajnH04
tU7fP5j/M/aNgd4eegD9YGTbh2LzAeCzoC8Ff71hEJwB/GPK8vPMacVaSiPr
aoL/1jN/BTwbAvvsj8BPw38MWVXYm2b/+6J/BPO7gp8Bfi8+6wLvjax3IfBh
ZG5B9lXQ+0DfkbS9OgNbkVWEvlL0VaCvAfJ3Q7+txD56F3qS+fWZfy/4A+iK
I5/NydhUAF6M/wahqwae89nrs+C5qMQyG0CflPZZr4fNm5HXB3w4+EzwGZyP
0cwfjry9nK+54NUZ34Vp3L914EPAC+CXo2MwcBk+6YRvR4GPBR+btL67Wd9k
1nc68rvX7d9O9LXF/kPoqgf9KPY9nDJehH0/IOtedAwo8h15DHo/ZKbR1xv5
fYFHJS1vD/PfRv5y5v+X+TnOTHfmPgJ+GPxx6PdBX8l6ZjP3AeRNQ1670PTl
0OdBvxofb9Z9g+crbK1N2revYc9W/HWQOZ+zvo2cjwPAP+Zsayn78z5wa3gO
l/pMtAKejLzt4CHyDiGvDzaH4Bvx3yvYdwD9r2DLBsYy5F0HXlZ3v9pk7FP5
VjHqMLKmFmz7n9A3hfmdCt7b68BHaz/QUcPcG1nTreBfIW899A/wx3Os/Wzw
I9A+wuavsK869t3fx/52AH6ENbyGrm2sbwm+28L674A+l3Ej/F8j/+MS++cg
8H903qB9xjgZ/r9H9tWl8jnwXMZC8HLwN1I+UzpbW7HnfeCeacfiKfzrBfwd
/74u957qrBSz5lWN/W8b9o+vNK9imGKZfCRflWLzRNZ2W9ZnXzHrduBO6O+e
cExQbBgOPi7hmK3Y3Tfn2N2D/T+L9V+RdiydhY4BwOPQeTXybwMfCzyz0jTd
Ed0V+VS+/ZDxPHBxaN8phryddwxQLOiCzo7oToK3qPAea69/j/3tFDvBV4Kv
hP659gMZjwN/G9m3Y9HZmvXekzL8LPrXob8079wmH8lX2nPt/VuyCXii8gP0
F1nvdNb6esqxUDH4HfZ2PfqHlfqObwDehA3TseUx+OcUfCZ1Nl9WPId2MOWz
31F7AvwS42z8NQx9A7ClL+Ny4BpkdETfRtbwW8V++LvAezX034DfBT4euDdj
MWe3Iz45Bd5CXbzXGrXWX/BvCWftSv6dAzwS+lXA9yD/WuQX5xzre7LGLpHv
vO6+zuizwDWyoZFl7MT+uayxY6ltlK3vxI4d8t8O4JuRMS/h+KtcPIT19ypz
Ds8hazE+a1fhfxH4EXhOKnEOVC78M3uyHHwD4wrlgqxzzYnMySL/udC+UU5f
IN9nnZtXobMx8Oisa4NrsGcUcC327NVdZbRLOefqvP+s+wF8GTovYy0jVdPk
rEO6dObPY25LeP4HbxH0sej+OLTvtOfa+4Z153UJ+GnoOzfyWVWOVK68Iu+9
3ap4zdoKylnSr5zJ3HwdXsuIgavq9P3AODFjH8gXKxjPMP9N5swuc82m2u13
dee/vXIi8K6Uc4Puv2J715TPzvXgR7HtAexZU+6cpty2IOWz+BJrqGW/X2LO
kArf2Zq0azDVYroDE5h/Rsq+VQ49DP593rld+fU74C+x72lkfwE+A3+uAh9S
Zht1V98AX1TsMzUM+hR89Aa0HPLTkWO8Yr3+TYXWDv09K7xmrb1LbNkD+NcN
uGtsWDFasfqZvO/uw8hYDXxy7LshG2TLu6FpryJjAf5bx3oHQx+kPYf3r3nH
IuXMhfhjnOJrkXl6xK5BVIsoBg7D3hYF15LKWcpdq5WvKxwD+rO+Peh7sMw1
omrFVXnHbuVQ5VLVrKpdVcOolhmat21ac3t0PSibkD0Cn7fA972TrvXagaex
bXXos1uteI1/72I8zPzp8NwJvAz6BOAF/GuJPZeCnwjeCXwZ/p2iMwJ8lPmn
RK5hVMvMZM2bgDthT9ty1/Db4T8H/FTwBuAvgleDn17umvZV8CPgVaylBhm1
wJPR1w19A9HxJvRmKdeKqmdf0PnKm6aYnmKta9OOzYoJ1djWpq6eVE5tkvQa
tVbFoDnA+yPnYtXMqp1bpax7kXIU8j5G/jHsu0Q5G/j50LWjfHQu/ngoad8M
Qn5v1XvQr4R+B/+y0LfVxXvVlKotHw/Nq/Osu9cDPIb/HPgXor8/+KnF9umT
4AtC13KzwRPImx35LsrH25HXlLGpzGvUWr/Mu/caCP2LvHsq9Vaq2TYCPxN6
bxXzz0be1/CkTnD9dBB4OvRe0IeDf4K8WaFrvTHgB8BHoX8t8AtNkNksCP6Z
d62hGviTvM+UztYc9NXP2gbZspL9WYw/n8DemoRr8n7wNoF+cYl7soH4ajPy
X024JlTt+BM2Nky4h1IvpTumu6YYo1ijHkq9lGLSNuAl/BsIf3/F/JxjumL7
fOwpA74ZelvwhtDXgV8f2975yJsE3DZ2LaI1aq13IPOWxq7pVNuNjtzr6o7q
rqrmlO9k41HgJ1OuLSfw76mUewbFtjLoxeqPIsPqadQ7PZd1LG/Dv6ngzTKO
5bojuivd0J8td008Ht5t6pmKXQO/DnxB6F7zTHTMVi7LOtecibyZyNvMONLI
NUBvxZ+Mc5fupO7mh1n3EmXI/wi4EfYlEu4B1AtM4N9WaGn+VUbuudR7iaex
6suCaxX1wOqFpVO6jzHn+axrYtXG6lG2AP9ccK8hGYfyrlF1frTnWyKfQfnz
GDJ/gHd12rlLPYB6gb9EzpWqZ9cA14SOJcp5x3NfwXNlv3qbU7PmV44tAh8X
eu/Fr9ysnKP9CbDpJ+a2Rt8FJa4hngb+sWCaeij1UkOTpt/Hv5mx16C1NFP8
BW4dGtb+qnfNIaNDiWPaSdCGhfaNcrZy+fC0e7tbsXcE8JDQsVR05XbVVKqt
1NOV4vt6yFyT8JpOVjyNfNY6868a+IbYZ1k6pXtE3rWbajbVbtPVA0N/gvEH
4N0599p6A9gDPI1/HRqbZwbwrmSdr5H/rPyNP2azlv7gy0O/KSgWK8c0D90D
a68UM0Pd14zP1iOcsfXs/8i0ex3dqV/JN5FtV8+u3v3CnN9aujOni3qhrHsL
3Vnd3dZ19XcZ8uO83yT0NqEY0hZ5bXKu5RUDFAueyDpXKab2Cx2zFLtUQ2xX
LZb13VEM7h66BlUtuhuZbwG/GRvWG5betvZFXq/yRXN0r429dzsUj4DXxYb1
BqW3qJq8e5e3+LcBWibnWK4csQh9L/Pv7Qr3oOpFl2adC5RjLwFvlXEtpxyp
XDk/dq+sO6PY+2nG+6Meb45sg76swmdUZ1U5S7lL/+6KXUOqllQMViyeEvtt
QDFQsXBW7LOtM6Cz0Df224hiyGXAHySdG4/nHNayKHZsV7xWL6+eWL2x3lh2
AQdp15OKWZ2TPnM6e8o5VfD/MvJZUk2v2v5wpWO17NddvD/224FyyKfwVuWc
W1WTLGX+aynXGuqRb4L+TaVzj+6r3loUUxVb9Wb3FL5tC/++hGt61fb/ZnyQ
cE++LOUeW732nXpvYO6K0LlEZ15nvzrttzjJOBK5J1BvoDePFcDfR6611EMe
0n1J+ayqp9Jb2pFK18rC1WstTbnX3AP/N/CflDKsnl69/Qk5v13qzbQC+MvI
Z0827wV+N+1aQD3TLeD/YuxM+Lzq7VU1sWpjvUnerPe0yL3f8TOHby/OOLcr
518EvD72WVXNqdrzpox7A/U46nXkE/lGPeREdJ+Xca2gGu3cjPdIeyUbdqtf
yPguq0d9j7VfHLuXVU18EfDerGOD3mT2Zf2mobeNLeDXilZw76yeQL3BNVnT
UshvGvmNSPzKUROzzlHKVXrzmQT+f+5VEuk=
           "]], 
          PolygonBox[{{5128, 5127, 6790, 3217, 6792}, {5755, 2428, 5754, 5127,
            5128}}]}]}, 
       {RGBColor[0.9796289990724493, 0.4542923637943448, 0.05209380424570462],
         EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgm0lsWRhj8F7uVuXPKv3/dffhQjwagMMAoqEKKIOmaGRUUiqImOmhkR
dFwwgqiAGyqIjkuiQVGTUQOikYxxQ0RBM4IYF4i4kIvIsIMKAi5g8j55K8dz
+E737b+6urq6uuqtarr8+0UnX7hvkiTfa5Mk+pfsKiTJEe2T5IlSkkyrT5Jb
9M1vlySPNCbJVPU31yTJG80i/E6SLFP7YUf3G9smyYJGz4H+wXKSTBft4nyS
nJQlyeUNSTI0+3bOmtok6SHaS0TzigS4v8Hj8LlIa19alyT/pfanonlLtA0a
H6OxG9t7bm+NX6G5mzT3JNE9qbHZkv2rnNbU+u8Wk+RYrTdGfAepnax559WZ
Vz+t84W+vvpqNPaAxq4Wry2ae4347pTsSzTnVvUb0yR5W3Q79E2QDOc1u39u
s+fv1rewrVt4vi4+4+r9N/3rRLdK/W7tPQdeC2ssw4qgWa9114rHzJznMR+e
Z0uOUfr9ZunwlEqSnCn9Dle7WjK36hsq1a9V+7G+y9Tv3OTfGK9L4yy0j1p9
faSHdmpHiOfJ4jlFPO/XN1TjXTRe1tz3Nff7mrtN+vhIclwhGb4W/bXis0ft
5foOVf9HLUnyW/XvFJ/XxaMD56mvqaP3+pfYb2t77zGndnno4Rc6m8PU7qw1
/86Sc7v4ZGpnd9A5SZ5JDeaFDONFM0F7nqK9X6l2RbP5w2+kZHkI/bUx7ZqQ
eZ147S8e69VOlU4v0N7ObvG+dtWaZ0k2c7j2O0Q28zv1Z0vG4diM9tMqvrdp
7uvSyzrxWap2pn57SbLXSoYNOe9tZDVJCqIdIP7/Ib5H67dessca0W9o7/vA
XXhA7Up996jfX/wGqz9CdOO0/irR/VVzN4lPV40vkP4XSNaPxLNTZ9mk6Lc2
eO0Hte4ajX+hdd/LPH5qwfeRe4VtY+e06GSv9vIiZySaHZyt+PfQ32eXfM/m
i8+t2tdGzTlQY7epv0n9Tlp/vr7VWusFtZtyludL0b8hHd+MrjR/V85zZ2je
fmqnaA9D2nmdg2OtgyruXy4Zphetlxc19pj636g/p2jd0ccuT1V/r/r91J+e
2U5e0dz1ojtc45+rf6zOprf2U5bM/9PJZ/rfkmVW0TpeL/73Fe0HXlX/I33v
SIZWtfumPnfOvyG1f2uv9pA6839Gc2YXLcNv1X7S6PPh7qfN3tvHOqOpzT5T
zvZ86eUQ0W+SbL8W38/UPzTve56of5/m3qHx7lpjX7Xvhz1012/H6wxPwrZl
D2PF53rxvUDto1q7+z5JMiznedgh92SuxtdrvI/2cnHO/u/ponWBTu7R+E90
N0eI9gbJ0E17G6B19hHNMPX3aHyX+u9It7O093/S2CB9PUXzacH3kHVOLFg3
z+HzpZO9mW1xpdqVmn+Y6LeL5gnJvlTrztIeb6+zrOjxgwbP/TuPzP3WTvZt
+Dz83ajUvA/I2ye8En6Bu75Y/WdF97LaRR1tb+gTXXJ/L5CeRut7NWi2hT85
pdk2Cj12Sv/3NeYBz62ia5Ut/6XJPhbbea7GPKH9U9DT8jf8bhWfanvb9vvy
UWXumGga46zvkT46SuefaO85tVnZ962i9l+0zkH1Pl985yH6HlC/V4PPiLPE
Bx8SNAukq1b9Xa9zHJlab+hvP/HaLZ77q10nfc0SzX3S5ybJ8J7GzxftjLLj
2FP6/dCy79DBauv0bRZNg9rPS44d40S/o8E287Xortd4V+3l44LvMff5Eu33
por998qC/RF+YGGL4zP34sta++NV4ZPRa9+IicMbHePZ73qNr9N3t3juKTlm
TZEMdXWO3VNrHKOId42i/0HBdzIpOb4QD2a29RkuCtuA30T1L21nHSyuN4Y5
L3W/d97rXtXRtPja1+p8J1eU3L8rZx7QsF/WuSLWOgGcoXXa72ObGd/R+0M3
E4P+/KLv175qh4h+cZ3vba9G9zmDy1LH1VzFZwhPaIi370XMvUS/TdScSyuO
t5wB/JdpD+drvNTZayMbdwD76hGyfSmb/KKD7/N/ptbBwJzP5+3ALcObbdPY
M+e/tN7rXpy6f5TWSTLb5Tep1xkfejgaf6F5L8svNYr2bPE9QWtfK7o/E/80
917xXFjnOJqKx+lBM12yL6mzneAnloSv2Df84X6p971Qa80T/Xwwj3i+UPad
fjnucq+Opllb+61f4L5frfnviP4HkmFyauxTqti+kA1cNF3jq9QfKJpLa33v
sLH/1RrDNf5U2WfF+XFe/SXP2FrHI/jAH77EemLV4BpjvX6B3zo2OG4dw9wY
f6mtMcjZQc9Y/8BC6+ssD7KdXDEGfVY6fqjWfe5wSee5rcH+8avM8R8McnvO
fu1p3cF/K/jsP+vk+wnvSsTz/nX29SMLbndo/HrxeVQ8r8uMicDD4AVw5V3i
M6XGeIox8MPywNXDW3w/6f9Y46dJn2eIZovGPxHfA/D5WueFDj5LzvFt/V3P
PRGPbUGztei/GX9Lv78TNK9rfEzFmKS/bOz8BsuDPi6ImHhR1fiYuDFJPC7S
2lO0h/s0dkXJcaCd+I3W3LtjL2A0aPLtjX3xL/20zq2N9l/Y5Bbwg+i3qp2j
+fM4L9F2LRm77cw5r2Dv6OP0inXQXfKc1ej1ZtfaruELzyVF2/g44kPOmOJj
jZ3WZH8H/TDJ/yv8Xtl/M46OHyw4HzmpYn/BHR0jfa9Mfa/eS/0bNA+ItkZ/
3yRbqhe/aTnnSS9prUdyjlu7qo55nDvnQk42L84RrH2hZJ7VxvoYFz59vOTO
q79MfPYEhpwj/Yxo8tlwLo9r7efUjpSu+jXbbh+KPArZwCUTMscp4hW52q9i
/MjMfXSAr8HnHKU9XaDxJRr/icZ/J7keb7R9/FG/zVH/4YpzP3JA9jmg3jKx
7mr1u4CxE+MY8MxHkv8BjW9vcIw7reC2WDK/uY3OdfET1Ubfx9kVj+8R7c0N
lmeR9LMmM5+PsCP9tlF8HhOfP8ZZT644H0InV7bxHb2ozj6MHBRb4ZzxX+Sx
7GNIZnp0OUM05zZ5LfYNroLvhoqx4jq1g+ptQ/D5UGNz6nwPu7YYh95Rcf46
I/BKVrQfGi4b2NhkGvAxOfddtc67H80Z1zyaee4tTZ7/z5lpBrc4N+cce4ZN
Ixf7rina7z+ssTZa+2nx6aF+XcV1gr7a1+IOxnP4bH6D5lOtubzoe3Foybq4
P/jP129tJccRuheXimalZOkmGY4InT8v+qnkQ7W2W2yFMzpT7QtV50LPq/0k
bABse3ezz5t8YFTmuU8WjPvBp6enlgN5tufsP/CJ+BDwELhoVclxhThweeCL
fGPEWtFs15x1nZzHDGh07MA/cj67tY/azs7dyOGIC0c2Oja01T43SIftyr7f
fRodOzc0GbuAl1aXrAf0AU6ZGHjmxJzzxUdSYy7wAef9rznnKPNS08MHLAEv
5pGDk9u1BgYmztMn1vduMe7pLHneVn+3xmt0f5eov1X919R+r8W5yxbte2mL
/U9NxNj9m3yP0D15FufdGvnXnVXHysMbHS/rWpxH7Ci4tgR/6AfnjGueSR1f
8d/4/RsKjr/bI+ZT7+A8plTsf/9cMj7p22TdDtH4qVrrXs37qdYarfGzWoxL
GecebC4Zh20p2V6x23bUWprtM/GdiyJvAIe82uKzGa29HKvfj29yLs894b5M
KrsWsS3qDPiBbTEXLDw81u3T7D7Y+P8q9kPU3mbWO6cAU5IrLWrwGQ1ucC5B
jjAz83hTwZiLnBrcdWqL48gLspPROfPultnncMe4X2CKLYEregWeYvzkZvsl
/qaWsCZqbmNz9hM9xOeZon07MQrMSM2I+HRv4D72cESLcdSB0sMfWpxLPdXi
nGZ1g/U7QfzHN9tHYcvgaTA8uQ64B9meyNnmsf0zS8YqZ6gdkjN2Jj8GF1Bf
o9a0s+Ta1y61txSM89pI5olFYwMwwvjA9twT6lLgA+wLbEueD05mH+iT2E+d
gv408Ti16pzzlKr9436RD/atGEumVcfOTwID0H4afcbJPchf91Y8fkzRPqM1
ajub/+GH1S7MrKtBBdcRsAdyzVeqrn8tUrtJd+AA7lLFtQryDbArvqd/+B8w
LH1yTPLVctwj6oLk5/i+M6oe/0Br7S25nvhNybGCmHGDaOZKnl9KtjFR59gQ
fmm9fjugyTF3dSfzfIb6QMlY/72S48m1ddbZkRXLUhKfr9Tfgn7U9muxP+he
di2A89+T2T5mhJ6pSVGb2h3xoU+T/SQ2Cx8wwYCi2y/E86aC978nte/Gh1/e
YiwMH2IJZ9g1bG9Q0e11or2xbLxyQ9lrnR7YHt2T40I3tOq6wc688wkwDHZw
l/4+Tv2y5B8imp9RoyjYBqlXkLvRYkv46g8L1j/nMKJqOmz26MxY64eZsTB9
4tG7gfPJy7Hj0cFnZ+RF5ETzS94j9Txy3VejbvJF1KuJFfsVXYfaWHH9nrgJ
/qZPHR4f8Gazx6knvhV+AZ9wvGQaK3mOy1wPZ4/cnUV540tq/9h7EjZP3Xth
1FionZ8X9KMi56dmCjYlN8VPnig+G6X3+1PnMeyFcyPfJTYRG8BwYLmBoqmp
OH60Ub99wdj1SnBCxX3GzpNMB4rmZ2on530/qIVTt8CHEBM3F2zf1PMGZsb2
x6hdmjpuva72rIrz8Z6iGVt2befCsvf1drwLkGuzF/zqTXnvk1o+dUzO6erI
9fG5a6P+xDz0A1Yi9hBvwO8Twk8mUWeg3nBO1f7zNznj1tbIJafVOeb2jNp7
PvwbWAfMcw53rmLsuBWcGzkOuQ4YYXMH4wTyA86XfIQ4WmlwLl+f+ayoc1M3
mhZrLUrt8/H9vSXbiZLt8KrrHIzjr/NRM8P/fLfedXDi5qrU/D9Mjae5l73J
LdKov7TYzx8V59QUbwLYM/ia+h3xtVfUNrAjaonUjMhbyO9PqTeufiri0Sad
yT6pfdvjmXPzvpGzrys4niwGSxZtP9jRM4GpwFanRCz4Mblp3H9qris7WYfd
Ct5j37BtMNfysLEzq64hvtjJ9VPwz41Fx7c3465RT1sRcY27gm1gIy/lXIMY
WjaWhA86/ZP2ktNab6htzKzbGZLru2WfQRe1R7W4xvFGyRiK2EFdAt/GXPzb
B5qfqf9+6nPvEjTUDrh/1I83R9wh/txRNaam1r4xNf0GtT+seO+35p1DYQ9g
dNbKwpbwE7wJkivxRkVMqtfctVHn3yndjIv3Jt6dwGAvR92P/Gd0+ENyd97p
qFkTK4g1+HXsnXyMHAEsT45Knoi/Rpe/6eQYkkWtannO+eRtWmtg1Xf46Krr
jdxJ7uOy1HGKeMXf2Br+ihyO/bAX8HsueL6bc872i7LvHjLN077aar8TuN8F
f/QHVFwDHtZg3HaNzmkStbKSa7fEWuIseoUeu+Id6bi4R+iX2g12Tp0M/4Jv
2RE2tlr8nxOvudSaSs7nuR+8Ec1T/03psW3BeQB9cgFqHNQJhoGdMudoY7kL
+vsx8elctLxgWWQuZMbEd+btQ/AfzCfXqUQtjDPhfY9zoZ0cfTB7l6DBv04K
2wADshb5xtK85/P2OCv1m9mP8q4lUHegtnBX5G6cNTVTeOGzlxVci7y24vwD
zMRZUhPlrPEL4H1qWJwr54adYWOfFfz+/WDFvgPaY6q2l3/UPLrVe++cxZio
CbH/0zPv8Y28zxGZydmGxpv4GeJ5QGY9zso7p58beT0+rDn82Of1fn/CB62J
t1F8IW+P5Jzc6StiDN+YZn5bujtv/zc19Mwb446QAZmhIaf4eYvvzrUl5zHg
H3D/uRXPfUd8dlftb7ZI/18VnFdfpbELq/ZV+E5qFbyNcV74bHw32LFH1ec5
LPPd4w5+Lp7tK8bAvHvwfsI+2ePe1BgeLI/8+BFsm3rVTbGXOanpT877reD2
eHuihgiW4Z1zROBgcOcRFePh3hXfIeIy94h67Oq4X7zFDQ2d8B51WOi/Q/TB
VwNi/oyC34zJGR4v2WexPm+VYFzW5L1uZur7e0Led3xw8KdetTHW3ZFaTnDr
NwXXv+ZqndGZa0MfaO6CnPPbY8u2gQ4hT3P0ubPYO+/ok+ItBR2CS4mNxEgw
Ce/mM0KfT1bsZ1Zozc6ZZbtPa92eWieD8vYnvaI+T54Dv7+mtiPODFt6OGp0
r6l9sWxftKBsbLI+/n8CuQK1DvYLFiNGcl9Wxtvi15nnMPfDvOMW8esc9S/O
/H9BFvO2WXAe+37m91jeQrCZc8vm2ZC5DrE21u2Z+f+LXFe2v+wW6z4XdQbq
Ddh+18jrwJHgybYVn8/mkPngeFMbI3keTb133v2eTf2uwxvdwKJx25Si8SC5
H9i3pWz8OlJz15Wd268vu35wYMhzUt46nS1+fcqOyZdpbHneNn+O9tE27xrB
91Prcn3Ixt7Y4/Vqx6Z+V+JtcFrmGtyvOxmDgEXIX6g1Dg9c9Hzk1OTWP0/9
PsQ7YffUb0o9Uvuq6eHPXy5+m29xViODT8/U9db/15q/T30uvIVeWXbtY2LZ
+IZz5H0B7Nwt3j3JOYgv1B1uiPzrCe11cNUYaJjaZVGLoCaBPvAL+AHei0YG
z+MiNxmls5tccm5FjkXtZ1TQvBnv5ryfsw56gy+1cs6OM8TOkPOVsv/fA++e
L/L/XjK/zX3FW2rZ2Hx1wXkY+Ri+96qyazwPS/5ros8YfhP/WSz4ft4ZmGFF
vBmR1/0hanrU9rB97Orv749R26fGf1BmfaLXjzO/464lXw4bw9b+BvvcjJY=

           "]], PolygonBox[CompressedData["
1:eJwtmHeYldURxg9ld9mimHvv3rZcFNQgQQSUooKoQFBMqFKkPVZM6IZmwEQF
RFEpFiBiUDQmoqwVonQQARNqVEQQNSxCWGBBRDosJr837/3jPN+cb+bMzJkz
Z8qpc8/wbsOqhhDGVwmhOt9m6RBaFYXQmjE5FsI+5juAdzIuLg5hbCSEOy4I
oV1BCNuB9/BvcU4ITWuEsBe4WiqEkXkh9MkN4cloCG0SIdwCnCoM4etkCC9A
cxTaOayvDn4i9CsuDOEN8JOAS2qHsO6iEFaxphL8aGT0RF5r6L8AvqskhEHM
y6uF8AD0D8VDiOaHUADPreg7gvlo5iMZw4EbQV8b+q2sfxj5TZhfwvxb5lOZ
b0XGZGTfznwBuhbC81LgJhilAHhXrRCWMv8amjLgGegwB0N9is4LmFci821s
U8qYh63OwmMC9BMZ54AL+LeLtRXsJx/4FPQtanjNfOar0Gc3+nzHyGPvK7BP
fr5tLFuPh2Yu8jbwbwLwpmLv9R3Wv8X8RCaEmhdZJ+l2C/spR3YF9PnIz4Nm
dY51qAE8BPoXmE+qGcJQ4Eehmcl5jUC/R4AbMnowb8n8SuAlyMuFV0vo60O/
Hpv8CG4f/DYBVzIq4HeI+XngxSnbago65GPfKqxvjb6PwuN95LeM2RZl0HwE
7XJ4FqH7FvivAG4T9dmUQ18V+e1ippX+q6DfBv6p7HktBD8C/OXY4iDzuchr
wzgH/2asbws8EpoG4K5kjAa+jvUbgXeBP4Z/zNJ5QT8QnjfBvzX8GoJ7ljEL
/BDw9aD/JfiZrD0P/t0i27+U/VQyjgBvRf+b2GsDzjNxgWX8DvmN2dNA8A/h
r42Ay1ifwR5job+X+aisfp3h/zL8t8d91hsZO4DvTdgfL2MMAO6IvO7wa876
2fBahQ/uvND+sxrZE8FPBX+GM1wPvinzuvD+DfPHmW9Bxnjm81kzhbUT0Hka
+nTiDCvwn8HZ/V7BGAq8HnwAvx59tqHP3cgYjKzx/PsI/GHZC/gt8IvjvpO6
m3dq/8Bvsv48+KbodBW6rGN9Oev3Mz4Bvhn8D0W2oWxZkLDvHmB9B3S9rcRn
9wr3cVDEd0x3bRb7P4vsbtAcB3+ENT9j7faUffF7Rk/wx+HfT/cN/FL028JY
C9wEHhNlH86gQ037lHxLNpPtpNN5ZJ1hHAIewpr7WXuOsQd4L+M88CbO+CLW
3owPXZPwHdFd6c+a21nbDH4Hcq2DdPkDNI3Qdx372RyxD8oXyxgngPei/7FC
+3AZ8Hr2fxhbTVa8RNb67P4VQ/4J/CpjXpHvlO5Wf+g35HlPzdClH/P7WD8d
noN0N6OGe8NvGbrMzsbjU9B8Bu1r+MRafGMJ/I5BexUy58r+jMbAHeGxAP5T
wa8B3yHmeDAN/AZwO5OO9c3hdzv7uzEb/9P8+xbcN0nD16Lz1eheNRsfpMNr
7P9hxbQ85wDlgsXQ1yA3ncI+S4CXIa8x8WIuPMalHBMUG35E5zbgJiGvGboc
xL6fIn8Ba/bgwsdYvxB4Sdy+UMpYBPxV3HdNd1p3uzPrY6zviM6dEvYp+dYx
/nWNOubq7v8/JqP728zfK3JM/jzmM9JZ6UyOMv8E/Nocn9k/gA9IJvx2MiqA
+/BvaKFtWgr9Is7gKXgtRP6HwF1Sjh1joOkKnCm27t/A7xBraxf77u1gzSjg
bTHHWuXELcwfQ8ZI5F8OfpJg1vyhyDlXubcF+6teYP9tDjyNPV5f6Jij2DOZ
8Wd0+z34J4CXodMuzraMsRx4NTIKscUT8P+42DlUsbk74+/A9+CD42o6xszj
PKpypq0429WsSUE/WzJybYP26PMcNCeRNxz9B8fto/LVPozlwG0ZRQX2KdUW
x9F3aa7X/K2WfVi+fJr9/cD8IfY7ocg+PQX+X2bjq2LkZmx1Azp8in4D+Ndf
8RaaJ9FlGPiF4O/OOFZrD9rLmBLbciL0DwI3Q/7aAp+pzlY5S7lrP6O68m/U
d0d3qCG+UZT0XakL/giyb4XHrejbEZm1kZ0btf66D6qVFGMVa//CHlcBV8vy
3wWPtop9MddeylnPI386aw4wn8H8NLje8FyKbWawfiP0Q7HHy4XOuUOAe/Ov
EbhfsN8rmP814v2qJjkYsQ1lyzOMX8NvYtx7fxr8m7rfKedO1Wiq1bawv4ju
P/waw+902r6hGHo27RgpXxPNv6DtnnasnAX/1vC6Mml5ssHn2OYk+6nMdQxt
jvyboRnE2rtY0yvtGkD+pjP7gr30Zf3TBa5J+og/PN7Pc03VQ/km47vVnT22
Ad4PTR3WXo+8XuhfzvySQt//X8H73ah9XzXS1cj+U8K1r2oG1Q4vRX12yuGq
Naaj47g836Eb066hVUv/pByps0m7llbOVO4chj3HcRb3o08n9NkNTWNwi9C/
DPhS8K3yfaYn0W922rWNaI7ErLN0151YKfvzb1qRfVy1xIvMexS5ZlDtMJN5
V+D26JdkP5fFzVs27g1udNL5qD4xcxTwoIxzdQNoKlT7xJ175jPeA95c7Fij
mPMI89ejriUls1PaMVS2lI0P6DwyvvuD2W+PjGss1VoNGDfEXCOoVlBO3Zi0
DWQL5cANJT5znf0Q8G1TziHKJTqzfdDfFnUtqBpCtcRoeCZrukYoBd9J9wXc
FMZ0ZJezfnaOe5z9wMvi9rWD7G953DWVaivdh5XAa9B5W03H1Hbodibi+3wS
nz3EXXkq6t5HPlAd/c5l6xHV4GdTrjlUe6gmms/6jzOuHeUD8oV+acf6XsT8
vsA3RN27qOZQ7aGYqNioHPFsxDWJapNu8LgRXoey9dhk5g8wn4KM/arVoFkP
bXN4lldxj9ci7Tuqu5pE5g7leuR1yfqzatNTEdtCPihffA7+HaFvpRjCfg6n
nYtU39zB+ntZ34z938L+lyZdQ6iWUE6fCv0lCefyhuiwDN7fRB3bVLMMlq3i
zo2qoVVLvwDNR9hmDfLmgH+plnO/YtjYlGtY1bKqsTfD64KYaUej/z5kbYq5
l1SPpF7pgbh7Q90R3ZX6SfeiqkHqARcg80nm1zDPB36i2LD+5YDPSbvWUo7P
BT4Zd+2mHlO95qaoY+1q9cDotzbqWkkxuJN6p4j7ZfHbWGKegvXvKLg3Uq7F
1UO+CVw9bVm6A9XUv0Xdm3WC35qka5jSbP5/V7bK9pOK4cpdIe67Jf5fsJd0
wrWQaqql0B+BPn6he9ze8NuZcu2sf8KNijpeqyfcrNic8X34jH+nMvY5+Z5q
ihHo9wH0D+e6ZrgWXu8wHi9wz/k2cKOUa1/VaI2BP4u5dlIMGStbpm3vrfDb
DVwv5dpfNfMVwDmqqXKzPYnqjZhtrR7+PuhnZLxWNdfzwI2y9atyinLLv9PG
S8YO1pcn7Ct78bFy7HEq2y8oBrSA9zMJvz1oT9OBi2PeexSaV9GnIOledyU8
81i7vdiyJUOyVAOrFlaNtTziO6m7+Qr4y7Fv55jjuWr+PfArLXauaM2avhHL
kKwJzIdD3wP6w4WOKep1TkccW/TvK+btUo6NqqlUW72uHJDvmK23hw7I71/T
NdE49NtXy7WzeIjXHzPurbSHs8wfjds2CdaPB/46Zlg9Z/+MdZSuqplXA8+M
uFf8Fpo9Efeo6lUVU+qiW+2EY4NqjkzCOV+5Xzm9DfB16NSk0DHqWuDLEvZ1
xZRLgf+Tcj2l/ugOeK9Fh3o1HJPXAXeJO3Yq53cFfifuXLVc/gfcHhu2R9+2
yIgpfhW7FlMMVyzPSbh2qwvN1SXOEcoVOiOd1ctJ96Z1sN+wmGsE5Tf12BXg
hmf8tiKdhsmWUeda9dR6S2jHvCz7vqFaTjaSrfRmpberUuYj1Itjkx2czcaU
31pU3+ltYgwyOgfn6AeBL04apx6sNvCPSff63ZiPR1Y9bFi/yDlQufBwLecq
0estpxL6odD3ZD4J+k9irkUGMDqi//ykex+9seit5RWNPL8JdVNtHbUs8TiW
dM2p2lM2/R7bPh41b70JngdfL+a96Q1AbwHPJF3LZpTTwf0Ud2+tNzq91UWy
/Zd6uMUR3zHdNeW0qcDzWL8ymOYN4BlRn63srbcM5TzlPt2BXOgTKb/lKIcp
lw1MunbHZcJvgXcrRhfax1S735/w24t8Rr6jnkC9gd5Q+kI7LOG3EtXwquVP
MH+kwG88x4HrpPy2o5pLtdeiYvemsuFixWNGpIZ7IvVGuSm/PTZnTR7w3Lhr
K+WnAO2QpGsz6TwUuDLht0b5jHxnXcJvL+rJdkXsw/JlvQnO0V6TzvXqn9Sb
/xBxblFNVBXciYjvimroQubTo8716gfvU68Y89unekD1gqXZflg98E8xv1no
bsqG3wH3i7u30pvRZHivSLiX0xvunawvzL736Aw/BP9i3P6jmnQa+61X4tym
mubn6ocz9k31fJ0z9hn5zpd6c0Xf/6rHquoYEpDfMm1b6t/1wAOhjxa5ZxsA
7YoS97KqMVRrfJBw76o3E72dNI3Zl6WTdJuQdC2mOzgeuFfGtaxyUk/g3oxd
NXym22PuyaW/crR696O13EspJ21Fv2UZv32qB1Uvqp5KvZV86BDwTRn3Knrz
0NtHl4hrJ71hXYd+raPeu3SqRL8xMfdyuvO6+8+nnWuUg6skHbMUuxSDnmX+
UsS5RTrvB34s5bd45Qjliv8Buc6UjQ==
           "]]}]}, 
       {RGBColor[
        0.8548375184864815, 0.32656189679445635`, 0.19428265598401237`], 
        EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFWgl0VFW2fYSQkKSKhHqv6g1VFekWI6gfUMFe2u3XBuQLTdBGAXH40KJo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           "]], PolygonBox[CompressedData["
1:eJwtmXm4ztUWx3/EOc5I551+73vOQYVUQoWedDWYbgkVIaqrohIJyZRZ5rEu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           "]], 
          PolygonBox[{{5793, 2456, 5795, 4908, 4909}, {5608, 5607, 5364, 2447,
            5778}, {5781, 2448, 5365, 5607, 5608}, {6810, 3235, 5359, 6212, 
           6213}, {6213, 6212, 5360, 3236, 6812}, {5656, 5655, 6809, 3235, 
           6808}, {5792, 2455, 5376, 5481, 5482}, {4878, 2730, 6211, 5655, 
           5656}, {5645, 5644, 5529, 1780, 5195}, {5482, 5481, 5378, 2456, 
           5794}}]}]}, 
       {RGBColor[
        0.6571224146251076, 0.22066619947375254`, 0.3451924846556064], 
        EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1WXmcjfUaf5FZzpwzONv7vufMSboINwqVe1PiimRUoqJbERXRJ9FgLDGy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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHm81nMWx3/duN3uc5fcZ/v9nnvviMEQSWJ6GTH1ylIKiciguEYplDZa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           "]], PolygonBox[CompressedData["
1:eJwtjrtOQlEQRTcK8gyF93p5WJkIlEggxk4rCulooLbUBH9DQqWJBK0tIOEP
DAmh9g+EwkoaQrClcU3OLVZmzsyevc/Z3WO7dyDpGGLQPZEWSekrkDzwQ6y/
yUuTlHRN/UO3gz7zJ/S/vvRZhIw0o46Yv0ElJ5XhwZMSaby5nUOc/t5zO9OY
1m7K7N7JiLCL8j6EPd5TfMf4NtjX4RI+0F1R1+z7/GEQuD/Z317gGZYFaUvW
N/UUbREW9D/MmtyVwrzzvMuyzFV40/FdlmUO8XqFW2YXZKXQHUGVPh64LMvc
cLvndltwWZaZZV9D1/Kdh3n9Aw1IMTk=
           "]]}]}, 
       {RGBColor[
        0.38125459450207433`, 0.13832560350755785`, 0.5017024267931632], 
        EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmHeUVdUVxi8iMjNMwVfuffe9O6NYglQbxAJGcamgYEHFXokK2EBUbAFr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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHlwVdUdx29AJCQhwbz37n3v5QZFRQXB6rihoIijgoKjIaC4IVJRcBRx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           "]], PolygonBox[CompressedData["
1:eJwtkD0vRFEQht8QsrvYr3vv7l13I1EgSPQqdCSiUND7AdbfICRCiwbNhvgR
WBoUOitRLAm3EaK5vuI5GcWTmcycd945079Um19uk1SCDvDLkgdleE9TJ5ZC
aSsjfRelgT5pEG4q0hj9KV+6Ir+GMziFBrS6pMuKvXWaL7SbzMgxKw6kF3jA
9JYZx/RmqtI0bHjSSlaaI9+jvwvjeMSd0g75GrpV2O+V6t3SITEb2uw8MaH3
CYlv/QP6BepFaKA/h2E8XlPSBfksPjX81j3zd3sskCfMOwntFu4m24FpMmhS
kIZ7ahH7N4kjaEY983F+wf/NfOcdSe091CPb3f1hiJu84fuI3x004Rk+qMXE
H978wiT/mIBW1d4/EfN456AAR+y0yLs/AaFB8w==
           "]]}]}, 
       {RGBColor[0., 0., 0.], EdgeForm[None], 
        GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHl0VdUVxi8IkhBCct9LXt4L9wUoolgZRGZksFagKmCZURGQMlqGVagK
HV39A2mRSqHV0iLUEkBxAMQiViMFRJkTUiDVItNqF1SFZcU6rLbY39fv/HHW
t++5++y7zz777P2913bKvJFzG0dRNL9RFF0FniyPoo8KouhJcG4cRZuvjqJ5
4C2MvyE/B64vjKJDLaLoLvRerWQg7wD/wjiC3ABeLLA8EqxlzbrmUVQH/orx
BOtfBXu34n2zKLq+Ioq2t7CdW9GfzbtNfGsO+ACjGvnb4Ix8FD2FzuPY34C9
nch1TY1/CvJU9FagPw2czvg18gxwCmMp8rfAmYy1yLPA+xh3Ik8E72UMQp4A
9sS3ofi2kDgMQL4buSt+dkMeiFyCXIAPvYujaBLPA9Osacl8QgxZ/0FRFC0C
74odp9XgnFwUrWR+NnikmWXt7Zu824rOJvBuxkDm7gH7YvMmbBZjcy3PP0Xn
d+BtsePUNRVFuyu99yL8fIL5Pjo7cBTPzyIX4e8zxPvqYn+jO8+D+HYW/7+D
XhXvtoBvSmY/e8FdjCzybrAY/SvYbwFWtLKdDPhGoef1jSbl9mcx53OMd5+y
rxb4/jbfWVrkWB+vdM4cA+sY+5FrwUklUTSZ8WATzorv/ZH5s2B7xlnmsuzx
OuSmnG0l8mS+cSfyIWIyTvvF9njw34zBxOo/YAX+jMGfk9ifif5K9E+gfw3v
arCZwU475FXIZcgNyCfwsy/yKc7mI+TT4D9jn+nH4Fdjf7cKnZXIldhfBXZk
zGO+DfPXI3dATpC/gnyBi1WI/L3YNt8DH2KcR34XnJi3/luJc1q5vRy8J+/9
1jA/NO/Y7GFP+/DlaKmfr5UdsBf2+6U8n0r5WfMdeH9Ie+QcD4Mx879kfSlY
iq2h+H+Qb52OfV6nwDGMbsRzLNhS+1Q+g4t5nsZZPgoO4PkMvvVPeUj+sWKT
9znuLouibcTuHWy+DN7Bu8vYaY/uiLxj/iz7Gp/3+W5HHpn3uWxJvI+Pwx5H
xravb+7D1jlsvqm7k3MMa8FpOefYVPAY+jcgTwaHpZ0PVdicSAzmkrcN7OEy
tl7DZqcMuinnX0ewC6M1370RHIv+zGLf0ZHk82bw+8TsJ7ybwvy9zI1l7GB+
LfdoPPJO5I3IPdDpjZ2e4FTsfLfY93YK8gLkM+iNyHIXeV6h/MS/Jfi5Hn97
hJxR7kTMd2C+MfgYuJSxh3dXeDcE+b/glpzzthMxL0WvF/Nfw84XqiHIn4Od
GddhrhW4N8RQsSwocW0Zxrs/s/YC8nFwNONh5LFgU3Q6tfT6LrF1E+Ut7x5h
fjI4jbEYeQa4TeeH/AdwFHqdyKXR4IbEufsM+ALjMPJm8HbGXOShwcaSsMdG
PNOOoluI4R7kU8zvTexv1+DzEZ7/jlyXuFepZzUjri157sZ8P+JQiNwZuTfy
J7Hjcxncz/w55INgx5bWkc1Lse1fVB3iXQPy64ljv6ylz6YPMflFkHuV+Gzk
84+I6e+J7Q9zzrNVRe5hR3m+gFyX89lLRz21S5n76X3lrjs6xxO6f4w12Guj
Opb4HAfjfyn50q/Y9/BEzv3lODgJnUXKGe7QzSmf762src85z5Xvg1g/ADsZ
dH/G984TqxQ5W5l2n17B2re5DzXU9Ld0L9KOp7hAz7RzoEBnS3zLsD+QtQty
3uN8sDDjmrMS/b/G3u/D4NcZR/BhMHgu3IeD3JGzKd+Hfcg1KffR/sjlrN+E
D9uxtzpjnrAGXI9OLfJJ5OmJ43MtPhcxvxzfmqd8JsvDuZRVOPfG4vucxGf3
PPIdyF1434q13WOfW1vVOr67DvuH1UtTjvXt2DgZasEO5FMp15E9yGN0T1hb
hZ0o7Rrbjticz7mWqgd2jYOO7l3K/XQ0a/en3GcnIPdjzUbtHbwp9jm2Vj2O
fV6fqe7m3V+OJu7r6u87wBtj7yUPvpi4rqq+bmYvC8mROmKVCX1Z/bl36Kfq
q6qFOjvl6cuJa69qsPqB+kJJueuf+Ilq4KN5czNxvT6h76j/vMNzLfPvVjo2
sic+o5hpnfr+uHLrl2Y8JCtfZpa5vjTOOy9UI3UvRjH/OfgI695njGDvV8qd
L7o/ulOqwar54hejcq7DqsdDcq7VqtkTcq7Jqs1P850PC8zDarLmdeJ34m1J
kflfdbl5kfjRb9nbcHSHg/0z7omTxWdCLVJNGoSf/0L+QPcCndHkz23g3qw5
rbjtwNjco5P6fuL+uwM7T8XmxSPA38SO+bDYXFL+yC/d9WuKfN/FY8RnsvjY
K3AYcRn1lrmFjt262Pf96dh3SPrqnT0DzxHf2ZI1dxWHfSPUN9W5Us6gghiV
5N1bJEvvKN89wPnWg50rzEvn4399bP49CPwk9FPVm/pQH1QnCtO++0fLnePS
Fz9XjVfd1N1bXWFOvgvdY4nzXPleXWEOv5/54aFHqFe041uX1Kf47vMV5vb1
6Bzg+Uns74/dU9Vbp2Onf+z8uQFsgR+72Mse3p/JOs6nwTZZr/0S28Vp+7gs
Y76vvej3gGqNas79+LC+0vVTdbQs6/uYAhfxvFj5m3F90d3cwtxD5c4f5dGh
SudhBd/pnDF3Fk/vnHIv0G+sJOO4KX7qS+rT6k0v5azz/75RYt4uPt8G/T7I
rTPuAaoh4/Dz53nn/ePgc2n3qdmJOYh6kO5S+wrz51m83xZyXrmvuqbaNSzU
TvU81dV/JOZy5xP3D8VhKf6/nvbeq/GtMmNufAp5TThfnfOlrPP5IrghnG91
+A2lfFec+wWOLa6tGqzc192sCrW0Ucr1TrH9Uhw8Nk+4oN8viTmzuPPijM9R
53lz4OTi5q8lroHinlMChxGXaRU40vuqqyHPle8dQnwUp2XB5kbwQGKb4u/a
p/ZblXEeKB++YG6nejDn8g3whZTzUPVM+aFYKWZJ4FQf6i5jcwX+vJQ2/50U
fhO9EjiVuNVjZa7tqvEPZHz3Z4FbM+5f6mPbY9eiJbHrpr57gbWZ0BPVG0/k
nUMNeddv/T5UPdoaeoe+0yTwT/HQjYl90W+RAeH3jn73bE277y7g/Stp/154
EPkHsWv4QsWg3LLqevO0/wfokfVvHd1TxWhT4IfiiVsDPxRP/CxrPv9p1hyk
Y+CiL4a7rxrQOvTNq4hx3/A7Ub8XVbf0P4Vy+r1K10Txi8OB+4kDDgn8RDyl
NnHu6fdlfeCW4pg1sX/rVoPdUz67+5EbAmcWd24buESzlHmbakVT5PGBS4tT
/w//l2TB
           "]], PolygonBox[CompressedData["
1:eJwtmHl0VdUVxi9TEkhIcu7Ley8JNwGstSgGGSzz0LpElMmKgBZUhjKPFrDV
ZbXUtmgXighdrXQJVAYRHAAHpGBEQEZlSoFAVUSKEluxtlZqa639fXz546z3
7Xv2mfbZ+9v7vNZjZw6Z0TCKou4Noqgxv1NDFK3KiaLa3ChaCB4XR9E1zaOo
slkU7QPPp81AvgP5FPhBdMaje2l+FI0CT6YtZ/xBvj0K/ivtysIoGsTcV4Ef
rYiiJ4ui6Ma8KPpjeRQ1TKKoDf0sHzUAb+bbHwqiaBOtUTqKRraIorGst4f5
1mejqDVr1qG/uEkU9WG+fHReR3cbbTtjp/NtHeufRv8x8BjaPOT1yPPBP6DN
R96M/HDwHrSXtxh/DHy03Hh10ygKzH0s8XozWe8o+CD9g9Hfh85h8DfZz2f0
30R/L+b7KPg83+I87cC30fqy3ijW+6X2gv4kzjMc+70D/j3ffsV8M1hvEXgi
7fEcn3cBeAtrbGGtQ/SvRn8E3/rQ/336fwEewbeezFfMfK+D12TYVxPbZAdj
Z6KzPsdrLAcPR6cr+nnoV4NH0b6DXIq8CzwenUXob2P+R8A5fJvHeXbiJFcj
Z7iPHPSfZj8p7HMC+UvkjYy/qZR98W0Nel0ZV1WJD7GHpeylBv1T7O2lsig6
ia+cZY0XwC9j0yPMX43zvQTOxpbfR+7KPAuR5zD/OOY/A66gnaF/AGfsSX+j
xLaWzRuD30zc34b+/eDDtA/q9Q+Bu6a4l0L7ZC7yetoB8BLWex68gPlns95Y
1nsfXIl+caH3/CL7/RPnOcR5hmDP4+AUOnvrx3dmPzV8219gH5Gv9GR8J/o7
0AqYvwz9WnAT9tNdd0P7FN1q7LMC3DL2fuVvvZFfTawve2wFP514vbuQ14AL
sP//WO81xu/FvmeDfVPrvwhuzHxz0V/G/XVCvpXWDdsP4X5/Dm5IPDYpsg1l
y4mJ71v6E8DD0emE/kD0HwiOScXmU9inB/c9j/HX5DlmHwSn2c/GPPtIFpwn
zmC+Oub7NuNr0TlbZB3ptqe/ZbH9oR14KDpV4L6s9zPwHbQBOeaYeeCO6LRC
/zT2GYLcWf5c7Bi/GpzPnGvzbJPm4BZ8O1XvDz3QH53YHvewn1HgXYn7dR9v
gAfSZiBfRX9/nZ/2Y+ShyMPAUex+yR2Y76sK70c2yGCbWu78IGufRy7n7lcg
r0X+FP85hf80jD2f1u/I+HRs/5P/d0G+ljsc2tScK+6dmth+D9OeYb770fkX
c12gvQe+j/Y5+Lfcx37wcTXkM7QejP918Pp1yG+DPwiO97bIR8F/pm2v588z
wW1b/f3WgJPYtlNMKfaeCb4rxcMJ8Wdw7IsDbgCfDvYP2eNa8BfiK8amuPPL
FU+xY1E+Ll//MPisOvMm8LngeJM/V4MLUj6rzlyH/XYn3o/ubA94E/Za19T+
0ALdD8tsjyXsKUL+S7BvK96VizSH5lpJfzP664Jzj/hD3P0ZrQu4iP22iX0m
nU02kq3OB8eyYvpv4I+Dc5u+fRL8TX35iinGl8f2Le1XvpiJfdfiOHFdaezY
VoyLG/oG2142lC1lM9nuOvq/RM6NzcXyCcWWcoBygXLMSN1l1vl7MWecXuYY
V6xfzBnBMaXYUkwPC87RytUaMwXcNHasLtQZYufMi7mT/rHBHCAuEIfcAp6r
+811zN4MbhZ77CLxXewm3J0zXCFbxOYWcYxyi2wsW/dGvsD4y5A/L3RO7Y98
jPZJoX26FlwSm2sVM4qdVrG5UjlatcE7GefKcsVfxnegu+hM/98Zf7jMsaCY
UGw2ih2L4gRx5Rtljh2ttwH8dTAXKOYV+w1ix75iWLH8Ff39Cm0D2eKtxP6t
eDkALs3a3rJPBlyd2B9036+Bl2ddi8i+y7KucZT7VQM8D16TdS5WTn4K/LL4
m/N9gfwT8L1p34/47x7w1BKfVz5YyPxTkPOKnPOaIu9AHo08itYf7ppeYvvL
54vpr8zYdgfZYwJeHcynW5FXqlah3Z1rm7QXDt6L9PuB7yyxvyrms8yXW+r8
pvH/xF5X0H8nepeA31bupkY4iXyp8h7yLYnvQ/a9FXw9+ncppui/Et3VxOxD
hfaf8fTvTDsX6kwDOE8h6+1Gfw+tCDwmsb/pfseCi7K+qyz6xegPSnyfut/B
6q9wn+50MGtdxpqvMNde1T7M14u2pplrrHnYZ0dw7SROFbfuZL9jilzPTaF/
eYl9XzEwh/kvzzoeFT9twB2yjl/FZ3vw8cS1rfy5NrGNZCvZSLaSjWSr2eJx
5q5LXHsqXj4C3512fCq+f5R2zaXaSzrPMW5t4vhRDbEOvCExHymeNqoWSxxP
4uca8WtifhJfvZKYY8W1ynnKfbennQ+Uw/+LvDfr2kk1+G7wAWJsJesPxAeK
0b0h61pVOb2f7oIcXZJvG/QGL+VM3bDXI6w3nfWeQO5S5DufhLyowrl1GC3L
fJuzrqX15tgEfiFlW4uDZsk/sn6riN8ucmOJY0U1QwPs2SvrWlj82QP8Zta1
pmrmfeBnU96L+Fa5WDW54lPrTQqu6VXb6zy3B9fM2+rjdwJ4d8a1nWKgbco1
mnKbcpxqy5GcYa04n/YN9lNVYu4R551KXGOr1lbNeRJbHs44/pQvj2S8R+11
BWPuh69aM8eA4JhR7NxX5j7VtKpttYbWUo2uWj2TmHvFAeKCc4l9SRzcF3ly
xr6sGly1+Nexaw3lWOXaqoxjWxzRDnyh1LWF4kFvi3as1y32GXXWlhnzVw/a
JRm/sfTWUs18hPNtSJtbdMaNadfYqrVVU50A/4dvG4NjXLGuN9zmen4cVx/z
in3FrGJXa2itStqZtN+IF9+KtIK0fVS+ukQ24jylafuWaop30f23/BH5HG11
uTlIXDRHvF/iml65v6NyHPdZlDjXiIPFxdPKnIv15tPb70jaXCnOrAHnoV9V
6Bp8Uol9Vr77mOIxZZ+Wr81njvHMNa7MWG/iB5iveeK1xfHi+srEtYI4WFys
N45qH63RmflGp8wNykmrWL9D7FpN8azauiZl35UP38Zas8psG7359favis1v
yh9twbHOVGw+0VuoD+0fxf7WEzw85dwnzt3A3UxOmfvEUdXIRWlzw8d6g2Pf
WSlzoThyF/37Ur5b3fHN7GV7yrlSOa8f8s5y36VqNL1FJ1S4HtWbcyJ4dmJb
ilPELc8F84d8ain42eC1tYffgZ8M9mfFq95m1wfzp+ZUrds2mEv1bRt4VXA8
y/+VKwcFzyXO2wIeHPwWk49vBX832JfkU78JfkOp3lNO6Qn+aTC/ygeXae7g
ekb/ATyutYP3Lk54NbgGVy0uPlHtvCQ4f2uMxj4UzBWKJ+XuA8G1seJXb4cN
wbGhGLlX9VFwbawaWW8N7UF7kc1kuyeC/y+RzWQ77UF70Xvue+B1wVhz/jD4
Pxj9FyOOmhG8htYSB6iW0X9M+q9JMTgt+D8Q8Y18TL72bvDbSfWa3jKyoWyp
PdwI3hX835TeEHpLjBBfBnOOuOd8qf+b0n8k+q8km/Le9R/UAvxjbtqxqP20
yrgmkm9rfeVycYbOojfr8QrnCOUK5awa5r4uOJ5l88XiXeXv+npXuf89dJJ8
/+ei/16U85Qr9O00fdMSv+2U45TrVCNrrOYoVM0Tez+KKcXW/wEL37fm
           "]], 
          PolygonBox[CompressedData["
1:eJwlkk1L1GEUxU+hYJbm48s0/1DLF0STEARNXWgGOovMhQiCCIkfQEXFqI9Q
Sy0JwkVuXAlKkAlCUZJiOLiwRYRRBAYDg0gmySD+Lndx4H/u3HPuveeZipGx
vtGLkmpANhi8Jn0M0jCovyydxKU2sAvfB/+oHUTS7XKppVCqpXaQJQ2USHXU
juEnoD1f6iqS7hZLk/Bv1od2B20tfYfwI9BMXwd91dRW4D/B2hVwHX+0E/B3
4MUl6VVMminxea3UlsAs/BbaU74zoBu/B/gNcUd5rvQp+D12Vz19eex8FczQ
95a+VCk7811D7T59FfQkmb3FDr+D72S79aOP4/cB/h70wS9YBgVSE9qn1BbY
txPPO/j9DX6j3VpFfi/RfoFv2wz4D3I4JI8nwbO1jHvRJtCeBb/H7mqkvsP3
Y5Ci/2vkc2xeAXNn6Z/mhmTk+U5TfwOyyWqfeprfq+gbNz908zHP8jl82eaQ
32qR+4RCz8dyamLuAjsng8+3PSxry/w1WMfjM17daDvQ/g/+9vYfeGZvlEMW
8EXLHp4pk26QVQP+PdQq6duL/Kbvwd/Z3ttytXwfWu78lmZuDGzCV0ErvsVx
z9CyfAT+0Lcbuad5r9lbsN9yzHOwPLbAHPfcRJdgzhT8HviFdgPtOdM1c38=

           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV0dtPz2EcwPEnbNhQI5VFGxsrNmOsNSQ2tJI2v5KWpjRRKqxozLhw4YaZ
PyC6kHJIB4c0ypAiOVRON+Z0zx1uvb4X772/n/f3uz3f53kWVx2JHY4LIfzB
prkhxC0MYQoCpmFqNC8KoSYxhBmeM+eFMJ2zeCYf0mfzOvMs3sBzuE6P5xxz
eloImznB3KAn8VZzhr6Nk81H9TTeYV6uF3K8dRMQnxzCmtQQelJCKNETzUlI
wVq9bX4IlXp2UgjNnk8gUx/0fa2+1HfpyECWPqw36ivNq7AaG/UcTHg3ifVa
NgadSQm+ad+Rq+XhiVaGX9pvxLRiDGsV+Kv9Q5lWjlFtP7b4xwmMo9t/XrDv
Xu5Bqr3mO4MC5KEwOg+k6bu4BMUoxW4s0Su4EntRhX1Yph/gg6jGNXut4RZr
1fMtcx13cgNf1pu419zId/gYt+rH+YF5hTvp52bzVT3O3MYDWpG9nPT/pxBz
hrkLQniqt9j3FbSiRC/SR/U2czs6UKqX65N6p7kL3dijn43OzLtq9Gn9+KKd
Q73WEK2jDeGrdh6NWhNGtJf4oV3Eae1MtL42hp/aJdT690MYspd85/aMt/OQ
vRRwh/1eRztu4gZ26l3cjdvRuaEHMf0e38fd6NzQF92X/ogH8BCPMYgy/TkP
YwgvMBLdpf6KxzCKN3gd3bP+jsfxFpOYiO5Y/8Af8R6f8Qk1+n9Tjo73
           "]], 
          LineBox[CompressedData["
1:eJwl0stLlGEUgPETFVFeG50ZHW1yNAqqMQiC6AJtorblQizctMhd/QutDIou
WNAmWgTSKuiGVLu0i1CpM+loNRkEpdUyN0VZv48WD8973nPe857vUjhx+uip
FRExgjutEcXmiPn2iK38nrfkIz7zAfGE/CRWZyI6WiL+piK+iKMpoktcQEk8
hZs5ffgj9thf4Om2iFq1i9breJf9naiIZ7DbHdf1voFf6Yh6uQZsNkOGm5HC
T3XD+p9Tk9LzPB9Dt7rj3MV9XORebtRvLa5YX8UL6+fYZoaq+BrW6Lvkecrm
+MFF+W70yNW4oy6ZHeP28s7dV/cA97DDPP3qfm+I6HTnXTX14tdmbOSX3MCv
OOvsRXWX8EY8g2msly9xGROYwiQ26feYh81U1TeHeffluT15Lv1KzpbRY/8M
d9jfiE58ElfcNYu0+bPIoMn+W33foYI5zCKn35DarHxV3MIfOM0j+rXJ/5HP
iFdh0PosHql5iJX29nqX+7Afg87UOXOBb2FUTY2aJ1zLY8nd5jmidsj6pF4D
yfuxvpz8Q87c9uzf1C5j0b/4FQs46Hm/c8E7Omy9nQ/xM99kHE9b///T/wAY
y2wA
           "]]},
         "0.08`"],
        Annotation[#, 0.08, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV0l9oj1EAxvGzG0lSNgybWK3U/M+kbBdu2Ga7GkJCVqyJbbTZTBmNttbG
xVJWpPZHKFMaayPhwrLExdZkEdaWIWZTs5Hm8158e87zPb9z3vOe95eUV5Rb
GBNCmED+vBDyFoaQGhfC8IIQPmMEKQkhFPIb+VF9DONYzZ/m0/jf+hT+YC1f
y2/mp/WY+BDaY0PIwBW+ETO4mbjPZaKFa8Vsbg46uG1o4+4ijotHJ5eDpvkh
NKPSmctkuuek4YZxyuIQHlvzBMuteSafYgX/XHZjDd8jX0Rjvlf2IZ1/I/ux
jv8kB5HJD8shrOcveO6o8RnvuN3cWTmmV/OTskrfy5+Xf/Vavs3ZqvWtzlkj
7+n1fHZiCHV6pqyXS5eEsAy9frfFXc5dFEIDn2+/AhxBBp/AX+WL9OM4gSw+
mW/hy/RTqEA2n4OV5lbhHFeF1+6yGKncBtRxF9HLlWATlxY9n7uMfq4cXc7+
ELecv0LelLnO+8h4j/vJtCYL16zJkdk4wO+QO9HK75a7kMfvk/txh8+TB3GI
b7fvYeO33qfD3IAs0B/whfKD/oz/GN2D3smXyCG9O/pmslTv4ivliN7Df4nu
x/7lOIl8d1Njfox/af5VdDfRXfOX+Cm+L3r/6P+Bo3wDH2PfAf0d3uMY38jP
4gf1oegMKOSv87H8iP4V31DMN/Hx/Hf9B0ajb8k384n8T30cv1DCt/JJ/IQ+
iSmU8rf5ZP6fPo3gf1fB/weWYJ7W
           "]], LineBox[CompressedData["
1:eJwl0jtI1VEcwPGfFNGD0pvXS3o1MLC8FkHQkIviYmRDzyEIipyaEicnjR5Q
LUENQUMNpaEWROXFoWgpCwRJkBqSW0P5JG8QVEpZff40fPme3+uc8z/31rZ3
HD5TEhF5dNZEXM1ENG2KuMRT6Yhe7kNnRcRwVcSDjRHPxYO8gAvyaQzJTao/
4cryiKP22G590h55PsENfM/MOf1nUSuukp+w3qW/RnxIfJ4Pcpbv6O9R78Zj
cUZ+3PqI/oxz6uVGnZvj9fLbeCtum5vD98qIH3iEU2YXeQk/0S6ez+rDLBar
5dHlHYr8FW/kx7HCWR/s/xE99u/GTvOnxQVMokHPiHyON/ANubW8GqVI4Vjy
Xtzs/i0YtX5n/7doFZdzClf03fVdvUjJV+C376nbHPGLy8RLem6Zb3SPVXw9
uYfvKmC3+h6sc5c/4jwm7DvMjfL70YZS9b28D1vwzHlPcdN+JWp1ciut++Va
nDNmvpk/eZvPeI+cuMA7+KH6C7zCa0y7U3Xy2+K4elFuAVlxq/iv+rzZZZ5L
3tdZX3hW7RvP8DVnX5Yf4Zcoc68D5geSt9Vzny/yGK/hQS6m//+f/wHIy3CG

           "]]},
         "0.07`"],
        Annotation[#, 0.07, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV01toj2EcwPFnKBcobf6O2wxtRShyKIdlGmlNWzSHpDGHjZVtJubUZi7E
HIvSFq3NNgxZ5lgOjbSGSE2hpayUu9kNRvJ5L75939/3PT3v898mFZSs2hUX
QviLjPgQtowNYSu+jQ6hkLdj5PgQSrgUfXo570ZMP8SH8Uuv4kpM0Gv4JMKY
EM7waaTotVyHofqKhBAuOS4bFUIz55hH6Ll8zbxHb+O15pi+jtvNB/SmWAib
zeneW8At5ir9qfM7zWmuL+bp3jkDb123YEIInc6X67Odn4O5WKJ36xXR86IZ
GViq9+oH9SxzNlYiU++LvlXPM6/FS3u3Cb/1AWzU8tGlbUPcuBAGYZNWgNda
Idqt+y7OWft7a1xmrZm4py3nePckoMg9ozmGLD2Rk1Cqp/BEZOupnIYKfRpP
RY6ei5mOb1pztXO3eJb5svfO4zvmU3o7zzc36Iv4ofm8/ogXm5v0PM9q5jX8
WL/ofC3qsNreZLmuQ683N6Ax2iN9jd6lXzVfRyvW65X2IT/aG9zW2vBROxrt
UfTt0TqiNaBHO4Yn9ucpHlhHkXXc5x38TFuY5G/AcTH2RnuBfUjXS7UyVJmr
sd37j/CQ5BD268cd97vuBL/xvn7rrXH8wvPP8oC5W//D58yv9PPRb8uf9cF8
wfyOa3kY9+rDuc78geuj35S/66N4g/d94jJrqfdtnYkhjDV3mJ/jBRr1cu7R
812fxD/cn8xXPO9L9D/Ek/mnPoVbzF+5lVP5n57GN8zf+T+iGpLK
           "]], 
          LineBox[CompressedData["
1:eJwl0l1ozXEYwPEHaaJNO8c42zkulERSWHHjQi0lw8USN7hAlDR3Xm64Me0F
bdqxmZeNK25wY5GmM7fG1ZGM4hxOlGJsk7xsPicX377P8/ye5/n9z6+zZN/R
puYZEZHD7gURb9MR71CTjNgjH89ETCCHJxjGkZqIJme/FkfM0bdDXItpeZqb
nU/q+4GCXUWk9O1Vz+t5gU4k5F3cyFN1EQ3czgfULvAHuzr4PM6hRf0+D6Ib
l5BFDw6aXe6eFSgsjDjBJ/ElYc7ZXNxS35aK2I5JebVvGuM29W/cwe2od+9n
+QYervW7UWfmK4/Y+dfOMfEUl/RdNPOJs9yNteZa5WfRKV8pf+MtXskr7bnt
e3+rzXK2VL4MveIh9dl6ctzmt7bisXiz85fu3cpD7i3YVcQj8Rp7HvIg9ovX
61mHeuwq36veZWeF/Q3yn+JFzlL4I75m/3Uk5QPcj9X6rvBVbFLv416k7Kjy
ZgneqJ7kETwtv6uZeZx33xZx1u5GrlRbZeYG38Rh9QHu93aj4j5+LR9FizvO
IG/uLt/DHZz2Dqcw057n3uEZpvUcN3MMJTsu4335P4Mi0naX+KPenb41I++x
o8rcA283v/xufEj9e+b/f/8fR3x8ZQ==
           "]]},
         "0.06`"],
        Annotation[#, 0.06, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV0ltMz2Ecx/EHuTCzWY4dhKuYTQkXXajJMY0RY1oOFW2xIo0LWVPJhspN
F2xsmotKm01OpXLOjRw2N1nMnaZcsYwIr9/Fe5/n+37+3+f3fX7/38LCI7ll
E0II/1AyM4SDc0NYOSOEL7NDGMFXLEkIoZxP57+rR/EDKXwVv4r/rR7HXyzj
G/gsfuKcEGIwGWn8FX4DP0U9FfdiQ8hGC9+K6VwsOrkcdHC3EcfF4wG3GZ1c
F+ZzC9DNbUHrrBC2ynTPem2WWne6wbVhaXwIL/X0Y7meN/I1UvkB+R6Z/Ef5
AWn8ZzmEHH5EDmMFf9a536yr3WWnvZro3ajP8X9knXovf1aOqy/wk+Lsqwv4
8zJG3chnOO+izJSNfJH9gyjGeveY6XdN/GF1KcqwkU/ir/IV6uM4gU38IfdP
trcIldwpvOJKkcKl4gxXh7dcOe57P51oNsc2c1yTubKLWzwvhO3WO5ChNwur
sUu9Rq7F5WhWuQ55fLv+zdbPzNds77ncor7J75Yv1W18v8xT3+KL9HXIA/Id
32H/Du4iP7qX3w3y3eoe9GIfvx9H7ZXjOdeHT+5Ujyfmf4oM/HTuGH6h2LeR
6V7HrCtQq7cuei/I5k9ylahXX0/033pug3Wf+ar4hCT/M9dub1z286P6mqJv
lotRd5urB724xF/RP43/bL6hiMjhtFmq8cFevjMG5R75yDlP9D5Eouc9lgV8
IVr0/ZBZ7lWDkejbj/CMNow5/zf+oJ0fcFayc/uc8SJ6l3pH1CVyWP4Hx5ei
hA==
           "]], LineBox[CompressedData["
1:eJwl0k2IzHEYwPFnJ2sjJ8yuWayUl4vkgIvbmotyEHaZKydhZ6O81MoBSeGy
OaySJiIvyxEbjcJhtqglzVAYLUua2h127dqQzz+Hb9/neX7P73l+/2mW7spv
7WqIiEd4MT+iuzkijwMYnhtxAa/FpXREo/Mj4h5x5+KIHdiGDmxHRj3VFtHK
Fb1nWiPKnHP21ZxLyC+MKGQi0uq1lohJZ1MoOGtyt+j8l/yb/Cp2i6t6x/VO
oKZ2Aye847DeQ3iXvFXPKT6JrP1P3HuGpxhx1sV57MV+7EO/d9xBw4KIXm9d
bla3ek3/CvFKHDSrauZdO+/xAwxgXH2dvtvi9fxTvsWcH5yTL1M/L77Ia+Wj
4jnOB+3bJM+I27AEKT29yUz1L/om+BMPo25vo57T4u/qFX6f/K487eyY906r
X1f7zTd5kq+ZN1NPic9yUf0cN2G2eQ+9Yxbf5+qiiA8YEOfURn33W3GnOWXu
4Dc8Zd+IvnZ5UZ7lx7yBC+bXeYb7JfcHUbXrI8bUs8lc7tPX4k0b5e1Ii3eq
fzZnjXw1Xonr9mxWH+Mhs/qS30/vqnkRVzgl34PAZflxPBcf5SH3evgl99v3
l2/xn+Q71CsoN///v/8Dph6BIQ==
           "]]},
         "0.05`"],
        Annotation[#, 0.05, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV1F9M11UYx/FDGCB2k+YPSqGhOcvBcE3EpAyxm9r4qy4LdBpe6ETaGujM
tUq25KINsEJzAjfVBUrUmH8mSH/cNPPPhWI1dVOrmTpozT9ghdnrXLz5nOdz
nvM8z/l+vz9y3nizqj4phLDCn5LJIazLDGE9biZC2EjrMPmJEBpoI+7wN9NN
SPDfp9swzl80JYSmeOaxEFrpEnFyRggv0TZxPb+TvixO579Cu8Rv8btppfhR
fhXdG/vxZ+uxiT5NX+NPs5+FbBRMC+GwvFp+jngmnkIh/2icgz9HnIs8FPFP
8xv482MeBtx5KS7wL6KEtwSDvFdxnXcDZbxyfMerxt6pIexDs9kKzFaI+ejh
JbJCWGD9HP5zNjwewgOayV/IK8LDvFSkoFicTidhrR4t5nvEeofaGfQTcR2/
nWbGmJ9DO8UN/C46Q/wpv1St3bSMfsF/x/67eA+l7v+svF7+B+LtaEYFfwF/
P79F3Iohd2zEi3E+tPN24mfeFhxxz+XOLcOQd9+tZyWtQJ57Vutfg3JnK1GB
fP5crOYnsr0L/T6cHsIZWm2/T41aOiTu0+s8nSe/ACv1WYUN9i/xB+1/g2+x
ht9sphq9V+IFs/U7cwQDWMN7ntbpuxFb1OjQ95o6b1v361tsvwSLcZO/X80D
OIg2tTeosYN+7twd+5/Ru7RcfgVKcSw+d1ov93tabI5x/RbT+/SE/SZ6mv4k
Z1v8/eC4/Ubxj/GbEp+i5+Rs5aXRZt4Z3nnrr62TrGf7np7BBDPsEqfQs2bN
5eUjD6m8q+73K67gd/yGcnVa1C6jCfqQ3L/cLd86Wf0JSOalxO8UC+VNjN8o
Bp1Po6nYo+8/4n/xC+5jHDP0fd35aqRhEu6qP0v9HnyJZc5+RXsxqv4P8fnE
bzY+DxxDh5yPPMePcVl8FVdwO87jrulIUfskvaV+rlpDzoT4Dchpj/+T6Ekz
ncIJjHhvw/hb/ojcP3EvPg86ypvpzBidrmYrb0Dcj0I5Y+Jh/go9R8wxjCxe
A7JxSN6IvBv8J8XX6HX8gS7x/823x9A=
           "]]},
         "0.04`"],
        Annotation[#, 0.04, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV01tM12Ucx/GHC2xrUzFRRCHAQJ2uhrmpRF0QCm5teSgrqThTdhBnAiq4
0k1FPKxpCTqXgWvhRZvHvMlOTsPNC6ymqzSbbXkhB42Drijr9Vy8+fw+n+/z
fH/f38Pzz6pcvaw2IYRQ5s+c8SHcmhxCD16cRKeEkCnbNTGEDLo/nZ8QQr96
Fh2kQxhAp9qnOCS/w0+jt+l0+ifNoen6VdEptJLm6luTHEIS/wI/hi6nY+lB
tQozlKMMj8qH9blh/RXPmTQhzkUv8+X0B+//Ed34Hpewx5p0s9/U8w+0yvZh
dvwuuhu/yq8jWdZm/Xh6jb+Kneo7UKJ/E92I9WjEBhxAlvX91vbh77QQ/kKu
7F96H0PyYeTIRsyaTQf5AfyjPoJq/ev1asA7qMNapJpnmvX3rL2LbPs/kf9s
/aHUEMbRWc4niX7EH1RPtH6mbAZOObOTOIHfUkJoptvwgPWNeo+iF+3pphfo
f/auldfhO/481ng+RzfZ12Xde/QCXSUfNMvb9A2zrcSI2reyb9Cr18e+rYe2
0yLZQtRYv4Ce0aOQfkmrZJXxPuhRHe8Jvlb7Cr/b32r/DZr6cAive8c8+VyU
2lOG/Hjv+JaHQljBb6G/4Jg+R3HF3vf12CQr4R+PdyDeEflueTdN0btC76Pm
WeYsz8ua1bajVP4qHrPnef2XI887+/gmPRfzjfQnHNG/E+vtW4cG2WXsdf57
cFrfPP2XxvvF70ALjsnnyBfLn8UMvafjiPxd9U46K/6PzfcI7eCr9G+nyWZ/
xnytapPV2mQr1FI9L5IXx9+sXmP4sRiNp2UFSJMXm38R5vqmW/xK8570/Bq9
iLb428GTeuajQtYVz9pcL2HYXRvCK7KzWCpbgo3m6JUX2lvEL8QCbJBflxfI
n+DzMB/18kvyp+K7MMEsyaiN366+ip5T3+w7z9Aafqq8mn7BN8lP05f5NHkJ
/ZxfJ/+MPsdnmD8TOb49G6P171A7jHZMjWeFB+Uf8B9iL9LjWcXfjnwrvw1b
MEmWgkT5PGd4z3Ous7tLZ9MOtKPQuRxHvzV9eMveNzHOuv8BiLPNWA==
           "]]},
         "0.03`"],
        Annotation[#, 0.03, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV1FdsjmEYxvGnhJSarVm0SmKrUDuolSBGEaMRThopItEEMdug9oqWaGnt
Elsk1oFQiQRH5gG1aRE7RpwQ/N6Df6/vvu7nue7ned+vX0pWzsR5MSGE8f6c
jQ/hVosQbqKiZQgdGmkkhfBHfaSVOiGEzo1D6IIO6ITq+h3pGXu/IsPncUix
pw2S0BrJaG9/tsx/smPkBfTgvW4SQiWqUD8xhHqoi+/NQ/iBb/iJ2mbVQRxa
2nfA/oPYjzIcQluzX9JXeIYXeI468j7I+Ij3+ITf/FqyYhEvr1S9ByXYh71o
I+8JfYpHeIwKxMkLiME/WdXoX349WXXRVt5x9QkcwymcRKq8t/QdKvEGVUhz
9+7ogRJrUu2/Q7vR1fprsBL5WIVSz/otappVA8lIwvOmIRQ7T2ufi2iRNVWo
4D/CX3nb+XO9jwfq+7iLX/w8d7jm/eTScrrOui/8g97XZ5ooc6HeSPNHYJaz
zka6c35TbzNnpnorfYnzZpxDpb3FMjbxstT9rO0bvRf+Tv4z2kx2tuwL5u7g
PeQV0O0oRJr1mbIv0ku4gP7mTuVNQZ7sk7JP4Dhu2L/Rvlz+l+j5yy3n5fOu
0sbmZZp3NLov7zJvKV2OZehkzxi5Y9HHnE/qxbJGqefTezhsThlyrJ8XwbuN
/bx90TlkzuHP5ZWod2MXDvFn8ufwP8otdobdvGm8XTTB2UY52w5+A++gkJeh
V0Dj9YbpFejV0tvMG6oX6/NA/gA0lzmYNwQDkY5BaBr5zj8Eae70Xp3lDOnq
GfQ6Cp2vAH2s741MXjm28DajZ/QuMIm3Xr0Oa7HIObrzJ/DXqFcjP3o2/FR+
Bn+VeiVWIDu6p/l57hFPc+mlZs7Bb2/9dNow+m1xnyV6p/Um81Ki2bSBXju9
BXplemOi75DeaFo/+v/Ty9GLk12kX4ydSOYnIZa/Qb0R65EYPTfU5C9VL8MS
NOIloDq/l+fUG92i30B36Irh7tWTdwX/AQJUvJg=
           "]]},
         "0.02`"],
        Annotation[#, 0.02, "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         {GrayLevel[0], Opacity[0.5], CapForm["Butt"], LineBox[CompressedData["
1:eJwV0ltMz2Ecx/En5DwbcihloxhizNjSuJFCDkvmgkJOYw4dmBk5y3nYlIkw
h3FhQuUiXTg2ksOWK4cbp407bDZh5PW7eP8/z/fd93me7+9Zg5YW5RbGhBAG
+tnYJ4TnSSG8wFPkqp/Jxr4h/BkQwm8s6h/Ccj7Zer3sLOfITjJHNut/qP+X
uhUL9S/hE6yLZUc5S8bKmfKJ/gf6P6k/Yp7+xXx/6yLZQWbL9nK6bNJ/X/8b
9Wvk6s/n46zXyXZymoyRU+Vj/ff0f1d/Q77+Aj7eeo0MMku2JYSQKR/pv6u/
jf+Hv1jBf+BTrN/3C+EdkgaG0CUuhMr4EE72CqHB326jHoG/lhhCOf/DvmZ1
a+8QWuz7KY/ac5/bL7+pL+r9Kjea4Q6/lf+sPseXWhfxhZjkrCruDCpxGqeQ
zheY+bZsQD0mmjmPW4C95niLWrPV4JWzK+zbxV1XV+MaWqLZ+O38V2fcNEsT
d4h7LA/Lam6fvKfeI/eiDCP174zOxDbsiM5BKj/bDHXyFmqRZrYZXDY2uOsl
rrj/MkrsKUYRd1F9Aedx1X2r+bX8WfUZVOESn+LMIUhGpfkW6qvi86I3kvmy
gp8rj6tzZC7mIMmeLDkVGcjEFCTwmearkePMe1OOlxncZCwzRxNOmKEC6fZM
wCKuEeXccWxzXxo/nzumPooj2MKP5+fxh9QHcQCb+LHRfPwXd5aZu4QbHb2L
HCN3c6PkKnWqXClHRu/Nj5CL1cOiWeRwuZnvGb2R9VAMRgqS0YNPjN4B8RgQ
fTu683GyD3qiN3qhC5/u+6/LG6jGWO8ygUtDlrnrsD36dnSzp2v0rtH/H7Zy
pejIxaKD/f8BHSehhA==
           "]]},
         "0.01`"],
        Annotation[#, 0.01, "Tooltip"]& ], {}, {}}}], {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[5], 
      AbsoluteThickness[1.25], 
      StyleBox[PointBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQzbB0oZX9jlX2UHq/gUlv6yzXi/ZQev8Fmye7elue
2EPp/ZO86n/PV/xkD6X3J7Xffpht89seSu/3txHiP5XI5AClD2yPcmAyeM/m
AKUPnPngNvHOPS4HKH2gKtJvvc91XgcofSCnUpRZfiq/A5Q+4OVcWldgKgDn
O1+OWBEpIghXP6s9ZvvECUJw85Zcuv8vvUMEbt+Nh2U/pM6Lwd2jIdfJ/tRA
0gHm3hhdBcYZ5dIOMP+kVSz2yMuXdYD5d6/O8vBlr+UcYOGxbU9XY/8peQdY
eGXvWlVySkDBgQEKCqc++6MSjuDnc7Qn7b2E4O+3vVCxoU0Rzn+X/+XnrzYl
OF/lm7yzM68KnB9k8d98y1Y1OP/RrW06hQU6cP5DMdUz+VzmcP7dkummH5tD
4XwAZPy6pA==
        "]],
       FontFamily->"Times New Roman",
       FontSize->14]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[5], 
       AbsoluteThickness[1.25], 
       StyleBox[{},
        FontFamily->"Times New Roman",
        FontSize->14]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], AbsolutePointSize[5], 
       AbsoluteThickness[1.25], 
       StyleBox[{},
        FontFamily->"Times New Roman",
        FontSize->14]}, {}}}, {{}, {}}}},
  AspectRatio->0.4,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"Im z\"", TraditionalForm], None}, {
     FormBox["\"Re z\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{0, 16.}, {-4., 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.784487580355513*^9, 3.784487653578899*^9}, {
   3.784487683607739*^9, 3.7844877249624434`*^9}, 3.784487796187105*^9, {
   3.784487834416353*^9, 3.784487900435051*^9}, 3.784490352227507*^9, {
   3.784491232671438*^9, 3.784491260244041*^9}, {3.784491298782878*^9, 
   3.784491314428595*^9}, {3.784491345229548*^9, 3.784491350369316*^9}, {
   3.784491478293676*^9, 3.784491499831256*^9}, 3.784491534630197*^9, {
   3.784507822646389*^9, 3.784507849219651*^9}, {3.784507920500094*^9, 
   3.784507929972128*^9}, 3.784507962193108*^9, 3.784508008268712*^9, {
   3.784508062524445*^9, 3.784508163837894*^9}, {3.7845082280682783`*^9, 
   3.784508303369478*^9}, 3.7845084317896843`*^9, 3.784508464432041*^9, {
   3.784508651639386*^9, 3.78450867002392*^9}, 3.784508701728965*^9, 
   3.784508745265133*^9, 3.7845087799289503`*^9, {3.784508816517541*^9, 
   3.784508883733459*^9}, 3.784509050634753*^9, {3.784509319089073*^9, 
   3.7845093770641623`*^9}, 3.784509450529272*^9, {3.784509748063209*^9, 
   3.7845097631928873`*^9}, 3.784546183778317*^9, 3.7845556559931183`*^9, {
   3.784555701947277*^9, 3.7845557731472673`*^9}, 3.784555884142947*^9, 
   3.784557694607939*^9, 3.784558071592889*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"a6599365-4446-4892-9e28-037fe6a971de"]
}, Open  ]],

Cell["\<\
This picture shows the Gauss points together with a contour plot of f(z) to \
demonstrate the singularity. Next, we approximate the integral by summing \
over the Gauss points:\
\>", "Text",
 CellChangeTimes->{{3.784509474150268*^9, 3.784509538344425*^9}, {
  3.784509958178348*^9, 
  3.784509967458274*^9}},ExpressionUUID->"60e50cb9-18b8-41df-8c59-\
3e6deb69855b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"pj", "[", 
     RowBox[{"[", 
      RowBox[{"i", ",", "2"}], "]"}], "]"}], 
    RowBox[{"f", "[", 
     RowBox[{"pj", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "1"}], "]"}], "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"3", "ng"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7828375983932915`*^9, 3.7828376024700284`*^9}, {
  3.784487864430263*^9, 3.784487872653232*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"6242f1bf-6ec9-4434-a7a1-529ca7b978fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "0.3594944466391196`"}], "+", 
  RowBox[{"0.05764979774891104`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.784487873013501*^9, 3.7844879052292147`*^9}, 
   3.784490354029262*^9, {3.7844912351426983`*^9, 3.784491263080696*^9}, {
   3.784491302393161*^9, 3.784491352815805*^9}, 3.784491539654838*^9, 
   3.784508313333145*^9, 3.784508474037682*^9, 3.7845087465587387`*^9, 
   3.784508787889676*^9, {3.784508822250873*^9, 3.78450888521423*^9}, 
   3.7845090546316547`*^9, 3.784509384032299*^9, 3.7845094599108887`*^9, {
   3.784509748378621*^9, 3.784509766838632*^9}, 3.784546184057151*^9, 
   3.784555656053664*^9, {3.784555724333194*^9, 3.784555773198983*^9}, 
   3.784555884196443*^9, 3.784557694912047*^9, 3.7845580718857813`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"90a9fe00-3efc-4254-8f71-bd50a8a541c9"]
}, Open  ]],

Cell["\<\
With only 30 Gauss points in total we obtain a result that differs only in \
the 7th significant digit from the correct one quoted above! Finally, we put \
the Gauss point generation into one practical function to be used later on \
(don\[CloseCurlyQuote]t forget, you get 3*nga Gauss points back):\
\>", "Text",
 CellChangeTimes->{{3.78450978893468*^9, 3.784509809454384*^9}, {
  3.784509842735238*^9, 3.7845098479909563`*^9}, {3.784509975245406*^9, 
  3.784509984546707*^9}, {3.784549318934587*^9, 3.784549344327313*^9}, {
  3.784549552886313*^9, 
  3.784549566158708*^9}},ExpressionUUID->"a7735c18-2a36-499a-b1cb-\
37ebb8074852"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gaupo", "[", 
   RowBox[{"nga_", ",", "zo_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"gwpp", "=", 
     RowBox[{"GaussianQuadratureWeights", "[", 
      RowBox[{"nga", ",", "0", ",", "1"}], "]"}]}], ";", 
    RowBox[{"gw1p", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"gwpp", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "1"}], "]"}], "]"}], "z0", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"gwpp", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], "z0", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nga"}], "}"}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"gw2p", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"gwpp", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], "-", "1"}], ")"}], "z0",
            "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}], "+", 
          RowBox[{"2", "z0"}]}], ",", 
         RowBox[{
          RowBox[{"gwpp", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], "z0", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"\[Alpha]", "*", "I"}]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nga"}], "}"}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"gw3p", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"c", "*", 
           RowBox[{"Tan", "[", 
            RowBox[{
             RowBox[{"Pi", "/", "2"}], 
             RowBox[{"gwpp", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}]}], "+", 
          RowBox[{"2", "z0"}]}], ",", 
         RowBox[{
          RowBox[{"Pi", "/", "2"}], 
          RowBox[{"gwpp", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "2"}], "]"}], "]"}], "*", 
          RowBox[{"c", "/", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"Pi", "/", "2"}], 
              RowBox[{"gwpp", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], "^", 
            "2"}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "nga"}], "}"}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"pj", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"gw1p", ",", "gw2p", ",", "gw3p"}], "]"}]}]}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.784549349302536*^9, 3.78454952403199*^9}, 
   3.7845583556714363`*^9},
 CellLabel->"In[53]:=",ExpressionUUID->"24097ddd-3aa1-4f08-b27f-db9f02cc7a37"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Analytic solution", "Section",
 CellChangeTimes->{{3.784540268162891*^9, 
  3.784540272981495*^9}},ExpressionUUID->"99f3d24d-da21-4dee-b5f4-\
f09fc30789c0"],

Cell["Taken from a previous exercise:", "Text",
 CellChangeTimes->{{3.784540276413496*^9, 
  3.7845402825328417`*^9}},ExpressionUUID->"b1dc380c-3da5-4b1a-a899-\
c504ad307f7f"],

Cell["\<\
Simplified version, setting \[HBar]=m=1; yet, all formulas contain these \
variables if one wants to set them to their actual values.
All formulas refer to Haberzettl lecture notes (2019).\
\>", "Text",
 CellChangeTimes->{{3.7779725598327713`*^9, 
  3.777972630802498*^9}},ExpressionUUID->"22fcb16d-cdf4-457f-a7e7-\
fe4549713c38"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[HBar]", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"von", "=", "0.05"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Give", " ", "potential", " ", "depth", " ", "and", " ", "potential", " ", 
    "radius", " ", "numerical", " ", "values"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"rn", "=", "2"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7778426295288773`*^9, 3.777842633211206*^9}, {
   3.777842927940629*^9, 3.777843111575741*^9}, {3.777843143659399*^9, 
   3.777843144839632*^9}, {3.777843240523862*^9, 3.777843344668272*^9}, {
   3.777843392094696*^9, 3.777843432343424*^9}, {3.777843482218629*^9, 
   3.777843490038206*^9}, {3.77784355266179*^9, 3.7778437613063498`*^9}, {
   3.777843802895014*^9, 3.777843870371915*^9}, {3.777844033118367*^9, 
   3.7778441581649513`*^9}, {3.777844629135627*^9, 3.777844630836648*^9}, {
   3.777851379970978*^9, 3.777851412409073*^9}, {3.777855107154592*^9, 
   3.7778551656974792`*^9}, 3.777855209178129*^9, {3.777855513950602*^9, 
   3.777855543942548*^9}, {3.7778556736209393`*^9, 3.777855685774908*^9}, 
   3.7778558530786047`*^9, 3.77797260021946*^9, {3.784546611447691*^9, 
   3.7845466216885366`*^9}, {3.7845467243007*^9, 3.78454677910459*^9}, {
   3.7845468366323357`*^9, 3.784546878479116*^9}, {3.784548303413947*^9, 
   3.784548320255495*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"fd3c86f9-873a-46a9-b760-351716198844"],

Cell[TextData[{
 "Program \[Gamma] from Eq. (7.73) and tan ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[ScriptL]"], TraditionalForm]],ExpressionUUID->
  "dcd35149-979d-49a5-9a07-32c7999c708c"],
 " from Eq. (7.75), then ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7bf9e11b-7ded-48b3-83eb-637533a1c142"],
 " from (7.49):"
}], "Text",
 CellChangeTimes->{{3.777972605618503*^9, 3.777972612297203*^9}, {
  3.777972661489333*^9, 3.7779727366346703`*^9}, {3.784540478309914*^9, 
  3.784540496293445*^9}, {3.784540535487048*^9, 
  3.784540536489962*^9}},ExpressionUUID->"c3c02bf9-f687-4918-a360-\
c1e258b757fa"],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "[", "l", "]"}], "[", 
      RowBox[{"k_", ",", "vo_", ",", "r_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"k", "^", "2"}], "+", 
           RowBox[{"2", 
            RowBox[{"m", "/", 
             RowBox[{"\[HBar]", "^", "2"}]}], "*", "vo"}]}], "]"}], "*", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"SphericalBesselJ", "[", 
             RowBox[{"l", ",", "x"}], "]"}], ",", "x"}], "]"}], "/", 
          RowBox[{"SphericalBesselJ", "[", 
           RowBox[{"l", ",", "x"}], "]"}]}]}], ")"}], "\[IndentingNewLine]", "/.", 
       RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"k", "^", "2"}], "+", 
            RowBox[{"2", 
             RowBox[{"m", "/", 
              RowBox[{"\[HBar]", "^", "2"}]}], "*", "vo"}]}], "]"}], "*", 
          "r"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
      RowBox[{"k_", ",", "vo_", ",", "r_"}], "]"}], "=", 
     "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"k", "*", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"SphericalBesselJ", "[", 
               RowBox[{"l", ",", "x"}], "]"}], ",", "x"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "[", "l", "]"}], "[", 
             RowBox[{"k", ",", "vo", ",", "r"}], "]"}], "*", 
            RowBox[{"SphericalBesselJ", "[", 
             RowBox[{"l", ",", "x"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"k", "*", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"SphericalBesselY", "[", 
               RowBox[{"l", ",", "x"}], "]"}], ",", "x"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "[", "l", "]"}], "[", 
             RowBox[{"k", ",", "vo", ",", "r"}], "]"}], "*", 
            RowBox[{"SphericalBesselY", "[", 
             RowBox[{"l", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], 
       "\[IndentingNewLine]", "/.", 
       RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"k", "*", "r"}]}], "}"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7778426295288773`*^9, 3.777842633211206*^9}, {
   3.777842927940629*^9, 3.777843111575741*^9}, {3.777843143659399*^9, 
   3.777843144839632*^9}, {3.777843240523862*^9, 3.777843344668272*^9}, {
   3.777843392094696*^9, 3.777843432343424*^9}, {3.777843482218629*^9, 
   3.777843490038206*^9}, {3.77784355266179*^9, 3.7778437613063498`*^9}, {
   3.777843802895014*^9, 3.777843870371915*^9}, {3.777844033118367*^9, 
   3.7778441581649513`*^9}, {3.777844629135627*^9, 3.777844630836648*^9}, {
   3.777851379970978*^9, 3.777851412409073*^9}, {3.777855107154592*^9, 
   3.7778551656974792`*^9}, 3.777855209178129*^9, {3.777855513950602*^9, 
   3.777855543942548*^9}, {3.7778556736209393`*^9, 3.777855685774908*^9}, 
   3.7778558530786047`*^9, 3.77797260021946*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"0de17312-f2b0-462d-8e66-68b6f3d19a1e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"t", "[", "l", "]"}], "[", "k_", "]"}], "=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", "/", 
         RowBox[{
          RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
          RowBox[{"k", ",", "von", ",", "rn"}], "]"}]}], "-", 
        RowBox[{"I", "*", "k"}]}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Define", " ", "S"}], ",", " ", "P", ",", " ", 
    RowBox[{
     RowBox[{"and", " ", "D"}], "-", 
     RowBox[{"wave", " ", "from", " ", 
      RowBox[{"(", "7.49", ")"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.777911699014045*^9, 3.777911773288547*^9}, {
   3.777912370490368*^9, 3.777912392332247*^9}, {3.7779124610296173`*^9, 
   3.777912492701548*^9}, {3.777912528097074*^9, 3.777912530983883*^9}, {
   3.7779125811540003`*^9, 3.777912722540344*^9}, {3.777912755325943*^9, 
   3.777912756181304*^9}, {3.777913109912396*^9, 3.777913125248138*^9}, {
   3.7779131565794992`*^9, 3.777913183938075*^9}, {3.777913263612808*^9, 
   3.7779132881570272`*^9}, {3.777913347918737*^9, 3.777913416488883*^9}, {
   3.7779134773548594`*^9, 3.777913489250724*^9}, {3.7779135507646627`*^9, 
   3.7779135770460367`*^9}, {3.777913655425433*^9, 3.777913690561138*^9}, {
   3.777913734554757*^9, 3.777913790260064*^9}, {3.777913820301655*^9, 
   3.777913842853264*^9}, {3.777913885447241*^9, 3.777913902926955*^9}, {
   3.7779141378465433`*^9, 3.777914269546398*^9}, {3.777914387175311*^9, 
   3.7779144070938377`*^9}, {3.777914482166615*^9, 3.777914612285224*^9}, {
   3.7779156227476873`*^9, 3.777915659443634*^9}, {3.777915731183126*^9, 
   3.777915758207039*^9}, {3.777917330046852*^9, 3.777917398208054*^9}, 
   3.77791799859509*^9, {3.777918036875984*^9, 3.777918246778537*^9}, {
   3.77791829687501*^9, 3.777918317219092*^9}, {3.777918369229374*^9, 
   3.777918369356702*^9}, 3.77791840046395*^9, {3.777918585164111*^9, 
   3.7779185916513643`*^9}, 3.777918626583932*^9, {3.7779197112853403`*^9, 
   3.777919760505095*^9}, {3.777919808830806*^9, 3.777919819211282*^9}, {
   3.777919917742535*^9, 3.777920003826735*^9}, {3.777922100128401*^9, 
   3.777922157409013*^9}, {3.77792220576365*^9, 3.7779222375011597`*^9}, 
   3.7779225081305933`*^9, {3.7779225612365923`*^9, 3.777922590452998*^9}, {
   3.777922621303775*^9, 3.777922690701433*^9}, {3.777922726261298*^9, 
   3.7779227471823893`*^9}, {3.777922784846883*^9, 3.777922874720862*^9}, {
   3.777922933289276*^9, 3.777922944992532*^9}, {3.777922977970014*^9, 
   3.777922986225087*^9}, {3.777923032203492*^9, 3.7779232050469503`*^9}, {
   3.777923244209289*^9, 3.777923281898417*^9}, {3.777926537235076*^9, 
   3.777926615229789*^9}, {3.7779309768955593`*^9, 3.777931088403751*^9}, {
   3.777931154151469*^9, 3.777931186739654*^9}, {3.7779338214385147`*^9, 
   3.777933822228671*^9}, {3.7779736616278477`*^9, 3.7779736667458563`*^9}, {
   3.78421141279814*^9, 3.784211415456683*^9}, {3.784211451462347*^9, 
   3.784211461915062*^9}, {3.784211498271432*^9, 3.784211588100317*^9}, {
   3.784211639097308*^9, 3.784211641551156*^9}, {3.784211681829809*^9, 
   3.784211685646735*^9}, {3.7842117160327053`*^9, 3.7842117598740053`*^9}, {
   3.7842118170133677`*^9, 3.784211849810527*^9}, {3.784211927910499*^9, 
   3.784212108823348*^9}, {3.784212149035027*^9, 3.784212151296688*^9}, {
   3.7842121859555473`*^9, 3.7842121866815157`*^9}, 3.784540404838892*^9, {
   3.784540541358313*^9, 3.7845405642232*^9}, {3.7845406189996777`*^9, 
   3.784540630239017*^9}, {3.7845406648707657`*^9, 3.784540665993766*^9}, {
   3.784541439210649*^9, 3.784541445160005*^9}, 3.784546609383049*^9},
 CellLabel->"In[24]:=",ExpressionUUID->"016f5fab-fa4c-4876-bd03-b3779ea55167"],

Cell[CellGroupData[{

Cell["\<\
Born approximation (not needed for exercise, but provides good check)\
\>", "Subsection",
 CellChangeTimes->{{3.784554766052444*^9, 3.784554769243208*^9}, {
  3.78456235150448*^9, 
  3.784562361847248*^9}},ExpressionUUID->"70d2a024-3191-4aeb-aa79-\
0a8c6c03bcdd"],

Cell["\<\
Before plotting this result, we also define the Born approximation to plot \
everything together. For this, we need the S-wave potential. We take this \
from the solution of exercise 3, sheet 4. In particular, all the undefined \
limits are calculated there. \
\>", "Text",
 CellChangeTimes->{{3.784541507108377*^9, 3.7845415357299347`*^9}, {
  3.784541878287725*^9, 3.7845418926852837`*^9}, {3.784545586938504*^9, 
  3.784545611299117*^9}},ExpressionUUID->"28fd6dad-887b-4858-8d1f-\
c44bafbfae2c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"pot", "[", 
    RowBox[{"k_", ",", "kp_", ",", "R_", ",", "Vo_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"2", "/", 
     RowBox[{"(", 
      RowBox[{"Pi", " ", 
       RowBox[{"\[HBar]", "^", "3"}]}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"-", "Vo"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"kp", " ", "k"}], ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"kp", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"k", " ", "R"}], "]"}], 
        RowBox[{"Cos", "[", 
         RowBox[{"kp", " ", "R"}], "]"}]}], "-", 
       RowBox[{"k", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"k", " ", "R"}], "]"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"kp", " ", "R"}], "]"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"k", "^", "2"}], "-", 
       RowBox[{"kp", "^", "2"}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"lim1", "[", 
     RowBox[{"k_", ",", "R_", ",", "Vo_"}], "]"}], "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"pot", "[", 
       RowBox[{"k", ",", "kp", ",", "R", ",", "Vo"}], "]"}], ",", 
      RowBox[{"kp", "\[Rule]", "k"}]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Limit", " ", "k"}], "\[Rule]", 
    RowBox[{"k", "'"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"lim2", "[", 
     RowBox[{"R_", ",", "Vo_"}], "]"}], "=", 
    RowBox[{"Limit", "[", 
     RowBox[{
      RowBox[{"lim1", "[", 
       RowBox[{"k", ",", "R", ",", "Vo"}], "]"}], ",", 
      RowBox[{"k", "\[Rule]", "0"}]}], "]"}]}], ";", " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Limit", " ", "k"}], "\[Rule]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"k", "'"}], "\[Rule]", " ", "0"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v", "[", 
     RowBox[{"k_", ",", "kp_"}], "]"}], "=", 
    RowBox[{"Which", "[", 
     RowBox[{
      RowBox[{"k", "\[Equal]", "kp"}], ",", 
      RowBox[{"lim1", "[", 
       RowBox[{"k", ",", "rn", ",", "von"}], "]"}], ",", 
      RowBox[{"k", "\[Equal]", "kp", "\[Equal]", "0"}], ",", 
      RowBox[{"lim2", "[", 
       RowBox[{"rn", ",", "von"}], "]"}], ",", 
      RowBox[{"1", "\[Equal]", "1"}], ",", 
      RowBox[{"pot", "[", 
       RowBox[{"k", ",", "kp", ",", "rn", ",", "von"}], "]"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Finally", ",", " ", 
    RowBox[{
    "we", " ", "need", " ", "to", " ", "apply", " ", "the", " ", "factor", 
     " ", "from", " ", 
     RowBox[{"Eq", ".", " ", 
      RowBox[{"(", "7.181", ")"}]}], " ", "to", " ", "convert", " ", "to", 
     " ", "the", " ", "small", " ", 
     RowBox[{"t", ":"}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vs", "[", "k_", "]"}], "=", 
   RowBox[{
    RowBox[{"-", "Pi"}], " ", "m", " ", "\[HBar]", " ", 
    RowBox[{"v", "[", 
     RowBox[{"k", ",", "k"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.780350976098288*^9, 3.7803511309823303`*^9}, {
   3.7803511778957243`*^9, 3.7803511837875977`*^9}, {3.780351466050989*^9, 
   3.780351527345626*^9}, {3.780351574412848*^9, 3.780351639468725*^9}, 
   3.780401947192628*^9, {3.780402037250512*^9, 3.780402038895914*^9}, {
   3.78454576003438*^9, 3.7845457948673697`*^9}, {3.784545861862419*^9, 
   3.784545938393667*^9}, {3.7845460279829206`*^9, 3.7845462423581142`*^9}, {
   3.784546284123275*^9, 3.784546354709056*^9}, {3.784546810285451*^9, 
   3.784546825965152*^9}, {3.7845482914555283`*^9, 3.784548294590252*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"f196cfca-6aee-47f1-8a26-9f211fa8c3dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Improved Born approximation (not needed for exercise)", "Subsection",
 CellChangeTimes->{{3.784554729464645*^9, 3.78455473689005*^9}, {
  3.7845623438405123`*^9, 
  3.784562348480554*^9}},ExpressionUUID->"09749e97-7787-4ad6-a2ff-\
cda21af85b5d"],

Cell[TextData[{
 "Also, we would like to test the improved Born approximation of Eq. (7.199). \
Note that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["T", "~"], "0"], "(", 
     RowBox[{
      RowBox[{"k", "'"}], ",", "k"}], ")"}], "=", 
    RowBox[{"2", "\[HBar]", " ", 
     RowBox[{
      SubscriptBox["mT", "0"], "(", 
      RowBox[{
       RowBox[{"\[HBar]k", "'"}], ",", "\[HBar]k"}], ")"}]}]}], 
   TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "b8226ff5-44bf-4152-b9ff-a6c04a25ace6"],
 ", see Eq. (7.184). For (7.199), we need ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["V", "~"], "0"], TraditionalForm]],ExpressionUUID->
  "a60332f4-a303-4aab-a01b-79cd14732de6"],
 " which carries the same factors:"
}], "Text",
 CellChangeTimes->{{3.784548094482767*^9, 3.784548122667955*^9}, {
  3.784548169818163*^9, 3.7845482275812683`*^9}, {3.784548378880967*^9, 
  3.784548447217943*^9}, {3.784548706741599*^9, 3.7845487301196337`*^9}, {
  3.784548764879835*^9, 
  3.7845487707759867`*^9}},ExpressionUUID->"d9c231cb-7516-477b-a4f3-\
75fb5e1346a8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vtil", "[", 
     RowBox[{"k_", ",", "kp_"}], "]"}], "=", 
    RowBox[{"2", "\[HBar]", " ", "m", " ", 
     RowBox[{"v", "[", 
      RowBox[{
       RowBox[{"\[HBar]", " ", "k"}], ",", 
       RowBox[{"\[HBar]", " ", "kp"}]}], "]"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", "7.183", " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.784548773914095*^9, 3.7845488715134373`*^9}, {
  3.7845489062900877`*^9, 3.784548920655485*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"8edc3dd5-a6eb-424a-8c8f-cb316193fa17"],

Cell[TextData[{
 "To calculate the integral in the denominator of Eq. (7.199), we use the \
complex path from above. Note that there is a typo in (7.199), denominator \
should be replaced according to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["k", "2"], "+", "i0", "-", 
     SuperscriptBox["p", "2"]}], " ", "\[Rule]", " ", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", "i0", "-", 
     SuperscriptBox["q", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "6ad1fe62-fd8c-4a81-811a-ea994b10ef95"],
 ". "
}], "Text",
 CellChangeTimes->{{3.784548924358747*^9, 3.784548956007962*^9}, {
  3.7845491862877903`*^9, 
  3.784549252600255*^9}},ExpressionUUID->"9bd64584-6960-41e2-96bc-\
ce6a3f744f58"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ng", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ttil", "[", 
    RowBox[{"p_", ",", "k_"}], "]"}], "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"gtmp", "=", 
      RowBox[{"gaupo", "[", 
       RowBox[{"ng", ",", "k", ",", "1"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"vtil", "[", 
       RowBox[{"p", ",", "k"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"gtmp", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"gtmp", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "1"}], "]"}], "]"}], "^", "2"}], "*", 
           RowBox[{
            RowBox[{"vtil", "[", 
             RowBox[{
              RowBox[{"gtmp", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", "k"}], "]"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"k", "^", "2"}], "-", 
              RowBox[{
               RowBox[{"gtmp", "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "1"}], "]"}], "]"}], "^", "2"}]}], 
             ")"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"3", " ", "ng"}]}], "}"}]}], "]"}]}], ")"}]}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tbi", "[", 
    RowBox[{"p_", ",", "k_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "Pi"}], " ", "m", " ", "\[HBar]"}], ")"}], 
    RowBox[{
     RowBox[{"ttil", "[", 
      RowBox[{
       RowBox[{"p", "/", "\[HBar]"}], ",", 
       RowBox[{"k", "/", "\[HBar]"}]}], "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", "\[HBar]", " ", "m"}], ")"}]}]}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Finally", " ", "translate", " ", 
     FormBox[
      SubscriptBox[
       OverscriptBox["T", "~"], "0"],
      TraditionalForm]}], "\[Rule]", 
    RowBox[{
     SubscriptBox["T", "0"], "\[Rule]", 
     SubscriptBox["t", "0"]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}]}], "Input",
 CellChangeTimes->{{3.784549269081152*^9, 3.7845492854763317`*^9}, {
   3.7845495955716057`*^9, 3.784549870201377*^9}, {3.7845499325342007`*^9, 
   3.784550007744781*^9}, {3.784552006591218*^9, 3.7845520309334097`*^9}, {
   3.784552157531189*^9, 3.784552158089056*^9}, {3.784553849845907*^9, 
   3.784553849973033*^9}, {3.784554033638039*^9, 3.7845540338735857`*^9}, 
   3.7845541110117607`*^9, {3.7845541554489822`*^9, 3.784554206484676*^9}, {
   3.784554241085531*^9, 3.784554305124483*^9}, {3.7845543531895123`*^9, 
   3.784554353290091*^9}, {3.7845545904859037`*^9, 3.7845545905854387`*^9}, {
   3.7845556705872107`*^9, 3.78455567068533*^9}, {3.784555824126669*^9, 
   3.784555860179247*^9}, {3.784562336635872*^9, 
   3.7845623370831137`*^9}},ExpressionUUID->"e203c066-cbcb-4d26-8f0d-\
cf21205fcbaa"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results ", "Subsection",
 CellChangeTimes->{{3.784554715598572*^9, 
  3.784554719001216*^9}},ExpressionUUID->"25ba45d8-49ea-47d8-81e5-\
7ac111c19004"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}], "]"}], ",", 
     RowBox[{"vs", "[", "k", "]"}], ",", 
     RowBox[{"Im", "[", 
      RowBox[{
       RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0.00001", ",", "2.5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<k [arb. units]\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(t\), \(0\)]\) [arb. units]\>\""}], "}"}]}], 
   ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Re \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[\(t\), \(0\)]\)(Born)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Im \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.7", ",", "0.7"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Black", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Brown", ",", " ", "DotDashed"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.784540609395072*^9, 3.7845407841106167`*^9}, {
   3.784541136005373*^9, 3.784541153918641*^9}, {3.7845411853871527`*^9, 
   3.7845412192829247`*^9}, {3.7845413610286417`*^9, 3.78454142222432*^9}, {
   3.784545303654924*^9, 3.784545307056052*^9}, {3.784546422746374*^9, 
   3.784546496025463*^9}, 3.784546526669379*^9, 3.784546650733032*^9, {
   3.784546795871825*^9, 3.7845467973516493`*^9}, {3.784546895683626*^9, 
   3.784546895866808*^9}, {3.784552976791554*^9, 3.7845529780535927`*^9}, {
   3.784553804914321*^9, 3.784553805192781*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"2b051aab-d6ac-4092-a101-d0cd8236fcf3"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwV1nk81dkbB/DLVVQUpYUW1FDZlbJ1fb6lwpUlZRsi60QSRRMjJGu2Lvda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         "]]},
       Annotation[#, "Charting`Private`Tag$7088#1"]& ], 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1nk01fkbB/DLlYwkogWNIkzZQkZheH+rKaKMFC2krJlMCBUSkqUryeVy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         "]]},
       Annotation[#, "Charting`Private`Tag$7088#2"]& ], 
      TagBox[
       {RGBColor[0.6, 0.4, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{0, Small, Small, Small}], LineBox[CompressedData["
1:eJwVl3c8Vu8bxx8eiVJJIZpKw4zSoPI5UvZ4IjOVFZLIqJCkECp78xzxldmy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         "]]},
       Annotation[#, "Charting`Private`Tag$7088#3"]& ]}, {}}, InsetBox[
     TemplateBox[{
      StyleBox["\"Re \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)\"", 
        FontFamily -> "Times", FontSize -> 12, StripOnInput -> False],
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)(Born)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False],StyleBox[
       "\"Im \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False]},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Dashing[{0, Small, Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Dashing[{0, Small, Small, Small}]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.6, 0.4, 0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.6`", ",", "0.4`", ",", "0.2`"}], "]"}], 
                    NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.6, 0.4, 0.2]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.6, 0.4, 0.2], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"\"Column\"", ",", 
                 RowBox[{"{", 
                   RowBox[{"Automatic", ",", "5"}], "}"}]}], "}"}]}]}], 
         "]"}]& )], Scaled[{0.7, 0.7}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{Automatic, Automatic},
   BaseStyle->{FontFamily -> "Times New Roman", FontSize -> 14},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\) [arb. units]\"", 
       TraditionalForm], None}, {
      FormBox["\"k [arb. units]\"", TraditionalForm], None}},
   FrameTicks->FrontEndValueCache[{{Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.08, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.06, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.04, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.02, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.02, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.04, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.06, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.08, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.12, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.14, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.16, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.18, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.22, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.24, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.26, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.28, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.32, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.34, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.36, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.38, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}}],
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{All, All},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           GrayLevel[0]], 
          Line[CompressedData["
1:eJwV1nk81dkbB/DLVVQUpYUW1FDZlbJ1fb6lwpUlZRsi60QSRRMjJGu2Lvda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           "]]}, "Charting`Private`Tag$7088#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwV1nk01fkbB/DLlYwkogWNIkzZQkZheH+rKaKMFC2krJlMCBUSkqUryeVy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           "]]}, "Charting`Private`Tag$7088#2"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0.6, 0.4, 0.2], 
           Dashing[{0, Small, Small, Small}]], 
          Line[CompressedData["
1:eJwVl3c8Vu8bxx8eiVJJIZpKw4zSoPI5UvZ4IjOVFZLIqJCkECp78xzxldmy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           "]]}, 
         "Charting`Private`Tag$7088#3"]}}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
      BaseStyle -> {FontFamily -> "Times New Roman", FontSize -> 14}, 
      DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{
        "\!\(\*SubscriptBox[\(t\), \(0\)]\) [arb. units]", None}, {
        "k [arb. units]", None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 400, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{Automatic, Automatic}, {
        Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         GrayLevel[0]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 0, 1], 
         Dashing[{Small, Small}]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0.6, 0.4, 0.2], 
         Dashing[{0, Small, Small, Small}]]}, {
        Style[
        "Re \!\(\*SubscriptBox[\(t\), \(0\)]\)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "\!\(\*SubscriptBox[\(t\), \(0\)]\)(Born)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Im \!\(\*SubscriptBox[\(t\), \(0\)]\)", FontFamily -> "Times", 
         FontSize -> 12]}, LegendMarkers -> None, LabelStyle -> {}, 
       LegendLayout -> {"Column", {Automatic, 5}}]], {0.7, 0.7}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.7845406453430567`*^9, 3.784540695620677*^9}, {
   3.784540733882937*^9, 3.784540770457159*^9}, 3.784541148084571*^9, {
   3.784541203521793*^9, 3.784541220383656*^9}, {3.784541374840275*^9, 
   3.784541423435296*^9}, 3.78454530787673*^9, 3.7845461857724047`*^9, {
   3.7845464290040207`*^9, 3.784546447939834*^9}, {3.784546482800511*^9, 
   3.784546497044561*^9}, 3.7845465273612623`*^9, {3.784546631707329*^9, 
   3.784546651871269*^9}, {3.784546737847823*^9, 3.784546798659523*^9}, {
   3.784546848052657*^9, 3.784546897092052*^9}, 3.784548312860504*^9, 
   3.784552987143059*^9, 3.784553806430697*^9, 3.7845545972855663`*^9, {
   3.784555657467106*^9, 3.784555673701828*^9}, {3.784555744218137*^9, 
   3.784555774435171*^9}, {3.784555865093451*^9, 3.784555885193657*^9}, 
   3.7845576962211237`*^9, 3.7845580732205687`*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"7b914fdd-21b2-4b7f-a10f-92dd3a137bd6"]
}, Open  ]],

Cell[TextData[{
 "S-wave ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c7bd99a4-5a21-4315-ad82-3bc79fe79b00"],
 " amplitude. Note that the Born approximation is only good for small ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "53065783-9191-416f-a196-ce3c193867c4"],
 " and large k (i.e., large energies). See HZ notes, discussion below Eq. \
(7.169).\nNext, a plot, in which we show the exact solution and the improved \
Born (IB) approximation (that has also an imaginary part, see Eq. (7.199)):"
}], "Text",
 CellChangeTimes->{{3.784541455281179*^9, 3.784541502601177*^9}, {
  3.784546955026348*^9, 3.784547004290365*^9}, {3.784554389424477*^9, 
  3.7845544411370363`*^9}, {3.78455451525451*^9, 
  3.78455451679263*^9}},ExpressionUUID->"53292113-9267-4905-b5f9-\
12929ec3b8ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}], "]"}], ",", 
     RowBox[{"Im", "[", 
      RowBox[{
       RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}], "]"}], ",", 
     RowBox[{"Re", "[", 
      RowBox[{"tbi", "[", 
       RowBox[{"k", ",", "k"}], "]"}], "]"}], ",", 
     RowBox[{"Im", "[", 
      RowBox[{"tbi", "[", 
       RowBox[{"k", ",", "k"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0.00001", ",", "2.5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<k [arb. units]\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(t\), \(0\)]\) [arb. units]\>\""}], "}"}]}], 
   ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Re \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Im \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Re \!\(\*SubscriptBox[\(t\), \(0\)]\)(IB)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Im \!\(\*SubscriptBox[\(t\), \(0\)]\)(IB)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.7", ",", "0.7"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Black", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Brown", ",", " ", "DotDashed"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", " ", "Dotted"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.784554455563005*^9, 3.7845545587279587`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"fdf6762b-0af9-4f3a-9fae-cd0fd612a62d"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       TagBox[
        {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
         LineBox[CompressedData["
1:eJwV1nk81dkbB/DLVVSE0kILaqhsUcoSPt9S4coS2YbIOlkSRROjSNZsXe61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          "]]},
        Annotation[#, "Charting`Private`Tag$7313#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
         Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVl3c8V/8Xxz98JEolhbSVhhmlQfK6Uvb4IKtUVpREWWWEQqjszeeKr8yW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          "]]},
        Annotation[#, "Charting`Private`Tag$7313#2"]& ], 
       TagBox[
        {RGBColor[0.6, 0.4, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
         Dashing[{0, Small, Small, Small}], LineBox[CompressedData["
1:eJwV0X1QE3QYB3DEDkgaipdwKAXsYHDjPEoxtsb2LSnkRRgMX3CSxGCIg42X
E3LX4kVQeVmAaby1ycvYC6IULzKF5W3d5RuBCf0M6cW0acTLRYIn6EX9+uO5
733+e57v4yfJFUkdHRwcwuj8n7zG4T6vVx8JUo8d+5cZR5Ae5a7efjQaHtcz
7CzqHXe6k11jDkAwoddso/YuMRauzklQG/HYLZL63KYVwbPQI0jx/mN7GrXP
hRiXBVUuTP2layqoE/zGso4+LMB7ikZZD/XpuaLRPKciNLevT/2Netzss03O
VuL+iHXEK55gY/mNhiPxKlj3ZLSIqZPi819IC0rg2V3e20F96xXGG2/GloHl
mr70N7WsIE0S8stxOIfM7owSEqybvHR2a24FYuX1Sj11N3/d9eA1JxH7Eyf/
5QSCOZf+4KCAKvATLUt2arXC+RDLXI1ettYnJZFg6w8H6/2j1chSJ0Tfo1a0
vvTUV16H0WHNebuIYHlz8H311GcQiTewOXsJbsTtXa7RnYGz1XH+R+qm0hL3
mpyzaMzuS/l4HwHn8URE1erneJ1x4erIfgJlr8p0gtmMvOpbkyfFBDF2g61i
thm2b07ncQ4SbPa8M1U+0AJXg4o9Qz2kCmAcj9SgbD7sQewHBNVfClll67V4
VHjT+pxa/FCJ0kkt3p/JqjQeIni+ayy/WNaKdxzaDi+nEmTyVd9e9WqDJYi3
84sPCcb2uYsExW1wDTHVcNPo/6p42fxd7TBp9o9LJQROuu+fWbrb8Ul/f/ET
aoVFWhG+oQMD0+yVj9IJBH/VaXn3OhDI0PbIMggMLgHsYb4O/iyPhrvUbsyh
wbc7dGj5ysXAkRIU8YQRQ06dWPz9XW499a977Le52Z0oO2C++DN1pEKZcuV2
JzaF75a+lknQc8rtT06oHvLxpmuJ1B7tusLLTXr4kz6+krpkiOPI+UePpOal
8DPU0xOjteY0A9bCxm+lTpiXbAm7ZkDgdIRNQ33Zadk4yDZCvBiYWEPt6/tp
6Ft1RpyKiCqVUVdymbZLi0bktCTNcqkXROa4HckmfBeQwV2h+yXn7J4asJgg
lFd6m6itJx5khvp14eIqTxRJzes5vDaotgsm5tdhN+n9g3fnW7e86ILngpXB
oZ6bsT2xCc+jwfFp0hXa338xi6EF
          "]], LineBox[CompressedData["
1:eJwVzn0w23cAx3FS1R5ny6p1pDcPvc6z0hBPa/dh1aYrusqq6FGWjnXzMHf2
0DNMV8xDqvMwM+06Qh88hkZTkdiKEKJZw+/7M66q5eahmCvF0nqa/fG+978v
K/4XvGiGjo7O4a3+/+7IS9/LLWvhm32bGcCnUX5Rf9dMQy2SI5q1th/TKOnd
5d+fXYclQXiZbSQN5mLplGK5DvuDuIMG52jksSwyWvj12LOT3zEcTiM91qHt
t0MNmNpL++AsjdWiprCi6gYs1XHaB0NpfC33WMkyESFVttIXHkIj1sjPOeGF
CDH7EsbdT9N4yZqYaDzQCIuoaQ8Bj4aLs22zfXQjMs8u3xk4RaM2pOGU+UAj
Uq28ujiBW947rTnb65pgU7XA+fzolucEtUpFiiEqThZ7udHoOWeiCiwRo/KB
QL16kIZ+Ulip8qEYfm/m/N3qvOW99tRN5tUM1yNBqWyHLd/cbLzQ+B4qhmVa
k300ovL1niUqJRi9jR0sJo0bQm7DzLoEu6evlk0a0XgsyU35xO0+dJs35RJD
GmeeMs1CK+7D0D84jr+Dhr/L2zx824LPHm6kzm4QZPtFWUqbWtCezWkbWiPo
Dq2cZ0+3IIBVkaV6TeBzyS7POliK8deqCdkKQdpPcWHleVJYZzBzZUsEsmqR
DatDioSDRoN/LBJo2xaXi7RS+Mru9va8IHAf4CiMnFshMI7hD84TWCd+df7d
pE5shP/1kVkBgVPWW2n2gk4o58wE1FUCt+v1pWY3O+H8rKnvSj6Bb8+E+t/B
TvR+w+MwBAThlmc8m70ViJfN5D7PIijUuBs5MbrAec8/rzqFYN1FKzEv6IYq
fnSo8VMCPW5xv1FNN/y+kyjCYggMIlzm1jq6MVoqFOpGE5jmXLB6vNQNu3JH
1kk+AXtsKO/nUCV2ekmODIcTXCiQRjEtezCaaOwoDiIgC8kGDFEv3E6UWH/o
TVDub2z3hqoX541d2TWeBLE3a7msiV4c4MZ4bPMgYISNZLD3qnCrctpM5Erg
/ODwJv8HFUzlWvE/jgS5+TpLnZF9SNy2x4lhQQCHrCeZTDUMZgMC43S3vJnm
awUOahTZXvZM26QwOCph3TimhtBmRHhlnUJc4VSIJEWN6QCf2apXFMpeHR+Y
nFaDdfm04b0FCktKQyW3/U/UfFn+KGyMQvDd40N6XhpEjAvltb9T8H6k/6Ty
qAYnx21e/iinYD6nGHufp8EHLabDSa0UJt/xnU2P1aAkjidmSyhc/MVrY+1X
DXJSFVXF9RSup9vvX2b0Q7Vd1PX8GoX5QwUjuZ79uFXV0xdYSOE/4PLsfw==

          "]], 
         LineBox[{{0.2706704573108062, 0.30551520972275104`}, {
          0.3027815891543275, 0.29920906392271623`}, {0.3036164180818192, 
          0.29903364277418965`}, {0.3044512470093109, 0.29885767762168847`}, {
          0.3061209048642943, 0.298504127994078}, {0.30946022057426104`, 
          0.2977906419114869}, {0.31613885199419456`, 0.2963388683178109}, {
          0.3294961148340616, 0.29334236364196953`}, {0.3562106405137957, 
          0.2870297614075672}, {0.4086652926809525, 0.2737757272123963}, {
          0.45759453545171624`, 0.26086465938288883`}, {0.5106513994383319, 
          0.24661328917484482`}, {0.5601828540285546, 0.23320562794785532`}, {
          0.6087399094264659, 0.2200317985581334}, {0.6403836727131756, 
          0.21146109512538333`}}], 
         LineBox[{{0.6419780540907266, 0.21103002233720158`}, {
          0.7105838532575993, 0.19261071604713878`}, {0.7638707416908214, 
          0.1785833278331841}, {0.8161832309317321, 0.16517236205931912`}, {
          0.8649703107762498, 0.153072294319375}, {0.9129812766929555, 
          0.14161241860458273`}}], 
         LineBox[{{0.9145756580705064, 0.14124006684113563`}, {
          0.9672743035005958, 0.12924810558561511`}, {1.0207912163804242`, 
          0.11772582548174015`}, {1.073333730067941, 0.10708850617820805`}, {
          1.122350834359065, 0.09778626844992948}, {1.13241202105273, 
          0.0959520982854346}}], 
         LineBox[{{1.1340064024302812`, 0.09566380227994435}, {
          1.2251148759766237`, 0.08026663022751859}, {1.2737597928948952`, 
          0.07291116725439996}, {1.3265323310290185`, 0.06560449074480669}, {
          1.3757794597667488`, 0.059405591367301835`}, {1.429154209720331, 
          0.05334401558112881}, {1.4815545604816016`, 0.04803397219576768}, {
          1.5304295018464793`, 0.0436282570308804}, {1.583432064427209, 
          0.03941575432929198}, {1.6329092176115458`, 
          0.035981983169336595`}, {1.6814119716035711`, 
          0.03305039972609977}, {1.701454131347962, 0.031956842248190745`}}], 
         LineBox[CompressedData["
1:eJwB0QIu/SFib1JlAgAAACwAAAACAAAAM4UazK8/+z9lD0nnnVGgPwyn+nnF
h/w/6H2UGS7TnD9WvqGjLYv8P5dCll9Uypw/oNVIzZWO/D/3pxADgcGcPzQE
lyBmlfw/iFv0Ve2vnD9bYTPHBqP8P7xrEtQRjZw/qhtsFEi+/D8PHhB2h0ic
P0eQ3a7K9Pw/GBZRbg/Emz+CecDjz2H9P2URAN7izJo/zAzESv5k/T9FT4Zo
BMaaPxWgx7EsaP0/bCZg0Sq/mj+oxs5/iW79PwfZ3DOGsZo/zhPdG0N7/T+C
+KD0dpaaPxqu+VO2lP0/Waq+Kj5hmj+z4jLEnMf9P+IwxJhR+pk/5EulpGkt
/j+L2w5T/jmZP6u0uxSIMP4/VEH7JWA0mT9yHdKEpjP+P+io5QrGLpk/AO/+
ZOM5/j+1sDgBniOZPxuSWCVdRv4/nPh/XX4NmT9S2AumUF/+P6f0f8L+4Zg/
wGRypzeR/j/SPf247Y2YP5t9P6oF9f4/zARt+QDxlz/abtW6Z/j+PzAZQ5zv
65c/GmBry8n7/j9b1IFY4uaXP5hCl+yNAv8/kpB0EdTclz+WB+8uFhD/P78r
6DLoyJc/kpGesyYr/z+N7luj0KGXP4ml/bxHYf8/n77Tzo1Wlz93zbvPic3/
P1xg464Xy5Y/tjquHbLQ/z9bYExEPMeWP/anoGva0/8/I8KCy2PDlj90goUH
K9r/Pw/BOaa7u5Y/cDdPP8zm/z9dCxtNjqyWP7RQcVcHAABABcujZL2Olj+t
ugTHSRkAQLhnnfUyVZY/n44rps5LAEC+9rU6/+mVP3qJZJ2ETQBAOtraborm
lT9WhJ2UOk8AQFjInHEY45U/DnoPg6ZSAEA4VhPYPNyVP35l819+WQBAGAW8
3KbOlT9cPLsZLmcAQPBvVmf9s5U/GupKjY2CAEC7cKXCoYCVPwnFMWkOngBA
4jr4w4dPlT9NiWEI
          "]], 
         LineBox[{{2.078770305517861, 0.020789564575890818`}, {
          2.0912979854232603`, 0.020623859328164105`}, {2.092118113740161, 
          0.020613268505283874`}, {2.093758370373962, 
          0.020592179128297777`}, {2.097038883641564, 
          0.020550365620372463`}, {2.1035999101767677`, 
          0.02046816913656687}, {2.1167219632471754`, 
          0.020309257600544358`}, {2.1429660693879913`, 
          0.02001148252363571}, {2.1919288722732295`, 0.01951517568734639}, {
          2.24501929637432, 0.01904029594820907}, {2.294584311079017, 
          0.018633050632241806`}, {2.296951487274487, 
          0.018614130870363725`}}], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAN7sxBGxjAkAO9zJIPwyTP75X6QjK
KgNAo9u36Q5Dkj8QDG4+iY8DQOXbTieQ2pE/tu9YGUuRA0DM4dCds9iRP1zT
Q/QMkwNAWF80sNbWkT+omhmqkJYDQEdfUqYb05E/PynFFZidA0B6rQ/IoMuR
P25GHO2mqwNAye2fZpe8kT/NgMqbxMcDQGASY3YynpE/cmS1dobJA0A9Ke9h
SJyRPxhIoFFIywNA3R4w2V2akT9kD3YHzM4DQG+JGGmHlpE//J0hc9PVA0AW
7bkC1Y6RPyy7eEri4wNAjkukwll/kT/SnmMlpOUDQE3iPzhofZE/eIJOAGbn
A0BwNTIzdnuRP8RJJLbp6gNA+XSqt5B3kT9b2M8h8fEDQPGLEvG/b5E/ALy6
/LLzA0AefoWHym2RP6afpdd09QNAPW2KoNRrkT/yZnuN+PgDQCmU/FjnZ5E/
mEpmaLr6A0DjqMX372WRPz4uUUN8/ANAYXPYF/hjkT/kETwePv4DQJGT5bj/
YZE/ivUm+f//A0A8vJ7aBmCRP9EBvJA=
          "]]},
        Annotation[#, "Charting`Private`Tag$7313#3"]& ], 
       TagBox[
        {RGBColor[1, 0.5, 0], AbsoluteThickness[1.6], Opacity[1.], 
         Dashing[{0, Small}], LineBox[CompressedData["
1:eJwBsQJO/SFib1JlAgAAACoAAAACAAAAO5e7shkU5T4QwtzjOHLnPWNIEYwz
dEk/k9Bmpma5sz410atYC0pZP1PM7f/jedM+HH+ndf7sYj+kqyJTqtPlPp4V
+T73NGk/uVbjCYtf8z4frEoI8HxvP9KGrbY3Qv4+UCHOaHTicj9s5ReOmcoF
P5Hsds1wBnY/RpUsoEauDT/Stx8ybSp5P77bTLhCZxM/EoPIlmlOfD8TNi5a
CJcYP1NOcftlcn8/fCD2i/xnHj/KDA0wMUuBP0nLHaHobSI/anJhYi/dgj94
fEBBMPolPwrYtZQtb4Q/8t+7UdXZKT+rPQrHKwGGP3MNUSzqDS4/7AizKygl
iT+lefd3ALwzP4xuB14mt4o/uqsOEDxYNj8t1FuQJEmMP5OQLXQjITk/bp8E
9SBtjz9T2uvlrzs/P4iCrJOPf5A/m5YIxF5HQT9YtdasjkiRP7E5PRyjCEM/
+Bor34zakj+k1JZ529NGP8hNVfiLo5M/18spgoveSD+YgH8Ri2yUP0vBMdtv
Aks/OObTQ4n+lT8KVlzFQZdPP3mxfKiFIpk/2tZtPy3/VD9K5KbBhOuZP5j8
mYwAblY/GhfR2oO0mj9uR+uop+pXP7p8JQ2CRpw/FO/hldMNWz/6R85xfmqf
P3EzVlme/mA/Zj18xb4ZoD+S12vrMO5hP85WEVI+fqA/VXkGUMjkYj+eiTtr
PUehP/9h9lrT5mQ/Pu+PnTvZoj/m8hkTEDxpP6YIJSq7PaM/rFyy85hhaj8O
Irq2OqKjP/8DmshQjWs/3lTkzzlrpD9kFPydifZtP3+6OAI4/aU/aiKNs9uE
cT/AheFmNCGpP8DHhkeJ+HY/O65nAyiOqT9O962Az7t3P7bW7Z8b+6k/KoQ6
ucZ/eD/s6sHywU+qP2ydQeVXGHk/4es5uQ==
          "]], LineBox[CompressedData["
1:eJwVxXs8EwgAB3CnlTuf3E3q5HFCnY88bvLKUL8eeuDKfVZKL88WF0WH6nrO
ms22sNkyTi3vlOW1MYRozCtsqqOPV5EopEt9kpK7++P7+ZoFR1KomhoaGh7/
+f/lAXH0GtNC1BKG3Xz550B8lzbW+EEC9+2tIsunF8E1XMWoDL6L02KfDGr6
JdDCrWtvuhfBRVeKM9o0hOt4kE6+LQYlwjXU5s84zBiOjpb8UgIicy4lSx0H
O5KlzIpaAvTsZuZY0lG4v+g3k+4SqCTrQr/tpiOzoJq9WFKKIFHOhsdEBgZr
5vdfHi7FsdIWN7PDDBipN1l8WlkGn+MfIM5jIPWT8sFkfBk6M8VkQ4d4cL0e
fX4UIEWbwW35dy5MtPj/2LYrVYpDZIq8OoaJJdEH0pofSqHYyI7LKWaCljHk
eI8sA9m2KNbZlIW6YvNFTlEyGHeqG6d9WfisoKqL8mWgBrrOf2WzcHpy4kS2
XjmEMVnLtk2xINUguRt7lSOB8MyZZ5yAt8v/0E6llWMwI1dywCsB4Rtm89lT
5cgo5h0SZiUgMInwLKq5AixxKO8N2BBn7yh6PV+BQ/d/OBJ5lI2+Cs6Fo45y
+KUvWvWQxca+IaKBX5Yca3636NrZzoa33U8UnK/E0Eh/Xsp2DhI8Ak2rSisx
OdjosT6EA6Vfzhv78Uq8SDmzZ9llDjbFreVa+FZBaz59RijjwLnbqVGHVI0L
ZxzkA/pcnMzfFDYRVA0r98i6+7Zc5J/zXtoqrIbb0jqyw1Yu9FcH7WXMVSOW
9uvseAQXs9FXX8w13YPnjfM33Wu4uLdihDB+uBanFtpXbPG5ikybFvOgbfWI
9Mn38A9JRE1qx/su/3oQ9q5Nvx2TiF6NR8qNZ+sR0Rm9ZxEzEbpPBo4bF9bj
lafB0/GCRNAvzpT1EBswZektvzWdiJBOk627+xuQF39jbDk9CRZRsSFu0Qr4
37LWqqpPhi1T95LVVQU81zMOXnmSDMfrd9MM8hTYqqXzKeZ1Mja3jHZ8/FsB
ktAiLFSbh8Om+1xkro1Y/TIztMSJhxSVs46tZhP0w/dra/F4mLebrTDhK/GX
78GZ3D18EHYI1Tp3lJAMxzddCeRD+4jd5JcHShwTFUTFnuBjJTvMrO+9EgML
8gEeiw/7571ckV8zvMbo0twaPsL4VYFE0xboTb8TmFul4PE/57Q1i1th/jFj
V4iuAJneemu/b2tFz5NacoaZAOF5hTsMR1txx8YwaGSdAJoH+hn2Rm2oy7YO
yqEIQKrfsBDMakMD3+qbPqEAnCSN94qAdhRM7741ZSQErJkD8cQOiAtMJyT2
1+BbtrOXQFbhFSUrrPmUCK5dSwZytqnQ3zu7L50ugslk4/MtFBWkJnpDYQIR
Xv68eYIWrkKpjrpqQSbC2XTy1y83VLD52J60eFaE6zSrNR801aDO1H0hX0zD
G3d+P8dFDR4z2WGvIg3/AkF7DVA=
          "]], LineBox[CompressedData["
1:eJwV1nk8VtkfB3AiIkOMtShEIi1CKfKZRiFUQpZKiZRky9aGmKYwtiZjrM/z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          "]], 
         LineBox[{{0.6419780540907266, 0.029023251559678057`}, {
          0.7105838532575993, 0.02674522573685329}, {0.7638707416908214, 
          0.024736580795406107`}, {0.8161832309317321, 
          0.022633549035366893`}, {0.8649703107762498, 
          0.020614817794341607`}, {0.9129812766929555, 
          0.018626373221222188`}}], 
         LineBox[{{0.9145756580705064, 0.01856085095541956}, {
          0.9672743035005958, 0.016431589634332465`}, {1.0207912163804242`, 
          0.014372880304611892`}, {1.073333730067941, 
          0.012488626021447171`}, {1.122350834359065, 
          0.010873547339632285`}, {1.13241202105273, 0.01056018701422437}}], 
         LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAY0i+5eMk8j/xRFUg2YaFP2aaYg4S
mvM/HNn1vlBUgD/KF9fyUWH0P6mv7j1E+3s/U7Mt93k59T/ial/gSpB3P8hO
o1IxA/Y/c1Ta5KkEdD+urZDQmwb2Px4PTrV09nM/lQx+TgYK9j+6HpQiSehz
P2LKWErbEPY/PVcYxA7Mcz/7RQ5ChR72P5GuN7YMlHM/Lj15Mdk59j/mZvHr
zyVzP5UrTxCBcPY/WmV3AlhQcj9iCPvN0N32P3R2E3COwHA/xjz7VCvh9j/x
ROXZ2LRwPypx+9uF5PY/hgMikCupcD/x2fvpOuv2P46wStLpkXA/gKv8BaX4
9j+2MEVAyWNwP55O/j15E/c/KCb4WBAJcD/ZlAGuIUn3Py7f6zpIs24/UCEI
jnK09z+hrvzEDCRsP7TRZFKTt/c/lQZ+vtkRbD8XgsEWtLr3P6UCsHSz/2s/
3uJ6n/XA9z9NG8H9jNtrP2uk7bB4zfc/WD7t0NeTaz+GJ9PTfub3Pzjjle/G
Bms/vS2eGYsY+D8kbYfL3vVpPyo6NKWjfPg/qF5cLZX3Zz8GcxAKCID4P6Ir
GmcX52c/4qvsbmyD+D+3BDHDptZnP5odpTg1ivg/9IUKw+y1Zz8KARbMxpf4
P4DuKwYVdWc/6sf38umy+D/u2ZbFz/VmP6pVu0Aw6fg/v/uG4LcAZj8qcULc
vFX5P5L4EpCmOmQ/BiZ7fudY+T+ikAxVGS5kP+LasyASXPk/TfTW45UhZD+Z
RCVlZ2L5Pxnt/UasCGQ/CBgI7hFv+T9Jqdl8TddjP+W+zf9miPk/YGICd1x2
Yz+gDFkjEbv5P+InLYqDu2I/FqhvamUg+j+/TdjHs2BhP28yuxWAI/o/dkce
+J5WYT/IvAbBmib6P0aSHTCSTGE/etGdF9As+j8Dbq6ikDhhP976y8Q6Ofo/
dNNVAu0QYT+mTSgfEFL6PwATPjQfw2A/NvPg07qD+j+N3XQRRi1gP1Y+Uj0Q
5/o/lQ5F6hMvXj8oUR2Jbur6P9/HBcY5HV4/+WPo1Mzt+j/y+52nbwteP5yJ
fmyJ9Po/b0wKTQvoXT/i1KqbAgL7P3rVFtcAol0/b2sD+vQc+z8Z0Lut2hhd
P5GJnPcnOfs/KfBFim+NXD/w/58d
          "]], LineBox[CompressedData["
1:eJwVjnk0lQkAxb/RgkoZpIn20PB4JDE5mvvJiUpv9xYiiXiyxWhBabGbNJV1
EinyjE4qrSJHZams0zLp5UlRM6NMyyTyvu978+aPe+75nXPvuXfx1hjhNh2C
ICRa/e8r0sw6LkCNseeu8Q1R/qj/ZOpQ3qjG7xcXdUfZ++HwwR/r2m6rMZiQ
185e4ofNhqFr3jWr4VCzS6A28QPBvuqzsl2NFveJp9cmfOEZLkpoe6pGUZXV
m2utvuh58cudtx/UePuNddujLb4Y6tATOy2l0GejyPQqkeHqJod+mRWFxX6s
e+HHZEgflobts6bQkcjPKUiTwVpPkdBqT8HFxT5rVrQM0R5rS2VuFArMjKKS
IcN43cE/94opFBqnL1k/JMUMxURCSwaFT2OBxgErpZA0ni63+5kCc/25WGUt
RdmTdZ35RyicbDrdK18ghdPkwkWh+RSUt0YTTutKsSloRdvUcgri5XLrIqUE
1eaRJusaKZjtWuyWe0gCr6OqmgefKQzaPZUfVIpxVJHa6zhOge3jZSvrEUPZ
yNIpVlPIfRFptKpVjOiRBHGEDo2d7ZUWc2vFKNhgSk03pGG49UacIFuMocm8
9RwWDSeyS1LsJsahhKbB7iAaF1dMRPlV+aBjRvMGJoTGuvLaUeqUD2aXtV2y
ldN4bUPEKAp9UNXatT8rmkbYmsZ5Jhk+6DJWmXsk0RCtDa71DvWBWc1X0bU8
GtuloSTbygeXXzk2n2yj0WuamJl/TgRqpzOr/QGNqNBfrWwqRPDUdz3+tZNG
5g7mQ8tJEZT27lskj7V/uZ8/GR0RgdjHo2a9pFFRpZqqEyvCxjmRTikTNLxu
x4vtfxBhyPtsRbgdgz3GszNK24U4d6XeJNOBwWBDeAi7RYi4+Q9TK1cwcN7T
s7u5UQjiPRMyuIpB5OO1tpNqhTA/LrMM8GRwnX/G7UGREMLe6ZX8QAZ7udzD
iWFCNIXEKVyOafMG6jnu+kJkdGbOkeQx2CRx0eRMEoLrfCojvlDb77dMHqAF
6NPtCLtUwmC8Yr5DwScBxqotv2dVM0gJcBvw6BOA/bG3asFdBs9eWvhWXBSg
eB+qp4wyWLdfkOEbIIAy+snNsHEtC3R3DUoFMNsS0X5fzWBiSu3Gn4QCFK0p
fJejo8GNf9KLK7wEKNB9zzY11GDPq+1LOY4CHD9WetmKpYE3FTHtkp4AWWfp
Bq8gDQKm2kSU1vFxryC387cQDZKCOPeVV/jQy7Tuny7XIJebFjzvIh/p28Wa
7mgNnvlVuVyo5CPV/ry7bK8G2fpXuo3y+DhQ598qL9Sg5uh7QWcMH7s767uz
OjXYPBL61zsbPq651syv7dEgqoh3x2AZH18UZRHKRxpILcgzjkv5iD+UpstS
auDXoArJNOdjhwsPHW80kOwwyg6ewccVfqxUlyDIXlmdXrWKh/M3J7etn0uQ
RudeB8+O4mHjR3pEZaZlz/pvN4Ty8G7ZmEncPIJcZNranxbIg23+31tPLCRI
maHBTSMhD9UxXcywJUHWLeRdOKDdqrQocj7sSJBkmV2cYhIPp46wKru8CVKu
/3DJhzIuErNCSlI5BLmEvPEl6QQXktSSPFceQSLH33JWHhczE2elVAoJ0n9A
GuudwUXytn8Dk30JUtWapzSL5sLfrX4uO4wgh+WK6waruTAb3pCTc4ggHw5+
p5o2wMGXoZRUj1RtX1RjH6fk4OGLhqSvaQTZOu0P5YvHHGQ/YW/flkWQuy1G
zLvuc/C1ychr9VGC3L/3buzoZQ56C5XESAlB3sr1b5JncaDfsjx8ZilBhvbt
rNfR8n8/+IQ5
          "]], LineBox[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAA2cJwU1KhAEAfxUMtFX9NPzCrLHD6
ugBASKdD7OczTT/LEO9rqLwAQD8CxYknL00/ANxzYwTAAECAPpxStiVNP2py
fVK8xgBAm3w5XxETTT8+n5AwLNQAQMT8qo637kw/5vi27AvvAECMIENwlqlM
PzesA2XLJAFA5m93hjwsTD/ST3R/XCYBQBWUhy/RKEw/bPPkme0nAUCJPkUG
aSVMP6A6xs4PKwFAAW36KaIeTD8KyYg4VDEBQC0tPsc5EUw/3OUNDN09AUDH
JqZJ+vZLP4IfGLPuVgFAeHoJf6DESz/OkiwBEokBQLqVtt2KZ0s/pPrc68SK
AUBbFVkRjGRLP3tijdZ3jAFAtD3Gt49hSz8oMu6r3Y8BQPdjXEieW0s/g9Gv
VqmWAUD01bzo109LPzgQM6xApAFABxLFs7g4Sz+jjTlXb78BQI5/mZINDEs/
eIhGrcz1AUB4ZrCR+LdKPxj+7wRPWwJAeB09OxwnSj9nvfIZKGACQEG0AtNp
IEo/jyOerg==
          "]], LineBox[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAN7sxBGxjAkCZdkWU6BtKP75X6QjK
KgNA89Z+FOgDST8QDG4+iY8DQI+sb/hyZkg/tu9YGUuRA0BvyFQPjWNIP1zT
Q/QMkwNAaPC8saVgSD+omhmqkJYDQNBijJPSWkg/PynFFZidA0AyOCmlGk9I
P25GHO2mqwNAhyoL3GI3SD/NgMqbxMcDQEh0Ey/LBkg/cmS1dobJA0DiolJK
tANIPxhIoFFIywNARLp9y5sASD9kD3YHzM4DQHskzvtl+kc//J0hc9PVA0CM
kZX65u1HPyy7eEri4wNA6RrhrZrURz/SnmMlpOUDQMofVr1p0Uc/eIJOAGbn
A0Dz5hwlN85HP8RJJLbp6gNAHrWv+szHRz9b2M8h8fEDQEq+Farkukc/ALy6
/LLzA0DjtCxoprdHP6afpdd09QNAyVQMeWa0Rz/yZnuN+PgDQGhKoJDhrUc/
mEpmaLr6A0DjQxqWnKpHPz4uUUN8/ANAiivo61WnRz/kETwePv4DQE8TdZEN
pEc/ivUm+f//A0DkVy+Gw6BHP/WetLY=
          "]]},
        Annotation[#, 
         "Charting`Private`Tag$7313#4"]& ], {}}, {{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}}, {}}, InsetBox[
     TemplateBox[{
      StyleBox["\"Re \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)\"", 
        FontFamily -> "Times", FontSize -> 12, StripOnInput -> False],
       StyleBox[
       "\"Im \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False],StyleBox[
       "\"Re \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)(IB)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False],StyleBox[
       "\"Im \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)(IB)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False]},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Dashing[{0, Small, Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Dashing[{0, Small, Small, Small}]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{0, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{0, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.6, 0.4, 0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.6`", ",", "0.4`", ",", "0.2`"}], "]"}], 
                    NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.6, 0.4, 0.2]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.6, 0.4, 0.2], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"\"Column\"", ",", 
                 RowBox[{"{", 
                   RowBox[{"Automatic", ",", "5"}], "}"}]}], "}"}]}]}], 
         "]"}]& )], Scaled[{0.7, 0.7}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{Automatic, Automatic},
   BaseStyle->{FontFamily -> "Times New Roman", FontSize -> 14},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\) [arb. units]\"", 
       TraditionalForm], None}, {
      FormBox["\"k [arb. units]\"", TraditionalForm], None}},
   FrameTicks->FrontEndValueCache[{{Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.08, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.06, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.04, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.02, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.02, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.04, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.06, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.08, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.12, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.14, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.16, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.18, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.22, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.24, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.26, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.28, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.32, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.34, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.36, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.38, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}}],
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{All, All},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           GrayLevel[0]], 
          Line[CompressedData["
1:eJwV1nk81dkbB/DLVVSE0kILaqhsUcoSPt9S4coS2YbIOlkSRROjSNZsXe61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           "]]}, 
         "Charting`Private`Tag$7313#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVl3c8V/8Xxz98JEolhbSVhhmlQfK6Uvb4IKtUVpREWWWEQqjszeeKr8yW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           "]]}, 
         "Charting`Private`Tag$7313#2"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0.6, 0.4, 0.2], 
           Dashing[{0, Small, Small, Small}]], 
          Line[CompressedData["
1:eJwV0X1QE3QYB3DEDkgaipdwKAXsYHDjPEoxtsb2LSnkRRgMX3CSxGCIg42X
E3LX4kVQeVmAaby1ycvYC6IULzKF5W3d5RuBCf0M6cW0acTLRYIn6EX9+uO5
733+e57v4yfJFUkdHRwcwuj8n7zG4T6vVx8JUo8d+5cZR5Ae5a7efjQaHtcz
7CzqHXe6k11jDkAwoddso/YuMRauzklQG/HYLZL63KYVwbPQI0jx/mN7GrXP
hRiXBVUuTP2layqoE/zGso4+LMB7ikZZD/XpuaLRPKciNLevT/2Netzss03O
VuL+iHXEK55gY/mNhiPxKlj3ZLSIqZPi819IC0rg2V3e20F96xXGG2/GloHl
mr70N7WsIE0S8stxOIfM7owSEqybvHR2a24FYuX1Sj11N3/d9eA1JxH7Eyf/
5QSCOZf+4KCAKvATLUt2arXC+RDLXI1ettYnJZFg6w8H6/2j1chSJ0Tfo1a0
vvTUV16H0WHNebuIYHlz8H311GcQiTewOXsJbsTtXa7RnYGz1XH+R+qm0hL3
mpyzaMzuS/l4HwHn8URE1erneJ1x4erIfgJlr8p0gtmMvOpbkyfFBDF2g61i
thm2b07ncQ4SbPa8M1U+0AJXg4o9Qz2kCmAcj9SgbD7sQewHBNVfClll67V4
VHjT+pxa/FCJ0kkt3p/JqjQeIni+ayy/WNaKdxzaDi+nEmTyVd9e9WqDJYi3
84sPCcb2uYsExW1wDTHVcNPo/6p42fxd7TBp9o9LJQROuu+fWbrb8Ul/f/ET
aoVFWhG+oQMD0+yVj9IJBH/VaXn3OhDI0PbIMggMLgHsYb4O/iyPhrvUbsyh
wbc7dGj5ysXAkRIU8YQRQ06dWPz9XW499a977Le52Z0oO2C++DN1pEKZcuV2
JzaF75a+lknQc8rtT06oHvLxpmuJ1B7tusLLTXr4kz6+krpkiOPI+UePpOal
8DPU0xOjteY0A9bCxm+lTpiXbAm7ZkDgdIRNQ33Zadk4yDZCvBiYWEPt6/tp
6Ft1RpyKiCqVUVdymbZLi0bktCTNcqkXROa4HckmfBeQwV2h+yXn7J4asJgg
lFd6m6itJx5khvp14eIqTxRJzes5vDaotgsm5tdhN+n9g3fnW7e86ILngpXB
oZ6bsT2xCc+jwfFp0hXa338xi6EF
           "]], 
          Line[CompressedData["
1:eJwVzn0w23cAx3FS1R5ny6p1pDcPvc6z0hBPa/dh1aYrusqq6FGWjnXzMHf2
0DNMV8xDqvMwM+06Qh88hkZTkdiKEKJZw+/7M66q5eahmCvF0nqa/fG+978v
K/4XvGiGjo7O4a3+/+7IS9/LLWvhm32bGcCnUX5Rf9dMQy2SI5q1th/TKOnd
5d+fXYclQXiZbSQN5mLplGK5DvuDuIMG52jksSwyWvj12LOT3zEcTiM91qHt
t0MNmNpL++AsjdWiprCi6gYs1XHaB0NpfC33WMkyESFVttIXHkIj1sjPOeGF
CDH7EsbdT9N4yZqYaDzQCIuoaQ8Bj4aLs22zfXQjMs8u3xk4RaM2pOGU+UAj
Uq28ujiBW947rTnb65pgU7XA+fzolucEtUpFiiEqThZ7udHoOWeiCiwRo/KB
QL16kIZ+Ulip8qEYfm/m/N3qvOW99tRN5tUM1yNBqWyHLd/cbLzQ+B4qhmVa
k300ovL1niUqJRi9jR0sJo0bQm7DzLoEu6evlk0a0XgsyU35xO0+dJs35RJD
GmeeMs1CK+7D0D84jr+Dhr/L2zx824LPHm6kzm4QZPtFWUqbWtCezWkbWiPo
Dq2cZ0+3IIBVkaV6TeBzyS7POliK8deqCdkKQdpPcWHleVJYZzBzZUsEsmqR
DatDioSDRoN/LBJo2xaXi7RS+Mru9va8IHAf4CiMnFshMI7hD84TWCd+df7d
pE5shP/1kVkBgVPWW2n2gk4o58wE1FUCt+v1pWY3O+H8rKnvSj6Bb8+E+t/B
TvR+w+MwBAThlmc8m70ViJfN5D7PIijUuBs5MbrAec8/rzqFYN1FKzEv6IYq
fnSo8VMCPW5xv1FNN/y+kyjCYggMIlzm1jq6MVoqFOpGE5jmXLB6vNQNu3JH
1kk+AXtsKO/nUCV2ekmODIcTXCiQRjEtezCaaOwoDiIgC8kGDFEv3E6UWH/o
TVDub2z3hqoX541d2TWeBLE3a7msiV4c4MZ4bPMgYISNZLD3qnCrctpM5Erg
/ODwJv8HFUzlWvE/jgS5+TpLnZF9SNy2x4lhQQCHrCeZTDUMZgMC43S3vJnm
awUOahTZXvZM26QwOCph3TimhtBmRHhlnUJc4VSIJEWN6QCf2apXFMpeHR+Y
nFaDdfm04b0FCktKQyW3/U/UfFn+KGyMQvDd40N6XhpEjAvltb9T8H6k/6Ty
qAYnx21e/iinYD6nGHufp8EHLabDSa0UJt/xnU2P1aAkjidmSyhc/MVrY+1X
DXJSFVXF9RSup9vvX2b0Q7Vd1PX8GoX5QwUjuZ79uFXV0xdYSOE/4PLsfw==

           "]], 
          
          Line[{{0.2706704573108062, 0.30551520972275104`}, {
           0.3027815891543275, 0.29920906392271623`}, {0.3036164180818192, 
           0.29903364277418965`}, {0.3044512470093109, 
           0.29885767762168847`}, {0.3061209048642943, 0.298504127994078}, {
           0.30946022057426104`, 0.2977906419114869}, {0.31613885199419456`, 
           0.2963388683178109}, {0.3294961148340616, 0.29334236364196953`}, {
           0.3562106405137957, 0.2870297614075672}, {0.4086652926809525, 
           0.2737757272123963}, {0.45759453545171624`, 
           0.26086465938288883`}, {0.5106513994383319, 
           0.24661328917484482`}, {0.5601828540285546, 
           0.23320562794785532`}, {0.6087399094264659, 0.2200317985581334}, {
           0.6403836727131756, 0.21146109512538333`}}], 
          
          Line[{{0.6419780540907266, 0.21103002233720158`}, {
           0.7105838532575993, 0.19261071604713878`}, {0.7638707416908214, 
           0.1785833278331841}, {0.8161832309317321, 0.16517236205931912`}, {
           0.8649703107762498, 0.153072294319375}, {0.9129812766929555, 
           0.14161241860458273`}}], 
          
          Line[{{0.9145756580705064, 0.14124006684113563`}, {
           0.9672743035005958, 0.12924810558561511`}, {1.0207912163804242`, 
           0.11772582548174015`}, {1.073333730067941, 0.10708850617820805`}, {
           1.122350834359065, 0.09778626844992948}, {1.13241202105273, 
           0.0959520982854346}}], 
          
          Line[{{1.1340064024302812`, 0.09566380227994435}, {
           1.2251148759766237`, 0.08026663022751859}, {1.2737597928948952`, 
           0.07291116725439996}, {1.3265323310290185`, 0.06560449074480669}, {
           1.3757794597667488`, 0.059405591367301835`}, {1.429154209720331, 
           0.05334401558112881}, {1.4815545604816016`, 0.04803397219576768}, {
           1.5304295018464793`, 0.0436282570308804}, {1.583432064427209, 
           0.03941575432929198}, {1.6329092176115458`, 
           0.035981983169336595`}, {1.6814119716035711`, 
           0.03305039972609977}, {1.701454131347962, 0.031956842248190745`}}], 
          Line[CompressedData["
1:eJwB0QIu/SFib1JlAgAAACwAAAACAAAAM4UazK8/+z9lD0nnnVGgPwyn+nnF
h/w/6H2UGS7TnD9WvqGjLYv8P5dCll9Uypw/oNVIzZWO/D/3pxADgcGcPzQE
lyBmlfw/iFv0Ve2vnD9bYTPHBqP8P7xrEtQRjZw/qhtsFEi+/D8PHhB2h0ic
P0eQ3a7K9Pw/GBZRbg/Emz+CecDjz2H9P2URAN7izJo/zAzESv5k/T9FT4Zo
BMaaPxWgx7EsaP0/bCZg0Sq/mj+oxs5/iW79PwfZ3DOGsZo/zhPdG0N7/T+C
+KD0dpaaPxqu+VO2lP0/Waq+Kj5hmj+z4jLEnMf9P+IwxJhR+pk/5EulpGkt
/j+L2w5T/jmZP6u0uxSIMP4/VEH7JWA0mT9yHdKEpjP+P+io5QrGLpk/AO/+
ZOM5/j+1sDgBniOZPxuSWCVdRv4/nPh/XX4NmT9S2AumUF/+P6f0f8L+4Zg/
wGRypzeR/j/SPf247Y2YP5t9P6oF9f4/zARt+QDxlz/abtW6Z/j+PzAZQ5zv
65c/GmBry8n7/j9b1IFY4uaXP5hCl+yNAv8/kpB0EdTclz+WB+8uFhD/P78r
6DLoyJc/kpGesyYr/z+N7luj0KGXP4ml/bxHYf8/n77Tzo1Wlz93zbvPic3/
P1xg464Xy5Y/tjquHbLQ/z9bYExEPMeWP/anoGva0/8/I8KCy2PDlj90goUH
K9r/Pw/BOaa7u5Y/cDdPP8zm/z9dCxtNjqyWP7RQcVcHAABABcujZL2Olj+t
ugTHSRkAQLhnnfUyVZY/n44rps5LAEC+9rU6/+mVP3qJZJ2ETQBAOtraborm
lT9WhJ2UOk8AQFjInHEY45U/DnoPg6ZSAEA4VhPYPNyVP35l819+WQBAGAW8
3KbOlT9cPLsZLmcAQPBvVmf9s5U/GupKjY2CAEC7cKXCoYCVPwnFMWkOngBA
4jr4w4dPlT9NiWEI
           "]], 
          
          Line[{{2.078770305517861, 0.020789564575890818`}, {
           2.0912979854232603`, 0.020623859328164105`}, {2.092118113740161, 
           0.020613268505283874`}, {2.093758370373962, 
           0.020592179128297777`}, {2.097038883641564, 
           0.020550365620372463`}, {2.1035999101767677`, 
           0.02046816913656687}, {2.1167219632471754`, 
           0.020309257600544358`}, {2.1429660693879913`, 
           0.02001148252363571}, {2.1919288722732295`, 0.01951517568734639}, {
           2.24501929637432, 0.01904029594820907}, {2.294584311079017, 
           0.018633050632241806`}, {2.296951487274487, 
           0.018614130870363725`}}], 
          Line[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAN7sxBGxjAkAO9zJIPwyTP75X6QjK
KgNAo9u36Q5Dkj8QDG4+iY8DQOXbTieQ2pE/tu9YGUuRA0DM4dCds9iRP1zT
Q/QMkwNAWF80sNbWkT+omhmqkJYDQEdfUqYb05E/PynFFZidA0B6rQ/IoMuR
P25GHO2mqwNAye2fZpe8kT/NgMqbxMcDQGASY3YynpE/cmS1dobJA0A9Ke9h
SJyRPxhIoFFIywNA3R4w2V2akT9kD3YHzM4DQG+JGGmHlpE//J0hc9PVA0AW
7bkC1Y6RPyy7eEri4wNAjkukwll/kT/SnmMlpOUDQE3iPzhofZE/eIJOAGbn
A0BwNTIzdnuRP8RJJLbp6gNA+XSqt5B3kT9b2M8h8fEDQPGLEvG/b5E/ALy6
/LLzA0AefoWHym2RP6afpdd09QNAPW2KoNRrkT/yZnuN+PgDQCmU/FjnZ5E/
mEpmaLr6A0DjqMX372WRPz4uUUN8/ANAYXPYF/hjkT/kETwePv4DQJGT5bj/
YZE/ivUm+f//A0A8vJ7aBmCRP9EBvJA=
           "]]}, 
         "Charting`Private`Tag$7313#3"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0.5, 0], 
           Dashing[{0, Small}]], 
          Line[CompressedData["
1:eJwBsQJO/SFib1JlAgAAACoAAAACAAAAO5e7shkU5T4QwtzjOHLnPWNIEYwz
dEk/k9Bmpma5sz410atYC0pZP1PM7f/jedM+HH+ndf7sYj+kqyJTqtPlPp4V
+T73NGk/uVbjCYtf8z4frEoI8HxvP9KGrbY3Qv4+UCHOaHTicj9s5ReOmcoF
P5Hsds1wBnY/RpUsoEauDT/Stx8ybSp5P77bTLhCZxM/EoPIlmlOfD8TNi5a
CJcYP1NOcftlcn8/fCD2i/xnHj/KDA0wMUuBP0nLHaHobSI/anJhYi/dgj94
fEBBMPolPwrYtZQtb4Q/8t+7UdXZKT+rPQrHKwGGP3MNUSzqDS4/7AizKygl
iT+lefd3ALwzP4xuB14mt4o/uqsOEDxYNj8t1FuQJEmMP5OQLXQjITk/bp8E
9SBtjz9T2uvlrzs/P4iCrJOPf5A/m5YIxF5HQT9YtdasjkiRP7E5PRyjCEM/
+Bor34zakj+k1JZ529NGP8hNVfiLo5M/18spgoveSD+YgH8Ri2yUP0vBMdtv
Aks/OObTQ4n+lT8KVlzFQZdPP3mxfKiFIpk/2tZtPy3/VD9K5KbBhOuZP5j8
mYwAblY/GhfR2oO0mj9uR+uop+pXP7p8JQ2CRpw/FO/hldMNWz/6R85xfmqf
P3EzVlme/mA/Zj18xb4ZoD+S12vrMO5hP85WEVI+fqA/VXkGUMjkYj+eiTtr
PUehP/9h9lrT5mQ/Pu+PnTvZoj/m8hkTEDxpP6YIJSq7PaM/rFyy85hhaj8O
Irq2OqKjP/8DmshQjWs/3lTkzzlrpD9kFPydifZtP3+6OAI4/aU/aiKNs9uE
cT/AheFmNCGpP8DHhkeJ+HY/O65nAyiOqT9O962Az7t3P7bW7Z8b+6k/KoQ6
ucZ/eD/s6sHywU+qP2ydQeVXGHk/4es5uQ==
           "]], 
          Line[CompressedData["
1:eJwVxXs8EwgAB3CnlTuf3E3q5HFCnY88bvLKUL8eeuDKfVZKL88WF0WH6nrO
ms22sNkyTi3vlOW1MYRozCtsqqOPV5EopEt9kpK7++P7+ZoFR1KomhoaGh7/
+f/lAXH0GtNC1BKG3Xz550B8lzbW+EEC9+2tIsunF8E1XMWoDL6L02KfDGr6
JdDCrWtvuhfBRVeKM9o0hOt4kE6+LQYlwjXU5s84zBiOjpb8UgIicy4lSx0H
O5KlzIpaAvTsZuZY0lG4v+g3k+4SqCTrQr/tpiOzoJq9WFKKIFHOhsdEBgZr
5vdfHi7FsdIWN7PDDBipN1l8WlkGn+MfIM5jIPWT8sFkfBk6M8VkQ4d4cL0e
fX4UIEWbwW35dy5MtPj/2LYrVYpDZIq8OoaJJdEH0pofSqHYyI7LKWaCljHk
eI8sA9m2KNbZlIW6YvNFTlEyGHeqG6d9WfisoKqL8mWgBrrOf2WzcHpy4kS2
XjmEMVnLtk2xINUguRt7lSOB8MyZZ5yAt8v/0E6llWMwI1dywCsB4Rtm89lT
5cgo5h0SZiUgMInwLKq5AixxKO8N2BBn7yh6PV+BQ/d/OBJ5lI2+Cs6Fo45y
+KUvWvWQxca+IaKBX5Yca3636NrZzoa33U8UnK/E0Eh/Xsp2DhI8Ak2rSisx
OdjosT6EA6Vfzhv78Uq8SDmzZ9llDjbFreVa+FZBaz59RijjwLnbqVGHVI0L
ZxzkA/pcnMzfFDYRVA0r98i6+7Zc5J/zXtoqrIbb0jqyw1Yu9FcH7WXMVSOW
9uvseAQXs9FXX8w13YPnjfM33Wu4uLdihDB+uBanFtpXbPG5ikybFvOgbfWI
9Mn38A9JRE1qx/su/3oQ9q5Nvx2TiF6NR8qNZ+sR0Rm9ZxEzEbpPBo4bF9bj
lafB0/GCRNAvzpT1EBswZektvzWdiJBOk627+xuQF39jbDk9CRZRsSFu0Qr4
37LWqqpPhi1T95LVVQU81zMOXnmSDMfrd9MM8hTYqqXzKeZ1Mja3jHZ8/FsB
ktAiLFSbh8Om+1xkro1Y/TIztMSJhxSVs46tZhP0w/dra/F4mLebrTDhK/GX
78GZ3D18EHYI1Tp3lJAMxzddCeRD+4jd5JcHShwTFUTFnuBjJTvMrO+9EgML
8gEeiw/7571ckV8zvMbo0twaPsL4VYFE0xboTb8TmFul4PE/57Q1i1th/jFj
V4iuAJneemu/b2tFz5NacoaZAOF5hTsMR1txx8YwaGSdAJoH+hn2Rm2oy7YO
yqEIQKrfsBDMakMD3+qbPqEAnCSN94qAdhRM7741ZSQErJkD8cQOiAtMJyT2
1+BbtrOXQFbhFSUrrPmUCK5dSwZytqnQ3zu7L50ugslk4/MtFBWkJnpDYQIR
Xv68eYIWrkKpjrpqQSbC2XTy1y83VLD52J60eFaE6zSrNR801aDO1H0hX0zD
G3d+P8dFDR4z2WGvIg3/AkF7DVA=
           "]], 
          Line[CompressedData["
1:eJwV1nk8VtkfB3AiIkOMtShEIi1CKfKZRiFUQpZKiZRky9aGmKYwtiZjrM/z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           "]], 
          
          Line[{{0.6419780540907266, 0.029023251559678057`}, {
           0.7105838532575993, 0.02674522573685329}, {0.7638707416908214, 
           0.024736580795406107`}, {0.8161832309317321, 
           0.022633549035366893`}, {0.8649703107762498, 
           0.020614817794341607`}, {0.9129812766929555, 
           0.018626373221222188`}}], 
          
          Line[{{0.9145756580705064, 0.01856085095541956}, {
           0.9672743035005958, 0.016431589634332465`}, {1.0207912163804242`, 
           0.014372880304611892`}, {1.073333730067941, 
           0.012488626021447171`}, {1.122350834359065, 
           0.010873547339632285`}, {1.13241202105273, 0.01056018701422437}}], 
          
          Line[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAY0i+5eMk8j/xRFUg2YaFP2aaYg4S
mvM/HNn1vlBUgD/KF9fyUWH0P6mv7j1E+3s/U7Mt93k59T/ial/gSpB3P8hO
o1IxA/Y/c1Ta5KkEdD+urZDQmwb2Px4PTrV09nM/lQx+TgYK9j+6HpQiSehz
P2LKWErbEPY/PVcYxA7Mcz/7RQ5ChR72P5GuN7YMlHM/Lj15Mdk59j/mZvHr
zyVzP5UrTxCBcPY/WmV3AlhQcj9iCPvN0N32P3R2E3COwHA/xjz7VCvh9j/x
ROXZ2LRwPypx+9uF5PY/hgMikCupcD/x2fvpOuv2P46wStLpkXA/gKv8BaX4
9j+2MEVAyWNwP55O/j15E/c/KCb4WBAJcD/ZlAGuIUn3Py7f6zpIs24/UCEI
jnK09z+hrvzEDCRsP7TRZFKTt/c/lQZ+vtkRbD8XgsEWtLr3P6UCsHSz/2s/
3uJ6n/XA9z9NG8H9jNtrP2uk7bB4zfc/WD7t0NeTaz+GJ9PTfub3Pzjjle/G
Bms/vS2eGYsY+D8kbYfL3vVpPyo6NKWjfPg/qF5cLZX3Zz8GcxAKCID4P6Ir
GmcX52c/4qvsbmyD+D+3BDHDptZnP5odpTg1ivg/9IUKw+y1Zz8KARbMxpf4
P4DuKwYVdWc/6sf38umy+D/u2ZbFz/VmP6pVu0Aw6fg/v/uG4LcAZj8qcULc
vFX5P5L4EpCmOmQ/BiZ7fudY+T+ikAxVGS5kP+LasyASXPk/TfTW45UhZD+Z
RCVlZ2L5Pxnt/UasCGQ/CBgI7hFv+T9Jqdl8TddjP+W+zf9miPk/YGICd1x2
Yz+gDFkjEbv5P+InLYqDu2I/FqhvamUg+j+/TdjHs2BhP28yuxWAI/o/dkce
+J5WYT/IvAbBmib6P0aSHTCSTGE/etGdF9As+j8Dbq6ikDhhP976y8Q6Ofo/
dNNVAu0QYT+mTSgfEFL6PwATPjQfw2A/NvPg07qD+j+N3XQRRi1gP1Y+Uj0Q
5/o/lQ5F6hMvXj8oUR2Jbur6P9/HBcY5HV4/+WPo1Mzt+j/y+52nbwteP5yJ
fmyJ9Po/b0wKTQvoXT/i1KqbAgL7P3rVFtcAol0/b2sD+vQc+z8Z0Lut2hhd
P5GJnPcnOfs/KfBFim+NXD/w/58d
           "]], 
          Line[CompressedData["
1:eJwVjnk0lQkAxb/RgkoZpIn20PB4JDE5mvvJiUpv9xYiiXiyxWhBabGbNJV1
EinyjE4qrSJHZams0zLp5UlRM6NMyyTyvu978+aPe+75nXPvuXfx1hjhNh2C
ICRa/e8r0sw6LkCNseeu8Q1R/qj/ZOpQ3qjG7xcXdUfZ++HwwR/r2m6rMZiQ
185e4ofNhqFr3jWr4VCzS6A28QPBvuqzsl2NFveJp9cmfOEZLkpoe6pGUZXV
m2utvuh58cudtx/UePuNddujLb4Y6tATOy2l0GejyPQqkeHqJod+mRWFxX6s
e+HHZEgflobts6bQkcjPKUiTwVpPkdBqT8HFxT5rVrQM0R5rS2VuFArMjKKS
IcN43cE/94opFBqnL1k/JMUMxURCSwaFT2OBxgErpZA0ni63+5kCc/25WGUt
RdmTdZ35RyicbDrdK18ghdPkwkWh+RSUt0YTTutKsSloRdvUcgri5XLrIqUE
1eaRJusaKZjtWuyWe0gCr6OqmgefKQzaPZUfVIpxVJHa6zhOge3jZSvrEUPZ
yNIpVlPIfRFptKpVjOiRBHGEDo2d7ZUWc2vFKNhgSk03pGG49UacIFuMocm8
9RwWDSeyS1LsJsahhKbB7iAaF1dMRPlV+aBjRvMGJoTGuvLaUeqUD2aXtV2y
ldN4bUPEKAp9UNXatT8rmkbYmsZ5Jhk+6DJWmXsk0RCtDa71DvWBWc1X0bU8
GtuloSTbygeXXzk2n2yj0WuamJl/TgRqpzOr/QGNqNBfrWwqRPDUdz3+tZNG
5g7mQ8tJEZT27lskj7V/uZ8/GR0RgdjHo2a9pFFRpZqqEyvCxjmRTikTNLxu
x4vtfxBhyPtsRbgdgz3GszNK24U4d6XeJNOBwWBDeAi7RYi4+Q9TK1cwcN7T
s7u5UQjiPRMyuIpB5OO1tpNqhTA/LrMM8GRwnX/G7UGREMLe6ZX8QAZ7udzD
iWFCNIXEKVyOafMG6jnu+kJkdGbOkeQx2CRx0eRMEoLrfCojvlDb77dMHqAF
6NPtCLtUwmC8Yr5DwScBxqotv2dVM0gJcBvw6BOA/bG3asFdBs9eWvhWXBSg
eB+qp4wyWLdfkOEbIIAy+snNsHEtC3R3DUoFMNsS0X5fzWBiSu3Gn4QCFK0p
fJejo8GNf9KLK7wEKNB9zzY11GDPq+1LOY4CHD9WetmKpYE3FTHtkp4AWWfp
Bq8gDQKm2kSU1vFxryC387cQDZKCOPeVV/jQy7Tuny7XIJebFjzvIh/p28Wa
7mgNnvlVuVyo5CPV/ry7bK8G2fpXuo3y+DhQ598qL9Sg5uh7QWcMH7s767uz
OjXYPBL61zsbPq651syv7dEgqoh3x2AZH18UZRHKRxpILcgzjkv5iD+UpstS
auDXoArJNOdjhwsPHW80kOwwyg6ewccVfqxUlyDIXlmdXrWKh/M3J7etn0uQ
RudeB8+O4mHjR3pEZaZlz/pvN4Ty8G7ZmEncPIJcZNranxbIg23+31tPLCRI
maHBTSMhD9UxXcywJUHWLeRdOKDdqrQocj7sSJBkmV2cYhIPp46wKru8CVKu
/3DJhzIuErNCSlI5BLmEvPEl6QQXktSSPFceQSLH33JWHhczE2elVAoJ0n9A
GuudwUXytn8Dk30JUtWapzSL5sLfrX4uO4wgh+WK6waruTAb3pCTc4ggHw5+
p5o2wMGXoZRUj1RtX1RjH6fk4OGLhqSvaQTZOu0P5YvHHGQ/YW/flkWQuy1G
zLvuc/C1ychr9VGC3L/3buzoZQ56C5XESAlB3sr1b5JncaDfsjx8ZilBhvbt
rNfR8n8/+IQ5
           "]], 
          Line[CompressedData["
1:eJwBkQFu/iFib1JlAgAAABgAAAACAAAA2cJwU1KhAEAfxUMtFX9NPzCrLHD6
ugBASKdD7OczTT/LEO9rqLwAQD8CxYknL00/ANxzYwTAAECAPpxStiVNP2py
fVK8xgBAm3w5XxETTT8+n5AwLNQAQMT8qo637kw/5vi27AvvAECMIENwlqlM
PzesA2XLJAFA5m93hjwsTD/ST3R/XCYBQBWUhy/RKEw/bPPkme0nAUCJPkUG
aSVMP6A6xs4PKwFAAW36KaIeTD8KyYg4VDEBQC0tPsc5EUw/3OUNDN09AUDH
JqZJ+vZLP4IfGLPuVgFAeHoJf6DESz/OkiwBEokBQLqVtt2KZ0s/pPrc68SK
AUBbFVkRjGRLP3tijdZ3jAFAtD3Gt49hSz8oMu6r3Y8BQPdjXEieW0s/g9Gv
VqmWAUD01bzo109LPzgQM6xApAFABxLFs7g4Sz+jjTlXb78BQI5/mZINDEs/
eIhGrcz1AUB4ZrCR+LdKPxj+7wRPWwJAeB09OxwnSj9nvfIZKGACQEG0AtNp
IEo/jyOerg==
           "]], 
          Line[CompressedData["
1:eJwBoQFe/iFib1JlAgAAABkAAAACAAAAN7sxBGxjAkCZdkWU6BtKP75X6QjK
KgNA89Z+FOgDST8QDG4+iY8DQI+sb/hyZkg/tu9YGUuRA0BvyFQPjWNIP1zT
Q/QMkwNAaPC8saVgSD+omhmqkJYDQNBijJPSWkg/PynFFZidA0AyOCmlGk9I
P25GHO2mqwNAhyoL3GI3SD/NgMqbxMcDQEh0Ey/LBkg/cmS1dobJA0DiolJK
tANIPxhIoFFIywNARLp9y5sASD9kD3YHzM4DQHskzvtl+kc//J0hc9PVA0CM
kZX65u1HPyy7eEri4wNA6RrhrZrURz/SnmMlpOUDQMofVr1p0Uc/eIJOAGbn
A0Dz5hwlN85HP8RJJLbp6gNAHrWv+szHRz9b2M8h8fEDQEq+Farkukc/ALy6
/LLzA0DjtCxoprdHP6afpdd09QNAyVQMeWa0Rz/yZnuN+PgDQGhKoJDhrUc/
mEpmaLr6A0DjQxqWnKpHPz4uUUN8/ANAiivo61WnRz/kETwePv4DQE8TdZEN
pEc/ivUm+f//A0DkVy+Gw6BHP/WetLY=
           "]]}, 
         "Charting`Private`Tag$7313#4"], {}}, {{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
      BaseStyle -> {FontFamily -> "Times New Roman", FontSize -> 14}, 
      DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{
        "\!\(\*SubscriptBox[\(t\), \(0\)]\) [arb. units]", None}, {
        "k [arb. units]", None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 400, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{Automatic, Automatic}, {
        Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         GrayLevel[0]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 0, 1], 
         Dashing[{Small, Small}]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0.6, 0.4, 0.2], 
         Dashing[{0, Small, Small, Small}]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[1, 0.5, 0], 
         Dashing[{0, Small}]]}, {
        Style[
        "Re \!\(\*SubscriptBox[\(t\), \(0\)]\)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Im \!\(\*SubscriptBox[\(t\), \(0\)]\)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Re \!\(\*SubscriptBox[\(t\), \(0\)]\)(IB)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Im \!\(\*SubscriptBox[\(t\), \(0\)]\)(IB)", FontFamily -> "Times", 
         FontSize -> 12]}, LegendMarkers -> None, LabelStyle -> {}, 
       LegendLayout -> {"Column", {Automatic, 5}}]], {0.7, 0.7}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.784554563999737*^9, 3.7845546040999203`*^9, {3.7845556608844233`*^9, 
   3.7845556780351553`*^9}, {3.7845557464596453`*^9, 3.784555776418898*^9}, {
   3.7845558300249367`*^9, 3.7845558869970217`*^9}, 3.78455594961091*^9, 
   3.784557698386011*^9, 3.7845580753956003`*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"391f0ead-3853-4f47-97f1-f6ef64c64d77"]
}, Open  ]],

Cell[TextData[{
 "This is quite an improved approximation to the true result, compared to the \
usual Born approximation! Yet, note also, that there are numerical \
instabilities close to threshold (k\[Rule]0) which we can understand from the \
denominator quoted above:  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", "2"], "+", "i0", "-", 
    SuperscriptBox["q", "2"]}], TraditionalForm]],ExpressionUUID->
  "677f406b-e95b-4e7d-8aa0-9e751df7495d"],
 ", (7.199). q is the integration variable. In the limit k\[Rule]0, the \
singularity is quite close to the origin in q, and the triangle-shaped path \
discussed at the beginning. Increasing \[Alpha] actually helps, so this is \
chosen as big as 0.7-1.0. Yet, we have to have an eye on it when solving the \
LSE, especially at low energies"
}], "Text",
 CellChangeTimes->{{3.784554627336863*^9, 3.78455468843989*^9}, {
  3.7845548354820957`*^9, 3.784554903471987*^9}, {3.7845557911451483`*^9, 
  3.7845558103923264`*^9}, {3.7845559007232313`*^9, 3.784555909947802*^9}, {
  3.784555959855658*^9, 
  3.784555981826844*^9}},ExpressionUUID->"c2ed3807-f87c-43b6-a47d-\
755d0e974ce5"],

Cell["\<\
In the following, we want to fully reconstruct the true result by solving the \
Lippmann-Schwinger equation (no approximations any more). \
\>", "Text",
 CellChangeTimes->{{3.784541455281179*^9, 3.784541502601177*^9}, {
   3.784546955026348*^9, 3.784547004290365*^9}, 3.7845543922773438`*^9, {
   3.784555985354259*^9, 
   3.784556009088731*^9}},ExpressionUUID->"174cb165-939c-4939-b3c7-\
09155d4732f1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution of the Lippmann-Schwinger equation", "Section",
 CellChangeTimes->{{3.784547013904038*^9, 
  3.7845470221541653`*^9}},ExpressionUUID->"adea2390-05c7-49ca-88b5-\
8db0932ed59a"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s program (7.179). Arguments are Energy E and number \
of Gauss points ",
 StyleBox["nga",
  FontSlant->"Italic"],
 ","
}], "Text",
 CellChangeTimes->{{3.7845563554291763`*^9, 3.784556361677066*^9}, {
  3.784556454827207*^9, 3.784556483299569*^9}, {3.784561456658893*^9, 
  3.784561460178535*^9}},ExpressionUUID->"da3181c9-3ef3-4814-a5d9-\
9def6246ae77"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"lse", "[", 
    RowBox[{"en_", ",", "nga_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pon", ",", "tmp", ",", "q", ",", "qn1", ",", "wq", ",", "n", ",", 
       "vmat", ",", "gp", ",", "tmat"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pon", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"2", "*", "m", "*", "en"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"On", "-", 
        RowBox[{"shell", " ", "momentum", " ", "for", " ", "on"}], "-", 
        RowBox[{"shell", " ", "point"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"tmp", "=", 
       RowBox[{"gaupo", "[", 
        RowBox[{"nga", ",", "pon", ",", "1"}], "]"}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"q", "=", 
       RowBox[{"tmp", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"List", " ", "of", " ", "off"}], "-", 
         RowBox[{"shell", " ", "Gauss", " ", "points"}]}], ",", " ", 
        RowBox[{
        "according", " ", "to", " ", "the", " ", "triangle", " ", "path"}]}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"qn1", "=", 
       RowBox[{"Append", "[", 
        RowBox[{"q", ",", "pon"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"List", " ", "of", " ", "off"}], "-", 
         RowBox[{"shell", " ", "GP"}]}], ",", " ", 
        RowBox[{
         RowBox[{"with", " ", "on"}], "-", 
         RowBox[{"shell", " ", "point", " ", "appended"}]}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"wq", "=", 
       RowBox[{"tmp", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"List", " ", "of", " ", "Gauss", " ", "weights"}], ",", " ", 
        RowBox[{
        "according", " ", "to", " ", "the", " ", "triangle", " ", "path"}]}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"3", "nga"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Number", " ", "of", " ", "Gauss", " ", "points"}], ",", " ", 
        
        RowBox[{
        "remember", " ", "it", " ", "is", " ", "3", "*", "nga", " ", "as", 
         " ", "there", " ", "are", " ", "three", " ", "straight", " ", 
         "lines", " ", "for", " ", "the", " ", "path"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"vmat", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{
           RowBox[{"qn1", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"qn1", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"n", "+", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"n", "+", "1"}]}], "}"}]}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Definition", " ", "of", " ", "V"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"gp", "=", 
       RowBox[{"DiagonalMatrix", "[", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"wq", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "*", 
             RowBox[{
              RowBox[{
               RowBox[{"q", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "^", "2"}], "/", 
              RowBox[{"(", 
               RowBox[{"en", "-", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "^", "2"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"2", "m"}], ")"}]}]}], ")"}]}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ",", "0."}], 
         "]"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Definition", " ", "of", " ", "G"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"eins", "=", 
       RowBox[{"DiagonalMatrix", "[", 
        RowBox[{"Table", "[", 
         RowBox[{"1.", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"n", "+", "1"}]}], "}"}]}], "]"}], "]"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Unit", " ", "matrix"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"tmat", "=", 
       RowBox[{
        RowBox[{"Inverse", "[", 
         RowBox[{"eins", "-", 
          RowBox[{"vmat", ".", "gp"}]}], "]"}], ".", "vmat"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"Solution", " ", "of", " ", "LSE"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"tmat", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"n", "+", "1"}], ",", 
         RowBox[{"n", "+", "1"}]}], "]"}], "]"}]}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"Pick", " ", "the", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"n", "+", "1"}], ",", 
         RowBox[{"n", "+", "1"}]}], ")"}], " ", "element", " ", "for", " ", 
       "on"}], "-", 
      RowBox[{"shell", " ", "solution"}]}], "*)"}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.784556326997809*^9, 3.784556328494375*^9}, {
   3.784556372941257*^9, 3.784556451220426*^9}, {3.784556502348586*^9, 
   3.784556608422616*^9}, {3.784556668729438*^9, 3.784556840829152*^9}, 
   3.7845569254020567`*^9, {3.784557006749634*^9, 3.7845570090256*^9}, {
   3.784557067767253*^9, 3.784557137794733*^9}, {3.784557178332782*^9, 
   3.784557265005451*^9}, {3.784557600894693*^9, 3.784557601157098*^9}, {
   3.7845578004520493`*^9, 3.784557800666243*^9}, {3.784557835244719*^9, 
   3.784557886655807*^9}, {3.7845579234539967`*^9, 3.784557951656122*^9}, {
   3.784557999371626*^9, 3.784558051827257*^9}, {3.784558108454379*^9, 
   3.784558108582821*^9}, {3.784558235357285*^9, 3.784558235726849*^9}, {
   3.7845583975612707`*^9, 3.7845586040583363`*^9}, {3.7845586571012278`*^9, 
   3.784558667178467*^9}, {3.784558710212084*^9, 3.7845588778717213`*^9}, {
   3.784561467040209*^9, 3.784561468663569*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"273934e9-77ec-4e58-8e81-6d1915d88d8f"],

Cell[TextData[{
 "Convert back ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "0"], "\[Rule]", " ", 
    SubscriptBox["t", "0"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "04bd1da4-6e27-46a7-b965-eaca5cb1d89c"],
 " and make the argument wave number k instead of energy E, to compare to \
previous results; also choose 30 Gauss points (=3*10):"
}], "Text",
 CellChangeTimes->{{3.784562016352262*^9, 
  3.784562085705764*^9}},ExpressionUUID->"cb57b97a-71ca-4411-a001-\
86feea9ac959"],

Cell[BoxData[
 RowBox[{
  RowBox[{"to", "[", "k_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "Pi"}], " ", "m", " ", "\[HBar]", "*", 
   RowBox[{"lse", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[HBar]", " ", "k"}], ")"}], "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "m"}], ")"}]}], ",", "10"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.784561474589244*^9, 3.784561515836008*^9}, {
  3.784561574074752*^9, 3.78456157623734*^9}, {3.784562044792644*^9, 
  3.784562048849299*^9}},ExpressionUUID->"8eba3fd1-59d0-4439-88f1-\
6e764600501e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final result", "Section",
 CellChangeTimes->{{3.7845621452188377`*^9, 
  3.784562146657735*^9}},ExpressionUUID->"e5590e57-57f5-4d31-af71-\
40563f2594eb"],

Cell[TextData[{
 "How numerically efficient is the routine? If we need, we can remove the \
generation of Gauss points from ",
 StyleBox["lse",
  FontSlant->"Italic"],
 " and pre-calculate it once."
}], "Text",
 CellChangeTimes->{{3.784561612167905*^9, 
  3.78456166690317*^9}},ExpressionUUID->"0c928247-0b6e-400e-992a-\
d9c180fbb235"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"to", "[", "k", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "0.1", ",", "1.1", ",", "0.01"}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.784561678355163*^9, 3.7845617072970963`*^9}, {
  3.7845617407404947`*^9, 3.784561740872257*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"d68eea5e-8fd0-4486-bdcf-8915a5a687e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.137555`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.784561708802902*^9, 3.784561742635627*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"4291ee17-f686-4ba5-90dc-5cccf425c3a0"]
}, Open  ]],

Cell[TextData[{
 "That is almost 100 calculations of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "710626a0-fda8-4457-a9fa-32c93e1888b4"],
 " per second, using 30 Gauss points - more than fast enough for our \
purposes. Finally, we check with the analytic result (check previous code for \
chosen values of R, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "17296a88-4a12-438f-9a26-6f2c8dfd7681"],
 "; always: m=\[HBar]=1):"
}], "Text",
 CellChangeTimes->{{3.7845617214956636`*^9, 3.784561767569874*^9}, {
  3.784562151659906*^9, 
  3.784562226541297*^9}},ExpressionUUID->"4df53f42-bb6d-42a7-a266-\
7e626ea009e6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Re", "[", 
      RowBox[{
       RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}], "]"}], ",", 
     RowBox[{"Im", "[", 
      RowBox[{
       RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}], "]"}], ",", 
     RowBox[{"Re", "[", 
      RowBox[{"to", "[", "k", "]"}], "]"}], ",", 
     RowBox[{"Im", "[", 
      RowBox[{"to", "[", "k", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0.00001", ",", "2.5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<k [arb. units]\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(t\), \(0\)]\) [arb. units]\>\""}], "}"}]}], 
   ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Re \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Im \!\(\*SubscriptBox[\(t\), \(0\)]\)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Re \!\(\*SubscriptBox[\(t\), \(0\)]\)(LSE)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}], ",", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Im \!\(\*SubscriptBox[\(t\), \(0\)]\)(LSE)\>\"", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", "12"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.7", ",", "0.7"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Black", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Brown", ",", " ", "DotDashed"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"Orange", ",", " ", "Dotted"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7845618068062162`*^9, 3.784561828543157*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"61bb2bae-0857-4401-a888-9f9479b4a86c"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      TagBox[
       {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwV1nk81dkbB/DLVVQUpYUW1FDZlbJ1fb6lwpUlZRsi60QSRRMjJGu2Lvda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         "]]},
       Annotation[#, "Charting`Private`Tag$17299#1"]& ], 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVl3c8Vu8bxx8eiVJJIZpKw4zSoPI5UvZ4IjOVFZLIqJCkECp78xzxldmy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         "]]},
       Annotation[#, "Charting`Private`Tag$17299#2"]& ], 
      TagBox[
       {RGBColor[0.6, 0.4, 0.2], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{0, Small, Small, Small}], LineBox[CompressedData["
1:eJwV1nk0VP0fB/BhVCpahKIeUVGEFCWS99WCqEjFiLJLlCWlSKWyJJJhMIns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         "]]},
       Annotation[#, "Charting`Private`Tag$17299#3"]& ], 
      TagBox[
       {RGBColor[1, 0.5, 0], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{0, Small}], LineBox[CompressedData["
1:eJwVl3k4VV8Xx68pkkoaUGSKiDIkRfE9jVfmIVMKkSEKiYokZY7IlCH3EpGQ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         "]]},
       Annotation[#, "Charting`Private`Tag$17299#4"]& ]}, {}}, InsetBox[
     TemplateBox[{
      StyleBox["\"Re \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)\"", 
        FontFamily -> "Times", FontSize -> 12, StripOnInput -> False],
       StyleBox[
       "\"Im \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False],StyleBox[
       "\"Re \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)(LSE)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False],StyleBox[
       "\"Im \\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\)(LSE)\"", FontFamily -> 
        "Times", FontSize -> 12, StripOnInput -> False]},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Dashing[{0, Small, Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0.6, 0.4, 0.2], 
                    Dashing[{0, Small, Small, Small}]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{0, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{0, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.6, 0.4, 0.2], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.4, 0.2666666666666667, 0.13333333333333336`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.6`", ",", "0.4`", ",", "0.2`"}], "]"}], 
                    NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.6, 0.4, 0.2]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.6, 0.4, 0.2], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small", ",", "Small", ",", "Small"}], 
                    "}"}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.5`", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"\"Column\"", ",", 
                 RowBox[{"{", 
                   RowBox[{"Automatic", ",", "5"}], "}"}]}], "}"}]}]}], 
         "]"}]& )], Scaled[{0.7, 0.7}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{Automatic, Automatic},
   BaseStyle->{FontFamily -> "Times New Roman", FontSize -> 14},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(t\\), \\(0\\)]\\) [arb. units]\"", 
       TraditionalForm], None}, {
      FormBox["\"k [arb. units]\"", TraditionalForm], None}},
   FrameTicks->FrontEndValueCache[{{Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.08, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.06, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.04, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.02, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.02, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.04, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.06, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.08, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.12, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.14, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.16, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.18, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.22, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.24, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.26, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.28, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.32, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.34, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.36, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.38, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}}],
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotRange->{All, All},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           GrayLevel[0]], 
          Line[CompressedData["
1:eJwV1nk81dkbB/DLVVQUpYUW1FDZlbJ1fb6lwpUlZRsi60QSRRMjJGu2Lvda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           "]]}, "Charting`Private`Tag$17299#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVl3c8Vu8bxx8eiVJJIZpKw4zSoPI5UvZ4IjOVFZLIqJCkECp78xzxldmy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           "]]}, 
         "Charting`Private`Tag$17299#2"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0.6, 0.4, 0.2], 
           Dashing[{0, Small, Small, Small}]], 
          Line[CompressedData["
1:eJwV1nk0VP0fB/BhVCpahKIeUVGEFCWS99WCqEjFiLJLlCWlSKWyJJJhMIns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           "]]}, "Charting`Private`Tag$17299#3"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[1, 0.5, 0], 
           Dashing[{0, Small}]], 
          Line[CompressedData["
1:eJwVl3k4VV8Xx68pkkoaUGSKiDIkRfE9jVfmIVMKkSEKiYokZY7IlCH3EpGQ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           "]]}, 
         "Charting`Private`Tag$17299#4"]}}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {Automatic, Automatic}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
      BaseStyle -> {FontFamily -> "Times New Roman", FontSize -> 14}, 
      DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{
        "\!\(\*SubscriptBox[\(t\), \(0\)]\) [arb. units]", None}, {
        "k [arb. units]", None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 400, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, PlotRange -> {All, All}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{Automatic, Automatic}, {
        Automatic, Automatic}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         GrayLevel[0]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 0, 1], 
         Dashing[{Small, Small}]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0.6, 0.4, 0.2], 
         Dashing[{0, Small, Small, Small}]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[1, 0.5, 0], 
         Dashing[{0, Small}]]}, {
        Style[
        "Re \!\(\*SubscriptBox[\(t\), \(0\)]\)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Im \!\(\*SubscriptBox[\(t\), \(0\)]\)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Re \!\(\*SubscriptBox[\(t\), \(0\)]\)(LSE)", FontFamily -> "Times", 
         FontSize -> 12], 
        Style[
        "Im \!\(\*SubscriptBox[\(t\), \(0\)]\)(LSE)", FontFamily -> "Times", 
         FontSize -> 12]}, LegendMarkers -> None, LabelStyle -> {}, 
       LegendLayout -> {"Column", {Automatic, 5}}]], {0.7, 0.7}, Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.784561837457848*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"c871851e-b09d-4c24-9b75-9727d2fa9694"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c5cb4170-7b03-4cd8-a166-69376dae6ca3"],
 ": Analytic result; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "0"], "(", "LSE", ")"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7029718e-f7f3-471f-892d-d6a31b0197a6"],
 ": Numerical result by solving the LSE. Satisfactory match with chosen \
number of Gauss points."
}], "Text",
 CellChangeTimes->{{3.784561869979518*^9, 3.784561882580269*^9}, {
  3.784562244397687*^9, 
  3.784562284015027*^9}},ExpressionUUID->"085c17c3-35e7-4be8-8f74-\
c6522bca351b"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{3840, 2195},
WindowMargins->{{-16, Automatic}, {Automatic, -16}},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 188, 3, 290, "Title",ExpressionUUID->"bebd264f-1102-45fa-9f6e-ad78d8abc5f8"],
Cell[CellGroupData[{
Cell[793, 29, 183, 3, 199, "Section",ExpressionUUID->"da47f219-0b48-4020-bd48-331af43a1f17"],
Cell[979, 34, 957, 14, 122, "Input",ExpressionUUID->"a5443482-a9b0-44cc-81f1-214ed93a58f0"],
Cell[1939, 50, 933, 22, 242, "Text",ExpressionUUID->"ac2d353a-dd0a-4f5b-a785-4a95e83dad82"],
Cell[CellGroupData[{
Cell[2897, 76, 2688, 60, 413, "Input",ExpressionUUID->"40f3b6eb-ad38-4fca-85a7-a5bf081f58ba"],
Cell[CellGroupData[{
Cell[5610, 140, 1238, 22, 66, "Print",ExpressionUUID->"edb82510-4b83-4a6a-8868-f723df5af45a"],
Cell[6851, 164, 1168, 21, 66, "Print",ExpressionUUID->"bfe26d6c-bc18-4865-b9e0-015516e5ac5b"],
Cell[8022, 187, 1244, 22, 66, "Print",ExpressionUUID->"8de0e11f-5023-4d14-8e0c-fbd4d0650969"]
}, Open  ]]
}, Open  ]],
Cell[9293, 213, 1020, 16, 231, "Text",ExpressionUUID->"30bd0776-58cb-4761-9df2-b959ccf28349"],
Cell[10316, 231, 1382, 28, 297, "Input",ExpressionUUID->"ab2df81e-2f5c-4338-ae51-1cf800c708a4"],
Cell[CellGroupData[{
Cell[11723, 263, 6497, 190, 587, "Input",ExpressionUUID->"6ec8be34-6aff-4e26-b8af-de1ea2b9d0d9"],
Cell[18223, 455, 205304, 3439, 576, "Output",ExpressionUUID->"a6599365-4446-4892-9e28-037fe6a971de"]
}, Open  ]],
Cell[223542, 3897, 375, 8, 101, "Text",ExpressionUUID->"60e50cb9-18b8-41df-8c59-3e6deb69855b"],
Cell[CellGroupData[{
Cell[223942, 3909, 578, 16, 122, "Input",ExpressionUUID->"6242f1bf-6ec9-4434-a7a1-529ca7b978fd"],
Cell[224523, 3927, 866, 13, 134, "Output",ExpressionUUID->"90a9fe00-3efc-4254-8f71-bd50a8a541c9"]
}, Open  ]],
Cell[225404, 3943, 642, 11, 166, "Text",ExpressionUUID->"a7735c18-2a36-499a-b1cb-37ebb8074852"],
Cell[226049, 3956, 3263, 95, 413, "Input",ExpressionUUID->"24097ddd-3aa1-4f08-b27f-db9f02cc7a37"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229349, 4056, 162, 3, 199, "Section",ExpressionUUID->"99f3d24d-da21-4dee-b5f4-f09fc30789c0"],
Cell[229514, 4061, 175, 3, 101, "Text",ExpressionUUID->"b1dc380c-3da5-4b1a-a899-c504ad307f7f"],
Cell[229692, 4066, 340, 7, 166, "Text",ExpressionUUID->"22fcb16d-cdf4-457f-a7e7-fe4549713c38"],
Cell[230035, 4075, 1537, 27, 355, "Input",ExpressionUUID->"fd3c86f9-873a-46a9-b760-351716198844"],
Cell[231575, 4104, 701, 18, 101, "Text",ExpressionUUID->"c3c02bf9-f687-4918-a360-c1e258b757fa"],
Cell[232279, 4124, 3619, 87, 529, "Input",ExpressionUUID->"0de17312-f2b0-462d-8e66-68b6f3d19a1e"],
Cell[235901, 4213, 3889, 66, 181, "Input",ExpressionUUID->"016f5fab-fa4c-4876-bd03-b3779ea55167"],
Cell[CellGroupData[{
Cell[239815, 4283, 273, 6, 159, "Subsection",ExpressionUUID->"70d2a024-3191-4aeb-aa79-0a8c6c03bcdd"],
Cell[240091, 4291, 508, 9, 166, "Text",ExpressionUUID->"28fd6dad-887b-4858-8d1f-c44bafbfae2c"],
Cell[240602, 4302, 3748, 103, 413, "Input",ExpressionUUID->"f196cfca-6aee-47f1-8a26-9f211fa8c3dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[244387, 4410, 251, 4, 159, "Subsection",ExpressionUUID->"09749e97-7787-4ad6-a2ff-cda21af85b5d"],
Cell[244641, 4416, 1139, 32, 101, "Text",ExpressionUUID->"d9c231cb-7516-477b-a4f3-75fb5e1346a8"],
Cell[245783, 4450, 563, 14, 122, "Input",ExpressionUUID->"8edc3dd5-a6eb-424a-8c8f-cb316193fa17"],
Cell[246349, 4466, 759, 20, 166, "Text",ExpressionUUID->"9bd64584-6960-41e2-96bc-ce6a3f744f58"],
Cell[247111, 4488, 3036, 82, 319, "Input",ExpressionUUID->"e203c066-cbcb-4d26-8f0d-cf21205fcbaa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[250184, 4575, 156, 3, 159, "Subsection",ExpressionUUID->"25ba45d8-49ea-47d8-81e5-7ac111c19004"],
Cell[CellGroupData[{
Cell[250365, 4582, 2507, 57, 239, "Input",ExpressionUUID->"2b051aab-d6ac-4092-a101-d0cd8236fcf3"],
Cell[252875, 4641, 61593, 1165, 862, "Output",ExpressionUUID->"7b914fdd-21b2-4b7f-a10f-92dd3a137bd6"]
}, Open  ]],
Cell[314483, 5809, 942, 21, 166, "Text",ExpressionUUID->"53292113-9267-4905-b5f9-12929ec3b8ee"],
Cell[CellGroupData[{
Cell[315450, 5834, 2503, 61, 297, "Input",ExpressionUUID->"fdf6762b-0af9-4f3a-9fae-cd0fd612a62d"],
Cell[317956, 5897, 94357, 1754, 871, "Output",ExpressionUUID->"391f0ead-3853-4f47-97f1-f6ef64c64d77"]
}, Open  ]],
Cell[412328, 7654, 1148, 22, 231, "Text",ExpressionUUID->"c2ed3807-f87c-43b6-a47d-755d0e974ce5"],
Cell[413479, 7678, 413, 8, 101, "Text",ExpressionUUID->"174cb165-939c-4939-b3c7-09155d4732f1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[413941, 7692, 190, 3, 199, "Section",ExpressionUUID->"adea2390-05c7-49ca-88b5-8db0932ed59a"],
Cell[414134, 7697, 393, 10, 101, "Text",ExpressionUUID->"da3181c9-3ef3-4814-a5d9-9def6246ae77"],
Cell[414530, 7709, 6442, 158, 819, "Input",ExpressionUUID->"273934e9-77ec-4e58-8e81-6d1915d88d8f"],
Cell[420975, 7869, 527, 14, 101, "Text",ExpressionUUID->"cb57b97a-71ca-4411-a001-86feea9ac959"],
Cell[421505, 7885, 592, 16, 85, "Input",ExpressionUUID->"8eba3fd1-59d0-4439-88f1-6e764600501e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[422134, 7906, 159, 3, 199, "Section",ExpressionUUID->"e5590e57-57f5-4d31-af71-40563f2594eb"],
Cell[422296, 7911, 335, 9, 101, "Text",ExpressionUUID->"0c928247-0b6e-400e-992a-d9c180fbb235"],
Cell[CellGroupData[{
Cell[422656, 7924, 430, 10, 122, "Input",ExpressionUUID->"d68eea5e-8fd0-4486-bdcf-8915a5a687e6"],
Cell[423089, 7936, 227, 4, 134, "Output",ExpressionUUID->"4291ee17-f686-4ba5-90dc-5cccf425c3a0"]
}, Open  ]],
Cell[423331, 7943, 773, 20, 166, "Text",ExpressionUUID->"4df53f42-bb6d-42a7-a266-7e626ea009e6"],
Cell[CellGroupData[{
Cell[424129, 7967, 2447, 59, 297, "Input",ExpressionUUID->"61bb2bae-0857-4401-a888-9f9479b4a86c"],
Cell[426579, 8028, 86011, 1591, 862, "Output",ExpressionUUID->"c871851e-b09d-4c24-9b75-9727d2fa9694"]
}, Open  ]],
Cell[512605, 9622, 685, 19, 101, "Text",ExpressionUUID->"085c17c3-35e7-4be8-8f74-c6522bca351b"]
}, Open  ]]
}, Open  ]]
}
]
*)

