(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    390791,       7340]
NotebookOptionsPosition[    387195,       7279]
NotebookOutlinePosition[    387558,       7295]
CellTagsIndexPosition[    387515,       7292]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Spherical Well", "Title",
 CellChangeTimes->{{3.7779725521805964`*^9, 
  3.777972554560192*^9}},ExpressionUUID->"553e1cc8-bbfa-43a2-a98f-\
726394317aaa"],

Cell["\<\
Simplified version, setting \[HBar]=m=1; yet, all formulas contain these \
variables if one wants to set them to their actual values.
All formulas refer to Haberzettl lecture notes (2019).\
\>", "Text",
 CellChangeTimes->{{3.7779725598327713`*^9, 
  3.777972630802498*^9}},ExpressionUUID->"b0255f18-63f2-4e7b-b993-\
f7c3beed0518"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[HBar]", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m", "=", "1."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "\[Gamma]", "]"}]}], "Input",
 CellChangeTimes->{{3.7778426295288773`*^9, 3.777842633211206*^9}, {
   3.777842927940629*^9, 3.777843111575741*^9}, {3.777843143659399*^9, 
   3.777843144839632*^9}, {3.777843240523862*^9, 3.777843344668272*^9}, {
   3.777843392094696*^9, 3.777843432343424*^9}, {3.777843482218629*^9, 
   3.777843490038206*^9}, {3.77784355266179*^9, 3.7778437613063498`*^9}, {
   3.777843802895014*^9, 3.777843870371915*^9}, {3.777844033118367*^9, 
   3.7778441581649513`*^9}, {3.777844629135627*^9, 3.777844630836648*^9}, {
   3.777851379970978*^9, 3.777851412409073*^9}, {3.777855107154592*^9, 
   3.7778551656974792`*^9}, 3.777855209178129*^9, {3.777855513950602*^9, 
   3.777855543942548*^9}, {3.7778556736209393`*^9, 3.777855685774908*^9}, 
   3.7778558530786047`*^9, 3.77797260021946*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"63721777-c1e2-48aa-b146-384c8312df57"],

Cell[TextData[{
 "Program \[Gamma] from Eq. (7.73) and tan ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Delta]", "\[ScriptL]"], TraditionalForm]],ExpressionUUID->
  "0d375ca6-9840-40f4-b43c-6c0c3fd6e18a"],
 " from Eq. (7.75)."
}], "Text",
 CellChangeTimes->{{3.777972605618503*^9, 3.777972612297203*^9}, {
  3.777972661489333*^9, 
  3.7779727366346703`*^9}},ExpressionUUID->"ff34988e-dcf9-4f49-9390-\
bdf0c66df236"],

Cell[BoxData[
 RowBox[{"Do", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Gamma]", "[", "l", "]"}], "[", 
      RowBox[{"k_", ",", "vo_", ",", "r_"}], "]"}], "=", 
     RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"k", "^", "2"}], "+", 
           RowBox[{"2", 
            RowBox[{"m", "/", 
             RowBox[{"\[HBar]", "^", "2"}]}], "*", "vo"}]}], "]"}], "*", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"SphericalBesselJ", "[", 
             RowBox[{"l", ",", "x"}], "]"}], ",", "x"}], "]"}], "/", 
          RowBox[{"SphericalBesselJ", "[", 
           RowBox[{"l", ",", "x"}], "]"}]}]}], ")"}], "\[IndentingNewLine]", "/.", 
       RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"k", "^", "2"}], "+", 
            RowBox[{"2", 
             RowBox[{"m", "/", 
              RowBox[{"\[HBar]", "^", "2"}]}], "*", "vo"}]}], "]"}], "*", 
          "r"}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
      RowBox[{"k_", ",", "vo_", ",", "r_"}], "]"}], "=", 
     "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"k", "*", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"SphericalBesselJ", "[", 
               RowBox[{"l", ",", "x"}], "]"}], ",", "x"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "[", "l", "]"}], "[", 
             RowBox[{"k", ",", "vo", ",", "r"}], "]"}], "*", 
            RowBox[{"SphericalBesselJ", "[", 
             RowBox[{"l", ",", "x"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"k", "*", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"SphericalBesselY", "[", 
               RowBox[{"l", ",", "x"}], "]"}], ",", "x"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{
             RowBox[{"\[Gamma]", "[", "l", "]"}], "[", 
             RowBox[{"k", ",", "vo", ",", "r"}], "]"}], "*", 
            RowBox[{"SphericalBesselY", "[", 
             RowBox[{"l", ",", "x"}], "]"}]}]}], ")"}]}], ")"}], 
       "\[IndentingNewLine]", "/.", 
       RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"k", "*", "r"}]}], "}"}]}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7778426295288773`*^9, 3.777842633211206*^9}, {
   3.777842927940629*^9, 3.777843111575741*^9}, {3.777843143659399*^9, 
   3.777843144839632*^9}, {3.777843240523862*^9, 3.777843344668272*^9}, {
   3.777843392094696*^9, 3.777843432343424*^9}, {3.777843482218629*^9, 
   3.777843490038206*^9}, {3.77784355266179*^9, 3.7778437613063498`*^9}, {
   3.777843802895014*^9, 3.777843870371915*^9}, {3.777844033118367*^9, 
   3.7778441581649513`*^9}, {3.777844629135627*^9, 3.777844630836648*^9}, {
   3.777851379970978*^9, 3.777851412409073*^9}, {3.777855107154592*^9, 
   3.7778551656974792`*^9}, 3.777855209178129*^9, {3.777855513950602*^9, 
   3.777855543942548*^9}, {3.7778556736209393`*^9, 3.777855685774908*^9}, 
   3.7778558530786047`*^9, 3.77797260021946*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"0273a1c5-2510-4b5c-a123-74f2e03e8306"],

Cell[TextData[{
 "Give the radius and potential depth ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "0"], ">", "0"}], TraditionalForm]],ExpressionUUID->
  "062448d3-35b9-4b71-8dd6-54d6a5f97690"],
 " numerical values; \nprogram the bound state energy eigenvalues from Eqs. \
(5.185, 5.187) ad the bound state condition (5.188), all for \[ScriptL]=0;\n\
Check for the existence of bound state using (5.186);\nEvaluate the energy of \
the shallowest ound state;\n\nOn the other hand, we know that bound state \
energies are poles of the partial-wave amplitude below threshold. They are \
locate on the real E-axis, first sheet. This translates to the positive \
imaginary axis in the k-plane. Therefore, for the given values of R and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "0"], TraditionalForm]],ExpressionUUID->
  "2305b1f6-2aa4-4e0d-86ca-0db33d69b8ba"],
 ", we should get the same bound state energies through analytic continuation \
of the scatterig amplitude ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],ExpressionUUID->
  "08719098-2875-42c8-b65e-49afbf8621b8"],
 " as those found by the bound state formalism of topic 5. \n\nFor this:\n\
Define the S-wave partial-wave amplitude ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]],ExpressionUUID->
  "d4c09402-b662-4467-b068-11b3ff856c6a"],
 " , for example, in terms of tan \[Delta]; \nfind pole in in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "o"], TraditionalForm]],ExpressionUUID->
  "18bb0652-5f3d-4628-911d-13ac7c87cbac"],
 " by searching for a zero in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    SubscriptBox["t", "0"]}], TraditionalForm]],ExpressionUUID->
  "d4d1d54f-0f0e-469d-94d3-ead8f05588a0"],
 ", with the prediction from topic 5 as start value for the numerical search; \
\ncompare both results; they are equal!"
}], "Text",
 CellChangeTimes->{{3.777972751082499*^9, 
  3.77797326996416*^9}},ExpressionUUID->"bee60cc0-76e0-4d6e-8b33-\
09db9a4d7881"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rn", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"von", "=", "1.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]", "[", "l", "]"}], "[", "k_", "]"}], "=", 
     RowBox[{"ArcTan", "[", 
      RowBox[{
       RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
       RowBox[{"k", ",", "von", ",", "rn"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "[", 
    RowBox[{"en_", ",", "vo_", ",", "r_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", "2"}], "m", " ", 
    RowBox[{
     RowBox[{"r", "^", "2"}], "/", 
     RowBox[{"\[HBar]", "^", "2"}]}], "*", "en"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v", "[", 
    RowBox[{"en_", ",", "vo_", ",", "r_"}], "]"}], "=", 
   RowBox[{"2", 
    RowBox[{"m", "/", 
     RowBox[{"\[HBar]", "^", "2"}]}], "*", "vo", "*", 
    RowBox[{"r", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"v", "[", 
     RowBox[{"en", ",", "von", ",", "rn"}], "]"}], ">", 
    RowBox[{
     RowBox[{"Pi", "^", "2"}], "/", "4"}]}], ",", 
   RowBox[{
   "Print", "[", "\"\<At least one S-wave bound state exists.\>\"", "]"}], 
   ",", 
   RowBox[{"Print", "[", "\"\<No S-wave bound state exists.\>\"", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Tan", "[", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"v", "[", 
           RowBox[{"en", ",", "von", ",", "rn"}], "]"}], "-", 
          RowBox[{"\[Lambda]", "[", 
           RowBox[{"en", ",", "von", ",", "rn"}], "]"}]}], "]"}], "]"}], 
       "\[Equal]", 
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"en", ",", "von", ",", "rn"}], "]"}], "-", 
            RowBox[{"\[Lambda]", "[", 
             RowBox[{"en", ",", "von", ",", "rn"}], "]"}]}], ")"}], "/", 
          RowBox[{"\[Lambda]", "[", 
           RowBox[{"en", ",", "von", ",", "rn"}], "]"}]}], "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"en", ",", 
        RowBox[{"-", "0.01"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<Shallowest S-wave bound state in k-plane from (5.188): \
\!\(\*SubscriptBox[\(k\), \(0\)]\)= \>\"", ",", 
    RowBox[{"polpred", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"2", "*", "m", "*", "sol"}], "]"}], "/", "\[HBar]"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Binding energy: \!\(\*SubscriptBox[\(E\), \(0\)]\) = \>\"", ",", 
   "sol"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"t", "[", "l", "]"}], "[", "k_", "]"}], "=", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"k", "/", 
        RowBox[{
         RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
         RowBox[{"k", ",", "von", ",", "rn"}], "]"}]}], "-", 
       RowBox[{"I", "*", "k"}]}], ")"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana", "=", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{
         RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "polpred"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<S-wave bound state found through analytic continuation of (7.75): \
\!\(\*SubscriptBox[\(k\), \(0\)]\) = \>\"", ",", "polana"}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.77784388210395*^9, 3.777843978586194*^9}, {
   3.777844291969359*^9, 3.77784429493474*^9}, {3.777844457164309*^9, 
   3.7778444697569933`*^9}, {3.777844759647744*^9, 3.7778447645725927`*^9}, {
   3.7778448124497766`*^9, 3.777844818993475*^9}, 3.7778553313432693`*^9, 
   3.7778554734822598`*^9, {3.777855550533103*^9, 3.777855554541403*^9}, {
   3.7778556339431553`*^9, 3.777855637423647*^9}, {3.77785581755824*^9, 
   3.777855827702503*^9}, {3.777855925662624*^9, 3.777855973662633*^9}, {
   3.7778562571100597`*^9, 3.777856261944406*^9}, {3.777856722643455*^9, 
   3.77785672488802*^9}, {3.7778571800578203`*^9, 3.7778571801853437`*^9}, {
   3.7779071345247*^9, 3.777907613320938*^9}, {3.777907649419372*^9, 
   3.777907664282469*^9}, 3.77790784346482*^9, {3.777907889473559*^9, 
   3.7779078978410397`*^9}, {3.7779079449630547`*^9, 3.777907955363146*^9}, {
   3.777907988444112*^9, 3.777908003868465*^9}, {3.777909170293817*^9, 
   3.777909181686729*^9}, {3.777909387428544*^9, 3.777909397291727*^9}, {
   3.7779094845903177`*^9, 3.777909513271907*^9}, {3.7779107804931803`*^9, 
   3.777910789812862*^9}, {3.777910819957911*^9, 3.7779108216937227`*^9}, {
   3.777911040445383*^9, 3.777911040763544*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"48f24a95-109c-4066-bc8e-01d0acd201a5"],

Cell[CellGroupData[{

Cell[BoxData["\<\"At least one S-wave bound state exists.\"\>"], "Print",
 CellChangeTimes->{{3.777907460142*^9, 3.77790761388488*^9}, 
   3.777907654468018*^9, 3.777907844353923*^9, {3.7779078900199842`*^9, 
   3.7779078981939487`*^9}, 3.777907955694974*^9, {3.777907989554243*^9, 
   3.77790800597867*^9}, {3.7779093884035177`*^9, 3.777909397564404*^9}, {
   3.777909506663513*^9, 3.7779095137746353`*^9}, {3.7779107809125357`*^9, 
   3.777910790055283*^9}, 3.777910824554371*^9, 3.777911040971499*^9, 
   3.777926314632452*^9, 3.784211428866221*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"3f487e2f-094d-4087-af8f-5b562f9388aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"Shallowest S-wave bound state in k-plane from (5.188): \\!\\(\
\\*SubscriptBox[\\(k\\), \\(0\\)]\\)= \"\>", "\[InvisibleSpace]", "0.`"}], 
   "\[VeryThinSpace]", "+", 
   RowBox[{"1.2571165629651215`", " ", "\[ImaginaryI]"}]}],
  SequenceForm[
  "Shallowest S-wave bound state in k-plane from (5.188): \!\(\*SubscriptBox[\
\(k\), \(0\)]\)= ", 
   Complex[0., 1.2571165629651215`]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777907460142*^9, 3.77790761388488*^9}, 
   3.777907654468018*^9, 3.777907844353923*^9, {3.7779078900199842`*^9, 
   3.7779078981939487`*^9}, 3.777907955694974*^9, {3.777907989554243*^9, 
   3.77790800597867*^9}, {3.7779093884035177`*^9, 3.777909397564404*^9}, {
   3.777909506663513*^9, 3.7779095137746353`*^9}, {3.7779107809125357`*^9, 
   3.777910790055283*^9}, 3.777910824554371*^9, 3.777911040971499*^9, 
   3.777926314632452*^9, 3.784211428890586*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"d3fbe990-ac45-4429-ac67-99fdaeb7a610"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Binding energy: \\!\\(\\*SubscriptBox[\\(E\\), \\(0\\)]\\) = \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.7901710264406202`"}]}],
  SequenceForm[
  "Binding energy: \!\(\*SubscriptBox[\(E\), \(0\)]\) = ", \
-0.7901710264406202],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777907460142*^9, 3.77790761388488*^9}, 
   3.777907654468018*^9, 3.777907844353923*^9, {3.7779078900199842`*^9, 
   3.7779078981939487`*^9}, 3.777907955694974*^9, {3.777907989554243*^9, 
   3.77790800597867*^9}, {3.7779093884035177`*^9, 3.777909397564404*^9}, {
   3.777909506663513*^9, 3.7779095137746353`*^9}, {3.7779107809125357`*^9, 
   3.777910790055283*^9}, 3.777910824554371*^9, 3.777911040971499*^9, 
   3.777926314632452*^9, 3.784211428893343*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"ce084619-bb7b-402f-804e-b47c8a71c3e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"\<\"S-wave bound state found through analytic continuation of \
(7.75): \\!\\(\\*SubscriptBox[\\(k\\), \\(0\\)]\\) = \"\>", 
    "\[InvisibleSpace]", "0.`"}], "\[VeryThinSpace]", "+", 
   RowBox[{"1.2571165629651215`", " ", "\[ImaginaryI]"}]}],
  SequenceForm[
  "S-wave bound state found through analytic continuation of (7.75): \
\!\(\*SubscriptBox[\(k\), \(0\)]\) = ", 
   Complex[0., 1.2571165629651215`]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.777907460142*^9, 3.77790761388488*^9}, 
   3.777907654468018*^9, 3.777907844353923*^9, {3.7779078900199842`*^9, 
   3.7779078981939487`*^9}, 3.777907955694974*^9, {3.777907989554243*^9, 
   3.77790800597867*^9}, {3.7779093884035177`*^9, 3.777909397564404*^9}, {
   3.777909506663513*^9, 3.7779095137746353`*^9}, {3.7779107809125357`*^9, 
   3.777910790055283*^9}, 3.777910824554371*^9, 3.777911040971499*^9, 
   3.777926314632452*^9, 3.7842114288952913`*^9},
 CellLabel->
  "During evaluation of \
In[5]:=",ExpressionUUID->"56c12891-8626-4169-a4cb-27547ab3eb3c"]
}, Open  ]]
}, Open  ]],

Cell["\<\
We have shown that the explicit bound-state formalism from topic 5 gives the \
same bound state position as the analytic cotinuation of the scattering \
amplitude below threshold. This demonstrates the power of analyticity: \
Although we have never cared about bound states for scattering, the \
information on the bound state spectrum is there and can be retrieved by \
analytic continuation. 

Next, let us visualize the transcendental equation (5.188) by plotting \
left-hand side, right-hand side, and the numerical solution of the equation:\
\>", "Text",
 CellChangeTimes->{{3.7779732838906384`*^9, 
  3.777973426084014*^9}},ExpressionUUID->"d4abd658-1b18-48d3-85e3-\
0bccea692215"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"style", ":=", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"12", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Tan", "[", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"v", "[", 
           RowBox[{"en", ",", "von", ",", "rn"}], "]"}], "-", 
          RowBox[{"\[Lambda]", "[", 
           RowBox[{"en", ",", "von", ",", "rn"}], "]"}]}], "]"}], "]"}], ",", 
       
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"en", ",", "von", ",", "rn"}], "]"}], "-", 
            RowBox[{"\[Lambda]", "[", 
             RowBox[{"en", ",", "von", ",", "rn"}], "]"}]}], ")"}], "/", 
          RowBox[{"\[Lambda]", "[", 
           RowBox[{"en", ",", "von", ",", "rn"}], "]"}]}], "]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"en", ",", 
       RowBox[{"-", "von"}], ",", "0"}], "}"}], ",", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<E\>\"", ",", "\"\<\>\""}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"{", 
         RowBox[{"Blue", ",", "Dashed"}], "}"}]}], "}"}]}]}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick", ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"sol", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"sol", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}], 
   ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"Inset", "[", 
     RowBox[{
      RowBox[{"Framed", "[", 
       RowBox[{
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"LineLegend", "[", 
            RowBox[{
             RowBox[{"{", "Black", "}"}], ",", 
             RowBox[{"{", "\"\<LHS (5.188)\>\"", "}"}], ",", "style"}], "]"}],
            ",", 
           RowBox[{"LineLegend", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Blue", ",", "Dashed"}], "}"}], ",", 
             RowBox[{"{", "\"\<RHS (5.188)\>\"", "}"}], ",", "style"}], "]"}],
            ",", 
           RowBox[{"LineLegend", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"Red", ",", "Thick"}], "}"}], ",", 
             RowBox[{"{", "\"\<Sol (5.188)\>\"", "}"}], ",", "style"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
        RowBox[{"FrameMargins", "\[Rule]", "0"}], ",", 
        RowBox[{"Background", "\[Rule]", "LightBlue"}]}], "]"}], ",", 
      RowBox[{"Scaled", "[", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", "0.9"}], "}"}], "]"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"End", " ", "of", " ", "the", " ", "Legends"}], "*)"}], "\n", 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.777909241090486*^9, 3.77790937302675*^9}, {
   3.7779095274635553`*^9, 3.7779095642172213`*^9}, {3.777909609929528*^9, 
   3.777909688931856*^9}, 3.777909815545714*^9, {3.777909900875779*^9, 
   3.777910097056831*^9}, {3.777910168844833*^9, 3.77791019900321*^9}, {
   3.77791027068644*^9, 3.777910346407309*^9}, {3.777910377625022*^9, 
   3.777910381704378*^9}, {3.777910448604526*^9, 3.777910458898924*^9}, {
   3.777910489012803*^9, 3.77791059834315*^9}, {3.777910667450899*^9, 
   3.77791076014818*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"4411991a-6edb-4769-820d-a3af945e8884"],

Cell[BoxData[
 GraphicsBox[{{{{{}, {}, 
      TagBox[
       {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
        LineBox[CompressedData["
1:eJwVkHs0lHkcxqfBsCoydJFNuVR0GSXrurvft62V7CxWSapti2hpi5yijoTk
uqc6YZE6ZVmXrEuo1bHxJRpsucW6lMS4jdtgzPv+RoNZ+8dznvP893k+Bp7+
rt5sFovlvJT/u9i9nigUBKtsXIUOVhTEh65M3LBIcCojYyJHtwg8M115dvME
lYwlZxKV/wLbhpSGo58Icv8Zn+1QlAN3qudMkIxgrCbr4rQlwpiOISuJIWhl
oTqTfKUaamzP3i+WEkwzE43Hm9bApeiZ1olpgkN9rX43eALg51ueV58ieCSi
Xf3K7TrY/DZEzWSS4Lus5dZpPfXQsYEDXqMEaz+oZEZ//xqsn63P7+4nuLLC
URZS1Ayr3v90gHwkeDqHt7LLowVGWVlCnV6C3YFKk1ldLZDGN9N1ebfE/2kd
92pjK8wP7IsWvCVoc/CrUPm9NkDu+VOlNQTtDCsH+b0dkGpdIm+pJnjMXuez
N1QnBJwkyWIkeNb+8jmzjE7YlBfRaPqCICt2q9H7011wY2+ybfpTgiAzMvi8
oxvsA1DnVhbBi7FbhgvSeqCxUavBJ2bJT6bj7yF9fXAk9U3L8SiCTo9E/v7L
+6HXM6bLJZIg01R03cqyH8RkfsQ2jKDDuKPdd7/2g4ahiKMZTPDvCtNXBXuE
4BRUub/Mh+BzvdeJKdcHoEn/XJWqPUEL4ZGvy5WHocW/tixXmaCeq42z2sIY
rBA9zkmKZ/DYwbYvwk9IQGMkcfxZLIMdMbzK1gAJaA6HmnVGM7ghy0RkFiUB
7uAPZbqRDEbLbpdwCyWwtm9O8DCEwaLaWcMg1iwYdh0czv2FwYGqmzPtObNg
XT9qXOHE4M1k6cvFZTTY1rX93MtnMM7TrW3nOhrsBBX5CkcGlyWmnLrAo+Hr
2rsW3xxgUEu+7b7xcRr2VdnsrwMGY6Lc9vo9o8HpeZxX6y4GlY7SNeHnGfDO
Nc0Y4jKYEOD1QH+SwBp+nGvvKgaNRyNBrCqD+ikRu1ODwYktIt9uQxlss8r1
qldncEckx1vJQwbiV1s2/8lmMGn63/gCgQyCBoxyAyQ0Ogcf97mXMwfR+vqF
8lYaeX4P/ccj5GD1MvSktHlpB4+PvEiXg8j7g8ZkI40l7U/qS1EOjgUP/Hsb
aDSxP2GtvSgHjS/1dldX0+h2Z8om89o8JHusexpdTGOxcGvCyYgFyE7ilmvd
pVGgdajQMl8BT5SCuTvv0Hj1kWu8VpMCygPf+zncorHpt8oVutMKaHL5Qy8s
jkaDR5U97utZFL3CMnQigkafY1tppVMsan+UB1UXSOOE9p2hwSkWJbycLrh2
mMbCyAeacUZsamJQeWOqK40OLpXzZVZsijnkG1zqQqN9r/8VFT6bUjc3Nxnj
08hvz/5x4RKb2i2uiXP/lsbD2YJR33o2Fe4zwje3pHH7KkrtxmUlaqM7r21k
LY21VbltzuPKVJefWuq71Ut+NoX7ruGoUAnXhScatZf+dw3e0jRQoTjZycMl
mjQ27nZU3HdXoSaki3OhqjRW2gaFmdWpUM8TmjfpECnyBDlt3U84VGD24yEO
LcWLsrxE3WYOtb08Mm9OIsXVdWLdlEkO9bDfyuKjWIqCGZenTttVqZu70g/k
DUvRIN88pu6xKuXSFHCB6pDiaRXD0JxSNUpd6LhnT7sUNZN1zu7oUKOcRhrG
wt5KUay94KY6q0b9B2Uwshw=
         "]], LineBox[CompressedData["
1:eJwVkHk4lHsfh8ckTfbd6S1FNIUKWZI6npJyrNmKHGRQpMTYKmWJKCKUQkVG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         "]]},
       Annotation[#, "Charting`Private`Tag$2783#1"]& ], 
      TagBox[
       {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
        Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVjWk41HsDhueMfakZM0glS6WiRSplSSrhVHS8EVJJC963rIlE25FlUlKK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         "]]},
       Annotation[#, 
        "Charting`Private`Tag$2783#2"]& ], {}}, {{}, {}, {}, {}, {}}, {{}, \
{}, {}, {}, {}}}, {}}, 
   {RGBColor[1, 0, 0], Thickness[Large], 
    LineBox[{{-0.7901710264406202, -1}, {-0.7901710264406202, 1}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times New Roman", FontSize -> 14},
  DisplayFunction->Identity,
  Epilog->InsetBox[
    BoxData[
     FormBox[
      FrameBox[
       TemplateBox[{
         TemplateBox[{"\"LHS (5.188)\""}, "LineLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontSize -> 12, FontFamily -> "Times"}, Background -> Automatic, 
             StripOnInput -> False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 InterpretationBox[
                  ButtonBox[
                   TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                   BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                   ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                   Automatic, Method -> "Preemptive"], 
                  GrayLevel[0], Editable -> False, Selectable -> False], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"12", ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Times\""}]}], 
                   "}"}]}]}], "]"}]& ), Editable -> True], 
         TemplateBox[{"\"RHS (5.188)\""}, "LineLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontSize -> 12, FontFamily -> "Times"}, Background -> Automatic, 
             StripOnInput -> False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "}"}], 
               ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"12", ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Times\""}]}], 
                   "}"}]}]}], "]"}]& ), Editable -> True], 
         TemplateBox[{"\"Sol (5.188)\""}, "LineLegend", 
          DisplayFunction -> (FormBox[
            StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.038000000000000006`] -> 
                    Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontSize -> 12, FontFamily -> "Times"}, Background -> Automatic, 
             StripOnInput -> False], TraditionalForm]& ), 
          InterpretationFunction :> (RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LabelStyle", "\[Rule]", 
                 RowBox[{"{", 
                   RowBox[{"12", ",", 
                    RowBox[{"FontFamily", "\[Rule]", "\"Times\""}]}], 
                   "}"}]}]}], "]"}]& ), Editable -> True]}, "RowDefault"], 
       RoundingRadius -> 5, FrameMargins -> 0, Background -> 
       RGBColor[0.87, 0.94, 1], StripOnInput -> False], TraditionalForm]], 
    Scaled[{0.5, 0.9}]],
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox["\"\"", TraditionalForm], None}, {
     FormBox["\"E\"", TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-1.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.9, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.7, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.3, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.9, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.7, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.3, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.3, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->400,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.5, 0}, {-5.028068207638559, 3.1186663358553153`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7779092762487392`*^9, 3.777909316597164*^9}, {
   3.777909366749185*^9, 3.777909398795299*^9}, 3.777909552812834*^9, {
   3.777909654543721*^9, 3.777909682576352*^9}, {3.7779098187524567`*^9, 
   3.777909825020083*^9}, 3.7779099033372583`*^9, 3.777909947208743*^9, {
   3.7779100117190933`*^9, 3.777910031102828*^9}, {3.7779100875960197`*^9, 
   3.777910097615247*^9}, {3.777910182284631*^9, 3.777910199725898*^9}, {
   3.7779103210903788`*^9, 3.777910346896903*^9}, 3.777910382224214*^9, {
   3.777910453701333*^9, 3.777910518257777*^9}, {3.7779105551138687`*^9, 
   3.777910598860882*^9}, {3.7779106739627132`*^9, 3.7779107923472223`*^9}, 
   3.777911043842929*^9, 3.777926314954937*^9, 3.784211431917202*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"0d907970-8e2a-4182-b67f-e6f8eadadebc"]
}, Open  ]],

Cell["Let us also plot S- and P-wave:", "Text",
 CellChangeTimes->{{3.777973436755039*^9, 
  3.777973446546905*^9}},ExpressionUUID->"2c74825a-880f-41e0-959d-\
e481f77457b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]", "[", "0", "]"}], "[", "k", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Delta]", "[", "1", "]"}], "[", "k", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0", ",", "5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(0\)]\)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(1\)]\)\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.85", ",", "0.8"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Brown", ",", "DotDashed"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<k\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(\[ScriptL]\)]\)[rad]\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Phase shifts from Eq. (7.75)\>\""}]}],
   "]"}]], "Input",
 CellChangeTimes->{{3.777843980828094*^9, 3.777843992832467*^9}, {
  3.777844323525565*^9, 3.7778444456665087`*^9}, {3.777844778426804*^9, 
  3.777844778803544*^9}, {3.77784484335633*^9, 3.777844849100786*^9}, {
  3.777855073806138*^9, 3.7778550786939898`*^9}, {3.777855373354438*^9, 
  3.777855430457898*^9}, {3.777855582737424*^9, 3.77785560661585*^9}, {
  3.777855645410935*^9, 3.777855657097746*^9}, {3.777855870402967*^9, 
  3.777855942616016*^9}, {3.7779076775789957`*^9, 3.777907739140637*^9}, {
  3.777909745582817*^9, 3.7779098016791563`*^9}, {3.777917376984405*^9, 
  3.777917387167231*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"3a5e0c1e-677d-4959-9558-23208229fe22"],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       TagBox[
        {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
         LineBox[CompressedData["
1:eJwBwQM+/CFib1JlAgAAADsAAAACAAAAnX5iBjFkez7EpTCivL+IvsTTIExX
IFk/LziqL9KzZr//xr6DICBpP9pPj7yes3a/ncCNHwUgeT/ng14ufrOGv2w9
dW33H4k/mp/nlFKzlr/T+2iU8B+ZP0GKOoDPsqa/B9viJ+0fqT8dnMbr2LC2
v6HKn3HrH7k/cwjFyQqpxr+ur4nbbC7KP/voy6bieNe/Zz/Rmexy0z/H7s5t
2UXhv27lKeO0rtk/z9BbeFeE5r8KIYQn3zjgP+nEe3XT7uu/jhDLKqFg4z/M
/Ff+jVXwv2LbVL8DzOY/23Lx7nKw8r9xxYRibyfqP6ckXphyv/S/HuRGBvYz
6j9RCk02mcb0v8sCCap8QOo/+ClbuLvN9L8lQI3xiVnqPxTfmF/02/S/2bqV
gKSL6j8LRer5M/j0v0Gwpp7Z7+o/kfLuV+ov9b8Rm8jaQ7jrP19dFYcjnPW/
sXAMUxhJ7T8iy++lRmf2v8yaE3mtVu0/agcApNZt9r/mxBqfQmTtP6VqmSBh
dPa/Ghkp62x/7T/l0xuKZYH2v4TBRYPBte0/hp+ozyub9r9WEn+zaiLuP/ly
FrWrzfa/+rPxE7377j/rcUfaZS73vxTe+DlSCe8/03UFVkA0978uCABg5xbv
P76A+PkUOve/Y1wOrBEy7z+fWmmwrEX3v8wEK0RmaO8/ET6qkZVc97+eVWR0
D9XvPzhKZQNLife/oXtr6jBX8D9F5NlqNN73vzDACfiHXfA/1ptdr/ji97/A
BKgF32PwPwjO9py35/e/4I3kII1w8D9ACg9tJfH3vx6gXVfpifA/yV9ZtcAD
+L+axE/EobzwP5Uj4Zn0J/i/kg00nhIi8T+tFtpbSGz4vyJS0qtpKPE/vyFD
DF9w+L+xlnC5wC7xPxaYqjxwdPi/0B+t1G478T+p49gZgnz4vw4yJgvLVPE/
Zu/mrWOM+L+KVhh4g4fxP3LaK5Udq/i/gp/8UfTs8T/7XjKoaOT4v1AwuHEr
8/E/jWuNE73n+L8ewXORYvnxP6SsiycM6/i/uuLq0NAF8j8MBLlJmvH4v/Il
2U+tHvI/Bqiienb++L/AtpRv5CTyP+xQqS6gAfm/jkdQjxsr8j8eY7+MxAT5
vyppx86JN/I/UId1SP0K+b/4+YLuwD3yP5Dn2aYRDvm/xoo+DvhD8j9ucdaw
IBH5v2KstU1mUPI/dcqEyS4X+b8wPXFtnVbyP9IcRNktGvm//s0sjdRc8j/N
wraWJx35v/eFyv5yYPI/1FrOquAe+b+8PQvj
          "]], LineBox[CompressedData["
1:eJwd1nc81d8bAHB73GHdSkZ2lOyUlDzHihAispKdJC0kJKMhUSqrKEp7UKKl
ZCVZZXyRqFzzXqPiugv5Hb9/eL1f93M/9znnPOd5HmX/Q85BfDw8PC74z9J/
L/71j5MOTkNkSrTEpAIHNkrKkZ5HTkOahNy2VXIcaDe4YqeYNA1TaYYmgcs5
UFi744BbyjSo34l4fEmKA+G7RC+kX5wGIUW+fVXiHCBEJTTOXZ+Gz79sP+gT
OGD2Jnx7z4tpmJyz7HFZZIOYreZ+8bfTcJoxkv5wng19vcMp26qmYeMX93MC
XDZEz3s3lDVPg2LOA9TIYMMzsLO+PDwNK3ak3c+ks0GpXsPKVnoGzIJOslS7
2cDT8Qu9i5mBNrJyv2IZG07TKm/FJM5AWPnRFb+fs0GU5wafccoMcB6PGdeV
sEFK26OuPGsGBD/G6Sc8ZsPqc23WJc9m4HWk+inTIjbYbqlxuD0yA2W1zZvb
rrKhdWdhie/kDDhm3XZduMwGl5B4CUXGDMQbPZfTzWCDd9bm9jxeBoz+dcsp
SmND+O9S1yx5BuQI//785QwbrhYVeac4M2BZd0ej3gk2rHyb+H6bBwMeCq7d
VX6cDflf9yoI+jKAWyG2CaLYcG9B7lfiQQZ8FR5n+x9jw+vdmQGxKQw4Z3Xp
He0gG0zCj9YZX2LAisBL0blhbKg+7bSancWADzmivvYH2ND4nDQaUcQAldnU
3NoQvL/EM6HhlQywUni6MBXABl+VgCatjwzITxkNqPdnw/AmM63xJgakJovU
3PZjw1TQwuS+bwx4GUy1Dd3LBt6qyCN+DAYwpT1a1nuxQT0iOHqX5iz0F613
fOTCBu3NP10K9GZhLFQvvs+ZDYY87rr0jbOgmvQ+TwrbPG37yCmLWSgJJp5P
dWKDzx2tXY+9ZyHn7Y7jD3awISj0ri7Tfxa23lwI4tizIUxPgWi2fxYIOTzi
Dtgx78RruiJnYdscO4LPjg3ZndO6fJdmQbuU9jXbhg03rh8g7siaBeXD79sF
sO/4Do3k5M0C7VfR7ihrNpRO/HdD+8EsOM9otQZsw+cp8IboUT0Ladmed/ZZ
suG/Rv3Rok/4ea7p7B8LvF8Zj2qmWmbhyX2FSyex6fL5J073zsKsEetUoTkb
BDecGi2ZmYWOgf4kkhkbSHOsGi5nFsw5r2xKEM6v6sM3rXiYEFLTLuuKvbJZ
bW5ajAm6tLGai8AGyRsHfjtKMaGjzsYzAFvnmwvpiAwT7qaPmRGwTYKsaoXU
mRDGdnGJMmWDxbrKmzu1mFBh+rZAD9v278aYfAMmTNaYvpncygb3k2v0DYAJ
eRdC1h/G3mtxi3TSignf274nb8AOFpUd+2THhNeFookLJmyIyCIW7HFnQklE
t28WdqzX6ZgHPkzw0RNcH4SdpLzgOhPIBKKW6GUj7POjkfqmB5jg6pJzlISd
8XSKdP4IE/4z9/4yuIUNOcf2jXUcZ0JL+MLN99g3jX/VKsQzoXO7zLdr2E8+
tsWUpTLB8u3KAx7YLy7Yui1mMOHIRelSE+y3O2v1bXOYoPnzk5kKdrW0CTnr
BhOCQu5LErAb+svGfhYxQbxTW4axmQ1firTrNB8xwXCw2fEXdtf+ewWRz5jg
nPPnSSt2v65ibNVLHJ/XosYH7KHZHDfieyYo6Hm+fo5922z9sf5avH9FG6Lv
Yu9Nb71U0oh/Tyk+Kw9b/tv+J4lteP8S1QQzsXvVBD+79DAhchXl3UXs3MOF
w6t/MuEMr07JBWy3d1v42MN4vRtdOlKxl4l0KzROMKGf12tVGnaby9Et+TNM
qFRbmXQJ+2IB2T2cywRjZXfm0vvtxx9EIF4WiMUOhudjE4wsL0uJsKCGe/LX
UnwNST+fDomxoOTPCCzFf7Y1pvHlchYoRH9LrMS2kF0xmiLPAtZbUl4LNk/w
c34vVRZEbDBM+IFd+dxeSVuTBdLcxdV/seMWRk0W9VjAnZVPFMT7a7w92aPN
iAWKGzaclcMu+/XmSqQVC+IGp33tsY9quZZY27Pg+KFfivuwdaP/NMm4sGAF
n6dXMvYjcQ3BSl8WzD8Pl63CDvGqUc7Yx4LI+1bnfmGvvr/H1D+cBVd/KFnw
4fwpNM08LhTHgtW0XTHbsXMO8tIdclggmtJ6fxh715t8IeWbLOh/NrpDHOev
lOAm1Zk7LLjt+XfUGPtifrh3TimOf8iv8TL26abvrT9bWPDBT4Roh+/H4bUv
XxwWYMODGK3cb/g+2Q6HnrxyhA0/9G5Xr8T3edtJ1SeW0bjubvA1s8U2X97X
y4xnQ+i/826x2JutdmzywnV8tJVHpg9b867ujOp9nBcNL0azcb1Q3zqm3PWU
DZejP8/VYqv8V+iUgvtO4kqC2x9sWUGp4olq/L14vZfbrNhADGKElPfhPHBL
lKZhiyw8ydk3iH+/iuIojuuRQFZQvQzua+0XzRIMsefrulTjWbhvCYk+isVm
e19y1vvHhpQasYwb2AyGdSJVgAP8fim2ldgTam9+bMN9ODveZOU89ti7I2TO
Sg5cSLCVkcH1b2iXpsljRQ6IvDvWaIj9a4IaukedAy0Xa1UcsftO510T1+ZA
mriLTAh2j/yuhur1HPA33H73FHZnGYl1bDMHUtm977Owm4dO7uqx5sAWy4kj
77Eb4jYmpzpwQEtj1Xwrdt2y389NXDmgd9/+zw/sqif3f015cWCYzbKaxH5n
6St+yx/PEZqPGRzs130rTV32c2CrFS9jqX6XRbSFCR7mwJOwO1vEsJ+RUvNe
RXHAcHFH7XLsJ3fMG/ef5MD+svokOewHJnNsudMccKsYOaK4VP87X2i0pnKg
qzsrRRm7MCzMLeEyB7xONVUuOV9g9RmDXLx+xkWSEnZufv+LoZsc+B3A2i+P
nWmYTc2+y4HeuXVfVmBnNDtIbn/CgU6RQENx7PRAYTRXygFn8uhlQezU+Q/h
T99w4FYv6dfSes5mRt/YW4XX82Cr9AR2kpZ+s+QnDgxoTuv2YcfX0bi1LRxg
P3qh0ogd4317bVQnB77IyI+VY0cxPN3XfOdArHpXdAH20TTKud4BPFc532g5
ix2u1lyeNsaBEj7TnwewQ9+dHjL9zYHE7Kx7DtjBu7ZS/s7i/Ym8Iq+L7T8x
a1Y0zwFHFcPNZGyf08WHXfm5UGh3gT2G88VTfl+BMIEL2t/fONVgu5Uptr6R
4MJawZkt17AdhjLWKShwob3mwTPAbl431Omthp9ft/qsFLbdMaP4PE0uhHv2
rRnE+W3D9+PrSiMu7EkkV5/Ert+uH7N7KxfSuPpPrLGtLp9Wzbbgwh27EUdx
bHOldVEUJy6ExYw8ycH3p2pfvKKzGxeuU6293bGhpK0hw5sLAeaBz1Zgm5hG
y4nt54I0M219Gr6fG7w/VokkcSHIuEnZE/fnsqKVodYpXPi0seOoMLbB+AHK
2YtcuBdzzKIU92udGKlg/jwu/FcwsZMHe03uXuK/F1zo+Vv/+CSuF/d+lpaZ
vOXC4FejxBXYqzWEfGKruLBpIqHsCa4vKi+fPGM3Y2u9V2vD9Ue+k+M6M8wF
/umKDxxc767L7VjUn+BCF/Og9ElsmYDCB4encXw/rhUv4Pq7Ynrb3OQ/Lqwe
1k1nGrNBQiKzcEx6Ds6pMx/VG+H6tnt0u4bCHMiHvb2xHptcsHkmSG0OgiYZ
ZTc24v6gM2A1qDcHFsjacv8GNvDb64z3b5+DiQ/5l/sNcL5dTcyUd5oD68K/
zuuxeb53bvVymwP9bcLKZ/Vxfdkfm9HjPwcCDZd7VPTYwDzXsKEjdg4I1MoD
m7TxvFPrn9DwdA5OHVXgbVdng+LlntCLZXOwe3qkcmg1rs8+Dq67KuaA1p/V
PaOG+wvbWPNXwxyc2dEqLqzKhivakp2swTkQzA/y5FVkw5acDxoasvMwnk08
bbEC1+fADVKTSvNA3i46Lrsc77f+4/lSjXnYeY6dNkXB+9Gc3Wa6YR6MfL/H
pkri+sUTHuvmhD/fv/tXJokNaaHyX86cnYfVOp6N07x4XjC68sYufR40jynv
TOfB6xEQuSOZOQ+Rmrv51BZZ4FswE33j1jzwvaUOWM2zwLCzUaX83Tx46Ww7
78XEfWbriaih6Xm4La9u0UpjgY5k1yqLvQswvvDWuh33lZH0kaSsoAUoKCYq
SzWz4AaBNTp6YAFqz/I/dGhkAUlgZWla9AJM7+RveF/PAjrTY1vX5QW4d+ap
R8QHFtzt6w/fX7eA5+n4AotnLJB/MPzh0tp/sLkuuvboJRZ0qjHVqLr/wNNb
JdY2nQUXbgmlGm78B7GUYmHFC7jPXdfY9c38H3wM7bpbeZYFPen7x1S8/8G1
48lqPSdxXz02KfHy4j9QeafyNPIACwgw69c38w8Mviky91myINpsjchL7j8Q
eWBgd98Mr8fCq/gS7yKokvV0B03xnGFTzTUXX4SaL3+KnYxZEOOcfvWh5iJE
va36zqfDgvGg1R+j/BZBg6N4oH4FC5rTXNdIflkEH+li45947rGe9GSpuPKg
l2hoQCSWCTeXJXeccudBPw5XhGbiuZCx5XFJnxcP+oreBq2KYEJh6ty+bH8e
dFBs/QeNg0zgauT3iB7mQerZ/l4Ke5nwxL//zZ9UHuRCH1iebc4EiZ69cZVV
PGjnu968emEm9NQE8npq8aLM4kLO0IVZKE+p81Ga5UUOesLnPK4yIFgw8ldr
Kx9y/ttY7xM1AwFHY8tJ1/nRX5mvekYh06C7b12rvZ8ASv4S5JoR+Be+SGkR
I40FUfXNGXmuxx+oKE7K0+IXQnqCf7pLp6ZAyN5VNkdICOkaf804MToFO2ka
13gJQmjQIDra8tcUjKq2ZHdJCCHTFPbgSNsUUK5JX0lQEELXl81e8ymfggPJ
T1I6jYXQobLWMfmTUyDn3hUZd1gINay6feW3+BTE8mo6NfcLoYjb3Ogyi0kY
sST2qA8IITVmgmzV1klwSpnYmzgkhHprKvK+Gk2CmnjJoY3jQsjn7B4bHq1J
aJY3vFTIFkIr9xVlX182CQqbTFsjKMIot1LR4/3IBNSEO9uv2i6Mtl7wnmq+
OAFapes7j9sLo6d/gk6dOD8B2bPLvNsdhRFTMt503ekJOBDXfeCcmzA68kjd
8eaJCViW6n3hb4AwkkiQmqkJnIDgu8GNH+OFkVq/E1PYZAIIfTE24WXC6HDA
G+n0qXHYePwh+dIrYaRv915pPX0c/KR62kveCqPt55R6+4fH4bXNhj1/q4RR
5Kp/fmb94xBc/vtIRAt+/+67v1DzOFRfDMyLGRFGndEEL5XH4zh/HabOrhRB
O+X1lkWEjcOdvrgX9+VEkISv5L3nIePw5fjj6AYFEfR69sn8TOA4qBeL8BNW
i6COQyz22T3j0CFbK52uL4LIebcNRhzGQYdhZHbVVgQxVcLenjcYh+F7ypkF
cSJo/epveoELdJg4PcDhTxBBbGrpSiaHDtP+t/aGJIsg1ej5zHQmHXgUldfp
p4qg1Uax1i2/6SCbo1RTkyOC3pqqx1yi0sHpnOKf4VIRdOLKR1WFz3TYHfTT
1falCEopgm6Rejr4WBRUFL8RQd+Pd5M4NXQ4sKhw7niVCOo/5camvaPD2eMK
CqKtIkjGcKKI/JwO7/atsteiiSBilned53U61Fr1P8+YEEHuV+gt+Tl0aFS9
IT37WwRxfI+bDGXSofun/OB7Jo7nZzUkX8Lx75aPcRQQRePGywt4z9BhjY3c
g6OKouhF+tW8hcN0yFwjI/DGVRTpnjgs/tOeDt4+6vcH3UWRqdMngQlbOqhl
rrcV8xZF3g05exZs6FC2uCMjwF8U3bYd1Na2okNnV5K82CFRlNT3m1G1lQ6U
MxOGASmiqOTWiM9LXTr0vuV0p18QRb//6cmI6NDh9h+h2NcXRZHeFn4BHy06
GHgrV5OzRNHkM7c9K9bSwXm9247Xt0TRo6jEitcqdLgy8CGIXCGK9h0+/Kdq
BR08pVtENlWKoqyUCJ5dy+mgsqP3sX+1KJLmSxMcp9Ch9DXj76tPomj5QcYP
NUk6tF9aG+/fKYr+8+jz/kSkg6Tp1exXk6LobylvXy0vHXqOFRpT/4iisSJP
+0weOhQ+fNpHYogincNy4SGLNNBb3qDizxVFHSmdL+QWaOA0MV9MEiagu2qR
DU/ZNMi4HvzJT4mA9n+i8MT9ocHxqKRjcaoEdG2TiU7qbxr4ON9UzFEnoGPk
1MK8KRpoEbqON2sRkJXxgGnDBA0+n7BaY2RMQNpuSj+saTR45urXudOEgBak
rR4eGqNBrv7JhDAgoMTBk1euj9IgmFbWc8uKgLydHz3mDNOAz0PtPMmZgFzz
SIf6qDSgGaINGq4ENNEud0se+6uE94CZOwGteXfj894BGhQ0XDU+7kNAcu6v
aFM/aWCyiZ8+EEpA/et0unX7aRApTbV9lUxApFVqfUY9NPCeWWC2nSWgQz0j
one7aWD5RaZo4jwBdeuk9S7Dljq3c045g4BGzg04zP9Hg2Jm1eO0fAJ6tsl9
nNZBg6z2vt33CwhI9Akj5wB2XDGbv+Y2AYk/raj43U4Du2A9b9YDAnoZmem8
2EaDsf8KSP7lBGRqIqy85SsNvjyveB33moB+niymf/lCg5fp3YE5FQR0e9/d
f8HYp63E3zdXE1Cq48epvFYaKJfHHzRqJaBg0QZHpRYaiFy+LuPchvdvnL+5
vpkGf8JefgzrJCDekeeBh7Ar1aZW3e7F7/tPt7O+iQaemXtaSaP4fMxSRC42
0kD+BUHuAJ2A2vpJhabYP9te7fs8SUCN923i/n6mQaC4FO9ZBgEVXakY2oOt
rvNhxxCLgJ686fCTxqbZh103nyMg8s4gwY4GGoSn1q9f5CWiwy/Sbzlh6z08
lrBHkIgslcdSpbBnPim1VIgQUWicRVzXJxpEC8YGR4sTUVvPXvdA7KQE3Wt/
5Ynou+RmxZx6fB4FfcOOSkQkt73ySAi2cOV5g2JVIpr//f7iFuy0ucGmUE0i
EkvYIjr6kQYOspdXftYmosAh490fsCWNTYM09InIZ6zM6Rp2dlTuv0EjIjov
QtJwxnbPsrIz30JE4oEeDD1subLpnEJTIhqRFnKQxC78a6+/x4qItlg7nuuq
o4G/BPdkhQ1+PmTn7gpsNd37jTL2ROQRHJ95C/thGG9glzMRCaetNDqKHXah
+JmhGxG9Dh5M88bWeeS1cMWDiKKrMvVssP80iNj+9SYiQ6qH7Abs0tHybEdf
Imp5uNdcFTtCKGDwaQARKd1vL5TCNlotoUfaR0RU45/a/Njv/EM/NxwkIpc9
UWWjtTSIT5ReoXGEiGh1Hje/Y5sV1vmfiSCiqkcpOV+xBT4cKRk8TkQLG/Vy
67Hr+xXmzWKJaL9UfO577JT5JpvCeHweyYUZ5dh2ciey/iUSUUR6fXQxtthm
dar3GXy+BKXtD7C/unfoVKTg+Jv7ObexrxxPiJVJI6LmV/rJN7Fds7Ubjl8i
IvNBh/7r2CvLe5d1XSEioRf7eXKxezvO+RlmExGD+WooCzt/2rD4yjW8fuEj
SZnYeyWp3D/5ROQ+1NJ2FVtF75K1YyER+TqINi15yMEk82kREbFH9wYvPX/v
IO0X8T5ej5NE/tL79qdla4c+IiINM6/AHGytxxYxDU/x/j1KfnUNe+rzn3r1
50REbm9Nz8d+NnaDcqaMiPjCTv8swD4mbOc7+Aq/r2LqThH2RnX2E7MKfP5P
PbvuY7Mt73IKKonIgiEd9gQ7rqIgua6aiOoqRoWeY/MYXCfT6nA+PFCZWNpP
YcVLygZNOB9/LsRVYa/gRG+v6yYi20dthB7s64eOdYz1EhFcPGr3A3vVyME9
5B84vydE7w5hq3X4H3EbIqJ2ZnbqX+z1T+2vjf0hItk5wwgizoeXqtaqZAYR
BasktElib75u9lSfheNvIUivxDY/t7E6ZoGIWntrzdWw6xf07Ap4SOja/KS8
Jvb2iHX/1fKTkNQ2x0+62E5+SjQSgYSGnvZEbMbu7JY9pk8moYfecmGA7e6w
fMFVgoRcoxvlLLH76sTPxVBISDNu4eRSfu/dQpAsWEFCG1Z+TbPHpj4XyKuV
ISERC39zJ+zgNYtqY/IkdMquJ9cFm36TU0xSIiELumeqG3b4csYmfVUS2uIi
LemBPX1hqsZVnYQWtoGGF3YkH80+Zi0JTaqKflq6X+zowa6bWiSUyiqh78GO
+93vW6tLQrqXjqX5YPME99BHDXB853PvLfl0X3sEaSMJhQaFrF+yiEvLPz1j
Elqdra+99P0Lnz+luJqQkFOG9cWl3xNDNVIxgD/v49u5FM+Vl+/yb5qT0KbV
1YeW4l2h/Uq91oqEym2Hh5yxrxc9fzZqQ0LRh7ofOWAryD7ZTLInoWeigu+2
Y9/KuFen54j3d/qX1NL+qQnfcnB1xus/PvhwK/aDk3k9J1xJ6HhQauxGbC1G
lv9NdxJ6tcojSQf7WWjGRI0XCS271fN6NbbhQGrUqA8JxRTmyMhjv9p9hofk
T0K9FzQL/p8PradS9YJI6GLhOksh7ErLmGWuISQUxt7Mz12qB/qH1twMJ6Hp
OJW3S/ln+2B/ac0REnJ44n7/C3aLQqDJaAQJvUAe1z5gdxI9nPRiSUip+nXU
0v1xT3Lp3RVPQnKN93afx+5j7wg8kUhChPSTayKxB4fNo2vO4fNh2pzZjm1e
0Hpb8wIJ/aDr8+hhF7p7tly5SEJNmfUqy7F9mo6oBGSRkGHsZqvvNTR4f3rB
vimXhA647tr0Dlve9Pzx9fkkdMHq0ps87N5nhc38RSRUTLPY4YZtHKrFOnCP
hBzZ5i762Lmqr5U7H5IQg3GwlYDtlv0l6s4zEop/U0F8U02D9th/SlaVJBSk
eZrNi62/IdXuaTUJqSRMLnypwvPQ1PKo5R9JqJQv1CYf28FPu2m4iYSq2ndk
6WI3bvOOPPuNhJKFuw6iDzRYyzNWMNVHQu4197mLlbi+vjnW6PaLhBbvcW++
x96mdUFRYxSvn6K8cj12jeTbz58YJKRg/MxQ6D3u901WDF02CbGSE4fL39Eg
4XSbQu4cCflsHkoKwDZljR0L4SMjiWMvwl9X0OBtn7SCqAQZOfMYxdm8pYFM
dpHNEQoZpcYK8o++wf3WUffYtxVkZGKo65CMvbFmW8PDVWRUUGKvUP4a95/7
kUdt15HRYZae8sJL3D/9eG+U6pCRpx1p23nsw7Lpn2QNyCjK+ZsoBVsn/Y78
+CYyuv/jgLdiOQ0eHe2ov7CNjK5VT5bKvqDB7a36ci1+ZHTxivLx3GK8PgdC
8lwgGW14HDEjhE3dO0hfG0JGn2Gj6rGnNFBNynp7NpyMwu3aMyyf0OBOPccD
xZLRRrNFp6aHNLjrWJP7IpOMHCMERoPu4Hz1zeOh5pBRBF+LaXERDUaORIRI
5OH4b1utYtzG80qm+qaDt8hIwd0pMPoW7g89qd3qxWSUf5an2/8mvl9+Liuu
fyKjQG7Zjvc5NGg4qhXf0EhGHwOI7L5sPK8lC44wW8joWTIS5GbRYM29V+Uu
nWQkK3seaWXifk+XcyUPkNGmLU5CRzLw+o8NXU3gktGtcZ/tMSk0eHomUnKf
thgyL5W0TYyiwYTJnqQzemLoF2Fsl1Pk0n22nClaL4ZYRcxn8hH4+/7L/vtl
LIbiD53weHoExwcvcj23iaHQgDG34jC8H5w/ig57xVCsWvFRHX9cXw6G6Wy4
LIa6aO801exw/qvtKnDJFEMDjMxd+dvx+fdtkTiaI4bcvHJrJW1w/tsSp4tv
iCFtRswRhiWeXzUela95JIYqxm9IXDPF+T0waiJfK4bkLYsv79WnwTnXADv+
WRz/p+IbQ8vweTr2eQexxdDP/Nmwfik8f2x3Df80J4ZuyfyR7pDA9Xmr9eUL
fOJIuvekYDkJz9fq67opEuLo+Pt1vi4CNDBgTfurrRNHu0VmNs5Nj8GP3KQY
Kz9xxCntJvO1jsGGvlsPz7WII1e7R5rusWMgoRPCLvkqjvYlLKTURY/BxCkd
654OcbSz9luuTtQY3FGtGFrTK47EDKS75g6PwbIDnYqNI+JI7lUvnizHgBvH
byfEI4HKp6SQ2M4x+EbcWG0jI4H89/9dzFUbg9y1eU9b7CSQUZZ0xdePo3Cq
Kj3X7o0E8vTMWJM5OAI75FzvNqpJotHSks9+zGEwC//kJXleEh150ey+X2YY
CuT91ZpnJdEeoWBS8KYh2Lx+nY4/SxKZrFqbZbdhCDq3M4zYbEl0Sor92MBg
CESOn7VTm5dErWuC0gW1huBw26OjcXxSSDTthn+l4hCgszNVWuJS6HqdwL54
4SGg/j69J32NFHKXYLRY9wyCWu39bAcvKVT9Sm1X1KlBaNVi3+nzlsLzjzun
P24QorNtXoT6SKFf9XvyrWMGoWk/7ctZPynUGadEVYochKMS60Q/7JNC3PyP
OeOhg/BhT3GsboQUngfLuVS3QfBkl/lKpEuhOe+ykAC9QRDwFzx086IU+pL1
/SpZZxCKm1xPamVIIZt3j8ferBsE3gLmNZurUshosociozEID6w2dSRck0JS
V69f+rtqEGavVFj9vSuFKmxcCCTSIGRo12i2V0ohTTPr8kkaFR5s8hJNqpJC
QglfA0pHqfDBgjGqXyOFPu9trToxTIUpD/W7lz9KIRF06bzEABXszqYq7myW
QoZetWE+PVQQ+um87Os3KTTSUiQf94kKsRmDCy0MKeSrZypee58KV/Li+k4y
pVDq1hMNP+5S4dG95RXabJwLNbfQQhEVet5ZR6fPSaEcC+tw80IqbKQ9nrbn
o6Atlw9WT+ZS4Y9ZxGiTOAXtqp2xbkilQvCMQNtnTQq6kFF968JhKvg8smz1
1qIg19qQWJlDVHDzO930W5uC1iiLvHh4kArbvvDXL9enoGxX/c1toVRQf8xX
4WdEQQ5o0zWTICoM+/Pc5VhQUOH7zZTTnlTok0G306woqKdA9JyRBxU6v54q
ULSmoNVuHxwmd1OhznTxmpUtBTl/fN2115UKd2T/XbzsREFq6zqe+zpRIbB9
LnrtHgqS9mU1f91GBe/zW6Le+VAQtU9B+qEVFXah2GOOvhTk5x17L9mSCpbF
3IORAXg9tWcywJwKaqkc/+r9FDQbWnW0fSsVBs1Y9h5RFKRxu2tfwAYq+D+f
Vjp/iYK8E31H16hTISzJZd72MgX93nDDTXs1FSJdyrpJVylom6NJoKEaFVJm
Iy9mZFOQuF/yTlsVKhQbc+ZyblDQ1jmaQZYCFTjVi133HlPQgpjA3zvSVOC7
6lsa8pSC3AxkNdpXUIEUWJ2uWUJBBd9lO3mxFYSSLYtLKSh2RDYlZBmO31ao
tPwNBck1hRNdJKmQ0U5Kr/tEQdWPPwteJ1Lx/HUw5OxnCioTEvKaJFChKKLV
wqaJgvIkvTjm2C9XZHCbWinIoFpYcFYE778nJaTjPwrqszfgjRCiwsi6CIus
bgpqtFWz+SZIhd/znQq7v1HQ1U2EDwibryD7v94+fH4/XuiuEKCCxqCMBXWQ
gkKv7a7q5aWCXlmMwp1hCnpdSdPcib35zHdO0CgFNRUPP/rMQwV7jRvPaHQK
+i5yuL9qcQCOHlBS+PuXgmyeLT7+tDAAcSaJnNIZCjoRvtHPAfsMmdoZMUtB
V+LmxLvnByC3pOgCm43P23bQbmpuAG4nCOx7y6WgFyYdbXHYj3cGmcfN4/XP
j5uTsctU6leZ/sPnoZmSV8AdgMoZdc7iIgWllCx0r8f+H3UwFVo=
          "]]},
        Annotation[#, "Charting`Private`Tag$3053#1"]& ], 
       TagBox[
        {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
         Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVlWk0FIofhmW0aKJQotsNXRpkS0UpfiS5VCpJlKSJhiRS2VMiS6hIJZGd
KFnHNWJ+1rEm00iFW1JXWTLGzJix//0/vOc9z3nOeb++SmRPaxdRERGR0MX8
v1OCycu2OQca5cDJcDzFeNPAUjx0UtEelPu7UdXkHH2BQQ9VVHSDn7XVWTeM
4+iS8eVFKz95w/jNgprxPwroKTWxCksV/SFC3uewA9TSNdjO9xYoN0GW6Zeo
/rGT/q/k8/nZj7fBQuaTnaHcv3TlHHG96Zk7wFwx0XFR7if9kuF1D4FCFBSe
aQ9I2cOhl3b1Z/FMY0D26L27kRFC+rT7oT4O5T60G3u9iWKKYNqSviiBWRyc
2h5y6KnTMtz/Nk5l8mM8bOi3LLRdKYG/Es1reW4JoCnvFrjsmjTGOM85cGce
gcaXezt8xNejjk6pkBP7BNT1n2mKWW9E1oxrwrjCU6gNLtq/TlMJfZo26bCL
kyB/4IK72hNl3PCwq+23aTKUHeOGXvRQRbrjXcrohxS4yZDWm6FqIFndmDBC
SYV3CU+3BrzRQdGZgHe8oDSgmmTt1D29Hbv6T/zJM0sHXlzbQ5KhHuYwdNy5
khnQotEQaOu8G/1eEWkTHzOg4eg7EyprL1rGDy6bSMuEM065khvMjXGjX60N
xy0LzisZ+Toe3IdjZ5IzxnWzgbY097a8336sMfUdZ89kg0lE8zVaxwGMV7M2
YjfkgPwPRem8oxbovFozZiw2F0S71905snAQl/cOkH4r5EGBXGmgCu8ofqqp
vj76Kw8EVhLFBfHWmJ+TWD9SnA8X6/WzDlnaoJW31dlh01cwzekmXltuh4p2
agVDqwrAQNd4wELyFE4Yis38+lAAKp2/lJk6DvhYvPLxT0ohhEe52b5xccIy
X0vvq3JFwJz0tHHNOIfJw/ry3KAiSJdWKVcbI+PlTmnKhFkxxL4djpArc0Hp
5GZRzscS4OYt5eUvuYQzkuV5XntLIZdFaFqOHvgjJPPoeFopSP2oZpfHemI5
Jfg5260MtM4M5IoXXcHUHnczz44yuFZymKJY4o2Rh+1Hx3SpYCnz6bFT9VU8
tX2HwdgMFSTTqMe62dfRNEfpm4dTOVgdXE87sN4XNeRXR/5uKIfsQ9rmtn/7
4fz80IfR2H/Aw99eu7YpANNbU6+MKNCAtGLjWWuFW8hLpKp/jaFBi8e+rfPD
t/AApe37+ykayK7bMNhSFYKjBMGJSlYlSDhkOU15h+IuQyuDqIgqUL3R2ETa
GoHRRGduEK8Kxn2JZWZqkfjls/8rr3PVsCV04dtPzSgM88neZLeHDokjri4D
ltHYWTgrSmIjdGduc6zouo/SIO4ooVUDTYQY7pKwB7hnS4JBhHMN5MzbnZdQ
isN7vDxuALMGqvWVe8gu8bgj7oML+WUtyKr9deT0+kd4s1XDctvZemB6G41d
3vwMXxT/s+Xlo3po8ZNZ+ZT7DN8n7iOotNfDkJTBDfPmZFSm2FXJ7W4AjXB3
im7Qc2wlhGmJyDRCaKlM26bl6Shr2Cv9jsEAnXNujma/s9BY+QL77zkGEKyn
9vZfyUY3IqetbnsT/Ek7OLxTmI1Vn5fdKU9rgtWnZ60kVuYi2UdXkBLQDOsZ
LlKW+/LwdWFU7yWtVpCdEw+mEV7jsPRwjOW5Vlhrr21anfgaST6WRqoJrfDX
gEBdS7sQ0/YS079PtQLZRD5aVacI41tiLpxqbIO2Tfeay92K0ef7fY65w1sw
qd7TXT1XiqnEtlAps06IdB+Ia8ugoZFhoMMtx06Q1/2te0a0Evsub93J9u0E
aiOjJJxciXLvowfb8zuBmKQ4n6z8BuMSD1lErmECVcKWXFFYhaEqHZILvUyg
GdeHUfsRKcB8OurNgrht82WrjtejSMZkZW80C/J22j5Uu1uPiWIb+1qzWJDd
c+lFcG09Nrdc2JTXzYLE/8KvvtNpQFWb2QwXgy5wlXkYMyfViL9cSa++LPkA
Rzb46P35hYEX42/QOx90g9au8Yo1Sa14+T+172WvP4Nho7XpnCkTVyqFkb7u
6ofCzQZB3tE9eG9Nm3q603cYsetFi9ZvSO61QUL7INC2avOZ1EG80hhG9iQN
A+NWkFia3wgWe606LmfxG7xcTb5t72BjeqD7sM7JcZg+GiC1QmsCb6fOHuON
cuDw7MVjEgY8FGH1G1cFcEF4inP+6pZJDBuipweEcOFJuB8pSWsSxUVSRHdH
ckFJuU0D9SZRWtO+gfqICy0VB6YI5pOoEsE0LyziQolZyi0/yiRa7qmzyhjk
wubUkuBVLybxYWamQ6Q1DyquOtd9JglQrjKk+oA9DxKn9k8ztAWY3Hl201In
Hky+3Glboi/AnLk/+kM8eHBWzdEn1FyAFScTzgdG8kAs33DvaooA+4h3Ll6m
8yCBo7nQli3ALdcu+Nmo8yEimQgsJSFqGnw9nqrDhxLzNa4LqkLcIWKnPazH
h9EvWt1qOkLcF2MxeNOUD95L9YP9jYTomKVh89KBD6yhyh+E00J83DWhLXqf
D9qyWaYND4WYkuROPPyID2TDx8e7koSY5fRj8MmzRX/JMmkgXYgli+ei+YIP
SUEHm6cKhdghRiPa1/KB8ao9RrpdiB9at/3MbOJDo8T4rrUsIfY9yK8be8uH
2gXXtWt7hDi8Mdk/rIcPpY6JJyR/CXHpzps/C7l82MX2HBwlTOGqGUHd9NTi
3t2mia8rp1C61uu5mcgkUGz7tjClplA+Ysj/wbJJeE2qCKmRm0JBqAWpYJHr
OEFy/Yv8P+R+SEo=
          "]], LineBox[CompressedData["
1:eJwd13c81d8fB/B7r3uvMj/33kpJVpKMykilct4hRRpmVkRZISOloVJWWVEy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          "]]},
        Annotation[#, 
         "Charting`Private`Tag$3053#2"]& ], {}}, {{}, {}, {}, {}, {}}, {{}, \
{}, {}, {}, {}}}, {}}, InsetBox[
     TemplateBox[{
      "\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(0\\)]\\)\"",
       "\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(1\\)]\\)\"",
       "\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\""},
      "LineLegend",
      DisplayFunction->(FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], FontFamily -> "Times New Roman", FontSize -> 
                    14, 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"GrayLevel", "[", "0", "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"FontFamily", "\[Rule]", "\"Times New Roman\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0", ",", "0", ",", "1"}], "]"}], NumberMarks -> 
                    False]], Appearance -> None, BaseStyle -> {}, 
                    BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     Scaled[{0.85, 0.8}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   BaseStyle->{FontFamily -> "Times New Roman", FontSize -> 14},
   DisplayFunction->Identity,
   Frame->{{True, True}, {True, True}},
   FrameLabel->{{
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(\[ScriptL]\\)]\\)[rad]\"", 
       TraditionalForm], None}, {
      FormBox["\"k\"", TraditionalForm], None}},
   FrameTicks->FrontEndValueCache[{{Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
       Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{-1.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {0.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1.5, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-2., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-1.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.1, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.3, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.7, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.9, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {2., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {3., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {4., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {5., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
          AbsoluteThickness[0.1]}}, {-1., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {-0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {0.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {1.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {2.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {3.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {4.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {4.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {4.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {4.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {5.2, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {5.4, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {5.6, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {5.8, 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}, {6., 
         FormBox[
          TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
          AbsoluteThickness[0.1]}}}}}],
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   ImagePadding->All,
   ImageSize->400,
   Method->{
    "DefaultBoundaryStyle" -> Automatic, 
     "DefaultGraphicsInteraction" -> {
      "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
       "Effects" -> {
        "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
         "Droplines" -> {
          "freeformCursorMode" -> True, 
           "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
     "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None, 
     "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         (Identity[#]& )[
          Part[#, 1]], 
         (Identity[#]& )[
          Part[#, 2]]}& )}},
   PlotLabel->FormBox["\"Phase shifts from Eq. (7.75)\"", TraditionalForm],
   PlotRange->{{0, 5}, {-1.5700384780990833`, 1.5700503009216196`}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           GrayLevel[0]], 
          Line[CompressedData["
1:eJwBwQM+/CFib1JlAgAAADsAAAACAAAAnX5iBjFkez7EpTCivL+IvsTTIExX
IFk/LziqL9KzZr//xr6DICBpP9pPj7yes3a/ncCNHwUgeT/ng14ufrOGv2w9
dW33H4k/mp/nlFKzlr/T+2iU8B+ZP0GKOoDPsqa/B9viJ+0fqT8dnMbr2LC2
v6HKn3HrH7k/cwjFyQqpxr+ur4nbbC7KP/voy6bieNe/Zz/Rmexy0z/H7s5t
2UXhv27lKeO0rtk/z9BbeFeE5r8KIYQn3zjgP+nEe3XT7uu/jhDLKqFg4z/M
/Ff+jVXwv2LbVL8DzOY/23Lx7nKw8r9xxYRibyfqP6ckXphyv/S/HuRGBvYz
6j9RCk02mcb0v8sCCap8QOo/+ClbuLvN9L8lQI3xiVnqPxTfmF/02/S/2bqV
gKSL6j8LRer5M/j0v0Gwpp7Z7+o/kfLuV+ov9b8Rm8jaQ7jrP19dFYcjnPW/
sXAMUxhJ7T8iy++lRmf2v8yaE3mtVu0/agcApNZt9r/mxBqfQmTtP6VqmSBh
dPa/Ghkp62x/7T/l0xuKZYH2v4TBRYPBte0/hp+ozyub9r9WEn+zaiLuP/ly
FrWrzfa/+rPxE7377j/rcUfaZS73vxTe+DlSCe8/03UFVkA0978uCABg5xbv
P76A+PkUOve/Y1wOrBEy7z+fWmmwrEX3v8wEK0RmaO8/ET6qkZVc97+eVWR0
D9XvPzhKZQNLife/oXtr6jBX8D9F5NlqNN73vzDACfiHXfA/1ptdr/ji97/A
BKgF32PwPwjO9py35/e/4I3kII1w8D9ACg9tJfH3vx6gXVfpifA/yV9ZtcAD
+L+axE/EobzwP5Uj4Zn0J/i/kg00nhIi8T+tFtpbSGz4vyJS0qtpKPE/vyFD
DF9w+L+xlnC5wC7xPxaYqjxwdPi/0B+t1G478T+p49gZgnz4vw4yJgvLVPE/
Zu/mrWOM+L+KVhh4g4fxP3LaK5Udq/i/gp/8UfTs8T/7XjKoaOT4v1AwuHEr
8/E/jWuNE73n+L8ewXORYvnxP6SsiycM6/i/uuLq0NAF8j8MBLlJmvH4v/Il
2U+tHvI/Bqiienb++L/AtpRv5CTyP+xQqS6gAfm/jkdQjxsr8j8eY7+MxAT5
vyppx86JN/I/UId1SP0K+b/4+YLuwD3yP5Dn2aYRDvm/xoo+DvhD8j9ucdaw
IBH5v2KstU1mUPI/dcqEyS4X+b8wPXFtnVbyP9IcRNktGvm//s0sjdRc8j/N
wraWJx35v/eFyv5yYPI/1FrOquAe+b+8PQvj
           "]], 
          Line[CompressedData["
1:eJwd1nc81d8bAHB73GHdSkZ2lOyUlDzHihAispKdJC0kJKMhUSqrKEp7UKKl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           "]]}, 
         "Charting`Private`Tag$3053#1"], 
        Annotation[{
          Directive[
           Opacity[1.], 
           AbsoluteThickness[1.6], 
           RGBColor[0, 0, 1], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwVlWk0FIofhmW0aKJQotsNXRpkS0UpfiS5VCpJlKSJhiRS2VMiS6hIJZGd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           "]], 
          Line[CompressedData["
1:eJwd13c81d8fB/B7r3uvMj/33kpJVpKMykilct4hRRpmVkRZISOloVJWWVEy
ExklikJERUYkq0QJqS/3XqPhIivid/r9w+P58Ln3jM/7/TqHjKOXiROFRCJZ
4h//ftuQCz+8YE2inco/PUolZtCmtKaB51KTyNnjl2GE6Aza7rSrhi4/iXY7
F2/PXjSDdJUq7hgrT6JbfGHCVeQZZDiqee622iQqMXOo6P0zjSwvKKiqoUm0
77NErdTPaeR3SzDtsOUk0jvidP7Z+2l03ib4XI7dJBrPknftfzuNrsj8NR8/
Nolmwv/bTtROo5hHv4Su+UyiwlzDDK+SafTw9ftzxeGTyFwJnd2VMo3YEwkW
gi8nUZHyk+37naZRxk71k19qJtFczcgUv900so9quV7wdhKtDB3lq7WYRl1y
tAbTzkkk+SOJpbtnGr039d12e3wScSs2bT6sNI0qnhhJqyhOIdvA268oY1Mo
wZM8vD9hCiWFNSZKXJ5ChpzjF274TKPu7JCInnuTaD87RklS8g+ivTgXpS0+
gYZrHAPfPJpF45m1n1Q+jCOp2M7j0cWzSCNl23V6yzgys9tvbvZ8Fj1rf/my
7804qpjeqvjtzSzq018Vll0xjm6oMNqn+meRdE3zX7PccbQtoXLtWvE55MNn
JHL4yjiKPC7RGhI6h7xvPNKR3DSO1jM+rtK1/4tyfzSK1mePIW4U98otp7/o
Q7986Ie7YyhVYGpgwP0vMpPPc+hPHUNC1OWFkWf+IvOLFvuE48fQ8KSV/sfY
vyjm/px4eOgYyu75csKt9i9aQhrJUXAdQxI5nMrr6+bR8B1lfsr6MdQuNynX
t2EeEQ8+B19QHEMRd+nhGprz6Ez7t6g5+TH0J3mt2WedeRRN7NanSY+hzii3
QVnbeVSsOuu5kzmGbp78SZREz6NP/7254DQ1igTQhEPPOP58A1XvaO0oOrNT
YVHJn3kkvnlLGlE1iri6NvnXyQvI+b9U/eqXo6h6T9UfHdEFVGtWd0GtdBSd
M4m6+UBxAYWV8N3Xzx1F353WvD7tsIDsjVkZ2rGjqCnSXIHRuoDu+l9b7es4
irSuX20Z7lhAMy7nAnPtR1FO7HO/2p4FFFCdoj1gO4qC42Wq/IcXEDfg/lfP
Q6NI8t2k8giFBEuNV7woMBpFHz9XvzaXJIHOw8989C2jaPdP6ylZcxK47fPM
nmOMojtLgj5csiRBuUZPVqPoKPq9La+gx4YEwn7BXXeER1F6+KxLvCMJfEr8
uMaLR9Gftbc7F3uT4NhenvcwaRQ9dPxSxgsnQbKXSxmbx0OUcFr8vmgS1G4W
eDf5i4csn6j45saSwLnDlSH8k4dopIuKxxJJMK91ktAf4iG7VMmUT9kksHZ7
3jf0Hw8RnfYBFa9IcLh70cepDzzkvBBmubKWBPumRFlGbTz0Qv6xxpl6Eti2
33HJesdDbqdIP1VbSEDZ4Gbs0MxD1cy7h7O7SdBJ8poTrOchv3192pGTJND8
tlNr9XMeeusnsHJohgTRAoXKz8p4SPq22tSuvyRQtpZZafyMh5qHrxQs8JFh
ScVwf/RTHpK/ulr6JIMMIoNFw1sf81Bn9TGytTIZJowFe/be4yHezi7xCxvI
8FDePVY9m4f4qw5opKuR4agVJU0yi4c0K7VcuFvIIHf5dPn8XR6Ke040++4i
g2KrUQk3lYcOFL9IjLAjw/A9zwbTeLxedbXCfAcy3PkaMO11i4cuFt5vfH+M
DFaGS22ux/HQw8c35sXcyWBRUfn40w0eEnjkeizLnwzbiy6bR1/nobrsJRtf
xpChO+nVuthrPNQrF27w7SYZCne8Mfl6lYcmMhcc+RLI4KZ4J2gjtlzG8C2D
VDLMp7fyukN56MqdV7MdD8ggYxGQZRHMQ8mrNJfOPCSD1Fvr0hdBPPTkdt56
icdkmLYJK1uD/S053sGxhAzRMfRLpCs8pJ3gUf+rmgyc3BdFnZd4yGJZ3zdG
HRlMZGy55tietw790WjA+ysj8qvjIg/dvqmjcr6VDC5zi716L/DQn+vLb/L3
kEFZ/epHIoCHmKLRDxW/kmGkiWmcdZ6H1kXz1e3rI4OSXlWwFrZl5K/pm4Nk
4EtiLfY6x0NPr9baSU+Q4efePsnpMzyUY9i4PGyaDLxlKrVJ2MlCbW0/Z8mw
uLD5rDZ2YMxX/ecUChSsiqPE+vPQSRMuSZZOAY8vnEZtbOclP8uvLqbA02Oc
2JHTPGSU+Ge9BUGBGFnughU2siYPvWBRoInZksrCVpNYlLlajALvLVXl3p3i
IbH0pWKjqygwK9vVYYwt4Cjx/pAMBZp7qyeXYc+tXh1RIUeBkgue33v9eKjv
/saFCCUKuMj81vLH7nDbXDa2ngKNJaoRu7HfKGmftFKjgK737yRx7PKfeiqv
NuH5EZ8deCd56FHB3gH5rRRoO+335Q12uo/J3ajtFNiQb8qfhX1D3crmN6LA
WdLc58vYIRP2S210KaDM//2AI/aZUufWKn0KJL6MP7oL2/2s5zUFQwpI3/QU
VcK22+ane30fXv+Fj/tY2Af/nvs7cRB/v5DqinlfHtKtvFxqa0aBonMd7t+x
NS9f9ak5RAG32iXQja2ge11J0YYC+55tiWnGXkmL58TYUeCVULBFNbZI/e20
KQcKXDypFlWGTb6WaWXnRIGK/DPri7B/G+ayXrtSwCA7WKMAmyv0pFnJgwLt
/heSHmF/bikNu+GFx4sPOpSP3RRTsXPGlwIpHY9dn2BXmLyetT9Ngezg5fUl
2E+WND2tO0uB4KB6jwrsrI9tXioXKEC3qjV9g52Q+HldXCAFOg1ET7djh1t/
6/8TRIGhExnNfdgBEgOpDmEU+NjkYzaO7dX789CbcAqscHen0vH+OKb/ZmyI
xvNz9/8kjm3mONt4K5YCJ1efqVfF1uIugqOJFPh2q5bjhK2SI/qnIYUCzq3P
+IOwpY8vK96YRoGoX2MqGdi0X6sV5rMpYJ+6/wQXe7pAse/YAwqsXPbrvCCu
h2Ef1duNDymQebbVTw373YQ2kVREAYdxCdFQ7JrSXW8XSigQF/01sxC75KxR
sHM5BcxMYwX+w075azWtXkWBavoODV1cn860U99aWiigPS25SwLXt7hUw6fZ
97jePka+McFu2bKqVaGDApN5OU/DsTU9Xr+80k2BhPqXpfPY9A9LUzQHKeBT
cLNuEvdTdnqJ+R0yH5gpdx6Rxf1qWS6wr5HKB2sjB+c9sIXa7fSm+flAyWbw
8TNsP35+dRMRPnhRS91mivtd78Qhgr6SDyx8Ig/E4Xxgb5t+66nBB0Geek93
4nxJNDeqTt7MB3RxVVoKtpFXelm9Fh8wez8wJrCLM/bkyOzkA/Cy3psXyEPB
i5NCOvbxgYv/rntSOL/kPm2FHS58cGfCXX11CA8d9T3/VCiZDy6Wbov3isDr
U+t9ui6VD4YHLX98wBYYgxL9dD4weq9pvCWShx770EsD7/HBFaa6OjkK97d3
7LPfhXxQty+/6UY0D8V73X/e08gHTbNllCexPNTg8aHq4V8+0NO2Ci9NwHmo
rFndQKKCvc47tCSRh7x/JFZz+aigT5p388Ze5mFXIy1AhXNuSGBtEq4v96Ha
uGVUyF/3YDYyGY/ntlAfsIEKD3stXmzG50vrOsc3SWpUUEhpyLyGnTFU+6Zk
ExX+M1Iq68I2cAtv4G2jQsiil7bn7uD5uS5tPLaHCreeWDAK0nhog4tSi5ED
Hj/+RdwwPr963aS8Hh2jgr8zm189g4ciPViEiCsVEu97a57DHvKZNW49QYXQ
oG9PqJk8lBnQ2GEcQAVfWdmkxfg8NLlUebrwEhVaLDbb7cYmXSkSYwVR4cpL
dmkQ9uGwFKv2a1QQUtmzbBpb7Ib7F4sEKiivHfjbgs/Xujj7i6XJVDjWvIlL
wuevX4Kp1PI7VGC1hWqrYr+/vc3hcxYVKIduqERhB6ZtoGjlUCFQ9dbzZ9jr
M1ZnJudRYZWaUk4fdsR9QY5NIRXcliyKVL2P+zF3IeTFUypkqfeds8AefDgu
v6qMChq006VnsXcVdrv2VlJhxNtq8XPs38Wti1ENFUjbri77jJ1RWpObVkeF
92s2OExgL7zI+3GkmQqTO4TTFHJ4KL8yLarqHRXK/L3DEbZt9c31su1UCJvK
zDTDFngd1nrlExW2zXZwXbDL6s9793dR4cE57YNnsV3fejH0eqkwrCzVcxV7
WfPRwqz/qGAdVRMaj13besiUxqHCn6+BRhnYJ9v2/nYapIKSZsm6h9iyHehW
3XcqmPo2iRdjv/ukrrl2hAqWRpoS5dgXu9Z+ChujQrKZt2IFtsqXlWcGJ6gQ
N0XSeYXd81V0hcEMFdoDz9j/c3gfX/mDOfy+V/lc+vf8Fs6UtQCJBllfo+/8
+76Bge+zx/looFR5qezfePHDX2830mkgkDrb9G8+ej8/7FAWoMExvdqOf/Md
G6nvjRSmwXKP7Hf/1nN37PmlnwQNfpX6lf9b78GJAun9S2jQVMaIOYM9P5VZ
lS+Gnx9z2u+M/fBPgqPoShoceXdszBjb5m8En7ckDcqLBM9u+7e/pMCsdzI0
kB92+CqL/Yzit0t1DQ3knpyRXZTzL+9cubEKNAjQcEff8ftbusg2bEyJBl1R
dupN2LUCBxVMN9Dgbs3l2VxsX2G9hiI1GvTXC98Kw25lKgue2koDbtwpVS1s
bU/PoZTtNGi7tUqUhZ1fn19fjWggLS77dwjXX3SAajChT4Pa473kG9jzH30d
Nxvg9TX5LzmK7alaDHZG+O+fN25Qwzbiav7NM6HBBwOxU29xP7yAM91t5jSw
nna4fRNbOaWsbMaSBoH99FprbMGD20/vtqeBc/V3oX7cT2/Ldo70udMgxiTe
pBv3p9aSoObFXjSQDRo3iMPOPVGbt9GXBjtSgtT3Yl9bvdv14hm8f/7FHwtx
f++JMvpvRQgNMh5tUXXDefBsIKoSrtKg79rnKAb2Wp3WVJcIGvivt35Xmo7z
f8rY+mksDU77WZPncZ68PnLow8E7NNA5E/zTG+eNxvPEJ/53aSD2WNJ0EXbW
0q7rd7JokLqCEZeK8yn4ra3Rj1waPByDzKrbPKSj4fg6rJQGHx3lPo3gvCuM
zszML6cBL/De1Cls2SH25Y6XNBg1Lx+ewflIvuOivbqWBkZFJXqzOD9f8XuW
VryjAXvIOr8f37c3Oubf4nyggdrxmwaW2OkvRk4KfcL1ttfo8Vt8/77k47vR
+gsNKOc3fcnB92/tbv8HE0M0ULRm3DXE9+/n+VdSlPnowJd1ffdqnPd0I3Px
BDodfJffu+qEzwPjobVJZAE62P55vTYbnxcDq5vjPxJ0fL4fuCgRzkOsJLEb
gZJ0yEnOuPwd37/dgx5ebd9KB0GmULYAPp9KpC/xox10aDu5464sPr/IFcah
D4AOPxIHpzbj+3PC9GTQxd10yH/XW2yNz8Maz52XFMzpQEKW3oH4frvS8uOp
AG86TDsdk9znjet7Iuc39yQdfj66/0nLC99/bpw/aexPh6L5yJE1J3hod7O0
j/xFOuzdp7PjtzvODx13j3cRdAhm/7b3ceGhRmXSUbn7dLi/X9X812EeOk9W
PNj0hQ5uzOFv03vwfUxPsFP+Pzrc3rzZM3k37terP+wvs+nAr1oYsVUfn6+i
BV6a3+mgc3AqyFsX388kNK6nT9PhrbZGcNUOHpLcot3ix+IHRZtQLk8V/z93
wsRolQE/KNzLUbu+HPdvz7k9J4r5ISfcxHlfxQjS9H8gfL2UH26WaWoXl48g
B2ZnW0E5PywuF0gQKx1Bz/ZsOjz6ih/MpBd9/lAwgpyfjvj4NfODYHzDX9m7
I6gq+ljKOS4/HP+q8F4yaAT/P7//V+jyRVAWv/h8tt4I4tyTiUsLWAQOlYan
Kip+oTiFFdQy88Xged9QJeL8TxST7FzvIC0AfS3pJ/Zr/EDWcYdbhAYEoPW9
X6raj2E0rZc9k1YhCMlSN45lxw6hfo7OmeowIdjK479k6TyIdNJaMhQjhKA8
Z+R1lMMgSre0br4RLQS5ytrPXtsOIrtGH9mjt4TARNL20Q7TQdT1OL2JL1MI
0o4NbN8Pg6jt/Lz0rgohKPb3WPgtPoiqGeUN9b+FoH++qcy7bQBl7FBd2ewg
DGKbIwrfGQ6g6v0CQbPHhCGxRidFZPcA6rPvH17nKgwuYBx0QHcArb5yqzz0
hDDEL4+y6to2gLLqZqzgvDC0pllZLFEZQNkHqhOL4oThV82gzkpiAOU4mC5L
rhcGj+HVty93ctEbX+WLb94Kg4/xcdHVHVw0GETjTjYLQ3jTn/L691ykcK/0
qWm7MCTNTLwSb+SiB8MrzYX/E4a2r1ueDLzkotyT7JuBf4ThLfHJWjKLix6F
nGK4qIiAwfLGBP6TXPRj++ErIRtFYMP9CS8Zby5S/q03nqkuAtfoxSHanvjz
jks6vm0VAY/JXZ5XXLgoBxUlWuuLgO5meV1VWy7KmuFJ7bcXAf+8dY+U9Lko
2dNj/aZYEYBjT2MSJLioS84szTQOf1+Gip24OBet6NlG+CaIQFxX4rl0MS5K
NBQcy08VgRitVXdLmFx0a23uU4VcEVi6EPZAYDEXxfw3sF2iRgQejD16bjzJ
QWHmR/fyTYgAX36qs80HDso40GPrNC0CBVuntq58z0EvDMxP1M+KQFSG98/e
Fg4a27E7NoIiCnLS+8d83nKQrbzSJxYhCmXcN0fqqjhIbWrMUU5JFGrPnpZS
eMJB+0bd/ULXi8LSd1XJawo4yPU7O2RQVRQmb9YMyj/ioNSvH3MebhGFfZSz
0xoPOGjRm/JfGvqiIFXY+vriXQ7qTbxybpeDKCwu7pqsv8FBMzdmI+4fE4VH
u+P5KbEctCTKL3Wxqyg4H0npQNc5yOCy86vmE6JwM08wsy6Cg4rdDOkWAaJg
OhbYTgrhoHAt5g3nBFGof/53fs0ZDtrUc/dBWLMoXHn0SG2NAwcR612nC96J
wp75tXeH7Dnox6X1uzs/iIJJl4LYEzsOylr9nK3QJQof47cwDGzx+O7tUm+5
ohCmkEhKPcRBfwL49tJJBBB10+/a9nPQYLazbzKZgGqTlry6fRz0saUhaT0f
ATct7N1eGnFQoXTMoAWdgDf6hVeKDDnoeK1E6H0hAsJWNHGr9Dnos6Bm1Z4V
BEwFeK51QhxUp5E02CNOQNu6nokQbby+w3OiPhIE+HCdAh7s4KCYgmq7JCkC
5l7a3pvexkF7TA/MDa0h4IJDhkTpFg56luy6OUKNAMU22tQTNQ66V9NoJ6VB
wLn0GfacKgfF/VgfWrSJgF9l3daG2N7aE+3dWwgw2nzv/Y8NHKTQd9lXGRFw
QqAj5oAKByWuS3nUvJcA1lcJn2sKHPR7XD87aB+e79UHESNrOehAxdjtrQcI
OLJL4oglNt3UMDLbhAD9yq9yavIcdCpg5vgFK7yeiLw0mhwHvdPPdlS3ISDS
9ajg5dUcpMwwth6yJcDerVhoQZaD2Nk5BuZHCCh7EfKSgm3SekhBxYUACt3U
TEGag/KT+KT7XQmwUvIYKpXioMXHCsSSjhPArjL6ZYD9aprOTztBQIOoiMYp
SQ7aIFvC6fEjoMubtHZQAtfHD4cvN04TQDv040k4NrdEuGPPGQLEzziFbMC+
s9eptvg8AbZv/o5eWslBQqeWZEZeweN1pZttE8f1jV4l6wQTwDw9ET+ygoNq
FnvcmA4hwLLXZCYb+9ydmsvHrhGQWx6+eAX2R1evs+IRBIyJCz7qWI77R32l
z7tIAprgm00c9lC975HtMQSkt2XWiWHr3ZC0HIsl4Dt16ZkeMQ5Kt317IOcm
AUfTv0llYluOyqAlCQSsqbTboYldJ/5+1Y9UPJ8/c+Inl3GQLCdgaUYaAas3
OQ3rY18oUBC2vEvAcJJPiAS2hl7gXE0WAS4iHYual+J6ElH+ffYeHi/ShHsf
+3vnp+8bcgh4q1V1Nhg7w3NDd0oeAftckh/qYM9v7m4zfkSA1wrGTjlsK0rY
W/4CAoKDYk/xYxc3qVW/fEzAXoVkvR9LcL8l9JadLCQgPP5eThu2h0P4k3XF
BBiGbbhdjv1GSfPB16d4v2dzV2RhX3oVlbi3jICQb7q3z2MPf3kVN1NOgPZ1
0oAbtsXseMz9FwQ4Vq9ItMKuWr42yrwCv7+0XbmG2Mqa1tf4XuH3vXrL8h3Y
CaZRIU+qCIjXyuzZiE3xeXXZvoYAvibNsTXYntHjF4RfE7C7Jd1UArszT/7c
8zpcT2ZRsyxs3Qar025vCNj/8B5bCDufG+kr9paATrdbi/mxxamvTrxuJGDQ
jeREwQ6RGT9+spmAAHLU6DyLg3ja8i4yrQSsnOl9MIdta2t1tPUdzo8HiVdn
sevPRtpfaCNgPZ/N/62WUGmj1E6AzfPXmf+eTy0eO/S5g4Cf6v4d/75vUdsa
s7BPBEiUCC3/N57fiOXBTZ8JEPOSdaZjfxWKNOrvwvsbaFouiG2oWLkntocA
pzVaokzskt1jeqiXgEWPvexXYMs4rdn58yuuj5zIbBnsyCuWO1L+IyC6W6FH
EXsqLWKrQT8B7c7dfzWwHV9WbJpiE9D3RYsG2C1do6rZXAIq9b/82Iu9dVpu
vekgAS3bLAsssbOWWiqSh3E/j8Fu53/1oB4hX/Ad15ulcoEfNtdzVFJwhICF
zsOfb2IbR8itLOMRoDrZFPOvHl7kHBJzGSPA4HsMpQT7Zv9L0ZoJApLvuS10
YYNVOOn8HM5bmwd1yrj+8k6/nFOYx3kVLVD2r16XxfGmPy7ges7w0LLC/tli
MarGxwDz+zfaw7CT9Vb3DS9mgG6fcuswNs3RojdRkAHZbw5lUHG/eF+61qUv
zADJbMvPkti7y0faMggGiHdbHzbD/r3hRY21GANeL5JbW4O9b6V59ls5BiAF
xtI83J+J7PWvbOQZYH+6/14dNvvRou4faxmQuTd/Vx92ALwgRJUYAPXLklbg
/n/otDrAVJUBbj5zUlexBR6PmvTsYIDgtfk/R3CeWJxt9PREDNhDrrc/j52h
k311Hhgg8n1F9C3srR2WFdJ6DPhW/EGzAdv1T+U6J0MGxKla7VLB+VWvF036
ZcEAYm3FazY2U8R15SVLBpzo9Oucwbb7tFOTsGaACrvhpAjOv0m3CXe1wwxQ
17igoYmto94aWmPHgKEHf4wNsKPncu6aHWFAwg+zQRts+eu2n04fZcCsDJ/3
v/z0tdQc43diwPiWWKsY7AoZQjjJGe/PJe+H6djmxTU6z90Y0H395cVK7PQL
qYeN3Bkg8+jyZDP2D33/M188GDDdqfumGzv4s2L+ghcDrPYlHJ/AfpdBbYjx
wfP3uq1Oxvkt4dHbL3OSAYvswnYLYbtuejZf6MeAtLCUjGXYRfOxK/ROM4C7
TXqnNPZ8vbtGhz8D7B4ckVqHbRi764DzWQY8n8rbqoodby11fOocnv9e88gt
2H2rZ4KvBjAgo6qIhbDX/2xLW3GRAYWxsk162OdKHpbnXmKA8jSp0AC77lJo
x7bLDPhtVVi1D5tpcITXdIUBC7p3pg5i2zG1BO2CGbDde+NBU+zcbpb8SAgD
sho6682wJ7N+QmAYAzqDBG3MsXeeqLdhXGNA6LKd9H/+0zmkXxvOgCeblqX/
+3yxrpCafyQDLu2+JW2M7Zm/fpViNAPOfzwQ9G98+RXGi75cZwAr4EvNHuxv
QSfHr8cywGSu+4sOdtKvW706NxngemCkaRu2idWzhok4Bpy7XxWpji1U21Wc
E8+AjRF8KxT/rW/93zSbRAYkv3b3lMK+lCQVIZLMAKXY0hAW9haqzumqFAZU
3sw9TMceO3HMwS+VAdrtIqNT+P09/BxqtDaNAVdnircNYjvpPdjclc6AD6v8
tn7C7lzxSxiyGND/u3zHE+wbwcTMWDYDbv1lbL+NvXdEjZ19nwH7uqS/hPyr
r1r/csE8Bsw92j9lhn1mQ3J2xUM83oivqxa2avKLGJ98BkyWWHlIYmd5kV0+
PWGA7KLXEn3/6r9rtUl4EQMM/oZUVWGL7dLfseMp7if3K0Np2OHiEazMZwzY
9nS86BC29+slr05UMmDiYEFDMe43xY2b82SqcP16M6WuYvcnW8W3VzPg/enJ
z1b/+tf7jodWHQN0lv30mcb9vX2lwgp6MwM4an31MtiTIYbUshb8vrxcuAM4
Hwp4HiPu7/D+1wfvf4gtW/fk9fsPDDAqk/61AXuRzzbf1C6cD6qFIrI4f6q7
Dx8+2IP7MT5xVRfOs/P6gXv4ehnAThG2jcH+tfK1pNt/DPiasMFmCudne93+
Ro1BBqQrfhIqwOdLtKpPycAQA8Z6A3UssXffvnk3+TsDBjWSry8wOajcp9Of
NMIAx8q0Y3uw0yQc5ZomcH49M8irJjhIS11pveMUzodvQeuOYrcb/N48Pc2A
rT9eDJOxF/mH7pWbw/UunaqiJYr3732ubwCFCXIHr5y7JYzzbvBkAJPKBOkL
Ex1rsbPmt4fm0JhAshw4+kwI14NSa1L7IibsHDsr2i6I8z90/JWyKBPu1RHe
E4s5qOv2i7fVBBMi02mKZ7H9ikLaLZlMOKsTwD+7iINyvokNBi9lwjNu/5oZ
fg5ibNsu+mUlE6rzMl/10nB/jwQfjlJggtgOJmU/Geczfb/LakUmUKleKkUk
fJ6sEvMpU2KCRH6f4zJsQ8MHwZz1TPCMu8r9OM9GhVnNeTs2MaGY5K8Ec2wU
ZLXsz8+dTHhdMBFXOMlGkt5f+YJ1mXA6IerN1AQbPQvNERbfxYQpp29jWtg/
irRk9Pfg8T8+Wft8nI3MROz33NnPhDPOG6cyeGwkV3M/fr8NE5TMfY6LDrNR
i/J0Vo8tE2g2Db83D7HRmfg9RcftmGDfu/eC3SAbNboNtYY6MGFvtFtoNpeN
fAmlxZUuTNC/e9RtZT8bVR7OP7/BjwlmuWn0e91sZD1dfISIwvtLsTHVaGQj
qiPN6040E3TEq3tWvmWj/EbzC8oxTBAXEbMhN7AROW0yac9NJkzfK9Wsq2Oj
nF1bPgQmMeGSsKzH5mo2mrjxfNdoNhPk906Olj5joxiVasW2CiYsuaZ7Sj0L
P7/FZvGVV0yYvP489UUGno/u7wHVaiZsmvh8XPcuG/2yks+Ofc2EGscdkwZ3
2GhvaLiUcRMToo5bDGklshH9q8mSd5+Z8HW4i/Eogo3Ox/T/bf7NhCNWZ6W6
vNnIeZz6vkGRBfJvrDbd02Aju1y9FltlFhTd5P9aq8ZGFg7BjSMqLFg2YNv0
30Y20m/lq1uqygK97Q/PLFNhI/k8ynOHzSzYcc1gt/saNuI4krJndFmAnkft
rF3KRsfaZs+sO8yCsdOBzjDRjxyfjElfu86CZ0fpBa0F/cjjiumcYSwL/DUW
ug0f9aNTpsWfhG6yoFSGdLE2tx9dnTgVHRPPgsrYApWi7H6Uv3VmNiGVBRyX
43EXU/rRTNXCx3t5LPgQl2b0LrQfxbQJRdXWs2BO8bPBadt+lJzp6RrawAKf
izzbOqt+lOnXorunkQV9daz9Sw/1o5JlMX8aW1ggaC3dWWDcj3qsWa4fOljA
3C/2/ZN+P1rbv0K3r58FsjonRKc29qONxeckszgsOLjSNE1zfT/SCumecRpg
QW+Zr94ppX5ktDb18dAwC1ICrXtG1vQjX3dpydFRFmhmv8/qEu9HAdsvzxSO
s0CJHA6s5f0oRLiv3W+CBYzLV4X3Lu1HiQWZEdPTLLBq8jJ4JtqPMgKpLuV/
WOCa61z5U6gf5Rk76QTMsWB3TaWfrEA/KpatW6U9z4JjslRPC/5+VDEuP7Ow
wIKamy/zrlH70f8Apox+MQ==
           "]]}, 
         "Charting`Private`Tag$3053#2"], {}}, {{}, {}, {}, {}, {}}, {{}, {}, \
{}, {}, {}}}, {}}, {
     DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
      AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
         Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
      GridLines -> {None, None}, DisplayFunction -> Identity, 
      PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
      DisplayFunction -> Identity, AspectRatio -> GoldenRatio^(-1), 
      Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
      BaseStyle -> {FontFamily -> "Times New Roman", FontSize -> 14}, 
      DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
      FrameLabel -> {{
        "\!\(\*SubscriptBox[\(\[Delta]\), \(\[ScriptL]\)]\)[rad]", None}, {
        "k", None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], ImageSize -> 400, 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}}, PlotLabel -> "Phase shifts from Eq. (7.75)", 
      PlotRange -> {{0, 5}, {-1.5700384780990833`, 1.5700503009216196`}}, 
      PlotRangeClipping -> True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
    Placed[
     Unevaluated[
      LineLegend[{
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         GrayLevel[0]], 
        Directive[FontFamily -> "Times New Roman", FontSize -> 14, 
         Opacity[1.], 
         AbsoluteThickness[1.6], 
         RGBColor[0, 0, 1], 
         Dashing[{Small, Small}]]}, {
       "\!\(\*SubscriptBox[\(\[Delta]\), \(0\)]\)", 
        "\!\(\*SubscriptBox[\(\[Delta]\), \(1\)]\)", 
        "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, LegendMarkers -> None, 
       LabelStyle -> {}, LegendLayout -> "Column"]], {0.85, 0.8}, 
     Identity]]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.7779077417378597`*^9, 3.777908014889962*^9, 3.777909698238928*^9, {
   3.77790976335063*^9, 3.7779098036006393`*^9}, 3.7779263191758127`*^9, 
   3.784211435481442*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"93fa1628-8d37-4a5e-9280-14b3e3bc54ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell["S-wave Pole Trajectories", "Section",
 CellChangeTimes->{{3.777973472490683*^9, 
  3.777973480219014*^9}},ExpressionUUID->"fa206de7-4be2-463b-92d4-\
bd82f1bd31bc"],

Cell[TextData[{
 "There are not only bound states but also resonances in the complex k-plane. \
To trace these singularities as a function of potential depth ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "0"], TraditionalForm]],ExpressionUUID->
  "9f72c04b-2b6c-462e-9c12-c5723f33b540"],
 " we work in the complex k-plane (only one Riemann sheet) instead of the \
energy plane. The energy plane is more intuitive but exhibits two Riemann \
sheets. \n\nThe following part is commented because it served to produce only \
one picture of the animation, and is only needed to design nicer pictures for \
it. Use this if you want to modify the animation, and copy \
\[OpenCurlyDoubleQuote]Grid[]\[CloseCurlyDoubleQuote].... to the animation \
once you are satisfied with appearance."
}], "Text",
 CellChangeTimes->{{3.777973482891066*^9, 
  3.77797365797785*^9}},ExpressionUUID->"94404cac-70da-4a78-9d23-\
19cc62547b8f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"von", "=", "0.009"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rn", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plopo", "=", "25"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"t", "[", "l", "]"}], "[", "k_", "]"}], "=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", "/", 
         RowBox[{
          RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
          RowBox[{"k", ",", "von", ",", "rn"}], "]"}]}], "-", 
        RowBox[{"I", "*", "k"}]}], ")"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Do", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[Delta]", "[", "l", "]"}], "[", "k_", "]"}], "=", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
        RowBox[{"k", ",", "von", ",", "rn"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana", "=", 
   RowBox[{
    RowBox[{"-", "1.5"}], "*", "I"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana2", "=", 
   RowBox[{"2", "-", 
    RowBox[{"2", "*", "I"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"polana3", "=", 
    RowBox[{"3.7", "-", 
     RowBox[{"2.1", "*", "I"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana", "=", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{
         RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "polana"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana2", "=", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{
         RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", "0"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "polana2"}], "}"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"polana3", "=", 
    RowBox[{
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{
          RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", "0"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "polana3"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"testp", "=", 
  RowBox[{"Grid", "[", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"ContourPlot", "[", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{"Abs", "[", 
            RowBox[{
             RowBox[{"t", "[", "0", "]"}], "[", 
             RowBox[{"rek", "+", 
              RowBox[{"I", "*", "imk"}]}], "]"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"rek", ",", 
            RowBox[{"-", "2"}], ",", "4"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"imk", ",", 
            RowBox[{"-", "2."}], ",", "2."}], "}"}], ",", 
          RowBox[{"PlotPoints", "\[Rule]", "plopo"}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<Re k\>\"", ",", "\"\<Im k\>\""}], "}"}]}], ",", 
          RowBox[{"BaseStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"FontFamily", "->", "\"\<Times New Roman\>\""}], ",", 
             RowBox[{"FontSize", "\[Rule]", "28"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"(*", "1000", "*)"}], "400"}], ",", 
          RowBox[{"FrameTicks", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "2"}], ",", "0", ",", "2", ",", "4"}], "}"}], 
               ",", "None"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "2"}], ",", "0", ",", "2"}], "}"}], ",", 
               "None"}], "}"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Framed", "[", 
            RowBox[{
             RowBox[{"\"\<\!\(\*SubscriptBox[\(V\), \(0\)]\) = \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"NumberForm", "[", 
                RowBox[{"von", ",", 
                 RowBox[{"{", 
                  RowBox[{"4", ",", "3"}], "}"}]}], "]"}], "]"}]}], 
             RowBox[{"(*", 
              RowBox[{"<>", "\"\<, R = \>\"", "<>", 
               RowBox[{"ToString", "[", "rn", "]"}]}], "*)"}], ",", 
             RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"2.5", ",", "1.7"}], "}"}], ",", 
           RowBox[{"Background", "\[Rule]", "LightBlue"}]}], "]"}], "]"}], 
        ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", "polana", "]"}], ",", 
               RowBox[{"Im", "[", "polana", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", "polana2", "]"}], ",", 
               RowBox[{"Im", "[", "polana2", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"Re", "[", "polana2", "]"}]}], ",", 
               RowBox[{"Im", "[", "polana2", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", "polana3", "]"}], ",", 
               RowBox[{"Im", "[", "polana3", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"Re", "[", "polana3", "]"}]}], ",", 
               RowBox[{"Im", "[", "polana3", "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
           RowBox[{"Line", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.2"}], ",", 
                RowBox[{
                 RowBox[{"Sqrt", "[", 
                  RowBox[{"2", "*", "m", "*", "von"}], "]"}], "/", 
                 "\[HBar]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.2", ",", 
                RowBox[{
                 RowBox[{"Sqrt", "[", 
                  RowBox[{"2", "*", "m", "*", "von"}], "]"}], "/", 
                 "\[HBar]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
       "]"}], ",", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Delta]", "[", "0", "]"}], "[", "k", "]"}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"k", ",", "0", ",", "4"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", "Black", "}"}]}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<k\>\"", ",", 
             "\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(0\)]\)[rad]\>\""}], 
            "}"}]}], ",", 
          RowBox[{"BaseStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"FontFamily", "->", "\"\<Times New Roman\>\""}], ",", 
             RowBox[{"FontSize", "\[Rule]", "28"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"(*", "1040", "*)"}], "410"}]}], "]"}], ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", "polana2", "]"}], ",", "0"}], "}"}], ",", 
             "0.05"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"Disk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Re", "[", "polana3", "]"}], ",", "0"}], "}"}], ",", 
             "0.05"}], "]"}]}], "}"}], "]"}]}], "]"}]}], "}"}], "}"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<test.PDF\>\""}], 
     ",", "testp", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Automatic"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.777911699014045*^9, 3.777911773288547*^9}, {
   3.777912370490368*^9, 3.777912392332247*^9}, {3.7779124610296173`*^9, 
   3.777912492701548*^9}, {3.777912528097074*^9, 3.777912530983883*^9}, {
   3.7779125811540003`*^9, 3.777912722540344*^9}, {3.777912755325943*^9, 
   3.777912756181304*^9}, {3.777913109912396*^9, 3.777913125248138*^9}, {
   3.7779131565794992`*^9, 3.777913183938075*^9}, {3.777913263612808*^9, 
   3.7779132881570272`*^9}, {3.777913347918737*^9, 3.777913416488883*^9}, {
   3.7779134773548594`*^9, 3.777913489250724*^9}, {3.7779135507646627`*^9, 
   3.7779135770460367`*^9}, {3.777913655425433*^9, 3.777913690561138*^9}, {
   3.777913734554757*^9, 3.777913790260064*^9}, {3.777913820301655*^9, 
   3.777913842853264*^9}, {3.777913885447241*^9, 3.777913902926955*^9}, {
   3.7779141378465433`*^9, 3.777914269546398*^9}, {3.777914387175311*^9, 
   3.7779144070938377`*^9}, {3.777914482166615*^9, 3.777914612285224*^9}, {
   3.7779156227476873`*^9, 3.777915659443634*^9}, {3.777915731183126*^9, 
   3.777915758207039*^9}, {3.777917330046852*^9, 3.777917398208054*^9}, 
   3.77791799859509*^9, {3.777918036875984*^9, 3.777918246778537*^9}, {
   3.77791829687501*^9, 3.777918317219092*^9}, {3.777918369229374*^9, 
   3.777918369356702*^9}, 3.77791840046395*^9, {3.777918585164111*^9, 
   3.7779185916513643`*^9}, 3.777918626583932*^9, {3.7779197112853403`*^9, 
   3.777919760505095*^9}, {3.777919808830806*^9, 3.777919819211282*^9}, {
   3.777919917742535*^9, 3.777920003826735*^9}, {3.777922100128401*^9, 
   3.777922157409013*^9}, {3.77792220576365*^9, 3.7779222375011597`*^9}, 
   3.7779225081305933`*^9, {3.7779225612365923`*^9, 3.777922590452998*^9}, {
   3.777922621303775*^9, 3.777922690701433*^9}, {3.777922726261298*^9, 
   3.7779227471823893`*^9}, {3.777922784846883*^9, 3.777922874720862*^9}, {
   3.777922933289276*^9, 3.777922944992532*^9}, {3.777922977970014*^9, 
   3.777922986225087*^9}, {3.777923032203492*^9, 3.7779232050469503`*^9}, {
   3.777923244209289*^9, 3.777923281898417*^9}, {3.777926537235076*^9, 
   3.777926615229789*^9}, {3.7779309768955593`*^9, 3.777931088403751*^9}, {
   3.777931154151469*^9, 3.777931186739654*^9}, {3.7779338214385147`*^9, 
   3.777933822228671*^9}, {3.7779736616278477`*^9, 3.7779736667458563`*^9}, {
   3.78421141279814*^9, 3.784211415456683*^9}, {3.784211451462347*^9, 
   3.784211461915062*^9}, {3.784211498271432*^9, 3.784211588100317*^9}, {
   3.784211639097308*^9, 3.784211641551156*^9}, {3.784211681829809*^9, 
   3.784211685646735*^9}, {3.7842117160327053`*^9, 3.7842117598740053`*^9}, {
   3.7842118170133677`*^9, 3.784211849810527*^9}, {3.784211927910499*^9, 
   3.784212108823348*^9}, {3.784212149035027*^9, 3.784212151296688*^9}, {
   3.7842121859555473`*^9, 3.7842121866815157`*^9}},
 CellLabel->
  "In[251]:=",ExpressionUUID->"ad629314-3d25-4fa2-a1ff-bc091f6dae49"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJx0nXd8FcXaxzf9JDkp2BBsUUSQawELFvDOKoJglwsqihpUrGAHUVFWRZTE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         "], {{
           {RGBColor[0.148, 0.33, 0.54], EdgeForm[None], 
            GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNVltsVFUUPaXVtJncTi25d3ruHVTkJbQ+C0o7VRkQBqLyAR+oRWmnI20F
NFGwtj5A409HY0ZLgpooGBMSPvzx8eEPhkQEY2wTKKWABR+J0U8TNRp5uNas
TeLHzdl33332Y+119rlzi09veGqWc24GTy2elwLnnm127vdrnLvc6NwVPG31
zn0UOrcg5dwX3rne2Llf6pzz0NXjGYT9qsS5d6Dvgu2lFvl4MZAf+qAv7hmC
rjPtXDvsdgSKR5sVgWzKkG/y0m+OnHsZ6248f0H/ZKB3yvti+dkPm2uRwwDi
5ZHD+gzyQZ75SP655w3Yz+B7EfrJBucWhtKthG1/oNiMu83s6X9vE3xCztUr
JvUHa7RuM58jWF/AMw65GTlvh3yd1/ftZvNHo96v5r/D6u0yv/S5AHv2QJ6P
tRvrEdS1CTYdJi/Hegx+5pl+t+FAH59iz1J8+wzrK7FsXo2U/1iT6luZCB/i
tA7yMuz7Drb3J+ode+iwfxX0b8eKxzwOQ/0Y+xAo7tU+MWf2ijJ7SnlJWhgW
oBs2TNrS0pM/9JnD822d9vX/D0/6pTxg+rLVuMdwGwz0jfpdWJ9BzkchP5Co
P+9jLSPvVsQaRe07LRZtiF+H5d8ZSGYOo03KiTVSt9z0zLfVaiFOw2bDdcTq
mkqLx+1WF31V8wGftoJj32ekK5u+FfiOYe2BfiIUzldwRqJQMTdCfxr41/Cs
IP9TXr6P4vvteN6D/gnYrMbTC//TWAt4+iCfxboCewYgPwR5KCPe5bFOws9G
9OYE1jvMTwn6WyHvg1yEvMRy64X8Z6POHTn6ON4r0C/C98Ohevgx/CxOiXdV
3qaEEfGZiNUL9qQzUp7Ml7Wxxgx8rA2ECTlCv/S/Bd9vNpkxC4YnfT4XKH/i
covl3JdRPdRPeeHCuu4MhSmxJZcr8PFWk94/MTy/shlWMT25xjPCWshx2pP3
Gyxn9if24tzXoXJjTszn+UAcIB+GTE+Z3Nxp3LvRaz7c4FX7LtMTa2LeFio+
zyqx6zE9e8I6We9tkO+NxCvy60vrRV+sfCuW8xbr1+JQHL5sc7srEk/Il55Y
s7gY6zzttflAnrUbTkWLS7xLhi05SG6RY+cz4sCY5czYFevXZpsbm+yMsEfE
hfcBOXOxRfOXc7iaaxb9mI3+Z1UL97MvzJf66QbNaPKZvN6aqH+8i8YTzfSJ
RPGpZw4n8H4B+pNYz2QUaw3WKbz/CP3pRNycP1u5MEYpJdx/bdGM+A1r3u4F
zqZZXnOwln3MyP4e4FqONONeB54z8NOfEnYlw5l4n2/QfUQcH8zI5r5IOTG3
HOSzyOln5HYOay1quwT5b8hLQ82/12B7Cu8/QD+ZiAuUGZM9+alZcc4kkqcT
zRHy9CRyvt5rdn2YaO7zzB4L1ZuC8ZZ3CPlJnnZHurcehu26SPf4XPh4JNaM
eBTrRcZArLpQfWV/v4H8QSJuBV7/B7wf3oT9Abt3eP/M85rv78bGqQbhw7pY
EzH8JxEOxIMxGOvfRNxgz6ozy+5zcqnR655IY12UVX8XZjVv1tq5OxSKu4Pw
04XY46glF+t7wc41a6We/Z8TSsfZPGw25Fh19tg/TM7uDvo/Z9wgRzgTaEOM
x2Jxu8brPuq2Pcti3eurI3Etb/cpcx61OXnB/mf4X/O5zV/WQb4MGnbkdb9h
x3NJG840noOS4XU3Yh1HrLti9YNx4lAznXOCc6XD/jN4fo+HOt+c62vsTvVe
+OTtXMwYn8nrEbv32eOs13yc47WPcYnTf45cZ8M=
               "]], 
              PolygonBox[CompressedData["
1:eJwtlMlLlnEQx0dTMF5erVfe5/V5Hq3MJc0oKi3ytfLNijoVRrTZwQV9pQ0q
KVpooYtvHSIPVtD2N1SHLl0yfSVQyCWX1BZoO3SyvbDPMB4GZuY7+8zvl99w
rPZoqojshtKgVWGR2+kirQGRqYhI0BWJB5GhTPhnnsjgXJF/IZFfvshz5BHk
GeS/yNM5ItuwTSFGHrEe4VOeaTrFYo7Ffo/9GPZ78Z8G/459OfZd0OoMkcos
kU6wAddi7cJmEH4/um/wR4iXjdyIvAz7GXRN8FciFusieBH4H99q0xp/wxfn
ihRmi9RTQyW1vEL3FnwCvAf/KLoGsAl0fWA1UCv8JHgS/Krmy7KcT6n1h2/z
0JhLiD2HnAfJvYca2qhl3Lde1b8X337fYquPzlJr0tqK8C/FvyTX+EZqqKKW
UnJcT7eaRol3z7HZnCKHT65C13q9ABXAD7s2K53hEHyM+PHZ/rrJ10KMPuKd
xX4ReB3xzgdtpvvAf/q2W61Pe1vomu0ZaAH8DWxqiF2H3KGzoL4O4jVR3zix
v7DjKFiSeGvBJ9HFA3ZTK7G95VmtVcS4CT8WsV41Rhl4DPka/GFsQuTLcu32
EuiqwTxsPnCoMXRfybWTGk+ErIfF2D6BigJWY3/YdqC7KGBmlzy7Gb0dzVEM
3k7/ZWBLoXbwB771WoH/ffgd0HHit6Hz8G3w7Na0hnrPdqq71RvZjO0dKJph
b+YufIQcL9JsJjobvTHdhe5kk289aW9aQwLsNXIz9XeiW47vZcdq7yFnBXiK
a7PXG0t1bQY6iz7wKvA8dKeDtmPd9UfwdciV0Cf4zznGa0214PNdm/UhaB68
C50MWs/a+4qw1dKibwL7nrDNRmfcrL16lvscPtupdb1jtzCF/0vwfNcw3ZHu
ao1nt6E5tmK70bHY+gaH9S1A70J2M9WOvTmdr+pGwbrDtgv9Ux7qbaArDdjM
k2AjEXvb+mZKkAd8q0XfmP5VWxybpc5EZ9M9u4832Az59qb0bekMc+F7w3ar
muMx8qBvtrqjDY7djN6O/gkJx2aos9Q/7QDyf5oPxM8=
               "]]}]}, 
           {RGBColor[
            0.5175636336629019, 0.485597443140317, 0.5148188223834698], 
            EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnHecVdX19i8zc4e5c6fdYW4fQAEVQUCUYkPA3pIgCtKLvURRFFuMRsUW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               "]], PolygonBox[CompressedData["
1:eJwtmXncjmUWx29e8j7eBS/Pcz/3fb+yE7IL2UmWDEUIIVvbFJpKi5koNUo1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               "]]}]}, 
           {RGBColor[
            0.771656822538396, 0.5748953689432063, 0.36544774649500045`], 
            EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFnXfcluP7x++nZ9zPXj33fuwVooTsUCKbROFLw4jIKpsGUkZWkl0q0pKZ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               "]], PolygonBox[CompressedData["
1:eJwlmXmgzdUWx3/XdC/3XMN1zzm/3zm3kqkSGTM0PJUUKolnSjJXVIbMeoVM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               "]], 
              PolygonBox[{{5480, 1970, 5218, 5110, 6493}, {6299, 5107, 5248, 
               1967, 6298}}]}]}, 
           {RGBColor[
            0.9200878612482252, 0.670219653120563, 0.3522723698694981], 
            EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnXm81tP2x59zOnVOT2d+5uc5ZB4y8zOTeQwh4xXupShFZqXSIKJBIZnK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               "]], PolygonBox[CompressedData["
1:eJwtmneAVUWyxg8MOnkG595z4wDCqogsuLLKru+pRPUh7rqKCRFMsCpRMggo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               "]]}]}, 
           {RGBColor[
            0.9606778275222658, 0.7716945688056644, 0.47810126531902386`], 
            EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnAeYlcXVxy+X3bu93b73LkRAQFE0KhYQoyIgAoKKiIJdQKOImhh7wU4s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               "]], 
              PolygonBox[CompressedData["
1:eJwtmHm8ltMWx5/S6bz1ns6p887v80oJuRqQ0iia06jxXpJcHw2aB2Wo1JWb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               "]], 
              PolygonBox[{{5913, 2442, 5089, 5099, 5912}, {7247, 5230, 5220, 
               2215, 5826}}]}]}, 
           {RGBColor[1., 0.8740569401481803, 0.6076067627778379], EdgeForm[
            None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVm1ollUYPunU952bc3ue93nerz+CSsE2t3T69o40KacNp9tK/VFkbRlZ
2pwGhQs3kYIgJc1pSU37IcxfGVtYEGrbFCIr0ldtYJH7SCbMrST9M6jr4rql
H4dzP+e5z33uj+u+zpnX1NL4xjTnXPFDzk3HvLPQuV0Yp2c490XCubI5zp2P
OXcp6VxlxLk+yAuKnVuIcQ46pzD3z3WuIqJ5wOQ49E9g75EUdALIBbAddy5X
pL1XMN+E7h8YDbCzMiK5bqZzF4v1bxxr5bBRilELnWxU69QfhvwI/n+f59yX
8HMRdP6C/U2FkulDxnOuJR/fkPdg3/ki6XMv5WrMlRh9kLtgcyb23sfe7bbW
j3ErqpnfY3nykb7ShyMFskubZbOd24r1h53mSpPpO3NI+eAs5Y5525Ev32h/
R4niZIyMqd1svo71ATu3AbHUe4ppM3SewKiH/r2I9jRC/gr7Dhfq/yTO6pmr
da7xH9c495o8GdVMHeb8QrHi+xlnHPbl7zuYJ/D9EmJ9D/KUp9oxJ2NR+V8F
+0sxLuQpj1xDSdxyYOAXxPVcUr7wXPq8IqLvesNPN0Yfvi/FFNcZbG622tDe
eFT/D0DeDyyV4ewPksotz2betqSU999iWiu1nPNMxsyc5ELEizqtSzu3GPsH
oLMkqbUO6PTMVu47LP+c95rMWlOmLm32WA5rA/n5OOxE8pUz1pf5GbAc/RlX
fkYxPwq9+Vh7Cvu+xfd0rA/5qgVl2pyICuvEWA30RyDXpIU1+sHvz+cIr+wR
2qLNesR3BvonIS9KqVeGrI+IEeKetWbc1JlvOKf/xNiqpHqiDvZWpXVOZyB/
7mD4UWGEWKFN9jftZ80W60AMXEENmuFnVVx9xnOZw+22n3srUvKDdaCfFw17
HNQhD2yA3v2IZGLmnuGc51QZ3gZRj/LZ0vsH2DzmiwNKk/I3E8gHxsLYRq0W
MWBsSZHyXm1+0T+eRewRt5UW10mLbYXhmbgmRonVH2Pat832kt/YH8Q2fVpp
/rcWymdicuBB/+TJlyrj2+9i4oHTsH0I+SsvUgz7k5IPIJaalHhhNeYWxHrV
U21ZC2KCub2cFA43wd5jgWwwH/TtapHwSQ7Omcw4cubzWIl0uMa8EXPMHXnx
dr5i5d4FxuHLEuKXTEJYOGE+JIz/eQ+UpNWbv8Ofj0LZ+SHQXcO8VFqOmMNa
zNegcxc1vR4Kd+x/9v4S1K4JebkMO1lPnEg+5L1zyjiEOScemHfa+BvjyRni
Wsq8C7h3PcZyyF5a3N0Pm2vTWv83Ja5tMJ1vSuQr/XwNPkzBn08C+TZhfUoO
ow+8d/i/u/j/O4i2yIeNafmWHyrunVZ35u2m9RG5iRxTGxPfdBjn+DHhvQF7
f4I8CJvPp/W/3biLPUeeZg5X49/T0FkbiBOZf9aBOeA688D4shZjtclcZx7p
P3PO+5z9xFh6sdcr0Fk1xg/kiTfh0/tY242zxmGjzZMO13i3sXe2Yu0tXzba
QuXoWKDemzRe4jfXmWNiMGc4HMbeIU84WIfatMJmHeY1KdWEb5OuAt2p5NvO
lHJZhvWNKfHyZ7B9Gzbehg8VVm/WPQpfbhl3dwU6447VtDElbBPjtH+8QFji
OV0m096YJ5vtkPdgvIx/OU/9yd7ciH/vFqouk570qMMev2PYHi0x/sd3PKE3
WIi5Na5zuwPlhLGfM7xN2V6+regPY581Rz7zHiEX7jM+zBpWfeMz1oZ1aUL9
OqHzLOYb8G2LL97ts7dPl721qq1G7CPGz9ifSYuTGzD7CWF5MfL6dUL3bQPy
1xboPN5LG6zPmYe9dpfxXmjFmb966lneaeQYcsgN7B9BvEcDcTVzxPysSWvv
1rjwyP4g3pg/xs/Yl4bib97PnwbitZGU6kSOoC/EBOvO+rMvWiyuXnsvkA/p
C/lqm+GCNWMOXwjEC8dh8zp8f9HXHUVeo/6IL56n/w/eSbRPHuD7hXZYO/oz
aD7xTbHC7jjipdl6eVkov3ZhPhqqhz4OxQXkhBhyvjmQj4ewlkmrj+eRH0Ld
MztD9Uqr3UFVxr2sGfuWeDibkh71q0LZI3bpA9+Duz3dK5lQ6wux78OkanMw
qW+uvxoKB7T9SiiuJFbvxpWna57iPAB5mi/+zhqX02/mKWOcOewLE2fj6k/W
a1+onO6w9/N6ywM5MpsWl1Vj/g+BMdXH
               "]], 
              PolygonBox[CompressedData["
1:eJwllU1sVVUUhbeA0B9akXfvu6/vdkIiiSS0FClQaBCNEZAUKSWUAWIDWEID
QQpMpIoGgolGKqCUiREcmOBEITDQ8KMijsREpRVN0IFUY0ka/oJOCPCtrMFO
1j57n33WXvfsc6esf7Vj65iI6MbGYX8VIh5JIi5MihitxAePrYn4e3LEH3nE
GPz3sYvEv8OOFyOOToz4GNtWitiRRTz3qNd68XdR7wD5Ux+PODghooe1AWI3
qyMGyf28LmJ6bUQj9m0asaYc8TN4A2evLbqmah/DPsNvg8M2uLzD/p3sH2TP
K8TWY83kptSbA98TcEjAu8jpB9+jXh/4l9S567BZ5BfJ2U7+V9R8mfp7yPma
/F78Fzmrn7XGxyIOkb+R/B/gdxF/M/FFudcUa2BtP7nLsFbOGsYWkXuizr2J
s7gvy117iPyfyta6P7GW0ryF/Umlz9xfNkdx3YBdhvsh+G0hfr0q4gPwMPVG
qPdMRcQl4r+hdxf1VtDDs6y9Bh5kbRr4P6wP/yr+KvDS8RH78K/gL8RvZ8+q
+oh/8RvRtwPcid0sWGNp3U3+dfymatfYC4eKKmsm7XT2tYLvjji8iz+Kf4r8
N+nvAXyX48/H5lF7cW4tR7h8b7H/CP0PT7bG0noAf6TSa1dz37277F1d4zs4
ixpPV7hmG3gKNgP/BfzF4Lai8W3OH6L+vYJ7Vq+XOWN7yXdLZ+is3cTeSHxH
1HMf+T3Y6Wr3sLbemkrLleAbBWsqLfWdjua+SzOJLwEPYMf4/vOpfzi3tr2J
v4001my8nZiLZkSaSJtWaQRurTdWTy3gqsz7fsfa8SvxG8BPMrsBHsUKE833
SOaZ1ew2U/8Ael5h7U61Z3QueGnqWdQe7VXvryfuRRqcQ59Pat1DXdkaSkvV
+BW8MfOs7eB7lLjrs0u+q/vwp+FndY5pxjRrWlOsk/0t7D1c9KzoTVhCP7Mz
34WZrM0B/wm/ngr3WCDerPmDyxPEnwIPJ56F/1l7Cb+hbK01Q/OofR4+42vc
g3ppz7z3e85YnnkGNYuaoY/Iv5D62+nMbrT7MfVsdWFfwn1B2dz0Ri0Eb8rc
i2ayq+hvoG/RQPwL8lenfvc0I525OYqrOF2Dews5H4InsHYGfudzv22f6r2i
Xpqaq960f4jfKfkta4LPbfD9kmdhL7W6dPdz75VGTeBvUnPRG6u3dqjgmdQs
6k04WPbd0Jv1PPgW9WbUuqZq6wydpbWT7F+RWwtx7sjNWdz1jzgLfq/st1Bv
rt7ehz724tY=
               "]], 
              PolygonBox[{{6040, 2996, 5239, 5081, 5582}, {7249, 2294, 2111, 
               5078, 7258}, {7248, 3033, 2864, 5097, 7262}, {7252, 5269, 5071,
                1937, 6866}}]}]}, 
           {RGBColor[1., 0.95, 0.75], EdgeForm[None], 
            GraphicsGroupBox[{
              PolygonBox[{{7250, 5234, 7253}, {7262, 5242, 7248}, {7251, 5102,
                7261}, {7258, 5232, 7249}}], 
              PolygonBox[{{5898, 5095, 5234, 7250}, {7249, 5232, 5102, 
               7251}, {7248, 5242, 5095, 5898}}]}]}}, {{}, {}, 
           TagBox[
            TooltipBox[
             {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
              LineBox[{7253, 7250, 5898, 7248, 7262}], 
              LineBox[{7258, 7249, 7251, 7261}]},
             "2"],
            Annotation[#, 2, "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
              LineBox[{5725, 6747, 6718, 6719, 6717, 5706, 5942, 5941, 6002, 
               6016, 6983, 6982, 6859, 5783, 7132, 5782, 6258, 5801, 6256, 
               5800, 6257, 6003, 5943, 6103, 6102, 6101, 5708, 7239, 7201, 
               7224, 7227, 7226, 7225, 7167, 7244, 7219}], 
              LineBox[{7254, 5588, 6196, 5586, 6195, 5587, 6197, 6441, 5944, 
               5670, 5992, 5727, 6034, 6035, 5835, 5348, 6748, 5347, 6334, 
               6333, 6681, 6680, 7062, 7061, 6701, 5689, 6700, 5688, 6797, 
               5774, 6246, 5773, 6796, 6010, 6011, 5786, 6250, 5785, 6387, 
               6386, 6577, 6385, 6398, 7263}], 
              LineBox[{7260, 5582, 6040, 6039, 6125, 5450, 7246, 6100, 6249, 
               7240, 5781, 7237, 7238, 6726, 5709, 6725, 6801, 6800, 7133, 
               5346, 6332, 6331, 6456, 6455, 6994, 6993, 6584, 5581, 6583, 
               5580, 7140, 5788, 6864, 6989, 6990, 6018, 6019, 5790, 6887, 
               5789, 6998, 5463, 6866, 7252, 7266}], 
              LineBox[{5700, 5968, 5967, 5396, 5969, 5397, 6374, 6373, 6421, 
               6420, 5427, 5990, 6424, 6423, 6422, 5726, 7071, 6984, 6860, 
               5570, 7013, 5597, 7186, 5598, 7187, 5571, 5897, 5888, 6575, 
               5568, 6574, 5569, 6576, 6988, 6004, 5754, 7102, 5755, 6839, 
               6959, 6960, 6707, 6708, 6706, 5700}]},
             "0"],
            Annotation[#, 0, "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
              LineBox[CompressedData["
1:eJwV0klI1HEUwPHnxVNGmy06aBOBngyCAm/ppUAi6KYURJSt5M2IZrJLhwqc
Lq12kA7iSatDq8sY7VmHvLVNRTpjzAiRRcc+/8OX73vv/5bfwKT39+w+URUR
j7ClNuLcmoit3LwuogmDqyNeoLAq4qX8FR6sjbiPe7ih96baXR7gO1xlxwC3
+17gz+pt4i50Io95+yp1EQsoY8LMDN5jGMfUjuMIut0/yj3qP809MT+FrFoG
o+IR5Nw679Y3LiTW/x2TyKNs9rX6GzzX/wxPcUv/F7Wv3Cs/iQ43O1IRKbXl
/ImX8Udu4yX2lezbLK7URzRyAx6qrzR/Xd/j5LZ4Tl+ruMjjPIZm+3f5dop/
+A3jdoxh1NyM/DbvlV9L7uu7yiu4Wi3nrZfl/XyFL/Ff9T8YkVd7x0a9ZXd2
yLf5vp3/2XtB/SIOiw+63c0H+BDn+J2Zt5hGRj6NWe+etDubxPqmxHk0yevk
KdSjxswvtSH9GTdOo+j2HCbU57nkHSUu8qJaF5+xa4E/2FHhrLyIpajBsPpZ
7sMe32v9vsXk/8W/eSe3YBNKenrt3SBO83qzaTSiBfvU/wMtqHxU
               "]], 
              LineBox[CompressedData["
1:eJwV0TtMk2EUh/HTwY0w9SJeiA4MajC6SLxATUpJDBtYYqJxMDG62K5UWZi9
RNwcVKB0AFc3IPUSE9vq4Ng4a7Rfo6MaEuDX4clz/uc973m/5Dt+qzJTTkXE
Iq5kIs4diRjDGZzFt3REni+jdzgiQRePzb7JRqw6HzgY8UT+lYso8E+e5C6X
+B/P8X/eNT/Pe9xxr61+aM9t9SduYtNsbShii9f4JS/xC37GB7yfMf9KTvMy
Z7mo3zoUsS3f7Nd2tfkRv9W/oE45q3oz+Lzc0G9xEyt6O3LOrr9clPPem+LE
nQ/6ie8eVZ/GHXvXeQMf9WuomKlz3f2y+rmzG3wd3+25p3/Xvap8H4POf+gv
eL/HHecJP5BPmJvlafmrfkl9FX/wGyP+yVMz752NyxNYsO8SX8Q7/S/8GSfN
HZVP8TAf40L/P+G1uoFr9u0DLKZR6w==
               "]], 
              LineBox[{5555, 5894, 5578, 6582, 5579, 7228, 5442, 7220, 5441, 
               7221, 5584, 7180, 5585, 7181, 5557, 6557, 5556, 6329, 6330, 
               5344, 5899, 6608, 5589, 6607, 5590, 6609, 5532, 6074, 6193, 
               6891, 5345, 6194, 5853, 5854, 5787, 6252, 6253, 6251, 6384, 
               6383, 5403, 6898, 6899, 6897, 6119, 6118, 6462, 6461}], 
              LineBox[CompressedData["
1:eJwVz8kuw3EUxfFbW2Ni6qCoqLE8jK0FsbERHbU2hAStIZF4C0kbIWpY2Ihn
kPAyfLr45tx7fufcf/65neLGfiIidjEzEVGYjFjFdjLidyyiQ7fQ5d2MR/Sb
p+WG0hEjGMY1v5mKuKItupaJWMeyzgoO5A/l3nlvWOI17D/u12nbzUvdC90p
2T9elt7Jtvhn/CY9pwXel96iGwvmPLryNfkFXh5dXtXeR1/xglP9I/0Tekzn
eZ/u5OTnzDk8u1PWezKP0llvRZqwl+gjHaRluQpK6PDayPay9m839+m9f2r4
1q23gd5N3rS55tt1fplWUcGHTlo/4z2NB9k9nRQvic2piH/t/zU8
               "]], 
              LineBox[{6955, 6281, 5659, 6669, 5509, 6530, 5510, 6531, 6954, 
               5315, 5886, 6666, 5655, 6665, 5656, 5829, 5336, 7236, 5654, 
               7195, 7197, 7196, 5502, 6523, 5503, 6524, 6947, 5313, 5885, 
               6663, 5649, 6662, 5650, 6664, 5827, 5828, 5647, 7193, 5648, 
               7194, 5499, 7052, 7053, 6832, 6940, 5307, 5333, 6660, 6507, 
               6508, 6312, 6661, 7054, 5643, 6833, 6941, 6510, 5493, 6509, 
               6512, 6511, 5308, 5884, 6655, 5641, 6654, 5642, 5826, 7247, 
               7257}]},
             RowBox[{"-", "2"}]],
            Annotation[#, -2, "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
              LineBox[{5287, 5903, 5904, 5905, 6029, 6028, 5610, 7188, 7042, 
               5618, 6875, 5617, 5814, 5813, 6023, 5797, 5844, 5843, 5357, 
               5857, 5858, 5798, 5815, 5289, 5868, 5292, 5817, 5799, 5856, 
               5855, 5359, 6081, 5845, 5378, 6024, 5818, 6690, 5678, 6344, 
               6345, 6230, 5677, 6227, 6229, 6228, 5907, 6643, 6211, 6212, 
               6140, 6142, 6141, 6646, 5624, 6484, 5470, 6483, 5471, 6485, 
               5625, 6876, 5626, 7045, 5473, 6294, 6295, 6296, 6934, 6488, 
               5476, 6297, 6298, 6299, 7255}], LineBox[CompressedData["
1:eJwV08lvDkAYx/HpQdpSe0tbiV1wslwcxZrYlwOqUVIpIWkllipBW60WsQZ/
gCXoZknFyXaqpcSBxHKii11rL0r5zOH7fmd+M88z87bzDsvdsLggIYTQ30fm
gBBSMkPogZr0EMrTQjg6KIQM+VXZWOPSjBDK5MW8m0t4tHwMRgwMYSQ22r/F
/iuyegyXbTZ/khrCJq7We6fa7WpT7e2SpfERe3fIt8q3oQi31AxRf5OHxn72
Fth7ybgXD7aWz8H8Ii5gux5bYg8u5CGy7s4sMk/kZLzVJ4nf8Q29Vxjn4Lpe
1+Jd9J3E461PwDhMNX+Knvoct15n/BzP8FePd/we1XiLN/iIVryKd8YJdZPV
vzZuMH7C3c0PGSdzpXP24pG7PEahvMKeClkll/EelKPdPI9/+46d+IVusjQ1
qah3pwzf/bQ+p3ASm5yx3r70+LdSu5/3oUC+Rp7Pa/kfr+L1nMPreCV3cTav
4SzO4+X8h5fyal7CuVyhbyfXxf+v8WV3uoSLWCVPcJ8SlOKhu9bKaxDM/8V9
sgf4pt93zJB3qJvJ99GIib7vKP3nytvUzON27sRvFFsrsWcXl3IJr+Mq96lG
rXkq1zlnvzOmYhqmxPMwHcesl6EcNfb34/7o0Ocn2p1ZJe8tO6/PPXxUtwAL
ccQ927hR3s6fsAjZ8fdl7bNxqdpP5tX69DHui+96/4hvSX5WnhzfMe7Gt6bm
PeYjy/phfT7ENx/fP87F3zGn4IseX9Fk32l5ouyMHg14oWYWZuOAHi/5tryJ
52AuDsqb+Y68hZv1mcfL4ru11mp8Rt8W8yLzJP3/AxzZrQw=
               "]], 
              LineBox[CompressedData["
1:eJwV0LsuRFEYxfE1iQyFknMG03gWlQQFtWIGiUmEjMatJW69ymUoqF0ShcoT
ICjnHdQuid8U/6z1rfPttbPPeHNtdrWSZAb1Mvkpkr+RpJ/+0gH6jI+hZKKe
VPmC1lCiK7+vJQ/YxR4eZe+45m/wordLB4eTV/6T/9IzZz4xP/Hbo8kOtrBp
bss36GKvkzboApq9u3S/obBT4giH6LN3PJZc6bjjO/SWXtIp56ZRxbp7W97W
pt++Tcoq9rr8gfP76MgusGJnyW4pOzef4RTL8nl5wz/4B8DgMEU=
               "]]},
             RowBox[{"-", "4"}]],
            Annotation[#, -4, "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
              LineBox[CompressedData["
1:eJwV0ltMyHEYxvFfpQszhxFFbgg5bXSwmYwLNmSzdCWHOWSraZNNDjdqzLBh
ozIxU5tDVjFyqowLhs0qhwulLI0xVzETFTaf/8W3532f9/TrX1O2FefujAkh
DPfjRkIIZUkh1NNSegC/xofwY2II/XRsYghzJ4SQw89F86QQ1tJvtM/Mc3F6
cghpaOKV6X0sLqVf6GX6lX+Jfpb30X30nd2d/C66X36PXnSzBtUY1Jdk93s3
7nvDPZzS06bWjlbsMVeCVj11aDJzWs9Nc7fQiEp9FRhSm+befJpC02iWnYvw
BI+xGPOiHfQZbbH7AXr0V9JEOp2fQCdgPGZgZHTL/Rpz1cjxhlw3N9FKtTPR
9zVfZPaT/h00lWbQNrV2/DSfbjYDmShX6+J3R98g+rvw4u1bRbPRoP4K/eYO
2XU4yvW9xEx5pvy3N/wzs4JXQDfKY8XDEIcB+TbkYyuK9GynwexK9UF7inmF
vF00nherlh3N09V0N77r++Udr8VvUIKxvBQ94+g0uoaXR3vl6+kF3yNM9j3t
Pej3iRPHIgZV6k95A3YuoUuxgDfL7BzMxnKsszM1+n0xCse9s9y+0eKF9j+M
btE8TOE12VOhPkY8gpbKy1BpdwGvghbSIXc3m9mCK3bW4ipKzDTqv407OBLt
1BsvbqbH5EcR425Anf4XatN5j+R/9MwQ/6Ub7N6Is/bW69sr7qQd+jpoN78L
b6P/YfkJ8UnclfeYfx+9yUy+N380c01ci2XyHj0f0Itk92PV41BlpiG6we+M
kL9DFhYjhXddfSo9Lz+HFrf+A0RXoKo=
               "]], 
              LineBox[{5297, 7134, 7135, 6804, 5710, 6727, 5711, 6369, 6370, 
               5390, 6728, 5391, 7063, 7064, 6712, 5704, 5937, 5936, 6000, 
               5935, 6381, 6380, 6379, 5703, 5837, 5362, 7229, 7230, 7177, 
               7179, 7178, 5454, 6042, 6043, 6044, 6186, 6185, 5890, 6200, 
               6201, 6170, 5540, 6169, 5541, 6571, 6572, 6568, 6570, 6569, 
               7154, 7153, 7152, 7204, 7203, 5763, 6813, 6814, 6810, 6812, 
               6811, 6231, 6198, 6916, 6199, 6115, 6442, 5859, 5432, 6031, 
               5431, 6171, 6172, 6084, 6346, 5360}], LineBox[CompressedData["
1:eJwVzcsuQ1EYBeAllWBI3IVEJKYkkk7amDKo20GCmTJu34kWz2CCkBhLPABp
PYFepj6DL+vsf/97ndV6s2iMJNmnNCcXkwP2KGaTmjyWnfmky+RMcmg2JYv/
O444tXPh/Tlr7s7kxEIyzhgn7j8YTieXS0mdT++u5RUP3izrv5crcpMNRvVU
ZJU7321aFPae9b7wRFNHgx6/POp+k6+U/bcl23yb38obtnX0nQf0+NH7xbu+
dbq+S/aq9racK3JgNqTPrtkOfwCvLvA=
               "]], LineBox[CompressedData["
1:eJwl0TsrhmEYAODbRNicPgx85Sc4RDlEGWz0ORQWC4szf4BFmRkY5ENGgyiH
Qc4WxWAxOOYvOKVcMlzdz3Ofnrfe5MBox0hGREyxXRiRVRSRST2PpRFPvJVE
vIjPzOk5E885kK8UqzgpjjjlmHPOSBVEbP7tSkQ00EQjO/kRt2w4r/Njz57e
tJl9ccK+Se7kx8UxMuXvvN1Ntr4ccum3v0KtV+yjS/3B3LKZJfLUut076SJF
j55VvWnWWJRbYNc3zfqeGVrtbjf77txmz7X6kDjIrflm9xa+1L9J6k3ZVS5+
un9QZ0ctTXLDaiNsmX2lXm7FfNq5Wk8VlQy4X3jjkkP1arGGK7Ofvu9SvPh7
x/4yjvTPuyfsu3e+cZ5O/P/LX3A0SOc=
               "]], LineBox[CompressedData["
1:eJwl0TcvRXEYB+BXok1KohNtdO9Vp3sXjBiURFnUTR98B6sgJAYSi43YiDaZ
lcHmC9j0CfGI4cnv/M9bzjk5DTPLQ0tZEbHCfllEojIiSYrV8oh0acSbfOeZ
V17IVMiSiI7qiMmqiCmzE3JazqnP0mpHC+PuN8t22sjYOa++wJH+R2rdW9NX
Jz/t/qDbuYtb9byaiHy+Pe+HbXsO9G7JMedR7rzPkzyy95A9Gs0W25EhzY56
kble1330MKhnVO/IX7/asMy1N4dsBtRveLN/zvw8D+YW5QL9ZnbNJLxzkmZS
HOu/YdP1Bl9mTvTu23kqL+UVZ1xwTpd9nVzrvf/7JtY9O+nbUyTopYd6Cigk
mxyaav7/4y+uQUB5
               "]]},
             RowBox[{"-", "6"}]],
            Annotation[#, -6, "Tooltip"]& ], 
           TagBox[
            TooltipBox[
             {GrayLevel[0], Opacity[0.5], CapForm["Butt"], 
              LineBox[{5958, 5691, 7118, 7119, 6851, 7161, 5379, 7160, 7159, 
               7207, 7206, 5690, 5957, 6104, 5416, 5982, 5415, 5983, 5417, 
               6105, 5958}], 
              LineBox[{5960, 5693, 7122, 7123, 6853, 7164, 5380, 7163, 7162, 
               7209, 7208, 5692, 5959, 6106, 5419, 5984, 5418, 5985, 5420, 
               6107, 5960}], 
              LineBox[{5964, 5695, 7126, 7127, 6855, 6978, 5382, 6977, 6854, 
               7125, 7124, 5694, 5963, 6108, 5422, 5986, 5421, 5987, 5423, 
               6109, 5964}], 
              LineBox[{5966, 5697, 7130, 7131, 6857, 6980, 5384, 6979, 6856, 
               7129, 7128, 5696, 5965, 6110, 5425, 5988, 5424, 5989, 5426, 
               6111, 5966}], 
              LineBox[{5723, 6416, 6417, 6418, 5953, 6007, 5954, 5414, 6419, 
               6746, 6745, 5724, 6434, 6992, 6433, 5705, 6715, 6716, 6382, 
               5402, 6798, 5401, 6753, 6754, 6752, 6756, 6755, 5567, 6573, 
               5566, 6795, 5770, 6793, 5769, 6794, 5952, 6415, 6414, 6413, 
               7070, 7069, 6987, 6863, 5576, 7017, 5545, 6581, 5577, 6396, 
               6397, 6808, 6809, 6435, 6436, 6437, 6020, 5428, 6744, 5723}], 
              LineBox[{7073, 6430, 6431, 6432, 5991, 6429, 6428, 6427, 5791, 
               6807, 5572, 6578, 5573, 6613, 6614, 6610, 6612, 6611, 5887, 
               6615, 5405, 6388, 6580, 6579, 5574, 6426, 6991, 6425, 5702, 
               6710, 6711, 6378, 5399, 5971, 5398, 5970, 6377, 6376, 6375, 
               5701, 6709, 5762, 6785, 6005, 6403, 6402, 6401, 6803, 6802, 
               6400, 6399, 5583, 6585, 5539, 7014, 5575, 6861, 6985, 7072, 
               7073}]},
             RowBox[{"-", "8"}]],
            Annotation[#, -8, "Tooltip"]& ], {}, {}}}], {}}, InsetBox[
        FrameBox["\<\"\\!\\(\\*SubscriptBox[\\(V\\), \\(0\\)]\\) = 0.009\"\>",
         
         RoundingRadius->5,
         StripOnInput->False], {2.5, 1.7},
        Background->RGBColor[0.87, 0.94, 1]], 
       {RGBColor[1, 0, 0], 
        DiskBox[{-1.0264873636382661*^-14, -1.5864583085678188}, \
{0.1, 0.066}]}, 
       {RGBColor[1, 0, 0], 
        DiskBox[{1.977861232822551, -1.851549081184028}, {0.1, 0.066}]}, 
       {RGBColor[1, 0, 0], 
        DiskBox[{-1.977861232822551, -1.851549081184028}, {0.1, 0.066}]}, 
       {RGBColor[1, 0, 0], 
        DiskBox[{3.668250166126394, -2.071066055216009}, {0.1, 0.066}]}, 
       {RGBColor[1, 0, 0], 
        DiskBox[{-3.668250166126394, -2.071066055216009}, {0.1, 0.066}]}, 
       {RGBColor[1, 0, 0], Thickness[0.005], 
        LineBox[{{-0.2, 0.1341640786499874}, {0.2, 0.1341640786499874}}]}},
      AspectRatio->1,
      AxesLabel->{None, None},
      AxesOrigin->{0., 0.},
      BaseStyle->{
        GrayLevel[0], FontFamily -> "Times New Roman", FontSize -> 28},
      DisplayFunction->Identity,
      Frame->True,
      FrameLabel->{{
         FormBox["\"Im k\"", TraditionalForm], None}, {
         FormBox["\"Re k\"", TraditionalForm], None}},
      FrameTicks->{{{{-2, 
           FormBox[
            RowBox[{"-", "2"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {2, 
           FormBox["2", TraditionalForm]}, {4, 
           FormBox["4", TraditionalForm]}}, None}, {{{-2, 
           FormBox[
            RowBox[{"-", "2"}], TraditionalForm]}, {0, 
           FormBox["0", TraditionalForm]}, {2, 
           FormBox["2", TraditionalForm]}}, None}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImageSize->400,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "GridLinesInFront" -> True},
      PlotRange->{{-2, 4}, {-2., 2.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.02]}},
      Ticks->{Automatic, Automatic}], 
     GraphicsBox[{{{{}, {}, 
         TagBox[
          {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
           LineBox[CompressedData["
1:eJwV1nc8lV8YAHD3XnvcayVEQxKlSLLzHCIhQqSQlVRG+d1LqXDtFSrrSpSd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            "]]},
          Annotation[#, "Charting`Private`Tag$13159#1"]& ]}, {}}, 
       {RGBColor[1, 0, 0], DiskBox[{1.977861232822551, 0}, 0.05]}, 
       {RGBColor[1, 0, 0], DiskBox[{3.668250166126394, 0}, 0.05]}},
      AspectRatio->1,
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      BaseStyle->{
        GrayLevel[0], FontFamily -> "Times New Roman", FontSize -> 28},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(0\\)]\\)[rad]\"", 
          TraditionalForm], None}, {
         FormBox["\"k\"", TraditionalForm], None}},
      FrameTicks->FrontEndValueCache[{{Automatic, 
          Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
          Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
         Automatic, {{0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {0.005, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {0.01, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {0.015, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {0.02, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-0.005, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.004, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.003, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.002, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.001, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.001, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.002, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.003, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.004, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.006, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.007, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.008, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.009, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.011, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.012, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.013, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.014, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.016, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.017, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.018, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.019, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.021, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.022, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.023, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.024, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.025, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {2., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {3., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {4., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
            
             AbsoluteThickness[0.1]}}, {-1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {4.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {4.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {4.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {4.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {5., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      ImageSize->410,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 4}, {0., 0.02308797511806173}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.784211438847211*^9, 3.7842114644163237`*^9}, 
   3.784211515485135*^9, 3.784211590412923*^9, 3.784211643937804*^9, 
   3.784211688385705*^9, 3.784211724161435*^9, 3.784211762795443*^9, 
   3.78421181946937*^9, 3.784211965907435*^9, {3.78421200713465*^9, 
   3.784212111897295*^9}, 3.784212156166875*^9, 3.784212196904663*^9},
 CellLabel->
  "Out[262]=",ExpressionUUID->"b7213f82-9677-4e81-beb0-17f3abdefd98"]
}, Open  ]],

Cell["\<\
Next, the animation is programmed. Find comments directly in the code.\
\>", "Text",
 CellChangeTimes->{{3.777973687017825*^9, 
  3.777973701547048*^9}},ExpressionUUID->"7c762c0a-c5a6-434f-bd4f-\
9b68522c42e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"rn", "=", "2."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plopo", "=", "13"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Provide", " ", "some", " ", "values", " ", "for", " ", "potential", " ",
       "radius", " ", "and", " ", "number", " ", "of", " ", "points", " ", 
      "to", " ", "animate"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
      "do", " ", "not", " ", "change", " ", "rn", " ", "because", " ", "the", 
       " ", "animation", " ", "is", " ", "optimzed", " ", "for", " ", "it", 
       " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"pole", " ", 
          RowBox[{"search", "!"}]}], ")"}], ".", " ", "\[IndentingNewLine]", 
        "Use"}], " ", "plopo"}], "=", 
      RowBox[{"3", " ", "for", " ", "test", " ", "reasons"}]}]}], ",", " ", 
    RowBox[{"=", 
     RowBox[{
     "13", " ", "for", " ", "a", " ", "smoother", " ", "rendering", " ", 
      "but", " ", "takes", " ", "a", " ", "long", " ", "time"}]}]}], " ", 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"polana", "=", 
    RowBox[{
     RowBox[{"-", "1.5"}], "*", "I"}]}], ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Initial", " ", "guesses", " ", "for", " ", "pole", " ", "positions", " ", 
    "for", " ", 
    SubscriptBox["V", "0"], " ", "almost", " ", "zero"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana2", "=", 
   RowBox[{"1.9", "-", 
    RowBox[{"2.4", "*", "I"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polana3", "=", 
   RowBox[{"3.7", "-", 
    RowBox[{"2.6", "*", "I"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"polana4", "=", 
    RowBox[{
     RowBox[{"-", "0.8"}], "*", "I"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Start", " ", "tracking", " ", "when", " ", 
      SubscriptBox["V", "0"]}], ">", "2.65"}], ";", " ", 
    RowBox[{
    "this", " ", "is", " ", "the", " ", "pole", " ", "that", " ", "emerges", 
     " ", "after", " ", "two", " ", "poles", " ", "met", " ", "on", " ", 
     "the", " ", "real", " ", 
     RowBox[{"axis", "."}]}]}], "  ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polpos", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polpos2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"polpos3", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"polpos4", "=", 
    RowBox[{"{", "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", "anivo", "]"}], "\[IndentingNewLine]", 
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"Do", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"von", "=", 
        RowBox[{"0.001", "+", 
         RowBox[{"3.5", "*", 
          RowBox[{"i", "^", "2"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"t", "[", "l", "]"}], "[", "k_", "]"}], "=", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"k", "/", 
              RowBox[{
               RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
               RowBox[{"k", ",", "von", ",", "rn"}], "]"}]}], "-", 
             RowBox[{"I", "*", "k"}]}], ")"}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"Define", " ", 
         SubscriptBox["t", "0"]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[Delta]", "[", "l", "]"}], "[", "k_", "]"}], "=", 
          RowBox[{"ArcTan", "[", 
           RowBox[{
            RowBox[{"tan\[Delta]", "[", "l", "]"}], "[", 
            RowBox[{"k", ",", "von", ",", "rn"}], "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{"Define", " ", "phase", " ", "shifts"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"polana", "=", 
        RowBox[{
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{
              RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "polana", ",", 
             RowBox[{"polana", "-", 
              RowBox[{"0.005", "I"}]}]}], "}"}]}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Search", " ", "for", " ", "poles", " ", "and", " ", "make", " ", "a",
          " ", "list", " ", "polposX", " ", "which", " ", "is", " ", 
         "actually", " ", "never", " ", "used"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"polana2", "=", 
        RowBox[{
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{
              RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "polana2", ",", 
             RowBox[{"polana2", "-", 
              RowBox[{"0.005", "I"}]}]}], "}"}]}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"polana3", "=", 
        RowBox[{
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"1", "/", 
             RowBox[{
              RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "polana3", ",", 
             RowBox[{"polana3", "-", 
              RowBox[{"0.005", "I"}]}]}], "}"}]}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"von", ">", "2.7"}], ",", 
         RowBox[{"polana4", "=", 
          RowBox[{
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"1", "/", 
               RowBox[{
                RowBox[{"t", "[", "0", "]"}], "[", "k", "]"}]}], "\[Equal]", 
              "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"k", ",", "polana4", ",", 
               RowBox[{"polana4", "-", 
                RowBox[{"0.001", "I"}]}]}], "}"}]}], "]"}], "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"polpos", ",", 
         RowBox[{"{", 
          RowBox[{"von", ",", 
           RowBox[{"Re", "[", "polana", "]"}], ",", 
           RowBox[{"Im", "[", "polana", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"polpos2", ",", 
         RowBox[{"{", 
          RowBox[{"von", ",", 
           RowBox[{"Re", "[", "polana2", "]"}], ",", 
           RowBox[{"Im", "[", "polana2", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"polpos3", ",", 
         RowBox[{"{", 
          RowBox[{"von", ",", 
           RowBox[{"Re", "[", "polana3", "]"}], ",", 
           RowBox[{"Im", "[", "polana3", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"AppendTo", "[", 
        RowBox[{"polpos4", ",", 
         RowBox[{"{", 
          RowBox[{"von", ",", 
           RowBox[{"Re", "[", "polana4", "]"}], ",", 
           RowBox[{"Im", "[", "polana4", "]"}]}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Make", " ", "a", " ", "frame", " ", "of", " ", "the", " ", 
         RowBox[{"animation", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"anivo", "[", "i", "]"}], "=", 
        RowBox[{"Grid", "[", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"ContourPlot", "[", 
               RowBox[{
                RowBox[{"Log", "[", 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"t", "[", "0", "]"}], "[", 
                   RowBox[{"rek", "+", 
                    RowBox[{"I", "*", "imk"}]}], "]"}], "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"rek", ",", 
                  RowBox[{"-", "2"}], ",", "4."}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"imk", ",", 
                  RowBox[{"-", "2."}], ",", "2."}], "}"}], ",", 
                RowBox[{"PlotPoints", "\[Rule]", "plopo"}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"\"\<Re k\>\"", ",", "\"\<Im k\>\""}], "}"}]}], ",", 
                RowBox[{"BaseStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Black", ",", 
                   RowBox[{"FontFamily", "->", "\"\<Times New Roman\>\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "28"}]}], "}"}]}], ",", 
                RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"Framed", "[", 
                  RowBox[{
                   RowBox[{"\"\<\!\(\*SubscriptBox[\(V\), \(0\)]\) = \>\"", "<>", 
                    RowBox[{"ToString", "[", 
                    RowBox[{"NumberForm", "[", 
                    RowBox[{"von", ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "3"}], "}"}]}], "]"}], "]"}], "<>", 
                    "\"\<, R = \>\"", "<>", 
                    RowBox[{"ToString", "[", "rn", "]"}]}], ",", 
                   RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"2.5", ",", "1.7"}], "}"}], ",", 
                 RowBox[{"Background", "\[Rule]", "LightBlue"}]}], "]"}], 
               "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Re", "[", "polana", "]"}], ",", 
                    RowBox[{"Im", "[", "polana", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], 
               "]"}], ",", " ", 
              RowBox[{"(*", " ", 
               RowBox[{
               "Insert", " ", "red", " ", "disks", " ", "to", " ", "mark", 
                " ", "pole", " ", "positions"}], " ", "*)"}], 
              "\[IndentingNewLine]", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Re", "[", "polana2", "]"}], ",", 
                    RowBox[{"Im", "[", "polana2", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], 
               "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Re", "[", "polana2", "]"}]}], ",", 
                    RowBox[{"Im", "[", "polana2", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], 
               "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Re", "[", "polana3", "]"}], ",", 
                    RowBox[{"Im", "[", "polana3", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], 
               "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Re", "[", "polana3", "]"}]}], ",", 
                    RowBox[{"Im", "[", "polana3", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], 
               "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"von", ">", "2.6"}], ",", "Red", ",", 
                   "Transparent"}], "]"}], ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Re", "[", "polana4", "]"}]}], ",", 
                    RowBox[{"Im", "[", "polana4", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0.1", ",", "0.066"}], "}"}]}], "]"}]}], "}"}], 
               "]"}], ",", " ", 
              RowBox[{"(*", " ", 
               RowBox[{
                RowBox[{
                "red", " ", "horizontal", " ", "bar", " ", "indicating", " ", 
                 "the", " ", "potential", " ", "depth", " ", "in", " ", "k"}],
                 "-", 
                RowBox[{"space", ":"}]}], " ", "*)"}], 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "0.2"}], ",", 
                    RowBox[{
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"2", "*", "m", "*", "von"}], "]"}], "/", 
                    "\[HBar]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.2", ",", 
                    RowBox[{
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"2", "*", "m", "*", "von"}], "]"}], "/", 
                    "\[HBar]"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{
              "Phase", " ", "shift", " ", "plot", " ", "to", " ", "the", " ", 
               "right"}], ";", " ", 
              RowBox[{
              "insert", " ", "also", " ", "real", " ", "parts", " ", "of", 
               " ", "pole", " ", "positions", " ", "to", " ", "indicate", " ",
                "their", " ", 
               RowBox[{"position", ":"}]}]}], " ", "*)"}], 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Plot", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Delta]", "[", "0", "]"}], "[", "k", "]"}], "}"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"k", ",", "0", ",", "4"}], "}"}], ",", 
                RowBox[{"PlotStyle", "\[Rule]", 
                 RowBox[{"{", "Black", "}"}]}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<k\>\"", ",", 
                   "\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(0\)]\)[rad]\>\""}],
                   "}"}]}], ",", 
                RowBox[{"BaseStyle", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Black", ",", 
                   RowBox[{"FontFamily", "->", "\"\<Times New Roman\>\""}], 
                   ",", 
                   RowBox[{"FontSize", "\[Rule]", "28"}]}], "}"}]}], ",", 
                RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
                RowBox[{"ImageSize", "\[Rule]", "1040"}]}], "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Re", "[", "polana2", "]"}], ",", "0"}], "}"}], 
                   ",", "0.05"}], "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Re", "[", "polana3", "]"}], ",", "0"}], "}"}], 
                   ",", "0.05"}], "]"}]}], "}"}], "]"}]}], "]"}]}], "}"}], 
          "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "1", ",", "0.0025"}], "}"}]}], "]"}], ",", 
    "i"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.777911069796879*^9, 3.777911107197145*^9}, {
   3.777911162398616*^9, 3.7779112429615192`*^9}, {3.7779114015551043`*^9, 
   3.77791151303344*^9}, {3.777911543291523*^9, 3.777911617686901*^9}, {
   3.7779122793526487`*^9, 3.77791233161727*^9}, {3.77791273993358*^9, 
   3.7779127887112226`*^9}, 3.7779139345108013`*^9, {3.7779144444646053`*^9, 
   3.77791446958418*^9}, {3.777914705167657*^9, 3.777914739216239*^9}, 
   3.777914803581781*^9, 3.777915999018914*^9, 3.7779173148072357`*^9, {
   3.777918287643858*^9, 3.7779182890988283`*^9}, {3.7779186374374027`*^9, 
   3.777918714127903*^9}, {3.777918800254323*^9, 3.7779188179146852`*^9}, {
   3.7779188578995943`*^9, 3.777918882396472*^9}, {3.777918925927771*^9, 
   3.7779189352478113`*^9}, {3.777919853338787*^9, 3.777919873043334*^9}, {
   3.777920024354561*^9, 3.7779200273541927`*^9}, 3.777920843934664*^9, {
   3.7779208821235228`*^9, 3.7779208868752728`*^9}, {3.777921709645895*^9, 
   3.7779217593931837`*^9}, {3.777922259757834*^9, 3.777922307105095*^9}, {
   3.77792236158846*^9, 3.7779224149494658`*^9}, {3.777923308297389*^9, 
   3.777923327875305*^9}, 3.77792339214819*^9, {3.77792351818091*^9, 
   3.7779235295326023`*^9}, {3.777923648445315*^9, 3.777923649794376*^9}, {
   3.777923795312228*^9, 3.777923798223567*^9}, {3.777923906436582*^9, 
   3.777923966824603*^9}, {3.777924063151*^9, 3.777924065469761*^9}, {
   3.77792415727349*^9, 3.777924162280732*^9}, 3.7779242039426603`*^9, {
   3.7779242557740297`*^9, 3.777924303392242*^9}, 3.777924665864991*^9, {
   3.777926134926489*^9, 3.777926136412323*^9}, {3.777926168957919*^9, 
   3.777926169821846*^9}, {3.777926248345501*^9, 3.777926293374775*^9}, 
   3.777926379522338*^9, {3.777926451782344*^9, 3.777926453803564*^9}, {
   3.77792649360843*^9, 3.777926495368188*^9}, {3.777926649880117*^9, 
   3.777926690510867*^9}, {3.7779267946239233`*^9, 3.77792679976497*^9}, 
   3.777926910113696*^9, {3.77792735394075*^9, 3.777927368080225*^9}, {
   3.777931231901993*^9, 3.77793128624039*^9}, {3.777931321504993*^9, 
   3.777931405303403*^9}, {3.777931482179077*^9, 3.777931525915778*^9}, {
   3.77793208885352*^9, 3.777932089327632*^9}, 3.777932171518243*^9, {
   3.777932864818286*^9, 3.777932910784358*^9}, {3.777932953061986*^9, 
   3.777932954532905*^9}, {3.777933091008957*^9, 3.777933107588751*^9}, {
   3.77793319221165*^9, 3.7779331927201777`*^9}, {3.777933282013649*^9, 
   3.777933302006029*^9}, {3.777933904601059*^9, 3.7779339202554617`*^9}, {
   3.777973707023397*^9, 3.777973741089283*^9}, {3.777973784404546*^9, 
   3.777974098716988*^9}, {3.777974231795802*^9, 
   3.7779742378700943`*^9}},ExpressionUUID->"d24f7f62-23cb-4f8b-b1e1-\
b6de9c72ae26"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0.`\\\"]\\) \
encountered.\"",2,347,65,32453454944060774528,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.77792702462654*^9, 3.7779279352665787`*^9, 
  3.777931658882596*^9, 3.777932294969906*^9, 3.777932886240642*^9, 
  3.7779329619629183`*^9, 3.777933110859642*^9, 3.77793319565834*^9, 
  3.777933305168947*^9, 3.777933929721719*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"05a94439-e5da-4987-ae2b-e771b31a66fa"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0.`\\\"]\\) \
encountered.\"",2,347,66,32453454944060774528,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.77792702462654*^9, 3.7779279352665787`*^9, 
  3.777931658882596*^9, 3.777932294969906*^9, 3.777932886240642*^9, 
  3.7779329619629183`*^9, 3.777933110859642*^9, 3.77793319565834*^9, 
  3.777933305168947*^9, 3.777933929776264*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"806e7901-d8e9-452d-822d-ef079ccbf955"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0.`\\\"]\\) \
encountered.\"",2,347,67,32453454944060774528,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.77792702462654*^9, 3.7779279352665787`*^9, 
  3.777931658882596*^9, 3.777932294969906*^9, 3.777932886240642*^9, 
  3.7779329619629183`*^9, 3.777933110859642*^9, 3.77793319565834*^9, 
  3.777933305168947*^9, 3.777933937666916*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"548a1121-49e3-4ef6-9aff-6c38839d8462"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Power\\\", \\\"::\\\", \
\\\"infy\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,347,68,32453454944060774528,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.77792702462654*^9, 3.7779279352665787`*^9, 
  3.777931658882596*^9, 3.777932294969906*^9, 3.777932886240642*^9, 
  3.7779329619629183`*^9, 3.777933110859642*^9, 3.77793319565834*^9, 
  3.777933305168947*^9, 3.777933937715501*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"eb9ae2c7-25f0-4e93-86aa-a7b3688f3978"],

Cell[BoxData[
 TemplateBox[{
  "FindRoot","lstol",
   "\"The line search decreased the step size to within tolerance specified \
by AccuracyGoal and PrecisionGoal but was unable to find a sufficient \
decrease in the merit function. You may need more than \
\\!\\(\\*RowBox[{\\\"MachinePrecision\\\"}]\\) digits of working precision to \
meet these tolerances.\"",2,347,69,32453454944060774528,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.77792702462654*^9, 3.7779279352665787`*^9, 
  3.777931658882596*^9, 3.777932294969906*^9, 3.777932886240642*^9, 
  3.7779329619629183`*^9, 3.777933110859642*^9, 3.77793319565834*^9, 
  3.777933305168947*^9, 3.777933968137536*^9},
 CellLabel->
  "During evaluation of \
In[337]:=",ExpressionUUID->"0ed1e9ec-98db-4074-8519-a22e2c7321c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"59.522532`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.777926160355582*^9, 3.77792624518848*^9, {3.777926285840455*^9, 
   3.777926294348565*^9}, 3.777926328108869*^9, 3.777926418843943*^9, 
   3.777926484543907*^9, 3.7779267120348053`*^9, 3.777926837098257*^9, 
   3.7779269497871*^9, 3.777927138387233*^9, 3.7779288096846657`*^9, 
   3.777931880353648*^9, 3.777932522239135*^9, 3.777932957884665*^9, 
   3.777933018803934*^9, 3.777933167507206*^9, 3.777933253026126*^9, 
   3.777933367534637*^9, 3.7779339874294157`*^9},
 CellLabel->
  "Out[347]=",ExpressionUUID->"68124d06-12b5-486d-9cef-29c886f2e5e3"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
     "\"\<Trajectory_Vo.avi\>\""}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"anivo", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "1", ",", "0.0025"}], "}"}]}], "]"}], ",", 
    
    RowBox[{"ImageSize", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"\"\<FrameRate\>\"", "\[Rule]", "10"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Once", " ", "exported"}], ",", " ", 
    RowBox[{
     RowBox[{
     "you", " ", "can", " ", "use", " ", "the", " ", "freeware", " ", 
      "\"\<handbrake\>\"", " ", "to", " ", "dramatically", " ", "shrink", " ",
       "the", " ", "file", " ", "size"}], ";", " ", 
     RowBox[{"as", " ", "is"}]}], ",", " ", 
    RowBox[{
    "this", " ", "would", " ", "produce", " ", "about", " ", "2", "GB", " ", 
     "of", " ", 
     RowBox[{"outbput", ".", " ", "After"}], " ", "720", "p", " ", 
     "rendering", " ", "with", " ", "hadbrake", " ", "and", " ", "a", " ", 
     "few", " ", "tweaks"}], ",", " ", 
    RowBox[{"2", "MB"}]}], "*)"}]}]}], "Input",
 CellChangeTimes->{{3.777915137650675*^9, 3.77791519510359*^9}, {
   3.777915232296373*^9, 3.7779152436008663`*^9}, {3.777915394030307*^9, 
   3.777915401032387*^9}, {3.777915795744589*^9, 3.777915799759807*^9}, {
   3.777915843562162*^9, 3.7779158514016733`*^9}, {3.7779159337744217`*^9, 
   3.77791593494773*^9}, {3.7779172394910393`*^9, 3.777917239569619*^9}, {
   3.777918656316739*^9, 3.777918661348632*^9}, {3.777919465925974*^9, 
   3.77791946608501*^9}, {3.777919540034256*^9, 3.777919551666645*^9}, {
   3.777919602556044*^9, 3.777919605949164*^9}, {3.777919640182396*^9, 
   3.7779196647455187`*^9}, {3.777920162339561*^9, 3.7779201625300817`*^9}, 
   3.7779205748747597`*^9, {3.777920737652994*^9, 3.777920795997776*^9}, {
   3.777920906683579*^9, 3.777920906962524*^9}, {3.777921857082596*^9, 
   3.7779218704996443`*^9}, {3.777924817910178*^9, 3.777924831326395*^9}, {
   3.777924890379293*^9, 3.777924890473625*^9}, {3.777924969949279*^9, 
   3.777924977333444*^9}, 3.777925008769086*^9, {3.777925260116901*^9, 
   3.777925262516203*^9}, {3.777925311551322*^9, 3.777925313894697*^9}, {
   3.777925357033671*^9, 3.777925357168961*^9}, {3.777925457607204*^9, 
   3.777925469142681*^9}, {3.777925508418358*^9, 3.777925568915901*^9}, {
   3.7779256997472687`*^9, 3.777925700906695*^9}, {3.7779257483984203`*^9, 
   3.777925786511023*^9}, 3.777925868493289*^9, {3.777925934175312*^9, 
   3.777925935550655*^9}, {3.7779260398770523`*^9, 3.777926045364293*^9}, {
   3.777926097032086*^9, 3.777926097182917*^9}, {3.777926143297571*^9, 
   3.777926185715705*^9}, {3.77792670174189*^9, 3.777926746051466*^9}, 
   3.777926777292551*^9, {3.7779268617644033`*^9, 3.7779268659346724`*^9}, {
   3.777926935077937*^9, 3.777926953038376*^9}, {3.777927379279113*^9, 
   3.7779273823745737`*^9}, {3.777974108966508*^9, 3.777974174475627*^9}, {
   3.7779742264083643`*^9, 
   3.7779742446269503`*^9}},ExpressionUUID->"9a6cc192-2c7b-488f-9303-\
f7d1105ff913"],

Cell["\<\
Finally, an animation of the result, commented for the moment, just watch the \
video instead:\
\>", "Text",
 CellChangeTimes->{{3.7779741816750107`*^9, 3.777974204867305*^9}, {
  3.777974311923554*^9, 
  3.777974327195334*^9}},ExpressionUUID->"cf4bbefd-05fd-4805-ab5b-\
54b3b75243b5"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"anivo", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1", ",", "0.0025"}], "}"}]}], "]"}], "]"}],
   " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7779128130973063`*^9, 3.777912843272003*^9}, {
   3.777914707879072*^9, 3.777914720870654*^9}, {3.777914778889358*^9, 
   3.777914781608386*^9}, {3.777915235086108*^9, 3.77791524612076*^9}, {
   3.7779187252397203`*^9, 3.777918745913342*^9}, 3.777921890274918*^9, 
   3.777923353048422*^9, {3.777923655976269*^9, 3.777923656719337*^9}, 
   3.7779246840478573`*^9, {3.7779268242935467`*^9, 3.7779268250111113`*^9}, 
   3.777926967590563*^9, {3.777974207934539*^9, 3.777974217673827*^9}, {
   3.777974248559025*^9, 
   3.777974251259596*^9}},ExpressionUUID->"b4a995b5-edfb-4527-b405-\
03e66fa08556"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{2479, 1570},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>2. Inherited,
FrontEndVersion->"12.0 for Linux x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 159, 3, 197, "Title",ExpressionUUID->"553e1cc8-bbfa-43a2-a98f-726394317aaa"],
Cell[742, 27, 340, 7, 118, "Text",ExpressionUUID->"b0255f18-63f2-4e7b-b993-f7c3beed0518"],
Cell[1085, 36, 1069, 17, 153, "Input",ExpressionUUID->"63721777-c1e2-48aa-b146-384c8312df57"],
Cell[2157, 55, 418, 11, 71, "Text",ExpressionUUID->"ff34988e-dcf9-4f49-9390-bdf0c66df236"],
Cell[2578, 68, 3618, 87, 423, "Input",ExpressionUUID->"0273a1c5-2510-4b5c-a123-74f2e03e8306"],
Cell[6199, 157, 2016, 46, 635, "Text",ExpressionUUID->"bee60cc0-76e0-4d6e-8b33-09db9a4d7881"],
Cell[CellGroupData[{
Cell[8240, 207, 5482, 145, 603, "Input",ExpressionUUID->"48f24a95-109c-4066-bc8e-01d0acd201a5"],
Cell[CellGroupData[{
Cell[13747, 356, 656, 10, 50, "Print",ExpressionUUID->"3f487e2f-094d-4087-af8f-5b562f9388aa"],
Cell[14406, 368, 1055, 21, 50, "Print",ExpressionUUID->"d3fbe990-ac45-4429-ac67-99fdaeb7a610"],
Cell[15464, 391, 895, 18, 50, "Print",ExpressionUUID->"ce084619-bb7b-402f-804e-b47c8a71c3e7"],
Cell[16362, 411, 1082, 21, 50, "Print",ExpressionUUID->"56c12891-8626-4169-a4cb-27547ab3eb3c"]
}, Open  ]]
}, Open  ]],
Cell[17471, 436, 697, 13, 259, "Text",ExpressionUUID->"d4abd658-1b18-48d3-85e3-0bccea692215"],
Cell[CellGroupData[{
Cell[18193, 453, 3816, 100, 468, "Input",ExpressionUUID->"4411991a-6edb-4769-820d-a3af945e8884"],
Cell[22012, 555, 32727, 657, 593, "Output",ExpressionUUID->"0d907970-8e2a-4182-b67f-e6f8eadadebc"]
}, Open  ]],
Cell[54754, 1215, 173, 3, 71, "Text",ExpressionUUID->"2c74825a-880f-41e0-959d-e481f77457b1"],
Cell[CellGroupData[{
Cell[54952, 1222, 1933, 45, 108, "Input",ExpressionUUID->"3a5e0c1e-677d-4959-9558-23208229fe22"],
Cell[56888, 1269, 82555, 1506, 619, "Output",ExpressionUUID->"93fa1628-8d37-4a5e-9280-14b3e3bc54ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139480, 2780, 169, 3, 136, "Section",ExpressionUUID->"fa206de7-4be2-463b-92d4-bd82f1bd31bc"],
Cell[139652, 2785, 919, 17, 259, "Text",ExpressionUUID->"94404cac-70da-4a78-9d23-19cc62547b8f"],
Cell[CellGroupData[{
Cell[140596, 2806, 13583, 341, 1458, "Input",ExpressionUUID->"ad629314-3d25-4fa2-a1ff-bc091f6dae49"],
Cell[154182, 3149, 203827, 3454, 882, "Output",ExpressionUUID->"b7213f82-9677-4e81-beb0-17f3abdefd98"]
}, Open  ]],
Cell[358024, 6606, 220, 5, 71, "Text",ExpressionUUID->"7c762c0a-c5a6-434f-bd4f-9b68522c42e0"],
Cell[CellGroupData[{
Cell[358269, 6615, 20653, 480, 2133, "Input",ExpressionUUID->"d24f7f62-23cb-4f8b-b1e1-b6de9c72ae26"],
Cell[378925, 7097, 576, 12, 81, "Message",ExpressionUUID->"05a94439-e5da-4987-ae2b-e771b31a66fa"],
Cell[379504, 7111, 576, 12, 81, "Message",ExpressionUUID->"806e7901-d8e9-452d-822d-ef079ccbf955"],
Cell[380083, 7125, 576, 12, 81, "Message",ExpressionUUID->"548a1121-49e3-4ef6-9aff-6c38839d8462"],
Cell[380662, 7139, 654, 13, 45, "Message",ExpressionUUID->"eb9ae2c7-25f0-4e93-86aa-a7b3688f3978"],
Cell[381319, 7154, 801, 15, 83, "Message",ExpressionUUID->"0ed1e9ec-98db-4074-8519-a22e2c7321c1"],
Cell[382123, 7171, 660, 12, 100, "Output",ExpressionUUID->"68124d06-12b5-486d-9cef-29c886f2e5e3"]
}, Open  ]],
Cell[382798, 7186, 3175, 60, 198, "Input",ExpressionUUID->"9a6cc192-2c7b-488f-9303-f7d1105ff913"],
Cell[385976, 7248, 295, 7, 71, "Text",ExpressionUUID->"cf4bbefd-05fd-4805-ab5b-54b3b75243b5"],
Cell[386274, 7257, 893, 18, 62, "Input",ExpressionUUID->"b4a995b5-edfb-4527-b405-03e66fa08556"]
}, Open  ]]
}, Open  ]]
}
]
*)

